@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -48,14 +48,14 @@ static AtkComponentIface *component_parent_iface;
 static GType parent_type;
 static gint priv_offset;
 static GQuark		quark_accessible_object = 0;
-#define GET_PRIVATE(object) ((GalA11yETableItemPrivate *) (((char *) object) + priv_offset))
+#define GET_PRIVATE(object) ((GalA11yETableItemPrivate *) (((gchar *) object) + priv_offset))
 #define PARENT_TYPE (parent_type)
 
 struct _GalA11yETableItemPrivate {
 	gint cols;
 	gint rows;
-	int selection_change_id;
-	int cursor_change_id;
+	gint selection_change_id;
+	gint cursor_change_id;
 	ETableCol ** columns;
 	ESelectionModel *selection;
 	AtkStateSet *state_set;
@@ -93,7 +93,7 @@ eti_ref_state_set (AtkObject *accessible)
 }
 
 inline static gint
-view_to_model_row(ETableItem *eti, int row)
+view_to_model_row(ETableItem *eti, gint row)
 {
 	if (eti->uses_source_model) {
 		ETableSubset *etss = E_TABLE_SUBSET(eti->table_model);
@@ -107,16 +107,16 @@ view_to_model_row(ETableItem *eti, int row)
 }
 
 inline static gint
-view_to_model_col(ETableItem *eti, int col)
+view_to_model_col(ETableItem *eti, gint col)
 {
 	ETableCol *ecol = e_table_header_get_column (eti->header, col);
 	return ecol ? ecol->col_idx : -1;
 }
 
 inline static gint
-model_to_view_row(ETableItem *eti, int row)
+model_to_view_row(ETableItem *eti, gint row)
 {
-	int i;
+	gint i;
 	if (row == -1)
 		return -1;
 	if (eti->uses_source_model) {
@@ -136,9 +136,9 @@ model_to_view_row(ETableItem *eti, int row)
 }
 
 inline static gint
-model_to_view_col(ETableItem *eti, int col)
+model_to_view_col(ETableItem *eti, gint col)
 {
-	int i;
+	gint i;
 	if (col == -1)
 		return -1;
 	for (i = 0; i < eti->cols; i++) {
@@ -159,7 +159,7 @@ static void
 eti_a11y_reset_focus_object (GalA11yETableItem *a11y, ETableItem *item, gboolean notify)
 {
 	ESelectionModel * esm;
-	int cursor_row, cursor_col, view_row, view_col;
+	gint cursor_row, cursor_col, view_row, view_col;
 	AtkObject *cell, *old_cell;
 
 	esm = item->selection;
@@ -185,7 +185,7 @@ eti_a11y_reset_focus_object (GalA11yETableItem *a11y, ETableItem *item, gboolean
 	cell = eti_ref_at (ATK_TABLE (a11y), view_row, view_col);
 
 	if (cell != NULL) {
-        	g_object_set_data (G_OBJECT (a11y), "gail-focus-object", cell);
+		g_object_set_data (G_OBJECT (a11y), "gail-focus-object", cell);
 		gal_a11y_e_cell_add_state (GAL_A11Y_E_CELL (cell), ATK_STATE_FOCUSED, FALSE);
 	} else
 		g_object_set_data (G_OBJECT (a11y), "gail-focus-object", NULL);
@@ -284,9 +284,9 @@ eti_ref_accessible_at_point (AtkComponent *component,
 			     gint y,
 			     AtkCoordType coord_type)
 {
-	int row = -1;
-	int col = -1;
-	int x_origin, y_origin;
+	gint row = -1;
+	gint col = -1;
+	gint x_origin, y_origin;
 	ETableItem *item;
 	GtkWidget *tableOrTree;
 
@@ -362,7 +362,7 @@ eti_ref_at (AtkTable *table, gint row, gint column)
 							    ATK_OBJECT (table),
 							    ecol->col_idx,
 							    column,
-						   	    row);
+							    row);
 		if (ATK_IS_OBJECT (ret)) {
 			g_object_weak_ref (G_OBJECT (ret),
 					   (GWeakNotify) cell_destroyed,
@@ -446,7 +446,7 @@ eti_get_column_extent_at (AtkTable *table,
 			  gint column)
 {
 	ETableItem *item;
-	int width;
+	gint width;
 
 	item = E_TABLE_ITEM (eti_a11y_get_gobject (ATK_OBJECT (table)));
 	if (!item)
@@ -469,7 +469,7 @@ eti_get_row_extent_at (AtkTable *table,
 		       gint column)
 {
 	ETableItem *item;
-	int height;
+	gint height;
 
 	item = E_TABLE_ITEM (eti_a11y_get_gobject (ATK_OBJECT (table)));
 	if (!item)
@@ -676,7 +676,7 @@ eti_atk_component_iface_init (AtkComponentIface *iface)
 }
 
 static void
-eti_rows_inserted (ETableModel * model, int row, int count,
+eti_rows_inserted (ETableModel * model, gint row, gint count,
 		   AtkObject * table_item)
 {
 	gint n_cols,n_rows,i,j;
@@ -684,7 +684,7 @@ eti_rows_inserted (ETableModel * model, int row, int count,
 	gint old_nrows;
 
 	g_return_if_fail (table_item);
- 	item_a11y = GAL_A11Y_E_TABLE_ITEM (table_item);
+	item_a11y = GAL_A11Y_E_TABLE_ITEM (table_item);
 
         n_cols = atk_table_get_n_columns (ATK_TABLE(table_item));
 	n_rows = atk_table_get_n_rows (ATK_TABLE(table_item));
@@ -711,7 +711,7 @@ eti_rows_inserted (ETableModel * model, int row, int count,
 }
 
 static void
-eti_rows_deleted (ETableModel * model, int row, int count,
+eti_rows_deleted (ETableModel * model, gint row, gint count,
 		  AtkObject * table_item)
 {
 	gint i,j, n_rows, n_cols, old_nrows;
@@ -799,8 +799,8 @@ eti_header_structure_changed (ETableHeader *eth, AtkObject *a11y)
         reorder = g_malloc0 (sizeof (gint) * n_cols);
 
         /* Compare with previously saved column headers. */
-        for ( i = 0 ; i < n_cols && cols[i]; i ++ ) {
-                for ( j = 0 ; j < prev_n_cols && prev_cols[j]; j ++ ) {
+        for ( i = 0; i < n_cols && cols[i]; i ++ ) {
+                for ( j = 0; j < prev_n_cols && prev_cols[j]; j ++ ) {
                         if ( prev_cols [j] == cols[i] && i != j ) {
 
                                 reorder_found = TRUE;
@@ -822,8 +822,8 @@ eti_header_structure_changed (ETableHeader *eth, AtkObject *a11y)
         }
 
         /* Now try to find if there are removed columns. */
-        for (i = 0 ; i < prev_n_cols && prev_cols[i]; i ++) {
-                for (j = 0 ; j < n_cols && cols[j]; j ++)
+        for (i = 0; i < prev_n_cols && prev_cols[i]; i ++) {
+                for (j = 0; j < n_cols && cols[j]; j ++)
                         if ( prev_cols [j] == cols[i] )
 				break;
 
@@ -840,14 +840,14 @@ eti_header_structure_changed (ETableHeader *eth, AtkObject *a11y)
 
 	/* Emit signals */
 	if (reorder_found)
-        	g_signal_emit_by_name (G_OBJECT(a11y_item), "column_reordered");
+		g_signal_emit_by_name (G_OBJECT(a11y_item), "column_reordered");
 
 
 	if (removed_found) {
 		for (i = 0; i < prev_n_cols; i ++ ) {
 			if (prev_state[i] == ETI_HEADER_REMOVED) {
 				g_signal_emit_by_name (G_OBJECT(a11y_item), "column-deleted", i, 1);
-				for (j = 0 ; j < n_rows; j ++)
+				for (j = 0; j < n_rows; j ++)
 					g_signal_emit_by_name (G_OBJECT(a11y_item), "children_changed::remove", ((j+1)*prev_n_cols+i), NULL, NULL);
 			}
 		}
@@ -857,7 +857,7 @@ eti_header_structure_changed (ETableHeader *eth, AtkObject *a11y)
 		for ( i = 0; i < n_cols; i ++ ) {
 			if (state[i] == ETI_HEADER_NEW_ADDED) {
 				g_signal_emit_by_name (G_OBJECT(a11y_item), "column-inserted", i, 1);
-				for (j = 0 ; j < n_rows; j ++)
+				for (j = 0; j < n_rows; j ++)
 					g_signal_emit_by_name (G_OBJECT(a11y_item), "children_changed::add", ((j+1)*n_cols+i), NULL, NULL);
 			}
 		}
@@ -949,7 +949,7 @@ static void eti_a11y_selection_model_added_cb (ETableItem *eti,
 static void eti_a11y_selection_changed_cb (ESelectionModel *selection,
 					   GalA11yETableItem *a11y);
 static void eti_a11y_cursor_changed_cb (ESelectionModel *selection,
-					int row, int col,
+					gint row, gint col,
 					GalA11yETableItem *a11y);
 
 /**
@@ -1021,7 +1021,7 @@ gal_a11y_e_table_item_new (ETableItem *item)
 	AtkObject *accessible;
 	ESelectionModel * esm;
 	AtkObject *parent;
-	const char *name;
+	const gchar *name;
 
 	g_return_val_if_fail (item && item->cols >= 0 && item->rows >= 0, NULL);
 	a11y = g_object_new (gal_a11y_e_table_item_get_type (), NULL);
@@ -1188,7 +1188,7 @@ eti_a11y_selection_changed_cb (ESelectionModel *selection, GalA11yETableItem *a1
 
 static void
 eti_a11y_cursor_changed_cb (ESelectionModel *selection,
-			    int row, int col,  GalA11yETableItem *a11y)
+			    gint row, gint col,  GalA11yETableItem *a11y)
 {
 	ETableItem *item;
 	GalA11yETableItemPrivate *priv = GET_PRIVATE (a11y);
