@@ -12,7 +12,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -29,7 +29,6 @@
 
 #define G_LOG_DOMAIN "eaddrconduit"
 
-#include <bonobo.h>
 #include <libxml/parser.h>
 #include <pi-source.h>
 #include <pi-socket.h>
@@ -96,7 +95,7 @@ static EContactField priority [] = {
 	E_CONTACT_FIELD_LAST
 };
 
-static int priority_label [] = {
+static gint priority_label [] = {
 	LABEL_WORK,
 	LABEL_HOME,
 	LABEL_FAX,
@@ -167,11 +166,11 @@ struct _EAddrConduitCfg {
  *       in UTF-8 format. A conversion must take place before calling
  *       this function (see e_pilot_utf8_to_pchar() in e-pilot-util.c)
  */
-static int
-e_pilot_add_category_if_possible(char *cat_to_add, struct CategoryAppInfo *category)
+static gint
+e_pilot_add_category_if_possible(gchar *cat_to_add, struct CategoryAppInfo *category)
 {
-	int i, j;
-	int retval = 0; /* 0 is the Unfiled category */
+	gint i, j;
+	gint retval = 0; /* 0 is the Unfiled category */
 	LOG(g_message("e_pilot_add_category_if_possible\n"));
 
 	for(i=0; i<PILOT_MAX_CATEGORIES; i++){
@@ -179,14 +178,14 @@ e_pilot_add_category_if_possible(char *cat_to_add, struct CategoryAppInfo *categ
 		   the PalmOS doesn't let 0-length strings for
 		   categories */
 		if(strlen(category->name[i]) == 0){
-			int cat_to_add_len;
-			int desktopUniqueID;
+			gint cat_to_add_len;
+			gint desktopUniqueID;
 
 			cat_to_add_len = strlen(cat_to_add);
 			retval = i;
 
 			if(cat_to_add_len > 15){
-				char tmpstr[16];
+				gchar tmpstr[16];
 				strncpy(tmpstr, cat_to_add,16);
 				tmpstr[16] = '\0';
 				/* Have to truncate the category name */
@@ -214,7 +213,7 @@ e_pilot_add_category_if_possible(char *cat_to_add, struct CategoryAppInfo *categ
 			 * we don't have much use for it at present.
 			 */
 			for (desktopUniqueID = 128; desktopUniqueID <= 255; desktopUniqueID++) {
-				int found = 0;
+				gint found = 0;
 				for(j=0; j<PILOT_MAX_CATEGORIES; j++){
 					if (category->ID[j] == desktopUniqueID) {
 						found = 1;
@@ -252,22 +251,22 @@ e_pilot_add_category_if_possible(char *cat_to_add, struct CategoryAppInfo *categ
  * is set to zero ("Unfiled").
  */
 static
-void e_pilot_local_category_to_remote(int * pilotCategory,
+void e_pilot_local_category_to_remote(gint * pilotCategory,
     EContact *contact, struct CategoryAppInfo *category)
 {
 	GList *c_list = NULL, *l;
-	char * category_string, *first_category = NULL;
-	int i;
+	gchar * category_string, *first_category = NULL;
+	gint i;
 	*pilotCategory = 0; /* default to "Unfiled" */
 	c_list = e_contact_get (contact, E_CONTACT_CATEGORY_LIST);
 	if (c_list) {
 		/* remember the first category */
-		first_category = e_pilot_utf8_to_pchar((const char *)c_list->data);
+		first_category = e_pilot_utf8_to_pchar((const gchar *)c_list->data);
 	}
 	l = c_list;
 	while(l && *pilotCategory == 0) {
 		/* list != 0, so at least 1 category is assigned */
-		category_string = e_pilot_utf8_to_pchar((const char *)l->data);
+		category_string = e_pilot_utf8_to_pchar((const gchar *)l->data);
 		for (i=0; i < PILOT_MAX_CATEGORIES; i++) {
 			/* only 15 chars + nul in palm category name */
 			if (strncmp(category_string,category->name[i], 15) == 0) {
@@ -297,10 +296,10 @@ void e_pilot_local_category_to_remote(int * pilotCategory,
  * conversion from a palm category to an evolution category
  */
 static
-void e_pilot_remote_category_to_local(int pilotCategory,
+void e_pilot_remote_category_to_local(gint pilotCategory,
     EContact *contact, struct CategoryAppInfo *category)
 {
-	char *category_string = NULL;
+	gchar *category_string = NULL;
 
 	if (pilotCategory != 0) {
 		/* pda has category assigned */
@@ -345,17 +344,17 @@ void e_pilot_remote_category_to_local(int pilotCategory,
 	}
 }
 
-static char *
-build_setup_path (const char *path, const char *key)
+static gchar *
+build_setup_path (const gchar *path, const gchar *key)
 {
 	return g_strconcat ("/apps/evolution/conduit", "/", path, "/", key, NULL);
 }
 
 static gboolean
-e_pilot_setup_get_bool (const char *path, const char *key, gboolean def)
+e_pilot_setup_get_bool (const gchar *path, const gchar *key, gboolean def)
 {
 	gboolean res = def;
-	char *full_path;
+	gchar *full_path;
 	GConfValue *value;
 	GConfClient *gconf;
 
@@ -380,10 +379,10 @@ e_pilot_setup_get_bool (const char *path, const char *key, gboolean def)
 }
 
 static void
-e_pilot_setup_set_bool (const char *path, const char *key, gboolean value)
+e_pilot_setup_set_bool (const gchar *path, const gchar *key, gboolean value)
 {
 	GError *error = NULL;
-	char *full_path;
+	gchar *full_path;
 	GConfClient *gconf;
 
 	g_return_if_fail (path != NULL);
@@ -403,11 +402,11 @@ e_pilot_setup_set_bool (const char *path, const char *key, gboolean value)
 	}
 }
 
-static char *
-e_pilot_setup_get_string (const char *path, const char *key, const char *def)
+static gchar *
+e_pilot_setup_get_string (const gchar *path, const gchar *key, const gchar *def)
 {
-	char *res = g_strdup (def);
-	char *full_path;
+	gchar *res = g_strdup (def);
+	gchar *full_path;
 	GConfValue *value;
 	GConfClient *gconf;
 
@@ -434,10 +433,10 @@ e_pilot_setup_get_string (const char *path, const char *key, const char *def)
 }
 
 static void
-e_pilot_setup_set_string (const char *path, const char *key, const char *value)
+e_pilot_setup_set_string (const gchar *path, const gchar *key, const gchar *value)
 {
 	GError *error = NULL;
-	char *full_path;
+	gchar *full_path;
 	GConfClient *gconf;
 
 	g_return_if_fail (path != NULL);
@@ -471,7 +470,7 @@ addrconduit_load_configuration (guint32 pilot_id)
 	g_assert (c != NULL);
 
 	c->pilot_id = pilot_id;
-	management = gnome_pilot_conduit_management_new ("e_address_conduit", GNOME_PILOT_CONDUIT_MGMT_ID);
+	management = gnome_pilot_conduit_management_new ((gchar *)"e_address_conduit", GNOME_PILOT_CONDUIT_MGMT_ID);
 	g_object_ref_sink (management);
 	config = gnome_pilot_conduit_config_new (management, pilot_id);
 	g_object_ref_sink (config);
@@ -578,7 +577,7 @@ e_addr_gui_new (EPilotSettings *ps)
 	EAddrConduitGui *gui;
 	GtkWidget *lbl;
 	gint rows, i;
-	static const char *items[] = {"Business", "Home", "Other", NULL};
+	static const gchar *items[] = {"Business", "Home", "Other", NULL};
 
 	g_return_val_if_fail (ps != NULL, NULL);
 	g_return_val_if_fail (E_IS_PILOT_SETTINGS (ps), NULL);
@@ -603,7 +602,7 @@ e_addr_gui_new (EPilotSettings *ps)
 	return gui;
 }
 
-static const int default_address_map[] = {
+static const gint default_address_map[] = {
 	E_CONTACT_ADDRESS_WORK,
 	E_CONTACT_ADDRESS_HOME,
 	E_CONTACT_ADDRESS_OTHER,
@@ -718,10 +717,10 @@ e_addr_context_destroy (EAddrConduitContext *ctxt)
 }
 
 /* Debug routines */
-static char *
+static const gchar *
 print_local (EAddrLocalRecord *local)
 {
-	static char buff[ 4096 ];
+	static gchar buff[ 4096 ];
 
 	if (local == NULL) {
 		sprintf (buff, "[NULL]");
@@ -742,9 +741,9 @@ print_local (EAddrLocalRecord *local)
 	return "";
 }
 
-static char *print_remote (GnomePilotRecord *remote)
+static gchar *print_remote (GnomePilotRecord *remote)
 {
-	static char buff[ 4096 ];
+	static gchar buff[ 4096 ];
 	struct Address addr;
 #ifdef PILOT_LINK_0_12
 	pi_buffer_t * buffer;
@@ -786,10 +785,10 @@ static char *print_remote (GnomePilotRecord *remote)
 }
 
 /* Utility routines */
-static char *
+static gchar *
 map_name (EAddrConduitContext *ctxt)
 {
-	char *filename = NULL;
+	gchar *filename = NULL;
 
 	filename = g_strdup_printf ("%s/.evolution/addressbook/local/system/pilot-map-%d.xml", g_get_home_dir (), ctxt->cfg->pilot_id);
 
@@ -951,21 +950,21 @@ is_syncable (EAddrConduitContext *ctxt, EAddrLocalRecord *local)
 	EContactField next_mail, next_home, next_work, next_fax;
 	EContactField next_other, next_main, next_pager, next_mobile;
 	gboolean syncable = TRUE;
-	int i, l = 0;
+	gint i, l = 0;
 
 	/* See if there are fields we can't sync or not in priority order */
 	get_next_init (&next_mail, &next_home, &next_work, &next_fax,
 		       &next_other, &next_main, &next_pager, &next_mobile);
 
 	for (i = entryPhone1; i <= entryPhone5 && syncable; i++) {
-		int phonelabel = local->addr->phoneLabel[i - entryPhone1];
-		const char *phone_str = local->addr->entry[i];
+		gint phonelabel = local->addr->phoneLabel[i - entryPhone1];
+		const gchar *phone_str = local->addr->entry[i];
 		gboolean empty = !(phone_str && *phone_str);
 
 		if (empty)
 			continue;
 
-		for ( ; priority_label[l] != -1; l++)
+		for (; priority_label[l] != -1; l++)
 			if (phonelabel == priority_label[l])
 				break;
 
@@ -1029,9 +1028,9 @@ is_syncable (EAddrConduitContext *ctxt, EAddrLocalRecord *local)
 }
 
 static void
-set_contact_text (EContact *contact, EContactField field, struct Address address, int entry)
+set_contact_text (EContact *contact, EContactField field, struct Address address, gint entry)
 {
-	char *text = NULL;
+	gchar *text = NULL;
 
 	if (address.entry[entry])
 		text = e_pilot_utf8_from_pchar (address.entry[entry]);
@@ -1041,8 +1040,8 @@ set_contact_text (EContact *contact, EContactField field, struct Address address
 	g_free (text);
 }
 
-static char *
-get_entry_text (struct Address address, int entry)
+static gchar *
+get_entry_text (struct Address address, gint entry)
 {
 	if (address.entry[entry])
 		return e_pilot_utf8_from_pchar (address.entry[entry]);
@@ -1051,7 +1050,7 @@ get_entry_text (struct Address address, int entry)
 }
 
 static void
-clear_entry_text (struct Address address, int field)
+clear_entry_text (struct Address address, gint field)
 {
 	if (address.entry[field]) {
 		free (address.entry[field]);
@@ -1060,7 +1059,7 @@ clear_entry_text (struct Address address, int field)
 }
 
 static void
-compute_status (EAddrConduitContext *ctxt, EAddrLocalRecord *local, const char *uid)
+compute_status (EAddrConduitContext *ctxt, EAddrLocalRecord *local, const gchar *uid)
 {
 	EBookChange *ebc;
 
@@ -1095,7 +1094,7 @@ local_record_to_pilot_record (EAddrLocalRecord *local,
 #ifdef PILOT_LINK_0_12
 	pi_buffer_t * buffer;
 #else
-	static char record[0xffff];
+	static gchar record[0xffff];
 #endif
 
 	g_assert (local->addr != NULL );
@@ -1127,7 +1126,7 @@ local_record_to_pilot_record (EAddrLocalRecord *local,
 
 	pi_buffer_free(buffer);
 #else
-	p.record = (unsigned char *)record;
+	p.record = (guchar *)record;
 	p.length = pack_Address (local->addr, p.record, 0xffff);
 #endif
 	return p;
@@ -1137,10 +1136,10 @@ static void
 local_record_from_ecard (EAddrLocalRecord *local, EContact *contact, EAddrConduitContext *ctxt)
 {
 	EContactAddress *address = NULL;
-	int phone = entryPhone1;
+	gint phone = entryPhone1;
 	EContactField field;
 	gboolean syncable;
-	int i;
+	gint i;
 
 	g_return_if_fail (local != NULL);
 	g_return_if_fail (contact != NULL);
@@ -1157,7 +1156,7 @@ local_record_from_ecard (EAddrLocalRecord *local, EContact *contact, EAddrCondui
 	 */
 	if (local->local.ID != 0) {
 		struct Address addr;
-		int cat = 0;
+		gint cat = 0;
 #ifdef PILOT_LINK_0_12
 		pi_buffer_t * record;
 		record = pi_buffer_new(DLP_BUF_SIZE);
@@ -1166,7 +1165,7 @@ local_record_from_ecard (EAddrLocalRecord *local, EContact *contact, EAddrCondui
 			return;
 		}
 #else
-		char record[0xffff];
+		gchar record[0xffff];
 #endif
 
 		if (dlp_ReadRecordById (ctxt->dbi->pilot_socket,
@@ -1183,7 +1182,7 @@ local_record_from_ecard (EAddrLocalRecord *local, EContact *contact, EAddrCondui
 #ifdef PILOT_LINK_0_12
 			unpack_Address (&addr, record, address_v1);
 #else
-			unpack_Address (&addr, (unsigned char *)record, 0xffff);
+			unpack_Address (&addr, (guchar *)record, 0xffff);
 #endif
 			for (i = 0; i < 5; i++) {
 				if (addr.entry[entryPhone1 + i])
@@ -1224,7 +1223,7 @@ local_record_from_ecard (EAddrLocalRecord *local, EContact *contact, EAddrCondui
 	}
 
 	if (address) {
-		char *add;
+		gchar *add;
 
 		/* If the address has 2 lines, make sure both get added */
 		if (address->ext != NULL &&
@@ -1258,7 +1257,7 @@ local_record_from_ecard (EAddrLocalRecord *local, EContact *contact, EAddrCondui
 		/* Sync by priority */
 		for (i = 0, phone = entryPhone1;
 		     priority[i] != E_CONTACT_FIELD_LAST && phone <= entryPhone5; i++) {
-			const char *phone_str;
+			const gchar *phone_str;
 
 			phone_str = e_contact_get_const (contact, priority[i]);
 			if (phone_str && *phone_str) {
@@ -1268,7 +1267,7 @@ local_record_from_ecard (EAddrLocalRecord *local, EContact *contact, EAddrCondui
 				phone++;
 			}
 		}
-		for ( ; phone <= entryPhone5; phone++)
+		for (; phone <= entryPhone5; phone++)
 			local->addr->phoneLabel[phone - entryPhone1] = phone - entryPhone1;
 		local->addr->showPhone = 0;
 	} else {
@@ -1281,14 +1280,14 @@ local_record_from_ecard (EAddrLocalRecord *local, EContact *contact, EAddrCondui
 
 		/* Not completely syncable, so do the best we can */
 		for (i = entryPhone1; i <= entryPhone5; i++) {
-			int phonelabel = local->addr->phoneLabel[i - entryPhone1];
-			const char *phone_str = NULL;
+			gint phonelabel = local->addr->phoneLabel[i - entryPhone1];
+			const gchar *phone_str = NULL;
 
 			if (phonelabel == LABEL_EMAIL && !is_next_done (next_mail)) {
 				phone_str = e_contact_get_const (contact, next_mail);
 				next_mail = get_next_mail (&next_mail);
 			} else if (phonelabel == LABEL_HOME && !is_next_done (next_home)) {
-  				phone_str = e_contact_get_const (contact, next_home);
+				phone_str = e_contact_get_const (contact, next_home);
 				next_home = get_next_home (&next_home);
 			} else if (phonelabel == LABEL_WORK && !is_next_done (next_work)) {
 				phone_str = e_contact_get_const (contact, next_work);
@@ -1323,11 +1322,11 @@ local_record_from_ecard (EAddrLocalRecord *local, EContact *contact, EAddrCondui
 
 static void
 local_record_from_uid (EAddrLocalRecord *local,
-		       const char *uid,
+		       const gchar *uid,
 		       EAddrConduitContext *ctxt)
 {
 	EContact *contact = NULL;
-	const char *cuid;
+	const gchar *cuid;
 	GList *l;
 
 	g_assert (local != NULL);
@@ -1362,10 +1361,10 @@ ecard_from_remote_record(EAddrConduitContext *ctxt,
 	EContactName *name;
 	EContactAddress *eaddress;
 	EContactField mailing_address;
-	char *txt, *find, *full_name;
+	gchar *txt, *find, *full_name;
 	EContactField next_mail, next_home, next_work, next_fax;
 	EContactField next_other, next_main, next_pager, next_mobile;
-	int i;
+	gint i;
 #ifdef PILOT_LINK_0_12
 	pi_buffer_t * buffer;
 #endif
@@ -1460,8 +1459,8 @@ ecard_from_remote_record(EAddrConduitContext *ctxt,
 		       &next_other, &next_main, &next_pager, &next_mobile);
 
 	for (i = entryPhone1; i <= entryPhone5; i++) {
-		int phonelabel = address.phoneLabel[i - entryPhone1];
-		char *phonenum = get_entry_text (address, i);
+		gint phonelabel = address.phoneLabel[i - entryPhone1];
+		gchar *phonenum = get_entry_text (address, i);
 
 		if (phonelabel == LABEL_EMAIL && !is_next_done (next_mail)) {
 			e_contact_set (contact, next_mail, phonenum);
@@ -1504,8 +1503,8 @@ static void
 check_for_slow_setting (GnomePilotConduit *c, EAddrConduitContext *ctxt)
 {
 	GnomePilotConduitStandard *conduit = GNOME_PILOT_CONDUIT_STANDARD (c);
-	int map_count;
-	const char *uri;
+	gint map_count;
+	const gchar *uri;
 
 	map_count = g_hash_table_size (ctxt->map->pid_map);
 	if (map_count == 0)
@@ -1532,12 +1531,12 @@ addressbook_authenticate (EBook *book,
 			  gpointer data)
 {
 	gchar *auth;
-	gchar *user;
+	const gchar *user;
 	gchar *passwd;
 	gchar *str_uri;
 	gchar *pass_key;
 	gchar *auth_domain;
-	gchar *component_name;
+	const gchar *component_name;
 	EUri *e_uri;
 
 	ESource *source = (ESource *)data;
@@ -1547,9 +1546,9 @@ addressbook_authenticate (EBook *book,
 	component_name = auth_domain ? auth_domain : "Addressbook";
 
 	if (auth && !strcmp ("plain/password", auth))
-		user = (gchar *)e_source_get_property (source, "user");
+		user = e_source_get_property (source, "user");
 	else
-		user = (gchar *)e_source_get_property (source, "email_addr");
+		user = e_source_get_property (source, "email_addr");
 	if (!user)
 		user = "";
 
@@ -1559,14 +1558,15 @@ addressbook_authenticate (EBook *book,
 	e_uri_free (e_uri);
 
 	passwd = e_passwords_get_password (component_name, pass_key);
-	if (passwd)
-		passwd = "";
+	if (!passwd)
+		passwd = g_strdup ("");
 
 	if (book)
 		if (!e_book_authenticate_user (book, user, passwd, auth, NULL))
 			LOG (g_warning ("Authentication failed"));
 	g_free (pass_key);
 	g_free (str_uri);
+	g_free (passwd);
 
 	return;
 }
@@ -1579,16 +1579,16 @@ pre_sync (GnomePilotConduit *conduit,
 {
 	GnomePilotConduitSyncAbs *abs_conduit;
 	EBookQuery *query;
-    	GList *l;
-	int len;
-	char *filename;
-	char *change_id;
-	char *auth;
+	GList *l;
+	gint len;
+	gchar *filename;
+	gchar *change_id;
+	gchar *auth;
 	gint num_records, add_records = 0, mod_records = 0, del_records = 0;
 #ifdef PILOT_LINK_0_12
 	pi_buffer_t *buffer;
 #else
-	unsigned char *buf;
+	guchar *buf;
 #endif
 
 	abs_conduit = GNOME_PILOT_CONDUIT_SYNC_ABS (conduit);
@@ -1645,7 +1645,7 @@ pre_sync (GnomePilotConduit *conduit,
 
 	for (l = ctxt->changed; l != NULL; l = l->next) {
 		EBookChange *ebc = l->data;
-		const char *uid;
+		const gchar *uid;
 
 		uid = e_contact_get_const (ebc->contact, E_CONTACT_UID);
 		if (!e_pilot_map_uid_is_archived (ctxt->map, uid)) {
@@ -1669,11 +1669,11 @@ pre_sync (GnomePilotConduit *conduit,
 	}
 
 	/* Set the count information */
-  	num_records = g_list_length (ctxt->cards);
-  	gnome_pilot_conduit_sync_abs_set_num_local_records(abs_conduit, num_records);
-  	gnome_pilot_conduit_sync_abs_set_num_new_local_records (abs_conduit, add_records);
-  	gnome_pilot_conduit_sync_abs_set_num_updated_local_records (abs_conduit, mod_records);
-  	gnome_pilot_conduit_sync_abs_set_num_deleted_local_records(abs_conduit, del_records);
+	num_records = g_list_length (ctxt->cards);
+	gnome_pilot_conduit_sync_abs_set_num_local_records(abs_conduit, num_records);
+	gnome_pilot_conduit_sync_abs_set_num_new_local_records (abs_conduit, add_records);
+	gnome_pilot_conduit_sync_abs_set_num_updated_local_records (abs_conduit, mod_records);
+	gnome_pilot_conduit_sync_abs_set_num_deleted_local_records(abs_conduit, del_records);
 
 #ifdef PILOT_LINK_0_12
 	buffer = pi_buffer_new(DLP_BUF_SIZE);
@@ -1684,9 +1684,9 @@ pre_sync (GnomePilotConduit *conduit,
 	len = dlp_ReadAppBlock (dbi->pilot_socket, dbi->db_handle, 0,
 			      DLP_BUF_SIZE, buffer);
 #else
-	buf = (unsigned char*)g_malloc (0xffff);
+	buf = (guchar *)g_malloc (0xffff);
 	len = dlp_ReadAppBlock (dbi->pilot_socket, dbi->db_handle, 0,
-			      (unsigned char *)buf, 0xffff);
+			      (guchar *)buf, 0xffff);
 #endif
 	if (len < 0) {
 		WARN (_("Could not read pilot's Address application block"));
@@ -1702,7 +1702,7 @@ pre_sync (GnomePilotConduit *conduit,
 	unpack_AddressAppInfo (&(ctxt->ai), buf, len);
 	g_free (buf);
 #endif
-  	check_for_slow_setting (conduit, ctxt);
+	check_for_slow_setting (conduit, ctxt);
 	if (ctxt->cfg->sync_type == GnomePilotConduitSyncTypeCopyToPilot
 	    || ctxt->cfg->sync_type == GnomePilotConduitSyncTypeCopyFromPilot)
 		ctxt->map->write_touched_only = TRUE;
@@ -1717,18 +1717,18 @@ post_sync (GnomePilotConduit *conduit,
 {
 	GList *changed;
 	gchar *filename, *change_id;
-	unsigned char *buf;
-	int dlpRetVal, len;
+	guchar *buf;
+	gint dlpRetVal, len;
 
 	LOG (g_message ( "post_sync: Address Conduit v.%s", CONDUIT_VERSION ));
 
 	/* Write AppBlock to PDA - updates categories */
-	buf = (unsigned char*)g_malloc (0xffff);
+	buf = (guchar *)g_malloc (0xffff);
 
 	len = pack_AddressAppInfo (&(ctxt->ai), buf, 0xffff);
 
 	dlpRetVal = dlp_WriteAppBlock (dbi->pilot_socket, dbi->db_handle,
-			      (unsigned char *)buf, len);
+			      (guchar *)buf, len);
 
 	g_free (buf);
 
@@ -1779,7 +1779,7 @@ set_status_cleared (GnomePilotConduitSyncAbs *conduit,
 		    EAddrLocalRecord *local,
 		    EAddrConduitContext *ctxt)
 {
-	const char *uid;
+	const gchar *uid;
 
 	LOG (g_message ( "set_status_cleared: clearing status\n" ));
 
@@ -1794,10 +1794,10 @@ for_each (GnomePilotConduitSyncAbs *conduit,
 	  EAddrLocalRecord **local,
 	  EAddrConduitContext *ctxt)
 {
-  	static GList *cards, *iterator;
-  	static int count;
+	static GList *cards, *iterator;
+	static gint count;
 
-  	g_return_val_if_fail (local != NULL, -1);
+	g_return_val_if_fail (local != NULL, -1);
 
 	if (*local == NULL) {
 		LOG (g_message ( "beginning for_each" ));
@@ -1809,7 +1809,7 @@ for_each (GnomePilotConduitSyncAbs *conduit,
 			LOG (g_message ( "iterating over %d records", g_list_length (cards) ));
 
 			*local = g_new0 (EAddrLocalRecord, 1);
-  			local_record_from_ecard (*local, cards->data, ctxt);
+			local_record_from_ecard (*local, cards->data, ctxt);
 			ctxt->locals = g_list_prepend (ctxt->locals, *local);
 
 			iterator = cards;
@@ -1829,7 +1829,7 @@ for_each (GnomePilotConduitSyncAbs *conduit,
 		} else {
 			LOG (g_message ( "for_each ending" ));
 
-  			/* Tell the pilot the iteration is over */
+			/* Tell the pilot the iteration is over */
 			*local = NULL;
 
 			return 0;
@@ -1845,7 +1845,7 @@ for_each_modified (GnomePilotConduitSyncAbs *conduit,
 		   EAddrConduitContext *ctxt)
 {
 	static GList *iterator;
-	static int count;
+	static gint count;
 
 	g_return_val_if_fail (local != NULL, 0);
 
@@ -1882,7 +1882,7 @@ for_each_modified (GnomePilotConduitSyncAbs *conduit,
 		} else {
 			LOG (g_message ( "for_each_modified ending" ));
 
-    			/* Signal the iteration is over */
+			/* Signal the iteration is over */
 			*local = NULL;
 
 			return 0;
@@ -1899,7 +1899,7 @@ compare (GnomePilotConduitSyncAbs *conduit,
 	 EAddrConduitContext *ctxt)
 {
 	GnomePilotRecord local_pilot;
-	int retval = 0;
+	gint retval = 0;
 
 	LOG (g_message ("compare: local=%s remote=%s...\n",
 			print_local (local), print_remote (remote)));
@@ -1927,7 +1927,7 @@ add_record (GnomePilotConduitSyncAbs *conduit,
 	    EAddrConduitContext *ctxt)
 {
 	EContact *contact;
-	int retval = 0;
+	gint retval = 0;
 
 	g_return_val_if_fail (remote != NULL, -1);
 
@@ -1958,8 +1958,8 @@ replace_record (GnomePilotConduitSyncAbs *conduit,
 {
 	EContact *new_contact;
 	EBookChange *ebc;
-	char *old_id;
-	int retval = 0;
+	gchar *old_id;
+	gint retval = 0;
 
 	g_return_val_if_fail (remote != NULL, -1);
 
@@ -1990,7 +1990,7 @@ replace_record (GnomePilotConduitSyncAbs *conduit,
 
 	/* Adding a record causes wombat to assign a new uid so we must tidy */
 	if (ebc && ebc->change_type == E_BOOK_CHANGE_CARD_DELETED) {
-		const char *uid = e_contact_get_const (local->contact, E_CONTACT_UID);
+		const gchar *uid = e_contact_get_const (local->contact, E_CONTACT_UID);
 		gboolean arch;
 
 		arch = e_pilot_map_uid_is_archived (ctxt->map, uid);
@@ -2016,7 +2016,7 @@ delete_record (GnomePilotConduitSyncAbs *conduit,
 	       EAddrConduitContext *ctxt)
 {
 	GError *error = NULL;
-	int retval = 0;
+	gint retval = 0;
 
 	g_return_val_if_fail (local != NULL, -1);
 	g_return_val_if_fail (local->contact != NULL, -1);
@@ -2040,7 +2040,7 @@ archive_record (GnomePilotConduitSyncAbs *conduit,
 		gboolean archive,
 		EAddrConduitContext *ctxt)
 {
-	int retval = 0;
+	gint retval = 0;
 
 	g_return_val_if_fail (local != NULL, -1);
 
@@ -2057,7 +2057,7 @@ match (GnomePilotConduitSyncAbs *conduit,
        EAddrLocalRecord **local,
        EAddrConduitContext *ctxt)
 {
-  	const char *uid;
+	const gchar *uid;
 
 	LOG (g_message ("match: looking for local copy of %s\n",
 	     print_remote (remote)));
@@ -2183,7 +2183,7 @@ conduit_get_gpilot_conduit (guint32 pilot_id)
 
 	LOG (g_message ( "in address's conduit_get_gpilot_conduit\n" ));
 
-	retval = gnome_pilot_conduit_sync_abs_new ("AddressDB", 0x61646472);
+	retval = gnome_pilot_conduit_sync_abs_new ((gchar *)"AddressDB", 0x61646472);
 	g_assert (retval != NULL);
 
 	ctxt = e_addr_context_new (pilot_id);
@@ -2192,22 +2192,22 @@ conduit_get_gpilot_conduit (guint32 pilot_id)
 	g_signal_connect (retval, "pre_sync", G_CALLBACK (pre_sync), ctxt);
 	g_signal_connect (retval, "post_sync", G_CALLBACK (post_sync), ctxt);
 
-  	g_signal_connect (retval, "set_pilot_id", G_CALLBACK (set_pilot_id), ctxt);
-  	g_signal_connect (retval, "set_status_cleared", G_CALLBACK (set_status_cleared), ctxt);
+	g_signal_connect (retval, "set_pilot_id", G_CALLBACK (set_pilot_id), ctxt);
+	g_signal_connect (retval, "set_status_cleared", G_CALLBACK (set_status_cleared), ctxt);
 
-  	g_signal_connect (retval, "for_each", G_CALLBACK (for_each), ctxt);
-  	g_signal_connect (retval, "for_each_modified", G_CALLBACK (for_each_modified), ctxt);
-  	g_signal_connect (retval, "compare", G_CALLBACK (compare), ctxt);
+	g_signal_connect (retval, "for_each", G_CALLBACK (for_each), ctxt);
+	g_signal_connect (retval, "for_each_modified", G_CALLBACK (for_each_modified), ctxt);
+	g_signal_connect (retval, "compare", G_CALLBACK (compare), ctxt);
 
-  	g_signal_connect (retval, "add_record", G_CALLBACK (add_record), ctxt);
-  	g_signal_connect (retval, "replace_record", G_CALLBACK (replace_record), ctxt);
-  	g_signal_connect (retval, "delete_record", G_CALLBACK (delete_record), ctxt);
-  	g_signal_connect (retval, "archive_record", G_CALLBACK (archive_record), ctxt);
+	g_signal_connect (retval, "add_record", G_CALLBACK (add_record), ctxt);
+	g_signal_connect (retval, "replace_record", G_CALLBACK (replace_record), ctxt);
+	g_signal_connect (retval, "delete_record", G_CALLBACK (delete_record), ctxt);
+	g_signal_connect (retval, "archive_record", G_CALLBACK (archive_record), ctxt);
 
-  	g_signal_connect (retval, "match", G_CALLBACK (match), ctxt);
-  	g_signal_connect (retval, "free_match", G_CALLBACK (free_match), ctxt);
+	g_signal_connect (retval, "match", G_CALLBACK (match), ctxt);
+	g_signal_connect (retval, "free_match", G_CALLBACK (free_match), ctxt);
 
-  	g_signal_connect (retval, "prepare", G_CALLBACK (prepare), ctxt);
+	g_signal_connect (retval, "prepare", G_CALLBACK (prepare), ctxt);
 
 	/* Gui Settings */
 	g_signal_connect (retval, "create_settings_window", G_CALLBACK (create_settings_window), ctxt);
