@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -83,7 +83,7 @@ struct _AddressbookViewPrivate {
 	EBook *book;
 	guint activity_id;
 	ESourceList *source_list;
-	char *passwd;
+	gchar *passwd;
 	EUserCreatableItemsHandler *creatable_items_handler;
 
 	EABMenu *menu;
@@ -96,12 +96,12 @@ enum DndTargetType {
 #define VCARD_TYPE        "text/x-vcard"
 #define SOURCE_VCARD_TYPE "text/x-source-vcard"
 static GtkTargetEntry drag_types[] = {
-	{ SOURCE_VCARD_TYPE, 0, DND_TARGET_TYPE_SOURCE_VCARD_LIST },
-	{ VCARD_TYPE, 0, DND_TARGET_TYPE_VCARD_LIST }
+	{ (gchar *) SOURCE_VCARD_TYPE, 0, DND_TARGET_TYPE_SOURCE_VCARD_LIST },
+	{ (gchar *) VCARD_TYPE, 0, DND_TARGET_TYPE_VCARD_LIST }
 };
 static gint num_drag_types = sizeof(drag_types) / sizeof(drag_types[0]);
 
-static void set_status_message (EABView *eav, const char *message, AddressbookView *view);
+static void set_status_message (EABView *eav, const gchar *message, AddressbookView *view);
 static void search_result (EABView *eav, EBookViewStatus status, AddressbookView *view);
 
 static void activate_source (AddressbookView *view, ESource *source);
@@ -115,7 +115,7 @@ static ESource *get_primary_source (AddressbookView *view);
 
 typedef struct {
 	GtkWidget *editor;
-	char *uid;
+	gchar *uid;
 	AddressbookView *view;
 } EditorUidClosure;
 
@@ -139,7 +139,7 @@ get_current_view (AddressbookView *view)
 }
 
 static void
-save_all_contacts_cb (BonoboUIComponent *uih, void *user_data, const char *path)
+save_all_contacts_cb (BonoboUIComponent *uih, gpointer user_data, const gchar *path)
 {
 	AddressbookView *view = (AddressbookView *) user_data;
 	EABView *v = get_current_view (view);
@@ -149,7 +149,7 @@ save_all_contacts_cb (BonoboUIComponent *uih, void *user_data, const char *path)
 }
 
 static void
-save_contact_cb (BonoboUIComponent *uih, void *user_data, const char *path)
+save_contact_cb (BonoboUIComponent *uih, gpointer user_data, const gchar *path)
 {
 	AddressbookView *view = (AddressbookView *) user_data;
 	EABView *v = get_current_view (view);
@@ -158,7 +158,7 @@ save_contact_cb (BonoboUIComponent *uih, void *user_data, const char *path)
 }
 
 static void
-view_contact_cb (BonoboUIComponent *uih, void *user_data, const char *path)
+view_contact_cb (BonoboUIComponent *uih, gpointer user_data, const gchar *path)
 {
 	AddressbookView *view = (AddressbookView *) user_data;
 	EABView *v = get_current_view (view);
@@ -167,7 +167,7 @@ view_contact_cb (BonoboUIComponent *uih, void *user_data, const char *path)
 }
 
 static void
-delete_contact_cb (BonoboUIComponent *uih, void *user_data, const char *path)
+delete_contact_cb (BonoboUIComponent *uih, gpointer user_data, const gchar *path)
 {
 	AddressbookView *view = (AddressbookView *) user_data;
 	EABView *v = get_current_view (view);
@@ -176,7 +176,7 @@ delete_contact_cb (BonoboUIComponent *uih, void *user_data, const char *path)
 }
 
 static void
-print_cb (BonoboUIComponent *uih, void *user_data, const char *path)
+print_cb (BonoboUIComponent *uih, gpointer user_data, const gchar *path)
 {
 	AddressbookView *view = (AddressbookView *) user_data;
 	EABView *v = get_current_view (view);
@@ -185,7 +185,7 @@ print_cb (BonoboUIComponent *uih, void *user_data, const char *path)
 }
 
 static void
-print_preview_cb (BonoboUIComponent *uih, void *user_data, const char *path)
+print_preview_cb (BonoboUIComponent *uih, gpointer user_data, const gchar *path)
 {
 	AddressbookView *view = (AddressbookView *) user_data;
 	EABView *v = get_current_view (view);
@@ -194,7 +194,7 @@ print_preview_cb (BonoboUIComponent *uih, void *user_data, const char *path)
 }
 
 static void
-stop_loading_cb (BonoboUIComponent *uih, void *user_data, const char *path)
+stop_loading_cb (BonoboUIComponent *uih, gpointer user_data, const gchar *path)
 {
 	AddressbookView *view = (AddressbookView *) user_data;
 	EABView *v = get_current_view (view);
@@ -203,7 +203,7 @@ stop_loading_cb (BonoboUIComponent *uih, void *user_data, const char *path)
 }
 
 static void
-cut_contacts_cb (BonoboUIComponent *uih, void *user_data, const char *path)
+cut_contacts_cb (BonoboUIComponent *uih, gpointer user_data, const gchar *path)
 {
 	AddressbookView *view = (AddressbookView *) user_data;
 	EABView *v = get_current_view (view);
@@ -212,7 +212,7 @@ cut_contacts_cb (BonoboUIComponent *uih, void *user_data, const char *path)
 }
 
 static void
-copy_contacts_cb (BonoboUIComponent *uih, void *user_data, const char *path)
+copy_contacts_cb (BonoboUIComponent *uih, gpointer user_data, const gchar *path)
 {
 	AddressbookView *view = (AddressbookView *) user_data;
 	EABView *v = get_current_view (view);
@@ -221,7 +221,7 @@ copy_contacts_cb (BonoboUIComponent *uih, void *user_data, const char *path)
 }
 
 static void
-paste_contacts_cb (BonoboUIComponent *uih, void *user_data, const char *path)
+paste_contacts_cb (BonoboUIComponent *uih, gpointer user_data, const gchar *path)
 {
 	AddressbookView *view = (AddressbookView *) user_data;
 	EABView *v = get_current_view (view);
@@ -230,7 +230,7 @@ paste_contacts_cb (BonoboUIComponent *uih, void *user_data, const char *path)
 }
 
 static void
-select_all_contacts_cb (BonoboUIComponent *uih, void *user_data, const char *path)
+select_all_contacts_cb (BonoboUIComponent *uih, gpointer user_data, const gchar *path)
 {
 	AddressbookView *view = (AddressbookView *) user_data;
 	EABView *v = get_current_view (view);
@@ -239,7 +239,7 @@ select_all_contacts_cb (BonoboUIComponent *uih, void *user_data, const char *pat
 }
 
 static void
-send_contact_cb (BonoboUIComponent *uih, void *user_data, const char *path)
+send_contact_cb (BonoboUIComponent *uih, gpointer user_data, const gchar *path)
 {
 	AddressbookView *view = (AddressbookView *) user_data;
 	EABView *v = get_current_view (view);
@@ -248,7 +248,7 @@ send_contact_cb (BonoboUIComponent *uih, void *user_data, const char *path)
 }
 
 static void
-send_contact_to_cb (BonoboUIComponent *uih, void *user_data, const char *path)
+send_contact_to_cb (BonoboUIComponent *uih, gpointer user_data, const gchar *path)
 {
 	AddressbookView *view = (AddressbookView *) user_data;
 	EABView *v = get_current_view (view);
@@ -257,17 +257,17 @@ send_contact_to_cb (BonoboUIComponent *uih, void *user_data, const char *path)
 }
 
 static void
-copy_all_contacts_to_cb (BonoboUIComponent *uih, void *user_data, const char *path)
+copy_all_contacts_to_cb (BonoboUIComponent *uih, gpointer user_data, const gchar *path)
 {
 	AddressbookView *view = (AddressbookView *) user_data;
 	EABView *v = get_current_view (view);
 
-       	if (v)
+	if (v)
 		eab_view_copy_to_folder (v, TRUE);
 }
 
 static void
-copy_contact_to_cb (BonoboUIComponent *uih, void *user_data, const char *path)
+copy_contact_to_cb (BonoboUIComponent *uih, gpointer user_data, const gchar *path)
 {
 	AddressbookView *view = (AddressbookView *) user_data;
 	EABView *v = get_current_view (view);
@@ -276,7 +276,7 @@ copy_contact_to_cb (BonoboUIComponent *uih, void *user_data, const char *path)
 }
 
 static void
-move_all_contacts_to_cb (BonoboUIComponent *uih, void *user_data, const char *path)
+move_all_contacts_to_cb (BonoboUIComponent *uih, gpointer user_data, const gchar *path)
 {
 	AddressbookView *view = (AddressbookView *) user_data;
 	EABView *v = get_current_view (view);
@@ -285,7 +285,7 @@ move_all_contacts_to_cb (BonoboUIComponent *uih, void *user_data, const char *pa
 }
 
 static void
-move_contact_to_cb (BonoboUIComponent *uih, void *user_data, const char *path)
+move_contact_to_cb (BonoboUIComponent *uih, gpointer user_data, const gchar *path)
 {
 	AddressbookView *view = (AddressbookView *) user_data;
 	EABView *v = get_current_view (view);
@@ -294,7 +294,7 @@ move_contact_to_cb (BonoboUIComponent *uih, void *user_data, const char *path)
 }
 
 static void
-forget_passwords_cb (BonoboUIComponent *uih, void *user_data, const char *path)
+forget_passwords_cb (BonoboUIComponent *uih, gpointer user_data, const gchar *path)
 {
 	e_passwords_forget_passwords();
 }
@@ -307,7 +307,7 @@ new_addressbook_folder (AddressbookView *view)
 }
 
 static void
-new_folder_cb (BonoboUIComponent *uih, void *user_data, const char *path)
+new_folder_cb (BonoboUIComponent *uih, gpointer user_data, const gchar *path)
 {
 	AddressbookView *view = (AddressbookView *) user_data;
 	new_addressbook_folder (view);
@@ -356,7 +356,7 @@ delete_addressbook_folder (AddressbookView *view)
 }
 
 static void
-delete_folder_cb (BonoboUIComponent *uih, void *user_data, const char *path)
+delete_folder_cb (BonoboUIComponent *uih, gpointer user_data, const gchar *path)
 {
 	AddressbookView *view = (AddressbookView *) user_data;
 	if (view)
@@ -369,7 +369,7 @@ edit_addressbook_folder (AddressbookView *view)
 {
 	AddressbookViewPrivate *priv = view->priv;
 	ESource *selected_source;
-	const char *uid;
+	const gchar *uid;
 	EditorUidClosure *closure;
 
 	selected_source = e_source_selector_peek_primary_selection (E_SOURCE_SELECTOR (priv->selector));
@@ -380,7 +380,7 @@ edit_addressbook_folder (AddressbookView *view)
 
 	closure = g_hash_table_lookup (priv->uid_to_editor, uid);
 	if (!closure) {
-		char *uid_copy = g_strdup (uid);
+		gchar *uid_copy = g_strdup (uid);
 
 		closure = g_new (EditorUidClosure, 1);
 		closure->editor = addressbook_config_edit_source (gtk_widget_get_toplevel(priv->notebook), selected_source);
@@ -400,7 +400,7 @@ edit_addressbook_folder (AddressbookView *view)
 }
 
 static void
-edit_folder_cb (BonoboUIComponent *uih, void *user_data, const char *path)
+edit_folder_cb (BonoboUIComponent *uih, gpointer user_data, const gchar *path)
 {
 	AddressbookView *view = (AddressbookView *) user_data;
 	if (view)
@@ -413,13 +413,13 @@ rename_addressbook_folder (AddressbookView *view)
 {
 	AddressbookViewPrivate *priv = view->priv;
 	ESource *source;
-	const char *old_name;
-	char *prompt, *new_name;
+	const gchar *old_name;
+	gchar *prompt, *new_name;
 	gboolean done = FALSE;
 
 	source = e_source_selector_peek_primary_selection (E_SOURCE_SELECTOR (priv->selector));
 	old_name = e_source_peek_name(source);
-     	prompt = g_strdup_printf (_("Rename the \"%s\" folder to:"), old_name);
+	prompt = g_strdup_printf (_("Rename the \"%s\" folder to:"), old_name);
 
 	while (!done) {
 		new_name = e_request_string (NULL, _("Rename Folder"), prompt, old_name);
@@ -441,7 +441,7 @@ rename_addressbook_folder (AddressbookView *view)
 }
 
 static void
-rename_folder_cb (BonoboUIComponent *uih, void *user_data, const char *path)
+rename_folder_cb (BonoboUIComponent *uih, gpointer user_data, const gchar *path)
 {
 	AddressbookView *view = (AddressbookView *) user_data;
 	if (view)
@@ -452,8 +452,8 @@ static gboolean
 folder_can_delete (AddressbookView *view)
 {
 	AddressbookViewPrivate *priv = view->priv;
-	ESource *source ;
-	const char *source_uri;
+	ESource *source;
+	const gchar *source_uri;
 
 	source = e_source_selector_peek_primary_selection (E_SOURCE_SELECTOR (priv->selector));
 	if(source) {
@@ -468,7 +468,7 @@ folder_can_delete (AddressbookView *view)
 }
 
 static void
-set_status_message (EABView *eav, const char *message, AddressbookView *view)
+set_status_message (EABView *eav, const gchar *message, AddressbookView *view)
 {
 	AddressbookViewPrivate *priv = view->priv;
 	EActivityHandler *activity_handler = priv->activity_handler;
@@ -479,7 +479,7 @@ set_status_message (EABView *eav, const char *message, AddressbookView *view)
 			priv->activity_id = 0;
 		}
 	} else if (priv->activity_id == 0) {
-		char *clientid = g_strdup_printf ("%p", view);
+		gchar *clientid = g_strdup_printf ("%p", (gpointer) view);
 
 		priv->activity_id = e_activity_handler_operation_started (
 			activity_handler, clientid, message, TRUE);
@@ -492,7 +492,7 @@ set_status_message (EABView *eav, const char *message, AddressbookView *view)
 }
 
 static void
-set_folder_bar_message (EABView *eav, const char *message, AddressbookView *view)
+set_folder_bar_message (EABView *eav, const gchar *message, AddressbookView *view)
 {
 	AddressbookViewPrivate *priv = view->priv;
 	EABView *current_view = get_current_view (view);
@@ -501,7 +501,7 @@ set_folder_bar_message (EABView *eav, const char *message, AddressbookView *view
 		ESource *source = eav->source;
 
 		if (source) {
-			const char *name = e_source_peek_name (source);
+			const gchar *name = e_source_peek_name (source);
 
 			e_info_label_set_info((EInfoLabel*)priv->info_widget, name, message);
 		}
@@ -599,23 +599,23 @@ static BonoboUIVerb verbs [] = {
 };
 
 static EPixmap pixmaps [] = {
-	E_PIXMAP ("/commands/ChangeFolderProperties", "document-properties", E_ICON_SIZE_MENU),
-	E_PIXMAP ("/commands/ContactDelete", "edit-delete", E_ICON_SIZE_MENU),
-	E_PIXMAP ("/commands/ContactsCopy", "edit-copy", E_ICON_SIZE_MENU),
-	E_PIXMAP ("/commands/ContactsCut", "edit-cut", E_ICON_SIZE_MENU),
-	E_PIXMAP ("/commands/ContactsPaste", "edit-paste", E_ICON_SIZE_MENU),
-	E_PIXMAP ("/commands/ContactsPrint", "document-print", E_ICON_SIZE_MENU),
-	E_PIXMAP ("/commands/ContactsPrintPreview", "document-print-preview", E_ICON_SIZE_MENU),
-	E_PIXMAP ("/commands/ContactsSaveAsVCard", "document-save-as", E_ICON_SIZE_MENU),
-	E_PIXMAP ("/commands/ContactsSendContactToOther", "mail-forward", E_ICON_SIZE_MENU),
-	E_PIXMAP ("/commands/ContactsSendMessageToContact", "mail-message-new", E_ICON_SIZE_MENU),
-	E_PIXMAP ("/commands/FolderCopy", "edit-copy", E_ICON_SIZE_MENU),
-	E_PIXMAP ("/commands/FolderDelete", "edit-delete", E_ICON_SIZE_MENU),
-	E_PIXMAP ("/commands/FolderMove", "folder-move", E_ICON_SIZE_MENU),
-	E_PIXMAP ("/commands/FolderSave", "document-save-as", E_ICON_SIZE_MENU),
+	E_PIXMAP ("/commands/ChangeFolderProperties", "document-properties", GTK_ICON_SIZE_MENU),
+	E_PIXMAP ("/commands/ContactDelete", "edit-delete", GTK_ICON_SIZE_MENU),
+	E_PIXMAP ("/commands/ContactsCopy", "edit-copy", GTK_ICON_SIZE_MENU),
+	E_PIXMAP ("/commands/ContactsCut", "edit-cut", GTK_ICON_SIZE_MENU),
+	E_PIXMAP ("/commands/ContactsPaste", "edit-paste", GTK_ICON_SIZE_MENU),
+	E_PIXMAP ("/commands/ContactsPrint", "document-print", GTK_ICON_SIZE_MENU),
+	E_PIXMAP ("/commands/ContactsPrintPreview", "document-print-preview", GTK_ICON_SIZE_MENU),
+	E_PIXMAP ("/commands/ContactsSaveAsVCard", "document-save-as", GTK_ICON_SIZE_MENU),
+	E_PIXMAP ("/commands/ContactsSendContactToOther", "mail-forward", GTK_ICON_SIZE_MENU),
+	E_PIXMAP ("/commands/ContactsSendMessageToContact", "mail-message-new", GTK_ICON_SIZE_MENU),
+	E_PIXMAP ("/commands/FolderCopy", "edit-copy", GTK_ICON_SIZE_MENU),
+	E_PIXMAP ("/commands/FolderDelete", "edit-delete", GTK_ICON_SIZE_MENU),
+	E_PIXMAP ("/commands/FolderMove", "folder-move", GTK_ICON_SIZE_MENU),
+	E_PIXMAP ("/commands/FolderSave", "document-save-as", GTK_ICON_SIZE_MENU),
 
-	E_PIXMAP ("/Toolbar/ContactsPrint", "document-print", E_ICON_SIZE_LARGE_TOOLBAR),
-	E_PIXMAP ("/Toolbar/ContactDelete", "edit-delete", E_ICON_SIZE_LARGE_TOOLBAR),
+	E_PIXMAP ("/Toolbar/ContactsPrint", "document-print", GTK_ICON_SIZE_LARGE_TOOLBAR),
+	E_PIXMAP ("/Toolbar/ContactDelete", "edit-delete", GTK_ICON_SIZE_LARGE_TOOLBAR),
 
 	E_PIXMAP_END
 };
@@ -628,7 +628,7 @@ control_activate (BonoboControl     *control,
 	AddressbookViewPrivate *priv = view->priv;
 	Bonobo_UIContainer remote_ui_container;
 	EABView *v = get_current_view (view);
-	char *xmlfile;
+	gchar *xmlfile;
 
 	remote_ui_container = bonobo_control_get_remote_ui_container (control, NULL);
 	bonobo_ui_component_set_container (uic, remote_ui_container, NULL);
@@ -684,7 +684,7 @@ control_activate_cb (BonoboControl *control,
 }
 
 static void
-gather_uids_foreach (char *key,
+gather_uids_foreach (gchar *key,
 		     gpointer value,
 		     GList **list)
 {
@@ -701,7 +701,7 @@ source_list_changed_cb (ESourceList *source_list, AddressbookView *view)
 	uids = NULL;
 	g_hash_table_foreach (priv->uid_to_view, (GHFunc)gather_uids_foreach, &uids);
 	for (l = uids; l; l = l->next) {
-		char *uid = l->data;
+		gchar *uid = l->data;
 		if (e_source_list_peek_source_by_uid (source_list, uid)) {
 			/* the source still exists, do nothing */
 		}
@@ -721,7 +721,7 @@ source_list_changed_cb (ESourceList *source_list, AddressbookView *view)
 	uids = NULL;
 	g_hash_table_foreach (priv->uid_to_editor, (GHFunc)gather_uids_foreach, &uids);
 	for (l = uids; l; l = l->next) {
-		char *uid = l->data;
+		gchar *uid = l->data;
 		if (e_source_list_peek_source_by_uid (source_list, uid)) {
 			/* the source still exists, do nothing */
 		}
@@ -801,7 +801,7 @@ get_primary_source (AddressbookView *view)
 {
 	AddressbookViewPrivate *priv = view->priv;
 	ESource *source;
-	char *uid;
+	gchar *uid;
 
 	uid = gconf_client_get_string (priv->gconf_client,
 				       "/apps/evolution/addressbook/display/primary_addressbook",
@@ -867,7 +867,7 @@ book_removed (EBook *book, EBookStatus status, gpointer data)
 }
 
 static void
-delete_addressbook_cb(EPopup *ep, EPopupItem *pitem, void *data)
+delete_addressbook_cb(EPopup *ep, EPopupItem *pitem, gpointer data)
 {
 	AddressbookView *view = data;
 	AddressbookViewPrivate *priv = view->priv;
@@ -903,13 +903,13 @@ delete_addressbook_cb(EPopup *ep, EPopupItem *pitem, void *data)
 }
 
 static void
-new_addressbook_cb(EPopup *ep, EPopupItem *pitem, void *data)
+new_addressbook_cb(EPopup *ep, EPopupItem *pitem, gpointer data)
 {
 	addressbook_config_create_new_source (gtk_widget_get_toplevel(ep->target->widget));
 }
 
 static void
-rename_addressbook_cb (EPopup *ep, EPopupItem *pitem, void *data)
+rename_addressbook_cb (EPopup *ep, EPopupItem *pitem, gpointer data)
 {
 	AddressbookView *view = data;
 	ESourceSelector *selector;
@@ -919,16 +919,16 @@ rename_addressbook_cb (EPopup *ep, EPopupItem *pitem, void *data)
 }
 
 static void
-save_addressbook_cb(EPopup *ep, EPopupItem *pitem, void *data)
+save_addressbook_cb(EPopup *ep, EPopupItem *pitem, gpointer data)
 {
 	AddressbookView *view = data;
 	EABView *v = get_current_view (view);
-       	if (v)
+	if (v)
 		eab_view_save_as (v, TRUE);
 }
 
 static void
-edit_addressbook_cb(EPopup *ep, EPopupItem *pitem, void *data)
+edit_addressbook_cb(EPopup *ep, EPopupItem *pitem, gpointer data)
 {
 	AddressbookView *view = data;
 	if (view)
@@ -946,19 +946,19 @@ primary_source_selection_changed_callback (ESourceSelector *selector,
 }
 
 static EPopupItem abv_source_popups[] = {
-	{ E_POPUP_ITEM, "10.new", N_("_New Address Book"), new_addressbook_cb, NULL, "address-book-new", 0, 0 },
- 	{ E_POPUP_ITEM, "20.saveasvcard", N_("Save As vCard..."), save_addressbook_cb, NULL,"document-save-as", 0, EAB_POPUP_SOURCE_PRIMARY },
-	{ E_POPUP_ITEM, "25.rename", N_("_Rename..."), rename_addressbook_cb, NULL, NULL, 0, EAB_POPUP_SOURCE_PRIMARY },
+	{ E_POPUP_ITEM, (gchar *) "10.new", (gchar *) N_("_New Address Book"), new_addressbook_cb, NULL, (gchar *) "address-book-new", 0, 0 },
+	{ E_POPUP_ITEM, (gchar *) "20.saveasvcard", (gchar *) N_("Save As vCard..."), save_addressbook_cb, NULL, (gchar *) "document-save-as", 0, EAB_POPUP_SOURCE_PRIMARY },
+	{ E_POPUP_ITEM, (gchar *) "25.rename", (gchar *) N_("_Rename..."), rename_addressbook_cb, NULL, NULL, 0, EAB_POPUP_SOURCE_PRIMARY },
 
-	{ E_POPUP_BAR,  "30.bar" },
-	{ E_POPUP_ITEM, "30.delete", N_("_Delete"), delete_addressbook_cb, NULL, "edit-delete", 0, EAB_POPUP_SOURCE_USER|EAB_POPUP_SOURCE_PRIMARY },
+	{ E_POPUP_BAR,  (gchar *) "30.bar" },
+	{ E_POPUP_ITEM, (gchar *) "30.delete", (gchar *) N_("_Delete"), delete_addressbook_cb, NULL, (gchar *) "edit-delete", 0, EAB_POPUP_SOURCE_USER|EAB_POPUP_SOURCE_PRIMARY },
 
-	{ E_POPUP_BAR,  "99.bar" },
-	{ E_POPUP_ITEM, "99.properties", N_("_Properties"), edit_addressbook_cb, NULL,"document-properties", 0, EAB_POPUP_SOURCE_PRIMARY },
+	{ E_POPUP_BAR,  (gchar *) "99.bar" },
+	{ E_POPUP_ITEM, (gchar *) "99.properties", (gchar *) N_("_Properties"), edit_addressbook_cb, NULL, (gchar *) "document-properties", 0, EAB_POPUP_SOURCE_PRIMARY },
 };
 
 static void
-abv_source_popup_free(EPopup *ep, GSList *list, void *data)
+abv_source_popup_free(EPopup *ep, GSList *list, gpointer data)
 {
 	g_slist_free(list);
 }
@@ -969,7 +969,7 @@ popup_event_callback(ESourceSelector *selector, ESource *source, GdkEventButton
 	EABPopup *ep;
 	EABPopupTargetSource *t;
 	GSList *menus = NULL;
-	int i;
+	gint i;
 	GtkMenu *menu;
 
 	/** @HookPoint-EABPopup:Addressbook Source Selector Context Menu
@@ -1035,7 +1035,7 @@ removed_contact_cb (EBook *book, EBookStatus status, gpointer closure)
 }
 
 static void
-merged_contact_cb (EBook *book, EBookStatus status, const char *id, gpointer closure)
+merged_contact_cb (EBook *book, EBookStatus status, const gchar *id, gpointer closure)
 {
 	MergeContext *merge_context = closure;
 
@@ -1088,7 +1088,7 @@ selector_tree_data_dropped (ESourceSelector *selector,
 	}
 	e_book_open (target_book, FALSE, NULL);
 
-	eab_book_and_contact_list_from_string ((char *)data->data, &source_book, &contactlist);
+	eab_book_and_contact_list_from_string ((gchar *)data->data, &source_book, &contactlist);
 
 	v = get_current_view (view);
 	g_object_get (v->model, "book",&source_book, NULL);
@@ -1241,7 +1241,7 @@ addressbook_view_init (AddressbookView *view)
 				 G_CALLBACK (primary_source_selection_changed_callback),
 				 G_OBJECT (view), 0);
 	g_signal_connect_after (priv->selector, "key_press_event",
-		       		G_CALLBACK (source_selector_key_press_event_callback),
+				G_CALLBACK (source_selector_key_press_event_callback),
 				G_OBJECT (view));
 	g_signal_connect_object (priv->selector, "popup_event",
 				 G_CALLBACK (popup_event_callback),
@@ -1252,7 +1252,7 @@ addressbook_view_init (AddressbookView *view)
 }
 
 static void
-destroy_editor (char *key,
+destroy_editor (gchar *key,
 		gpointer value,
 		gpointer nada)
 {
@@ -1342,7 +1342,7 @@ activate_source (AddressbookView *view,
 		 ESource *source)
 {
 	AddressbookViewPrivate *priv = view->priv;
-	const char *uid;
+	const gchar *uid;
 	GtkWidget *uid_view;
 	EBook *book;
 	BookOpenData *data;
@@ -1496,8 +1496,8 @@ addressbook_view_peek_folder_view (AddressbookView *view)
 
 void
 addressbook_view_edit_contact (AddressbookView* view,
-			       const char* source_uid,
-			       const char* contact_uid)
+			       const gchar * source_uid,
+			       const gchar * contact_uid)
 {
 	AddressbookViewPrivate *priv = view->priv;
 
