@@ -11,7 +11,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -59,7 +59,7 @@ GtkWidget         *addressbook_view_peek_statusbar        (AddressbookView *view
 BonoboControl     *addressbook_view_peek_folder_view      (AddressbookView *view);
 
 void              addressbook_view_edit_contact           (AddressbookView* view,
-							   const char* source_id,
-							   const char* contact_id);
+							   const gchar * source_id,
+							   const gchar * contact_id);
 
 #endif /* _ADDRESSBOOK_VIEW_H_ */
