@@ -1,28 +1,24 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-
-/*
- * eab-contact-compare.c
- *
- * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
- *
- * Authors: Jon Trowbridge <trow@ximian.com>
- *          Chris Toshok <toshok@ximian.com>
- */
-
 /*
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
+ *
+ * Authors:
+ *		Jon Trowbridge <trow@ximian.com>
+ *      Chris Toshok <toshok@ximian.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301
- * USA.
  */
 
 #include <config.h>
@@ -50,7 +46,7 @@ combine_comparisons (EABContactMatchType prev,
    sucky way like this.  But it can be fixed later. */
 
 /* This is very Anglocentric. */
-static gchar *name_synonyms[][2] = {
+static const gchar *name_synonyms[][2] = {
 	{ "jon", "john" },   /* Ah, the hacker's perogative */
 	{ "joseph", "joe" },
 	{ "robert", "bob" },
@@ -480,11 +476,11 @@ eab_contact_compare_email (EContact *contact1, EContact *contact2)
 	   we find an exact match, there is no reason to keep
 	   checking. */
 	while (i1 && match != EAB_CONTACT_MATCH_EXACT) {
-		char *addr1 = (char *) i1->data;
+		gchar *addr1 = (gchar *) i1->data;
 
 		i2 = contact2_email;
 		while (i2 && match != EAB_CONTACT_MATCH_EXACT) {
-			char *addr2 = (char *) i2->data;
+			gchar *addr2 = (gchar *) i2->data;
 
 			match = combine_comparisons (match, compare_email_addresses (addr1, addr2));
 
@@ -644,7 +640,7 @@ use_common_book_cb (EBook *book, gpointer closure)
 	gint p=0;
 	gchar *contact_file_as, *qj;
 	EBookQuery *query = NULL;
-	int i;
+	gint i;
 
 	if (book == NULL) {
 		info->cb (info->contact, NULL, EAB_CONTACT_MATCH_NONE, info->closure);
@@ -703,7 +699,7 @@ use_common_book_cb (EBook *book, gpointer closure)
 	for(i = 0; query_parts[i] != NULL; i++)
 		g_free(query_parts[i]);
 	if (p > 1) {
-		char *s;
+		gchar *s;
 		s = g_strdup_printf ("(or %s)", qj);
 		query = e_book_query_from_string (s);
 		g_free (s);
