@@ -11,7 +11,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -56,11 +56,11 @@ void                eab_transfer_contacts         (EBook       *source,
 						   gboolean     delete_from_source,
 						   GtkWindow   *parent_window);
 
-void                eab_contact_save              (char *title,
+void                eab_contact_save              (gchar *title,
 						   EContact *contact,
 						   GtkWindow *parent_window);
 
-void                eab_contact_list_save         (char *title,
+void                eab_contact_list_save         (gchar *title,
 						   GList *list,
 						   GtkWindow *parent_window);
 
@@ -70,7 +70,7 @@ typedef enum {
 } EABDisposition;
 
 void                eab_send_contact              (EContact       *contact,
-						   int             email_num,
+						   gint             email_num,
 						   EABDisposition  disposition);
 void                eab_send_contact_list         (GList          *contacts,
 						   EABDisposition  disposition);
@@ -81,9 +81,9 @@ GtkWidget *eab_create_image_chooser_widget (gchar *name, gchar *string1, gchar *
 ESource            *eab_select_source             (const gchar *title, const gchar *message,
 						   const gchar *select_uid, GtkWindow *parent);
 
-/* To parse quoted printable address & return email & name fields */						
+/* To parse quoted printable address & return email & name fields */
 gboolean eab_parse_qp_email (const gchar *string, gchar **name, gchar **email);
-char *eab_parse_qp_email_to_html (const gchar *string);
+gchar *eab_parse_qp_email_to_html (const gchar *string);
 
 G_END_DECLS
 
