@@ -1,21 +1,22 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- *  Authors: Michael Zucchi <notzed@ximian.com>
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
- *  Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; version 2 of the License.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * Authors:
+ *		Michael Zucchi <notzed@ximian.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  */
 
@@ -52,7 +53,7 @@ eabp_target_free(EPopup *ep, EPopupTarget *t)
 	switch (t->type) {
 	case EAB_POPUP_TARGET_SELECT: {
 		EABPopupTargetSelect *s = (EABPopupTargetSelect *)t;
-		int i;
+		gint i;
 
 		for (i=0;i<s->cards->len;i++)
 			g_object_unref(s->cards->pdata[i]);
@@ -114,7 +115,7 @@ eab_popup_get_type(void)
 	return type;
 }
 
-EABPopup *eab_popup_new(const char *menuid)
+EABPopup *eab_popup_new(const gchar *menuid)
 {
 	EABPopup *eabp = g_object_new(eab_popup_get_type(), NULL);
 
@@ -137,7 +138,7 @@ EABPopup *eab_popup_new(const char *menuid)
 
 
 EABPopupTargetURI *
-eab_popup_target_new_uri(EABPopup *emp, const char *uri)
+eab_popup_target_new_uri(EABPopup *emp, const gchar *uri)
 {
 	EABPopupTargetURI *t = e_popup_target_new(&emp->popup, EAB_POPUP_TARGET_URI, sizeof(*t));
 	guint32 mask = ~0;
@@ -161,11 +162,11 @@ eab_popup_target_new_uri(EABPopup *emp, const char *uri)
 
 
 EABPopupTargetSelect *
-eab_popup_target_new_select(EABPopup *eabp, struct _EBook *book, int readonly, GPtrArray *cards)
+eab_popup_target_new_select(EABPopup *eabp, struct _EBook *book, gint readonly, GPtrArray *cards)
 {
 	EABPopupTargetSelect *t = e_popup_target_new(&eabp->popup, EAB_POPUP_TARGET_SELECT, sizeof(*t));
 	guint32 mask = ~0;
-	int has_email = FALSE, i;
+	gint has_email = FALSE, i;
 
 	/* FIXME: duplicated in eab-menu.c */
 
@@ -218,7 +219,7 @@ eab_popup_target_new_source(EABPopup *eabp, ESourceSelector *selector)
 {
 	EABPopupTargetSource *t = e_popup_target_new(&eabp->popup, EAB_POPUP_TARGET_SOURCE, sizeof(*t));
 	guint32 mask = ~0;
-	const char *source_uri;
+	const gchar *source_uri;
 	ESource *source;
 
 	/* TODO: this is duplicated for calendar and tasks too */
@@ -246,7 +247,7 @@ eab_popup_target_new_source(EABPopup *eabp, ESourceSelector *selector)
 #ifdef ADAPTED_TO_E_NAME_SELECTOR
 
 EABPopupTargetSelectNames *
-eab_popup_target_new_select_names(EABPopup *eabp, struct _ESelectNamesModel *model, int row)
+eab_popup_target_new_select_names(EABPopup *eabp, struct _ESelectNamesModel *model, gint row)
 {
 	EABPopupTargetSelectNames *t = e_popup_target_new(&eabp->popup, EAB_POPUP_TARGET_SELECT_NAMES, sizeof(*t));
 
@@ -289,7 +290,7 @@ eab_popup_target_new_select_names(EABPopup *eabp, struct _ESelectNamesModel *mod
 
 */
 
-static void *eabph_parent_class;
+static gpointer eabph_parent_class;
 #define eabph ((EABPopupHook *)eph)
 
 static const EPopupHookTargetMask eabph_select_masks[] = {
@@ -337,7 +338,7 @@ eabph_finalise(GObject *o)
 static void
 eabph_class_init(EPluginHookClass *klass)
 {
-	int i;
+	gint i;
 
 	((GObjectClass *)klass)->finalize = eabph_finalise;
 	((EPluginHookClass *)klass)->id = "org.gnome.evolution.addressbook.popup:1.0";
