@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -27,10 +27,8 @@
 #include <unistd.h>
 
 #include <glib.h>
+#include <glib/gi18n.h>
 #include <glib/gstdio.h>
-#include <bonobo-activation/bonobo-activation.h>
-#include <libbonobo.h>
-#include <libgnome/libgnome.h>
 
 #include <libebook/e-book.h>
 #include <libebook/e-contact.h>
@@ -148,7 +146,7 @@ struct _EContactCSVFieldData
 {
 	gint csv_field;
 	gint contact_field;
-	gchar *csv_name;
+	const gchar *csv_name;
 	EContactCSVDataType data_type;
 };
 
@@ -168,7 +166,7 @@ static EContactCSVFieldData csv_field_data[] = {
 	{E_CONTACT_CSV_PHONE_HOME,	E_CONTACT_PHONE_HOME,	   "", DT_STRING},
 	{E_CONTACT_CSV_ORG,		E_CONTACT_ORG,		   "", DT_STRING},
 	/*E_CONTACT_CSV_ADDRESS_BUSINESS, */
-	{E_CONTACT_CSV_ADDRESS_BUSINESS_STREET,	  NOMAP, "Business Address", 	      DT_STRING},
+	{E_CONTACT_CSV_ADDRESS_BUSINESS_STREET,	  NOMAP, "Business Address",	      DT_STRING},
 	{E_CONTACT_CSV_ADDRESS_BUSINESS_EXT,	  NOMAP, "Business Address2",         DT_STRING},
 	{E_CONTACT_CSV_ADDRESS_BUSINESS_CITY,	  NOMAP, "Business Address City",     DT_STRING},
 	{E_CONTACT_CSV_ADDRESS_BUSINESS_REGION,	  NOMAP, "Business Address State",    DT_STRING},
@@ -181,7 +179,7 @@ static EContactCSVFieldData csv_field_data[] = {
 	{E_CONTACT_CSV_ADDRESS_HOME_REGION,   NOMAP, "Home Address State",    DT_STRING},
 	{E_CONTACT_CSV_ADDRESS_HOME_POSTCODE, NOMAP, "Home Address PostCode", DT_STRING},
 	{E_CONTACT_CSV_ADDRESS_HOME_COUNTRY,  NOMAP, "Home Address Country",  DT_STRING},
-	{E_CONTACT_CSV_PHONE_MOBILE, 	      E_CONTACT_PHONE_MOBILE,       "", DT_STRING},
+	{E_CONTACT_CSV_PHONE_MOBILE,	      E_CONTACT_PHONE_MOBILE,       "", DT_STRING},
 	{E_CONTACT_CSV_PHONE_CAR,	      E_CONTACT_PHONE_CAR,          "", DT_STRING},
 	{E_CONTACT_CSV_PHONE_BUSINESS_FAX,    E_CONTACT_PHONE_BUSINESS_FAX, "", DT_STRING},
 	{E_CONTACT_CSV_PHONE_HOME_FAX,        E_CONTACT_PHONE_HOME_FAX,     "", DT_STRING},
@@ -244,10 +242,9 @@ gchar *e_contact_get_csv (EContact * contact, GSList * csv_all_fields);
 gchar *delivery_address_get_sub_field (const EContactAddress * delivery_address, DeliveryAddressField sub_field);
 gchar *check_null_pointer (gchar * orig);
 gchar *escape_string (gchar * orig);
-int output_n_cards_file (FILE * outputfile, GList *contacts, int size, int begin_no, CARD_FORMAT format);
+gint output_n_cards_file (FILE * outputfile, GList *contacts, gint size, gint begin_no, CARD_FORMAT format);
 static void fork_to_background (void);
 void set_pre_defined_field (GSList ** pre_defined_fields);
-guint action_list_cards_init (ActionContext * p_actctx);
 
 
 /* function declarations*/
@@ -569,10 +566,10 @@ escape_string (gchar *orig)
 	return dest;
 }
 
-int
-output_n_cards_file (FILE * outputfile, GList *contacts, int size, int begin_no, CARD_FORMAT format)
+gint
+output_n_cards_file (FILE * outputfile, GList *contacts, gint size, gint begin_no, CARD_FORMAT format)
 {
-	int i;
+	gint i;
 	if (format == CARD_FORMAT_VCARD) {
 		for (i = begin_no; i < size + begin_no; i++) {
 			EContact *contact = g_list_nth_data (contacts, i);
@@ -631,11 +628,11 @@ action_list_cards (GList *contacts, ActionContext * p_actctx)
 {
 	FILE *outputfile;
 	long length;
-	int IsFirstOne;
-	int series_no;
+	gint IsFirstOne;
+	gint series_no;
 	gchar *file_series_name;
 	CARD_FORMAT format;
-	int size;
+	gint size;
 
 	length = g_list_length (contacts);
 
