@@ -12,7 +12,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -30,7 +30,6 @@
 #define G_LOG_DOMAIN "ememoconduit"
 
 #include <glib/gi18n.h>
-#include <libgnome/gnome-config.h>
 #include <libecal/e-cal-types.h>
 #include <libecal/e-cal.h>
 #include <libecal/e-cal-time-util.h>
@@ -87,7 +86,7 @@ struct _EMemoLocalRecord {
 	struct Memo *memo;
 };
 
-int lastDesktopUniqueID;
+gint lastDesktopUniqueID;
 
 static void
 memoconduit_destroy_record (EMemoLocalRecord *local)
@@ -120,15 +119,14 @@ memoconduit_load_configuration (guint32 pilot_id)
 	gchar prefix[256];
 
 
-	g_snprintf (prefix, 255, "/gnome-pilot.d/e-memo-conduit/Pilot_%u/",
-		    pilot_id);
+	g_snprintf (prefix, 255, "e-memo-conduit/Pilot_%u", pilot_id);
 
 	c = g_new0 (EMemoConduitCfg,1);
 	g_assert (c != NULL);
 
 	c->pilot_id = pilot_id;
 
-	management = gnome_pilot_conduit_management_new ("e_memo_conduit", GNOME_PILOT_CONDUIT_MGMT_ID);
+	management = gnome_pilot_conduit_management_new ((gchar *)"e_memo_conduit", GNOME_PILOT_CONDUIT_MGMT_ID);
 	g_object_ref_sink (management);
 	config = gnome_pilot_conduit_config_new (management, pilot_id);
 	g_object_ref_sink (config);
@@ -138,8 +136,6 @@ memoconduit_load_configuration (guint32 pilot_id)
 	g_object_unref (management);
 
 	/* Custom settings */
-	gnome_config_push_prefix (prefix);
-
 	if (!e_cal_get_sources (&c->source_list, E_CAL_SOURCE_TYPE_JOURNAL, NULL))
 		c->source_list = NULL;
 	if (c->source_list) {
@@ -154,11 +150,9 @@ memoconduit_load_configuration (guint32 pilot_id)
 		}
 	}
 
-	c->secret = gnome_config_get_bool ("secret=FALSE");
-	c->priority = gnome_config_get_int ("priority=3");
-	c->last_uri = gnome_config_get_string ("last_uri");
-
-	gnome_config_pop_prefix ();
+	c->secret = e_pilot_setup_get_bool (prefix, "secret", FALSE);
+	c->priority = e_pilot_setup_get_int (prefix, "priority", 3);
+	c->last_uri = e_pilot_setup_get_string (prefix, "last_uri", NULL);
 
 	return c;
 }
@@ -168,18 +162,12 @@ memoconduit_save_configuration (EMemoConduitCfg *c)
 {
 	gchar prefix[256];
 
-	g_snprintf (prefix, 255, "/gnome-pilot.d/e-memo-conduit/Pilot_%u/",
-		    c->pilot_id);
+	g_snprintf (prefix, 255, "e-memo-conduit/Pilot_%u", c->pilot_id);
 
-	gnome_config_push_prefix (prefix);
 	e_pilot_set_sync_source (c->source_list, c->source);
-	gnome_config_set_bool ("secret", c->secret);
-	gnome_config_set_int ("priority", c->priority);
-	gnome_config_set_string ("last_uri", c->last_uri);
-	gnome_config_pop_prefix ();
-
-	gnome_config_sync ();
-	gnome_config_drop_all ();
+	e_pilot_setup_set_bool (prefix, "secret", c->secret);
+	e_pilot_setup_set_int (prefix, "priority", c->priority);
+	e_pilot_setup_set_string (prefix, "last_uri", c->last_uri ? c->last_uri : "");
 }
 
 static EMemoConduitCfg*
@@ -309,10 +297,10 @@ e_memo_context_destroy (EMemoConduitContext *ctxt)
 }
 
 /* Debug routines */
-static char *
+static gchar *
 print_local (EMemoLocalRecord *local)
 {
-	static char buff[ 64 ];
+	static gchar buff[ 64 ];
 
 	if (local == NULL) {
 		sprintf (buff, "[NULL]");
@@ -326,12 +314,13 @@ print_local (EMemoLocalRecord *local)
 		return buff;
 	}
 
-	return "";
+	strcpy (buff, "");
+	return buff;
 }
 
-static char *print_remote (GnomePilotRecord *remote)
+static gchar *print_remote (GnomePilotRecord *remote)
 {
-	static char buff[ 64 ];
+	static gchar buff[ 64 ];
 	struct Memo memo;
 #ifdef PILOT_LINK_0_12
 	pi_buffer_t *buffer;
@@ -368,7 +357,7 @@ static char *print_remote (GnomePilotRecord *remote)
 	return buff;
 }
 
-static int
+static gint
 start_calendar_server (EMemoConduitContext *ctxt)
 {
 	g_return_val_if_fail (ctxt != NULL, -2);
@@ -389,7 +378,7 @@ get_default_timezone (void)
 {
 	EConfigListener *listener;
 	icaltimezone *timezone = NULL;
-	char *location;
+	gchar *location;
 
 	listener = e_config_listener_new ();
 
@@ -408,10 +397,10 @@ get_default_timezone (void)
 	return timezone;
 }
 
-static char *
+static gchar *
 map_name (EMemoConduitContext *ctxt)
 {
-	char *filename;
+	gchar *filename;
 
 	filename = g_strdup_printf ("%s/.evolution/memos/local/system/pilot-map-memo-%d.xml", g_get_home_dir (), ctxt->cfg->pilot_id);
 
@@ -425,7 +414,7 @@ next_changed_item (EMemoConduitContext *ctxt, GList *changes)
 	GList *l;
 
 	for (l = changes; l != NULL; l = l->next) {
-		const char *uid;
+		const gchar *uid;
 
 		ccc = l->data;
 
@@ -438,7 +427,7 @@ next_changed_item (EMemoConduitContext *ctxt, GList *changes)
 }
 
 static void
-compute_status (EMemoConduitContext *ctxt, EMemoLocalRecord *local, const char *uid)
+compute_status (EMemoConduitContext *ctxt, EMemoLocalRecord *local, const gchar *uid)
 {
 	ECalChange *ccc;
 
@@ -473,7 +462,7 @@ local_record_to_pilot_record (EMemoLocalRecord *local,
 #ifdef PILOT_LINK_0_12
 	pi_buffer_t * buffer;
 #else
-	static char record[0xffff];
+	static gchar record[0xffff];
 #endif
 
 	memset(&p, 0, sizeof (p));
@@ -506,7 +495,7 @@ local_record_to_pilot_record (EMemoLocalRecord *local,
 
 	pi_buffer_free(buffer);
 #else
-	p.record = (unsigned char *)record;
+	p.record = (guchar *)record;
 	p.length = pack_Memo (local->memo, p.record, 0xffff);
 #endif
 	return p;
@@ -518,7 +507,7 @@ local_record_to_pilot_record (EMemoLocalRecord *local,
 static void
 local_record_from_comp (EMemoLocalRecord *local, ECalComponent *comp, EMemoConduitContext *ctxt)
 {
-	const char *uid;
+	const gchar *uid;
 	GSList *d_list = NULL;
 	ECalComponentText *description;
 	ECalComponentClassification classif;
@@ -549,9 +538,9 @@ local_record_from_comp (EMemoLocalRecord *local, ECalComponent *comp, EMemoCondu
 		struct Memo memo;
 		pi_buffer_t * record;
 #else
-		char record[0xffff];
+		gchar record[0xffff];
 #endif
-		int cat = 0;
+		gint cat = 0;
 
 #ifdef PILOT_LINK_0_12
 		record = pi_buffer_new(DLP_BUF_SIZE);
@@ -614,7 +603,7 @@ local_record_from_comp (EMemoLocalRecord *local, ECalComponent *comp, EMemoCondu
 
 static void
 local_record_from_uid (EMemoLocalRecord *local,
-		       const char *uid,
+		       const gchar *uid,
 		       EMemoConduitContext *ctxt)
 {
 	ECalComponent *comp;
@@ -660,8 +649,8 @@ comp_from_remote_record (GnomePilotConduitSyncAbs *conduit,
 	struct Memo memo;
 	struct icaltimetype now;
 	icaltimezone *utc_zone;
-	char *txt, *txt2, *txt3;
-	int i;
+	gchar *txt, *txt2, *txt3;
+	gint i;
 #ifdef PILOT_LINK_0_12
 	pi_buffer_t * buffer;
 #endif
@@ -706,7 +695,7 @@ comp_from_remote_record (GnomePilotConduitSyncAbs *conduit,
 		e_cal_component_set_comment_list (comp, NULL);
 		e_cal_component_set_summary(comp, NULL);
 	} else {
-		int idxToUse = -1, ntext = strlen(memo.text);
+		gint idxToUse = -1, ntext = strlen(memo.text);
 		gboolean foundNL = FALSE;
 		GSList l;
 		ECalComponentText text, sumText;
@@ -767,8 +756,8 @@ static void
 check_for_slow_setting (GnomePilotConduit *c, EMemoConduitContext *ctxt)
 {
 	GnomePilotConduitStandard *conduit = GNOME_PILOT_CONDUIT_STANDARD (c);
-	int map_count;
-	const char *uri;
+	gint map_count;
+	const gchar *uri;
 
 	/* If there are no objects or objects but no log */
 	map_count = g_hash_table_size (ctxt->map->pid_map);
@@ -799,9 +788,9 @@ pre_sync (GnomePilotConduit *conduit,
 {
 	GnomePilotConduitSyncAbs *abs_conduit;
 	GList *l;
-	int len;
-	unsigned char *buf;
-	char *filename, *change_id;
+	gint len;
+	guchar *buf;
+	gchar *filename, *change_id;
 	icalcomponent *icalcomp;
 	gint num_records, add_records = 0, mod_records = 0, del_records = 0;
 #ifdef PILOT_LINK_0_12
@@ -863,7 +852,7 @@ pre_sync (GnomePilotConduit *conduit,
 
 	for (l = ctxt->changed; l != NULL; l = l->next) {
 		ECalChange *ccc = l->data;
-		const char *uid;
+		const gchar *uid;
 
 		e_cal_component_get_uid (ccc->comp, &uid);
 		if (!e_pilot_map_uid_is_archived (ctxt->map, uid)) {
@@ -903,13 +892,13 @@ pre_sync (GnomePilotConduit *conduit,
 		return -1;
 	}
 
- 	len = dlp_ReadAppBlock (dbi->pilot_socket, dbi->db_handle, 0,
+	len = dlp_ReadAppBlock (dbi->pilot_socket, dbi->db_handle, 0,
 				DLP_BUF_SIZE,
 				buffer);
 #else
-	buf = (unsigned char*)g_malloc (0xffff);
+	buf = (guchar *)g_malloc (0xffff);
 	len = dlp_ReadAppBlock (dbi->pilot_socket, dbi->db_handle, 0,
-			      (unsigned char *)buf, 0xffff);
+			      (guchar *)buf, 0xffff);
 #endif
 	if (len < 0) {
 		WARN (_("Could not read pilot's Memo application block"));
@@ -921,7 +910,7 @@ pre_sync (GnomePilotConduit *conduit,
 #ifdef PILOT_LINK_0_12
 	buf = g_new0 (unsigned char,buffer->used);
 	memcpy(buf, buffer->data, buffer->used);
- 	unpack_MemoAppInfo (&(ctxt->ai), buf, len);
+	unpack_MemoAppInfo (&(ctxt->ai), buf, len);
 	pi_buffer_free(buffer);
 #else
 	unpack_MemoAppInfo (&(ctxt->ai), buf, len);
@@ -946,15 +935,15 @@ post_sync (GnomePilotConduit *conduit,
 {
 	GList *changed;
 	gchar *filename, *change_id;
-	unsigned char *buf;
-	int dlpRetVal, len;
+	guchar *buf;
+	gint dlpRetVal, len;
 
-	buf = (unsigned char*)g_malloc (0xffff);
+	buf = (guchar *)g_malloc (0xffff);
 
 	len = pack_MemoAppInfo (&(ctxt->ai), buf, 0xffff);
 
 	dlpRetVal = dlp_WriteAppBlock (dbi->pilot_socket, dbi->db_handle,
-			      (unsigned char *)buf, len);
+			      (guchar *)buf, len);
 
 	g_free (buf);
 
@@ -996,7 +985,7 @@ set_pilot_id (GnomePilotConduitSyncAbs *conduit,
 	      guint32 ID,
 	      EMemoConduitContext *ctxt)
 {
-	const char *uid;
+	const gchar *uid;
 
 	LOG (g_message ( "set_pilot_id: setting to %d\n", ID ));
 
@@ -1011,7 +1000,7 @@ set_status_cleared (GnomePilotConduitSyncAbs *conduit,
 		    EMemoLocalRecord *local,
 		    EMemoConduitContext *ctxt)
 {
-	const char *uid;
+	const gchar *uid;
 
 	LOG (g_message ( "set_status_cleared: clearing status\n" ));
 
@@ -1027,7 +1016,7 @@ for_each (GnomePilotConduitSyncAbs *conduit,
 	  EMemoConduitContext *ctxt)
 {
 	static GList *comps, *iterator;
-	static int count;
+	static gint count;
         GList *unused;
 
 	g_return_val_if_fail (local != NULL, -1);
@@ -1047,7 +1036,7 @@ for_each (GnomePilotConduitSyncAbs *conduit,
 			/* NOTE: ignore the return value, otherwise ctxt->locals
 			 * gets messed up. The calling function keeps track of
 			 * the *local variable */
-		        unused = g_list_prepend (ctxt->locals, *local);
+			unused = g_list_prepend (ctxt->locals, *local);
 			iterator = comps;
 		} else {
 			LOG (g_message ( "no events" ));
@@ -1087,7 +1076,7 @@ for_each_modified (GnomePilotConduitSyncAbs *conduit,
 		   EMemoConduitContext *ctxt)
 {
 	static GList *iterator;
-	static int count;
+	static gint count;
         GList *unused;
 
 	g_return_val_if_fail (local != NULL, 0);
@@ -1150,7 +1139,7 @@ compare (GnomePilotConduitSyncAbs *conduit,
 {
 	/* used by the quick compare */
 	GnomePilotRecord local_pilot;
-	int retval = 0;
+	gint retval = 0;
 
 	LOG (g_message ("compare: local=%s remote=%s...\n",
 			print_local (local), print_remote (remote)));
@@ -1178,8 +1167,8 @@ add_record (GnomePilotConduitSyncAbs *conduit,
 	    EMemoConduitContext *ctxt)
 {
 	ECalComponent *comp;
-	char *uid;
-	int retval = 0;
+	gchar *uid;
+	gint retval = 0;
 
 	g_return_val_if_fail (remote != NULL, -1);
 
@@ -1208,7 +1197,7 @@ replace_record (GnomePilotConduitSyncAbs *conduit,
 		EMemoConduitContext *ctxt)
 {
 	ECalComponent *new_comp;
-	int retval = 0;
+	gint retval = 0;
 
 	g_return_val_if_fail (remote != NULL, -1);
 
@@ -1231,7 +1220,7 @@ delete_record (GnomePilotConduitSyncAbs *conduit,
 	       EMemoLocalRecord *local,
 	       EMemoConduitContext *ctxt)
 {
-	const char *uid;
+	const gchar *uid;
 
 	g_return_val_if_fail (local != NULL, -1);
 	g_return_val_if_fail (local->comp != NULL, -1);
@@ -1253,8 +1242,8 @@ archive_record (GnomePilotConduitSyncAbs *conduit,
 		gboolean archive,
 		EMemoConduitContext *ctxt)
 {
-	const char *uid;
-	int retval = 0;
+	const gchar *uid;
+	gint retval = 0;
 
 	g_return_val_if_fail (local != NULL, -1);
 
@@ -1272,7 +1261,7 @@ match (GnomePilotConduitSyncAbs *conduit,
        EMemoLocalRecord **local,
        EMemoConduitContext *ctxt)
 {
-	const char *uid;
+	const gchar *uid;
 
 	LOG (g_message ("match: looking for local copy of %s\n",
 			print_remote (remote)));
@@ -1394,7 +1383,7 @@ conduit_get_gpilot_conduit (guint32 pilot_id)
 
 	LOG (g_message ( "in memo's conduit_get_gpilot_conduit\n" ));
 
-	retval = gnome_pilot_conduit_sync_abs_new ("MemoDB", 0x6D656D6F);
+	retval = gnome_pilot_conduit_sync_abs_new ((gchar *)"MemoDB", 0x6D656D6F);
 	g_assert (retval != NULL);
 
 	ctxt = e_memo_context_new (pilot_id);
@@ -1403,22 +1392,22 @@ conduit_get_gpilot_conduit (guint32 pilot_id)
 	g_signal_connect (retval, "pre_sync", G_CALLBACK (pre_sync), ctxt);
 	g_signal_connect (retval, "post_sync", G_CALLBACK (post_sync), ctxt);
 
-  	g_signal_connect (retval, "set_pilot_id", G_CALLBACK (set_pilot_id), ctxt);
-  	g_signal_connect (retval, "set_status_cleared", G_CALLBACK (set_status_cleared), ctxt);
+	g_signal_connect (retval, "set_pilot_id", G_CALLBACK (set_pilot_id), ctxt);
+	g_signal_connect (retval, "set_status_cleared", G_CALLBACK (set_status_cleared), ctxt);
 
-  	g_signal_connect (retval, "for_each", G_CALLBACK (for_each), ctxt);
-  	g_signal_connect (retval, "for_each_modified", G_CALLBACK (for_each_modified), ctxt);
-  	g_signal_connect (retval, "compare", G_CALLBACK (compare), ctxt);
+	g_signal_connect (retval, "for_each", G_CALLBACK (for_each), ctxt);
+	g_signal_connect (retval, "for_each_modified", G_CALLBACK (for_each_modified), ctxt);
+	g_signal_connect (retval, "compare", G_CALLBACK (compare), ctxt);
 
-  	g_signal_connect (retval, "add_record", G_CALLBACK (add_record), ctxt);
-  	g_signal_connect (retval, "replace_record", G_CALLBACK (replace_record), ctxt);
-  	g_signal_connect (retval, "delete_record", G_CALLBACK (delete_record), ctxt);
-  	g_signal_connect (retval, "archive_record", G_CALLBACK (archive_record), ctxt);
+	g_signal_connect (retval, "add_record", G_CALLBACK (add_record), ctxt);
+	g_signal_connect (retval, "replace_record", G_CALLBACK (replace_record), ctxt);
+	g_signal_connect (retval, "delete_record", G_CALLBACK (delete_record), ctxt);
+	g_signal_connect (retval, "archive_record", G_CALLBACK (archive_record), ctxt);
 
-  	g_signal_connect (retval, "match", G_CALLBACK (match), ctxt);
-  	g_signal_connect (retval, "free_match", G_CALLBACK (free_match), ctxt);
+	g_signal_connect (retval, "match", G_CALLBACK (match), ctxt);
+	g_signal_connect (retval, "free_match", G_CALLBACK (free_match), ctxt);
 
-  	g_signal_connect (retval, "prepare", G_CALLBACK (prepare), ctxt);
+	g_signal_connect (retval, "prepare", G_CALLBACK (prepare), ctxt);
 
 	/* Gui Settings */
 	g_signal_connect (retval, "create_settings_window", G_CALLBACK (create_settings_window), ctxt);
