@@ -1,31 +1,31 @@
-/* Evolution calendar - alarm notification dialog
- *
- * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
- * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
- *
- * Author: Federico Mena-Quintero <federico@ximian.com>
+/*
+ * Evolution calendar - alarm notification dialog
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
+ *
+ * Authors:
+ *		Federico Mena-Quintero <federico@ximian.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #include <config.h>
 #include <stdio.h>
 #include <string.h>
 #include <glib/gi18n.h>
-#if 0
-#  include <libgnomeui/gnome-winhints.h>
-#endif
 #include <glade/glade.h>
 #include <libedataserver/e-time-utils.h>
 #include <libecal/e-cal-time-util.h>
@@ -64,6 +64,7 @@ typedef struct {
 	GtkWidget *snooze_time_min;
 	GtkWidget *snooze_time_hrs;
 	GtkWidget *snooze_btn;
+	GtkWidget *dismiss_btn;
 	GtkWidget *minutes_label;
 	GtkWidget *hrs_label;
 	GtkWidget *description;
@@ -92,8 +93,8 @@ static void
 an_update_minutes_label (GtkSpinButton *sb, gpointer data)
 {
 	AlarmNotify *an;
-	char *new_label;
-	int snooze_timeout_min;
+	gchar *new_label;
+	gint snooze_timeout_min;
 
 	an = (AlarmNotify *) data;
 
@@ -107,8 +108,8 @@ static void
 an_update_hrs_label (GtkSpinButton *sb, gpointer data)
 {
 	AlarmNotify *an;
-	char *new_label;
-	int snooze_timeout_hrs;
+	gchar *new_label;
+	gint snooze_timeout_hrs;
 
 	an = (AlarmNotify *) data;
 
@@ -169,7 +170,7 @@ edit_pressed_cb (GtkButton *button, gpointer user_data)
 static void
 snooze_pressed_cb (GtkButton *button, gpointer user_data)
 {
-	int snooze_timeout;
+	gint snooze_timeout;
 	AlarmNotify *an = user_data;
 	GtkTreeIter iter;
 	GtkTreeModel *model = NULL;
@@ -188,7 +189,30 @@ snooze_pressed_cb (GtkButton *button, gpointer user_data)
 	if (!snooze_timeout)
 		snooze_timeout = DEFAULT_SNOOZE_MINS;
 	(* funcinfo->func) (ALARM_NOTIFY_SNOOZE, snooze_timeout, funcinfo->func_data);
+}
 
+static void
+dismiss_pressed_cb (GtkButton *button, gpointer user_data)
+{
+	AlarmNotify *an = user_data;
+	GtkTreeModel *model = gtk_tree_view_get_model (GTK_TREE_VIEW (an->treeview));
+
+	g_return_if_fail (model != NULL);
+
+	if (gtk_tree_model_iter_n_children (model, NULL) <= 1) {
+		gtk_dialog_response (GTK_DIALOG (an->dialog), GTK_RESPONSE_CLOSE);
+	} else {
+		GtkTreeIter iter;
+		AlarmFuncInfo *funcinfo = NULL;
+		GtkTreeSelection *selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (an->treeview));
+
+		if (gtk_tree_selection_get_selected (selection, &model, &iter))
+			gtk_tree_model_get (model, &iter, ALARM_FUNCINFO_COLUMN, &funcinfo, -1);
+
+		g_return_if_fail (funcinfo);
+
+		(* funcinfo->func) (ALARM_NOTIFY_DISMISS, -1, funcinfo->func_data);
+	}
 }
 
 static void
@@ -229,7 +253,7 @@ notified_alarms_dialog_new (void)
 
 			G_TYPE_POINTER /* FuncInfo*/));
 
-	char *gladefile;
+	gchar *gladefile;
 
 	gladefile = g_build_filename (EVOLUTION_GLADEDIR,
 				      "alarm-notify.glade",
@@ -253,10 +277,11 @@ notified_alarms_dialog_new (void)
 	an->scrolledwindow = glade_xml_get_widget (an->xml, "treeview-scrolledwindow");
 	snooze_btn = glade_xml_get_widget (an->xml, "snooze-button");
 	an->snooze_btn = snooze_btn;
+	an->dismiss_btn = glade_xml_get_widget (an->xml, "dismiss-button");
 	edit_btn = glade_xml_get_widget (an->xml, "edit-button");
 
 	if (!(an->dialog && an->scrolledwindow && an->treeview && an->snooze_time_min && an->snooze_time_hrs
-	      && an->description && an->location && edit_btn && snooze_btn)) {
+	      && an->description && an->location && edit_btn && snooze_btn && an->dismiss_btn)) {
 		g_message ("alarm_notify_dialog(): Could not find all widgets in Glade file!");
 		g_object_unref (an->xml);
 		g_free (an);
@@ -289,6 +314,7 @@ notified_alarms_dialog_new (void)
 
 	g_signal_connect (edit_btn, "clicked", G_CALLBACK (edit_pressed_cb), an);
 	g_signal_connect (snooze_btn, "clicked", G_CALLBACK (snooze_pressed_cb), an);
+	g_signal_connect (an->dismiss_btn, "clicked", G_CALLBACK (dismiss_pressed_cb), an);
 	g_signal_connect (G_OBJECT (an->dialog), "response", G_CALLBACK (dialog_response_cb), an);
 	g_signal_connect (G_OBJECT (an->dialog), "destroy", G_CALLBACK (dialog_destroyed_cb), an);
 
@@ -299,11 +325,11 @@ notified_alarms_dialog_new (void)
 
 	/* Set callback for updating the snooze "minutes" label */
 	g_signal_connect (G_OBJECT (an->snooze_time_min), "value_changed",
-	 		G_CALLBACK (an_update_minutes_label), an);
+			G_CALLBACK (an_update_minutes_label), an);
 
 	/* Set callback for updating the snooze "hours" label */
 	g_signal_connect (G_OBJECT (an->snooze_time_hrs), "value_changed",
-	 		G_CALLBACK (an_update_hrs_label), an);
+			G_CALLBACK (an_update_hrs_label), an);
 
 
 	na = g_new0 (AlarmNotificationsDialog, 1);
@@ -337,8 +363,8 @@ notified_alarms_dialog_new (void)
 GtkTreeIter
 add_alarm_to_notified_alarms_dialog (AlarmNotificationsDialog *na, time_t trigger,
 				time_t occur_start, time_t occur_end,
-				ECalComponentVType vtype, const char *summary,
-				const char *description, const char *location,
+				ECalComponentVType vtype, const gchar *summary,
+				const gchar *description, const gchar *location,
 				AlarmNotifyFunc func, gpointer func_data)
 {
 	GtkTreeIter iter;
