@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -39,13 +39,8 @@
 #include "calendar-config-keys.h"
 #include "calendar-config.h"
 
-
-
 static GConfClient *config = NULL;
 
-/* Store the zones here, this is not destroyed as the ical timezones */
-static GHashTable *custom_zones = NULL;
-
 static void
 do_cleanup (void)
 {
@@ -78,7 +73,7 @@ calendar_config_remove_notification (guint id)
 gboolean
 calendar_config_locale_supports_12_hour_format (void)
 {
-	char s[16];
+	gchar s[16];
 	time_t t = 0;
 
 	calendar_config_init ();
@@ -88,7 +83,7 @@ calendar_config_locale_supports_12_hour_format (void)
 }
 
 /* Returns the string representation of a units value */
-static const char *
+static const gchar *
 units_to_string (CalUnits units)
 {
 	switch (units) {
@@ -108,7 +103,7 @@ units_to_string (CalUnits units)
 
 /* opposite function to 'units_to_string' */
 static CalUnits
-string_to_units (const char *units)
+string_to_units (const gchar *units)
 {
 	CalUnits res;
 
@@ -156,7 +151,7 @@ calendar_config_add_notification_calendars_selected (GConfClientNotifyFunc func,
 }
 
 /* The primary calendar */
-char *
+gchar *
 calendar_config_get_primary_calendar (void)
 {
 	calendar_config_init ();
@@ -165,7 +160,7 @@ calendar_config_get_primary_calendar (void)
 }
 
 void
-calendar_config_set_primary_calendar (const char *primary_uid)
+calendar_config_set_primary_calendar (const gchar *primary_uid)
 {
 	calendar_config_init ();
 
@@ -185,115 +180,73 @@ calendar_config_add_notification_primary_calendar (GConfClientNotifyFunc func, g
 	return id;
 }
 
+gboolean
+calendar_config_get_use_system_timezone (void)
+{
+	calendar_config_init ();
+
+	return gconf_client_get_bool (config, CALENDAR_CONFIG_USE_SYSTEM_TIMEZONE, NULL);
+}
+
+void
+calendar_config_set_use_system_timezone (gboolean use)
+{
+	calendar_config_init ();
+
+	if (calendar_config_get_use_system_timezone () != use) {
+		gconf_client_set_bool (config, CALENDAR_CONFIG_USE_SYSTEM_TIMEZONE, use, NULL);
+		gconf_client_notify (config, CALENDAR_CONFIG_TIMEZONE);
+
+		/* FIXME: notify CALENDAR_CONFIG_TIMEZONE change on system timezone change
+		   itself too, when using system timezone. How to receive such change? */
+	}
+}
+
+guint
+calendar_config_add_notification_use_system_timezone (GConfClientNotifyFunc func, gpointer data)
+{
+	calendar_config_init ();
+
+	return gconf_client_notify_add (config, CALENDAR_CONFIG_USE_SYSTEM_TIMEZONE, func, data, NULL, NULL);
+}
 
 /* The current timezone, e.g. "Europe/London". It may be NULL, in which case
    you should assume UTC (though Evolution will show the timezone-setting
    dialog the next time a calendar or task folder is selected). */
 gchar *
 calendar_config_get_timezone (void)
+{
+	if (calendar_config_get_use_system_timezone ())
+		return e_cal_util_get_system_timezone_location ();
+
+	return calendar_config_get_timezone_stored ();
+}
+
+gchar *
+calendar_config_get_timezone_stored (void)
 {
 	calendar_config_init ();
 
 	return gconf_client_get_string (config, CALENDAR_CONFIG_TIMEZONE, NULL);
 }
 
-static void
-set_standard_offsets (icalcomponent *zone_comp, int offset)
-{
-	icalcomponent *dl_comp, *s_comp;
-	icalproperty *offset_from, *offset_to;
-
-	/* Set the offset of the standard component to all the daylight components also */
-	for (dl_comp = icalcomponent_get_first_component (zone_comp, ICAL_XDAYLIGHT_COMPONENT); dl_comp != NULL;
-			dl_comp = icalcomponent_get_next_component (zone_comp, ICAL_XDAYLIGHT_COMPONENT)) {
-		offset_to = icalcomponent_get_first_property (dl_comp, ICAL_TZOFFSETTO_PROPERTY);
-		icalproperty_set_tzoffsetto (offset_to, offset);
-	}
-
-	/* Set the tzto offset of the standard component to tzfrom */
-	for (s_comp = icalcomponent_get_first_component (zone_comp, ICAL_XSTANDARD_COMPONENT); s_comp != NULL;
-			s_comp = icalcomponent_get_next_component (zone_comp, ICAL_XSTANDARD_COMPONENT)) {
-		offset_from = icalcomponent_get_first_property (s_comp, ICAL_TZOFFSETFROM_PROPERTY);
-		icalproperty_set_tzoffsetfrom (offset_from, offset);
-	}
-}
-
 icaltimezone *
 calendar_config_get_icaltimezone (void)
 {
-	char *location;
+	gchar *location;
 	icaltimezone *zone = NULL;
 
 	calendar_config_init ();
 
 	location = calendar_config_get_timezone ();
 	if (location) {
-		icalcomponent *icalcomp, *dl_comp;
-
 		zone = icaltimezone_get_builtin_timezone (location);
-		icalcomp = icaltimezone_get_component (zone);
-
-
-		if (!(dl_comp = icalcomponent_get_first_component (icalcomp, ICAL_XDAYLIGHT_COMPONENT))) {
-			g_free (location);
-			return zone;
-		}
-
-		if (!calendar_config_get_daylight_saving () && zone) {
-			icalcomponent *zone_comp, *s_comp;
-			icalproperty *tz_prop, *offset_to;
-			icaltimezone *st_zone = NULL;
-			int offset;
-			const char *tzid;
-			char *n_tzid;
-
-			tzid = icaltimezone_get_tzid (zone);
-			n_tzid = g_strconcat (tzid, "-(Standard)", NULL);
-
-			if (!custom_zones) {
-				custom_zones = g_hash_table_new (g_str_hash, g_str_equal);
-			} else if ((st_zone = g_hash_table_lookup (custom_zones, n_tzid))) {
-				g_free (n_tzid);
-				g_free (location);
-				return st_zone;
-			}
-
-			zone_comp = icalcomponent_new_clone (icalcomp);
-			s_comp = icalcomponent_get_first_component (zone_comp, ICAL_XSTANDARD_COMPONENT);
-
-			if (!s_comp) {
-				g_free (n_tzid);
-				icalcomponent_free (zone_comp);
-				g_free (location);
-				return zone;
-			}
-
-			offset_to = icalcomponent_get_first_property (s_comp, ICAL_TZOFFSETTO_PROPERTY);
-			offset = icalproperty_get_tzoffsetto (offset_to);
-
-			set_standard_offsets (zone_comp, offset);
-
-			tz_prop = icalcomponent_get_first_property (zone_comp, ICAL_TZID_PROPERTY);
-			if (tz_prop) {
-				icalcomponent_remove_property (zone_comp, tz_prop);
-			}
-
-			tz_prop = icalproperty_new_tzid (n_tzid);
-			icalcomponent_add_property (zone_comp, tz_prop);
-
-			st_zone = icaltimezone_new ();
-			icaltimezone_set_component (st_zone, zone_comp);
-
-			zone = st_zone;
-			g_hash_table_insert (custom_zones, n_tzid, zone);
-		}
 
 		g_free (location);
 	}
 	return zone;
 }
 
-
 /* Sets the timezone. If set to NULL it defaults to UTC.
    FIXME: Should check it is being set to a valid timezone. */
 void
@@ -319,35 +272,6 @@ calendar_config_add_notification_timezone (GConfClientNotifyFunc func, gpointer
 	return id;
 }
 
-gboolean
-calendar_config_get_daylight_saving (void)
-{
-	calendar_config_init ();
-
-	return gconf_client_get_bool (config, CALENDAR_CONFIG_DAYLIGHT_SAVING, NULL);
-
-}
-
-void
-calendar_config_set_daylight_saving (gboolean daylight_saving)
-{
-	calendar_config_init ();
-
-	gconf_client_set_bool (config, CALENDAR_CONFIG_DAYLIGHT_SAVING, daylight_saving, NULL);
-}
-
-guint
-calendar_config_add_notification_daylight_saving (GConfClientNotifyFunc func, gpointer data)
-{
-	guint id;
-
-	calendar_config_init ();
-
-	id = gconf_client_notify_add (config, CALENDAR_CONFIG_DAYLIGHT_SAVING, func, data, NULL, NULL);
-
-	return id;
-}
-
 /* Whether we use 24-hour format or 12-hour format (AM/PM). */
 gboolean
 calendar_config_get_24_hour_format	(void)
@@ -663,11 +587,40 @@ calendar_config_add_notification_time_divisions (GConfClientNotifyFunc func, gpo
 	return id;
 }
 
+/* Scroll in a month view by a week, not by a month */
+gboolean
+calendar_config_get_month_scroll_by_week (void)
+{
+	calendar_config_init ();
+
+	return gconf_client_get_bool (config, CALENDAR_CONFIG_MONTH_SCROLL_BY_WEEK, NULL);
+}
+
+void
+calendar_config_set_month_scroll_by_week (gboolean value)
+{
+	calendar_config_init ();
+
+	gconf_client_set_bool (config, CALENDAR_CONFIG_MONTH_SCROLL_BY_WEEK, value, NULL);
+}
+
+guint
+calendar_config_add_notification_month_scroll_by_week (GConfClientNotifyFunc func, gpointer data)
+{
+	guint id;
+
+	calendar_config_init ();
+
+	id = gconf_client_notify_add (config, CALENDAR_CONFIG_MONTH_SCROLL_BY_WEEK, func, data, NULL, NULL);
+
+	return id;
+}
+
 /* Whether we show the Marcus Bains Line (current time), and in what colors. */
 void
-calendar_config_get_marcus_bains (gboolean *show_line, const char **dayview_color, const char **timebar_color)
+calendar_config_get_marcus_bains (gboolean *show_line, const gchar **dayview_color, const gchar **timebar_color)
 {
-	static char *dcolor = NULL, *tcolor = NULL;
+	static gchar *dcolor = NULL, *tcolor = NULL;
 
 	calendar_config_init ();
 
@@ -855,7 +808,7 @@ calendar_config_set_month_vpane_pos	(gint	      vpane_pos)
 	gconf_client_set_int (config, CALENDAR_CONFIG_MONTH_VPANE_POS, vpane_pos, NULL);
 }
 
-float
+gfloat
 calendar_config_get_tag_vpane_pos	(void)
 {
 	calendar_config_init ();
@@ -865,7 +818,7 @@ calendar_config_get_tag_vpane_pos	(void)
 
 
 void
-calendar_config_set_tag_vpane_pos	(float	      vpane_pos)
+calendar_config_set_tag_vpane_pos	(gfloat	      vpane_pos)
 {
 	calendar_config_init ();
 
@@ -902,7 +855,7 @@ calendar_config_add_notification_tasks_selected (GConfClientNotifyFunc func, gpo
 }
 
 /* The primary task list */
-char *
+gchar *
 calendar_config_get_primary_tasks (void)
 {
 	calendar_config_init ();
@@ -911,7 +864,7 @@ calendar_config_get_primary_tasks (void)
 }
 
 void
-calendar_config_set_primary_tasks (const char *primary_uid)
+calendar_config_set_primary_tasks (const gchar *primary_uid)
 {
 	calendar_config_init ();
 
@@ -980,7 +933,7 @@ calendar_config_add_notification_memos_selected (GConfClientNotifyFunc func, gpo
 }
 
 /* The primary memo list */
-char *
+gchar *
 calendar_config_get_primary_memos (void)
 {
 	calendar_config_init ();
@@ -989,7 +942,7 @@ calendar_config_get_primary_memos (void)
 }
 
 void
-calendar_config_set_primary_memos (const char *primary_uid)
+calendar_config_set_primary_memos (const gchar *primary_uid)
 {
 	calendar_config_init ();
 
@@ -1133,7 +1086,7 @@ calendar_config_add_notification_hide_completed_tasks (GConfClientNotifyFunc fun
 CalUnits
 calendar_config_get_hide_completed_tasks_units	(void)
 {
-	char *units;
+	gchar *units;
 	CalUnits cu;
 
 	calendar_config_init ();
@@ -1156,7 +1109,7 @@ calendar_config_get_hide_completed_tasks_units	(void)
 void
 calendar_config_set_hide_completed_tasks_units	(CalUnits	cu)
 {
-	char *units;
+	gchar *units;
 
 	calendar_config_init ();
 
@@ -1431,7 +1384,7 @@ calendar_config_set_use_default_reminder (gboolean value)
  *
  * Return value: Interval for default reminders.
  **/
-int
+gint
 calendar_config_get_default_reminder_interval (void)
 {
 	calendar_config_init ();
@@ -1447,7 +1400,7 @@ calendar_config_get_default_reminder_interval (void)
  * appointments.
  **/
 void
-calendar_config_set_default_reminder_interval (int interval)
+calendar_config_set_default_reminder_interval (gint interval)
 {
 	calendar_config_init ();
 
@@ -1465,7 +1418,7 @@ calendar_config_set_default_reminder_interval (int interval)
 CalUnits
 calendar_config_get_default_reminder_units (void)
 {
-	char *units;
+	gchar *units;
 	CalUnits cu;
 
 	calendar_config_init ();
@@ -1502,7 +1455,7 @@ calendar_config_set_default_reminder_units (CalUnits units)
  * are retrieved even when returns FALSE.
  **/
 gboolean
-calendar_config_get_ba_reminder (int *interval, CalUnits *units)
+calendar_config_get_ba_reminder (gint *interval, CalUnits *units)
 {
 	calendar_config_init ();
 
@@ -1511,7 +1464,7 @@ calendar_config_get_ba_reminder (int *interval, CalUnits *units)
 	}
 
 	if (units) {
-		char *str;
+		gchar *str;
 
 		str = gconf_client_get_string (config, CALENDAR_CONFIG_BA_REMINDER_UNITS, NULL);
 		*units = string_to_units (str);
@@ -1530,7 +1483,7 @@ calendar_config_get_ba_reminder (int *interval, CalUnits *units)
  * @units: The units of the reminder; can be NULL.
  **/
 void
-calendar_config_set_ba_reminder (gboolean *enabled, int *interval, CalUnits *units)
+calendar_config_set_ba_reminder (gboolean *enabled, gint *interval, CalUnits *units)
 {
 	calendar_config_init ();
 
@@ -1552,10 +1505,10 @@ calendar_config_set_ba_reminder (gboolean *enabled, int *interval, CalUnits *uni
  * Returns the subexpression to use to filter out completed tasks according
  * to the config settings. The returned sexp should be freed.
  **/
-char*
+gchar *
 calendar_config_get_hide_completed_tasks_sexp (gboolean get_completed)
 {
-	char *sexp = NULL;
+	gchar *sexp = NULL;
 
 	if (calendar_config_get_hide_completed_tasks ()) {
 		CalUnits units;
@@ -1572,7 +1525,7 @@ calendar_config_get_hide_completed_tasks_sexp (gboolean get_completed)
 			else
 				sexp = g_strdup ("(is-completed?)");
 		} else {
-			char *isodate;
+			gchar *isodate;
 			icaltimezone *zone;
 			struct icaltimetype tt;
 			time_t t;
@@ -1650,10 +1603,10 @@ calendar_config_set_dir_path (const gchar *path)
 	gconf_client_set_string (config, CALENDAR_CONFIG_SAVE_DIR, path, NULL);
 }
 
-char *
+gchar *
 calendar_config_get_dir_path (void)
 {
-	char *path;
+	gchar *path;
 
 	calendar_config_init ();
 
@@ -1688,14 +1641,14 @@ calendar_config_free_day_second_zones (GSList *zones)
 
 /* keeps max 'day_second_zones_max' zones, if 'location' is already in a list, then it'll became first there */
 void
-calendar_config_set_day_second_zone (const char *location)
+calendar_config_set_day_second_zone (const gchar *location)
 {
 	calendar_config_init ();
 
 	if (location && *location) {
 		GSList *lst, *l;
 		GError *error = NULL;
-		int max_zones;
+		gint max_zones;
 
 		/* configurable max number of timezones to remember */
 		max_zones = gconf_client_get_int (config, CALENDAR_CONFIG_DAY_SECOND_ZONES_MAX, &error);
@@ -1713,7 +1666,7 @@ calendar_config_set_day_second_zone (const char *location)
 			if (l->data && g_str_equal (l->data, location)) {
 				if (l != lst) {
 					/* isn't first in the list */
-					char *val = l->data;
+					gchar *val = l->data;
 
 					lst = g_slist_remove (lst, val);
 					lst = g_slist_prepend (lst, val);
@@ -1742,7 +1695,7 @@ calendar_config_set_day_second_zone (const char *location)
 }
 
 /* location of the second time zone user has selected. Free with g_free. */
-char *
+gchar *
 calendar_config_get_day_second_zone (void)
 {
 	calendar_config_init ();
@@ -1756,7 +1709,7 @@ calendar_config_select_day_second_zone (void)
 	icaltimezone *zone = NULL;
 	ETimezoneDialog *tzdlg;
 	GtkWidget *dialog;
-	char *second_location;
+	gchar *second_location;
 
 	second_location = calendar_config_get_day_second_zone ();
 	if (second_location && *second_location)
@@ -1772,8 +1725,16 @@ calendar_config_select_day_second_zone (void)
 	dialog = e_timezone_dialog_get_toplevel (tzdlg);
 
 	if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT) {
+		const gchar *location = NULL;
+
 		zone = e_timezone_dialog_get_timezone (tzdlg);
-		calendar_config_set_day_second_zone (zone ? icaltimezone_get_location (zone) : NULL);
+		if (zone == icaltimezone_get_utc_timezone ()) {
+			location = "UTC";
+		} else if (zone) {
+			location = icaltimezone_get_location (zone);
+		}
+
+		calendar_config_set_day_second_zone (location);
 	}
 
 	g_object_unref (tzdlg);
