@@ -1,21 +1,25 @@
-/* Evolution calendar - Component editor factory object
- *
- * Copyright (C) 2001 Ximian, Inc.
- *
- * Authors: Federico Mena-Quintero <federico@ximian.com>
+/*
+ * Evolution calendar - Component editor factory object
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
+ *
+ * Authors:
+ *		Federico Mena-Quintero <federico@ximian.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -52,7 +56,7 @@ typedef struct {
 
 	union {
 		struct {
-			char *uid;
+			gchar *uid;
 		} existing;
 
 		struct {
@@ -67,13 +71,13 @@ typedef struct {
 	CompEditorFactory *factory;
 
 	/* Uri of the calendar, used as key in the clients hash table */
-	char *uri;
+	gchar *uri;
 
 	/* Client of the calendar */
 	ECal *client;
 
 	/* Count editors using this client */
-	int editor_count;
+	gint editor_count;
 
 	/* Pending requests; they are pending if the client is still being opened */
 	GSList *pending;
@@ -228,7 +232,7 @@ editor_destroy_cb (GtkObject *object, gpointer data)
 
 /* Starts editing an existing component on a client that is already open */
 static void
-edit_existing (OpenClient *oc, const char *uid)
+edit_existing (OpenClient *oc, const gchar *uid)
 {
 	ECalComponent *comp;
 	icalcomponent *icalcomp;
@@ -265,7 +269,7 @@ edit_existing (OpenClient *oc, const char *uid)
 		if (e_cal_component_has_attendees (comp))
 			flags |= COMP_EDITOR_MEETING;
 
-		editor = COMP_EDITOR (event_editor_new (oc->client, flags));
+		editor = event_editor_new (oc->client, flags);
 		break;
 
 	case E_CAL_COMPONENT_TODO:
@@ -273,14 +277,14 @@ edit_existing (OpenClient *oc, const char *uid)
 		break;
 
 	default:
-		g_message ("edit_exiting(): Unsupported object type %d", (int) vtype);
+		g_message ("edit_exiting(): Unsupported object type %d", (gint) vtype);
 		g_object_unref (comp);
 		return;
 	}
 
 	/* Set the object on the editor */
 	comp_editor_edit_comp (editor, comp);
-	comp_editor_focus (editor);
+	gtk_window_present (GTK_WINDOW (editor));
 	g_object_unref (comp);
 
 	oc->editor_count++;
@@ -308,15 +312,15 @@ edit_new (OpenClient *oc, const GNOME_Evolution_Calendar_CompEditorFactory_CompE
 
 	switch (type) {
 	case GNOME_Evolution_Calendar_CompEditorFactory_EDITOR_MODE_EVENT:
-		editor = COMP_EDITOR (event_editor_new (oc->client, FALSE));
+		editor = event_editor_new (oc->client, FALSE);
 		comp = cal_comp_event_new_with_current_time (oc->client, FALSE);
 		break;
 	case GNOME_Evolution_Calendar_CompEditorFactory_EDITOR_MODE_MEETING:
-		editor = COMP_EDITOR (event_editor_new (oc->client, TRUE));
+		editor = event_editor_new (oc->client, TRUE);
 		comp = cal_comp_event_new_with_current_time (oc->client, FALSE);
 		break;
 	case GNOME_Evolution_Calendar_CompEditorFactory_EDITOR_MODE_ALLDAY_EVENT:
-		editor = COMP_EDITOR (event_editor_new (oc->client, FALSE));
+		editor = event_editor_new (oc->client, FALSE);
 		comp = cal_comp_event_new_with_current_time (oc->client, TRUE);
 		break;
 	case GNOME_Evolution_Calendar_CompEditorFactory_EDITOR_MODE_TODO:
@@ -331,7 +335,7 @@ edit_new (OpenClient *oc, const GNOME_Evolution_Calendar_CompEditorFactory_CompE
 	comp_editor_edit_comp (editor, comp);
 	if (type == GNOME_Evolution_Calendar_CompEditorFactory_EDITOR_MODE_MEETING)
 		event_editor_show_meeting (EVENT_EDITOR (editor));
-	comp_editor_focus (editor);
+	gtk_window_present (GTK_WINDOW (editor));
 
 	oc->editor_count++;
 	g_signal_connect (editor, "destroy", G_CALLBACK (editor_destroy_cb), oc);
@@ -417,6 +421,12 @@ cal_opened_cb (ECal *client, ECalendarStatus status, gpointer data)
 						 "%s", _("Permission denied to open the calendar"));
 		break;
 
+	case E_CALENDAR_STATUS_AUTHENTICATION_REQUIRED:
+		dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL,
+						 GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE,
+						 "%s", _("Authentication Required"));
+		break;
+
 	case E_CALENDAR_STATUS_AUTHENTICATION_FAILED :
 		dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL,
 						 GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE,
@@ -441,7 +451,7 @@ cal_opened_cb (ECal *client, ECalendarStatus status, gpointer data)
  * open request.
  */
 static OpenClient *
-open_client (CompEditorFactory *factory, ECalSourceType source_type, const char *uristr)
+open_client (CompEditorFactory *factory, ECalSourceType source_type, const gchar *uristr)
 {
 	CompEditorFactoryPrivate *priv;
 	ECal *client;
@@ -485,7 +495,7 @@ open_client (CompEditorFactory *factory, ECalSourceType source_type, const char
  * NULL on failure; in the latter case it sets the ev exception.
  */
 static OpenClient *
-lookup_open_client (CompEditorFactory *factory, ECalSourceType source_type, const char *str_uri, CORBA_Environment *ev)
+lookup_open_client (CompEditorFactory *factory, ECalSourceType source_type, const gchar *str_uri, CORBA_Environment *ev)
 {
 	CompEditorFactoryPrivate *priv;
 	OpenClient *oc;
@@ -516,7 +526,7 @@ lookup_open_client (CompEditorFactory *factory, ECalSourceType source_type, cons
 
 /* Queues a request for editing an existing object */
 static void
-queue_edit_existing (OpenClient *oc, const char *uid)
+queue_edit_existing (OpenClient *oc, const gchar *uid)
 {
 	Request *request;
 
@@ -566,7 +576,7 @@ impl_editExisting (PortableServer_Servant servant,
 	if (editor == NULL) {
 		edit_existing (oc, uid);
 	} else {
-		comp_editor_focus (editor);
+		gtk_window_present (GTK_WINDOW (editor));
 	}
 }
 
