@@ -1,24 +1,28 @@
-/* Evolution calendar - task details page
- *
- * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
- *
- * Authors: Federico Mena-Quintero <federico@ximian.com>
- *          Miguel de Icaza <miguel@ximian.com>
- *          Seth Alves <alves@hungry.com>
- *          JP Rosevear <jpr@ximian.com>
+/*
+ * Evolution calendar - task details page
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
+ *
+ * Authors:
+ *		Federico Mena-Quintero <federico@ximian.com>
+ *      Miguel de Icaza <miguel@ximian.com>
+ *      Seth Alves <alves@hungry.com>
+ *      JP Rosevear <jpr@ximian.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -48,8 +52,8 @@ struct _TaskDetailsPagePrivate {
 	/* Widgets from the Glade file */
 	GtkWidget *main;
 
-	GtkWidget *status;
-	GtkWidget *priority;
+	GtkWidget *status_combo;
+	GtkWidget *priority_combo;
 	GtkWidget *percent_complete;
 
 	GtkWidget *date_completed_label;
@@ -61,7 +65,7 @@ struct _TaskDetailsPagePrivate {
 };
 
 /* Note that these two arrays must match. */
-static const int status_map[] = {
+static const gint status_map[] = {
 	ICAL_STATUS_NONE,
 	ICAL_STATUS_INPROCESS,
 	ICAL_STATUS_COMPLETED,
@@ -73,10 +77,10 @@ typedef enum {
 	PRIORITY_HIGH,
 	PRIORITY_NORMAL,
 	PRIORITY_LOW,
-	PRIORITY_UNDEFINED,
+	PRIORITY_UNDEFINED
 } TaskEditorPriority;
 
-static const int priority_map[] = {
+static const gint priority_map[] = {
 	PRIORITY_HIGH,
 	PRIORITY_NORMAL,
 	PRIORITY_LOW,
@@ -161,12 +165,12 @@ task_details_page_focus_main_widget (CompEditorPage *page)
 	tdpage = TASK_DETAILS_PAGE (page);
 	priv = tdpage->priv;
 
-	gtk_widget_grab_focus (priv->status);
+	gtk_widget_grab_focus (priv->status_combo);
 }
 
 
 static TaskEditorPriority
-priority_value_to_index (int priority_value)
+priority_value_to_index (gint priority_value)
 {
 	TaskEditorPriority retval;
 
@@ -182,10 +186,10 @@ priority_value_to_index (int priority_value)
 	return retval;
 }
 
-static int
+static gint
 priority_index_to_value (TaskEditorPriority priority)
 {
-	int retval;
+	gint retval;
 
 	switch (priority) {
 	case PRIORITY_UNDEFINED:
@@ -237,8 +241,8 @@ sensitize_widgets (TaskDetailsPage *tdpage)
 	if (!e_cal_is_read_only (client, &read_only, NULL))
 		read_only = TRUE;
 
-	gtk_widget_set_sensitive (priv->status, !read_only);
-	gtk_widget_set_sensitive (priv->priority, !read_only);
+	gtk_widget_set_sensitive (priv->status_combo, !read_only);
+	gtk_widget_set_sensitive (priv->priority_combo, !read_only);
 	gtk_widget_set_sensitive (priv->percent_complete, !read_only);
 	gtk_widget_set_sensitive (priv->completed_date, !read_only);
 	gtk_widget_set_sensitive (priv->url_label, !read_only);
@@ -251,10 +255,10 @@ task_details_page_fill_widgets (CompEditorPage *page, ECalComponent *comp)
 {
 	TaskDetailsPage *tdpage;
 	TaskDetailsPagePrivate *priv;
-	int *priority_value, *percent = NULL;
+	gint *priority_value, *percent = NULL;
 	TaskEditorPriority priority;
 	icalproperty_status status;
-	const char *url;
+	const gchar *url;
 	struct icaltimetype *completed = NULL;
 
 	tdpage = TASK_DETAILS_PAGE (page);
@@ -286,7 +290,7 @@ task_details_page_fill_widgets (CompEditorPage *page, ECalComponent *comp)
 		} else
 			status = ICAL_STATUS_NONE;
 	}
-	e_dialog_option_menu_set (priv->status, status, status_map);
+	e_dialog_combo_box_set (priv->status_combo, status, status_map);
 
 	if (percent)
 		e_cal_component_free_percent (percent);
@@ -321,7 +325,7 @@ task_details_page_fill_widgets (CompEditorPage *page, ECalComponent *comp)
 	} else {
 		priority = PRIORITY_UNDEFINED;
 	}
-	e_dialog_option_menu_set (priv->priority, priority, priority_map);
+	e_dialog_combo_box_set (priv->priority_combo, priority, priority_map);
 
 	/* URL */
 	e_cal_component_get_url (comp, &url);
@@ -341,8 +345,8 @@ task_details_page_fill_component (CompEditorPage *page, ECalComponent *comp)
 	struct icaltimetype icalcomplete, icaltoday;
 	icalproperty_status status;
 	TaskEditorPriority priority;
-	int priority_value, percent;
-	char *url;
+	gint priority_value, percent;
+	gchar *url;
 	gboolean date_set;
 	icaltimezone *zone = calendar_config_get_icaltimezone ();
 
@@ -354,11 +358,11 @@ task_details_page_fill_component (CompEditorPage *page, ECalComponent *comp)
 	e_cal_component_set_percent (comp, &percent);
 
 	/* Status. */
-	status = e_dialog_option_menu_get (priv->status, status_map);
+	status = e_dialog_combo_box_get (priv->status_combo, status_map);
 	e_cal_component_set_status (comp, status);
 
 	/* Priority. */
-	priority = e_dialog_option_menu_get (priv->priority, priority_map);
+	priority = e_dialog_combo_box_get (priv->priority_combo, priority_map);
 	priority_value = priority_index_to_value (priority);
 	e_cal_component_set_priority (comp, &priority_value);
 
@@ -426,7 +430,7 @@ task_details_page_fill_timezones (CompEditorPage *page, GHashTable *timezones)
 	zone = icaltimezone_get_utc_timezone ();
 	if (zone) {
 		if (!g_hash_table_lookup (timezones, icaltimezone_get_tzid (zone)))
-			g_hash_table_insert (timezones, icaltimezone_get_tzid (zone), zone);
+			g_hash_table_insert (timezones, (gpointer) icaltimezone_get_tzid (zone), zone);
 	}
 
 	return TRUE;
@@ -461,8 +465,8 @@ get_widgets (TaskDetailsPage *tdpage)
 	g_object_ref (priv->main);
 	gtk_container_remove (GTK_CONTAINER (priv->main->parent), priv->main);
 
-	priv->status = GW ("status");
-	priv->priority = GW ("priority");
+	priv->status_combo = GW ("status-combobox");
+	priv->priority_combo = GW ("priority-combobox");
 	priv->percent_complete = GW ("percent-complete");
 
 	priv->date_completed_label = GW ("date_completed_label");
@@ -479,8 +483,8 @@ get_widgets (TaskDetailsPage *tdpage)
 
 #undef GW
 
-	return (priv->status
-		&& priv->priority
+	return (priv->status_combo
+		&& priv->priority_combo
 		&& priv->percent_complete
 		&& priv->date_completed_label
 		&& priv->completed_date
@@ -538,19 +542,19 @@ date_changed_cb (EDateEdit *dedit, gpointer data)
 				     &completed_tt.hour,
 				     &completed_tt.minute);
 
-	status = e_dialog_option_menu_get (priv->status, status_map);
+	status = e_dialog_combo_box_get (priv->status_combo, status_map);
 
 	if (!date_set) {
 		completed_tt = icaltime_null_time ();
 		if (status == ICAL_STATUS_COMPLETED) {
-			e_dialog_option_menu_set (priv->status,
+			e_dialog_combo_box_set (priv->status_combo,
 						  ICAL_STATUS_NONE,
 						  status_map);
 			e_dialog_spin_set (priv->percent_complete, 0);
 		}
 	} else {
 		if (status != ICAL_STATUS_COMPLETED) {
-			e_dialog_option_menu_set (priv->status,
+			e_dialog_combo_box_set (priv->status_combo,
 						  ICAL_STATUS_COMPLETED,
 						  status_map);
 		}
@@ -565,7 +569,7 @@ date_changed_cb (EDateEdit *dedit, gpointer data)
 }
 
 static void
-status_changed (GtkMenu	*menu, TaskDetailsPage *tdpage)
+status_changed (GtkWidget *combo, TaskDetailsPage *tdpage)
 {
 	TaskDetailsPagePrivate *priv;
 	icalproperty_status status;
@@ -581,7 +585,7 @@ status_changed (GtkMenu	*menu, TaskDetailsPage *tdpage)
 
 	comp_editor_page_set_updating (COMP_EDITOR_PAGE (tdpage), TRUE);
 
-	status = e_dialog_option_menu_get (priv->status, status_map);
+	status = e_dialog_combo_box_get (priv->status_combo, status_map);
 	if (status == ICAL_STATUS_NONE) {
 		e_dialog_spin_set (priv->percent_complete, 0);
 		e_date_edit_set_time (E_DATE_EDIT (priv->completed_date), ctime);
@@ -638,7 +642,7 @@ percent_complete_changed (GtkAdjustment	*adj, TaskDetailsPage *tdpage)
 			status = ICAL_STATUS_INPROCESS;
 	}
 
-	e_dialog_option_menu_set (priv->status, status, status_map);
+	e_dialog_combo_box_set (priv->status_combo, status, status_map);
 	e_date_edit_set_time (E_DATE_EDIT (priv->completed_date), ctime);
 	complete_date_changed (tdpage, ctime, complete);
 
@@ -668,8 +672,8 @@ init_widgets (TaskDetailsPage *tdpage)
 	/* Connect signals. The Status, Percent Complete & Date Completed
 	   properties are closely related so whenever one changes we may need
 	   to update the other 2. */
-	g_signal_connect((GTK_OPTION_MENU (priv->status)->menu),
-			    "deactivate",
+	g_signal_connect (GTK_COMBO_BOX (priv->status_combo),
+			    "changed",
 			    G_CALLBACK (status_changed), tdpage);
 
 	g_signal_connect((GTK_SPIN_BUTTON (priv->percent_complete)->adjustment),
@@ -678,7 +682,7 @@ init_widgets (TaskDetailsPage *tdpage)
 
 	/* Priority */
 	g_signal_connect_swapped (
-		GTK_OPTION_MENU (priv->priority)->menu, "deactivate",
+		GTK_COMBO_BOX (priv->priority_combo), "changed",
 		G_CALLBACK (comp_editor_page_changed), tdpage);
 
 	/* Completed Date */
@@ -709,7 +713,7 @@ task_details_page_construct (TaskDetailsPage *tdpage)
 {
 	TaskDetailsPagePrivate *priv = tdpage->priv;
 	CompEditor *editor;
-	char *gladefile;
+	gchar *gladefile;
 
 	editor = comp_editor_page_get_editor (COMP_EDITOR_PAGE (tdpage));
 
