@@ -12,7 +12,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -302,7 +302,7 @@ static void
 task_editor_init (TaskEditor *te)
 {
 	CompEditor *editor = COMP_EDITOR (te);
-	GtkUIManager *manager;
+	GtkUIManager *ui_manager;
 	GtkActionGroup *action_group;
 	GError *error = NULL;
 
@@ -344,9 +344,9 @@ task_editor_init (TaskEditor *te)
 		action_group, assigned_task_entries,
 		G_N_ELEMENTS (assigned_task_entries), te);
 
-	manager = comp_editor_get_ui_manager (editor);
-	gtk_ui_manager_add_ui_from_string (manager, ui, -1, &error);
-	e_plugin_ui_register_manager ("task-editor", manager, te);
+	ui_manager = comp_editor_get_ui_manager (editor);
+	gtk_ui_manager_add_ui_from_string (ui_manager, ui, -1, &error);
+	e_plugin_ui_register_manager ("task-editor", ui_manager, te);
 
 	if (error != NULL) {
 		g_critical ("%s: %s", G_STRFUNC, error->message);
@@ -391,7 +391,7 @@ task_editor_edit_comp (CompEditor *editor, ECalComponent *comp)
 
 	if (attendees != NULL) {
 		GSList *l;
-		int row;
+		gint row;
 
 		task_page_hide_options (priv->task_page);
 		task_page_set_assignment (priv->task_page, TRUE);
@@ -403,7 +403,7 @@ task_editor_edit_comp (CompEditor *editor, ECalComponent *comp)
 			ia = E_MEETING_ATTENDEE (e_meeting_attendee_new_from_e_cal_component_attendee (ca));
 			/* If we aren't the organizer or the attendee is just delegating, don't allow editing */
 			if (!comp_editor_get_user_org (editor) || e_meeting_attendee_is_set_delto (ia))
- 				e_meeting_attendee_set_edit_level (ia,  E_MEETING_ATTENDEE_EDIT_NONE);
+				e_meeting_attendee_set_edit_level (ia,  E_MEETING_ATTENDEE_EDIT_NONE);
 			task_page_add_attendee (priv->task_page, ia);
 
 			g_object_unref (ia);
