@@ -1,21 +1,25 @@
-/* Evolution calendar - Data model for ETable
- *
- * Copyright (C) 2004 Ximian, Inc.
- *
- * Authors: Rodrigo Moya <rodrigo@ximian.com>
+/*
+ * Evolution calendar - Data model for ETable
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
+ *
+ * Authors:
+ *		Rodrigo Moya <rodrigo@ximian.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -36,15 +40,15 @@ struct _ECalModelCalendarPrivate {
 };
 
 static void e_cal_model_calendar_finalize (GObject *object);
-static int ecmc_column_count (ETableModel *etm);
-static void *ecmc_value_at (ETableModel *etm, int col, int row);
-static void ecmc_set_value_at (ETableModel *etm, int col, int row, const void *value);
-static gboolean ecmc_is_cell_editable (ETableModel *etm, int col, int row);
-static void *ecmc_duplicate_value (ETableModel *etm, int col, const void *value);
-static void ecmc_free_value (ETableModel *etm, int col, void *value);
-static void *ecmc_initialize_value (ETableModel *etm, int col);
-static gboolean ecmc_value_is_empty (ETableModel *etm, int col, const void *value);
-static char *ecmc_value_to_string (ETableModel *etm, int col, const void *value);
+static gint ecmc_column_count (ETableModel *etm);
+static gpointer ecmc_value_at (ETableModel *etm, gint col, gint row);
+static void ecmc_set_value_at (ETableModel *etm, gint col, gint row, gconstpointer value);
+static gboolean ecmc_is_cell_editable (ETableModel *etm, gint col, gint row);
+static gpointer ecmc_duplicate_value (ETableModel *etm, gint col, gconstpointer value);
+static void ecmc_free_value (ETableModel *etm, gint col, gpointer value);
+static gpointer ecmc_initialize_value (ETableModel *etm, gint col);
+static gboolean ecmc_value_is_empty (ETableModel *etm, gint col, gconstpointer value);
+static gchar *ecmc_value_to_string (ETableModel *etm, gint col, gconstpointer value);
 
 static void ecmc_fill_component_from_model (ECalModel *model, ECalModelComponent *comp_data,
 					    ETableModel *source_model, gint row);
@@ -103,7 +107,7 @@ e_cal_model_calendar_finalize (GObject *object)
 }
 
 /* ETableModel methods */
-static int
+static gint
 ecmc_column_count (ETableModel *etm)
 {
 	return E_CAL_MODEL_CALENDAR_FIELD_LAST;
@@ -137,7 +141,7 @@ get_dtend (ECalModelCalendar *model, ECalModelComponent *comp_data)
 				if (model_zone)
 					icaltimezone_convert_time (&tt_end, zone, model_zone);
 			} else
-				tt_end = icaltime_from_timet_with_zone (comp_data->instance_end, tt_end.is_date, 
+				tt_end = icaltime_from_timet_with_zone (comp_data->instance_end, tt_end.is_date,
 						model_zone);
 		}
 
@@ -156,19 +160,19 @@ get_dtend (ECalModelCalendar *model, ECalModelComponent *comp_data)
 	return comp_data->dtend;
 }
 
-static void *
+static gpointer
 get_location (ECalModelComponent *comp_data)
 {
 	icalproperty *prop;
 
 	prop = icalcomponent_get_first_property (comp_data->icalcomp, ICAL_LOCATION_PROPERTY);
 	if (prop)
-		return (void *) icalproperty_get_location (prop);
+		return (gpointer) icalproperty_get_location (prop);
 
-	return "";
+	return (gpointer) "";
 }
 
-static void *
+static gpointer
 get_transparency (ECalModelComponent *comp_data)
 {
 	icalproperty *prop;
@@ -189,8 +193,8 @@ get_transparency (ECalModelComponent *comp_data)
 	return NULL;
 }
 
-static void *
-ecmc_value_at (ETableModel *etm, int col, int row)
+static gpointer
+ecmc_value_at (ETableModel *etm, gint col, gint row)
 {
 	ECalModelComponent *comp_data;
 	ECalModelCalendar *model = (ECalModelCalendar *) etm;
@@ -205,7 +209,7 @@ ecmc_value_at (ETableModel *etm, int col, int row)
 
 	comp_data = e_cal_model_get_component_at (E_CAL_MODEL (model), row);
 	if (!comp_data)
-		return "";
+		return (gpointer) "";
 
 	switch (col) {
 	case E_CAL_MODEL_CALENDAR_FIELD_DTEND :
@@ -216,17 +220,17 @@ ecmc_value_at (ETableModel *etm, int col, int row)
 		return get_transparency (comp_data);
 	}
 
-	return "";
+	return (gpointer) "";
 }
 
 static void
-set_dtend (ECalModelComponent *comp_data, const void *value)
+set_dtend (ECalModelComponent *comp_data, gconstpointer value)
 {
 	ECellDateEditValue *dv = (ECellDateEditValue *) value;
 	icalproperty *prop;
 	icalparameter *param;
-	const char *tzid;
-	
+	const gchar *tzid;
+
 	prop = icalcomponent_get_first_property (comp_data->icalcomp, ICAL_DTEND_PROPERTY);
 	if (prop)
 		param = icalproperty_get_first_parameter (prop, ICAL_TZID_PARAMETER);
@@ -243,7 +247,7 @@ set_dtend (ECalModelComponent *comp_data, const void *value)
 
 		return;
 	}
-	
+
 	/* If the TZID is set to "UTC", we set the is_utc flag. */
 	tzid = dv->zone ? icaltimezone_get_tzid (dv->zone) : "UTC";
 	if (tzid && !strcmp (tzid, "UTC"))
@@ -261,9 +265,9 @@ set_dtend (ECalModelComponent *comp_data, const void *value)
 	/* If the TZID is set to "UTC", we don't want to save the TZID. */
 	if (tzid && strcmp (tzid, "UTC")) {
 		if (param) {
-			icalparameter_set_tzid (param, (char *) tzid);
+			icalparameter_set_tzid (param, (gchar *) tzid);
 		} else {
-			param = icalparameter_new_tzid ((char *) tzid);
+			param = icalparameter_new_tzid ((gchar *) tzid);
 			icalproperty_add_parameter (prop, param);
 		}
 	} else if (param) {
@@ -272,7 +276,7 @@ set_dtend (ECalModelComponent *comp_data, const void *value)
 }
 
 static void
-set_location (ECalModelComponent *comp_data, const void *value)
+set_location (ECalModelComponent *comp_data, gconstpointer value)
 {
 	icalproperty *prop;
 
@@ -285,16 +289,16 @@ set_location (ECalModelComponent *comp_data, const void *value)
 		}
 	} else {
 		if (prop)
-			icalproperty_set_location (prop, (const char *) value);
+			icalproperty_set_location (prop, (const gchar *) value);
 		else {
-			prop = icalproperty_new_location ((const char *) value);
+			prop = icalproperty_new_location ((const gchar *) value);
 			icalcomponent_add_property (comp_data->icalcomp, prop);
 		}
 	}
 }
 
 static void
-set_transparency (ECalModelComponent *comp_data, const void *value)
+set_transparency (ECalModelComponent *comp_data, gconstpointer value)
 {
 	icalproperty *prop;
 
@@ -331,7 +335,7 @@ set_transparency (ECalModelComponent *comp_data, const void *value)
 }
 
 static void
-ecmc_set_value_at (ETableModel *etm, int col, int row, const void *value)
+ecmc_set_value_at (ETableModel *etm, gint col, gint row, gconstpointer value)
 {
 	ECalModelComponent *comp_data;
 	CalObjModType mod = CALOBJ_MOD_ALL;
@@ -377,14 +381,38 @@ ecmc_set_value_at (ETableModel *etm, int col, int row, const void *value)
 		break;
 	}
 
-	if (e_cal_modify_object (comp_data->client, comp_data->icalcomp, CALOBJ_MOD_ALL, NULL)) {
+	if (e_cal_modify_object (comp_data->client, comp_data->icalcomp, mod, NULL)) {
+		gboolean strip_alarms = TRUE;
+
 		if (itip_organizer_is_user (comp, comp_data->client) &&
-		    send_component_dialog (NULL, comp_data->client, comp, FALSE))
-			itip_send_comp (E_CAL_COMPONENT_METHOD_REQUEST, comp,
-					comp_data->client, NULL, NULL, NULL);
+		    send_component_dialog (NULL, comp_data->client, comp, FALSE, &strip_alarms)) {
+			ECalComponent *send_comp = NULL;
+
+			if (mod == CALOBJ_MOD_ALL && e_cal_component_is_instance (comp)) {
+				/* Ensure we send the master object, not the instance only */
+				icalcomponent *icalcomp = NULL;
+				const gchar *uid = NULL;
+
+				e_cal_component_get_uid (comp, &uid);
+				if (e_cal_get_object (comp_data->client, uid, NULL, &icalcomp, NULL) && icalcomp) {
+					send_comp = e_cal_component_new ();
+					if (!e_cal_component_set_icalcomponent (send_comp, icalcomp)) {
+						icalcomponent_free (icalcomp);
+						g_object_unref (send_comp);
+						send_comp = NULL;
+					}
+				}
+			}
+
+			itip_send_comp (E_CAL_COMPONENT_METHOD_REQUEST, send_comp ? send_comp : comp,
+					comp_data->client, NULL, NULL, NULL, strip_alarms);
+
+			if (send_comp)
+				g_object_unref (send_comp);
+		}
 	} else {
 		g_warning (G_STRLOC ": Could not modify the object!");
-		
+
 		/* FIXME Show error dialog */
 	}
 
@@ -392,7 +420,7 @@ ecmc_set_value_at (ETableModel *etm, int col, int row, const void *value)
 }
 
 static gboolean
-ecmc_is_cell_editable (ETableModel *etm, int col, int row)
+ecmc_is_cell_editable (ETableModel *etm, gint col, gint row)
 {
 	ECalModelCalendar *model = (ECalModelCalendar *) etm;
 
@@ -403,6 +431,9 @@ ecmc_is_cell_editable (ETableModel *etm, int col, int row)
 	if (col < E_CAL_MODEL_FIELD_LAST)
 		return E_TABLE_MODEL_CLASS (e_cal_model_calendar_parent_class)->is_cell_editable (etm, col, row);
 
+	if (!e_cal_model_test_row_editable (E_CAL_MODEL (etm), row))
+		return FALSE;
+
 	switch (col) {
 	case E_CAL_MODEL_CALENDAR_FIELD_DTEND :
 	case E_CAL_MODEL_CALENDAR_FIELD_LOCATION :
@@ -413,8 +444,8 @@ ecmc_is_cell_editable (ETableModel *etm, int col, int row)
 	return FALSE;
 }
 
-static void *
-ecmc_duplicate_value (ETableModel *etm, int col, const void *value)
+static gpointer
+ecmc_duplicate_value (ETableModel *etm, gint col, gconstpointer value)
 {
 	g_return_val_if_fail (col >= 0 && col < E_CAL_MODEL_CALENDAR_FIELD_LAST, NULL);
 
@@ -442,7 +473,7 @@ ecmc_duplicate_value (ETableModel *etm, int col, const void *value)
 }
 
 static void
-ecmc_free_value (ETableModel *etm, int col, void *value)
+ecmc_free_value (ETableModel *etm, gint col, gpointer value)
 {
 	g_return_if_fail (col >= 0 && col < E_CAL_MODEL_CALENDAR_FIELD_LAST);
 
@@ -461,8 +492,8 @@ ecmc_free_value (ETableModel *etm, int col, void *value)
 	}
 }
 
-static void *
-ecmc_initialize_value (ETableModel *etm, int col)
+static gpointer
+ecmc_initialize_value (ETableModel *etm, gint col)
 {
 	g_return_val_if_fail (col >= 0 && col < E_CAL_MODEL_CALENDAR_FIELD_LAST, NULL);
 
@@ -481,7 +512,7 @@ ecmc_initialize_value (ETableModel *etm, int col)
 }
 
 static gboolean
-ecmc_value_is_empty (ETableModel *etm, int col, const void *value)
+ecmc_value_is_empty (ETableModel *etm, gint col, gconstpointer value)
 {
 	g_return_val_if_fail (col >= 0 && col < E_CAL_MODEL_CALENDAR_FIELD_LAST, TRUE);
 
@@ -499,8 +530,8 @@ ecmc_value_is_empty (ETableModel *etm, int col, const void *value)
 	return TRUE;
 }
 
-static char *
-ecmc_value_to_string (ETableModel *etm, int col, const void *value)
+static gchar *
+ecmc_value_to_string (ETableModel *etm, gint col, gconstpointer value)
 {
 	g_return_val_if_fail (col >= 0 && col < E_CAL_MODEL_CALENDAR_FIELD_LAST, g_strdup (""));
 
