@@ -12,7 +12,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -35,7 +35,7 @@
 #include "e-cal-model.h"
 #include "itip-utils.h"
 #include "misc.h"
-#include "e-calendar-marshal.h"
+#include "e-util/e-util.h"
 #include "calendar-config.h"
 
 typedef struct {
@@ -90,19 +90,19 @@ struct _ECalModelPrivate {
 static void e_cal_model_dispose (GObject *object);
 static void e_cal_model_finalize (GObject *object);
 
-static int ecm_column_count (ETableModel *etm);
-static int ecm_row_count (ETableModel *etm);
-static void *ecm_value_at (ETableModel *etm, int col, int row);
-static void ecm_set_value_at (ETableModel *etm, int col, int row, const void *value);
-static gboolean ecm_is_cell_editable (ETableModel *etm, int col, int row);
-static void ecm_append_row (ETableModel *etm, ETableModel *source, int row);
-static void *ecm_duplicate_value (ETableModel *etm, int col, const void *value);
-static void ecm_free_value (ETableModel *etm, int col, void *value);
-static void *ecm_initialize_value (ETableModel *etm, int col);
-static gboolean ecm_value_is_empty (ETableModel *etm, int col, const void *value);
-static char *ecm_value_to_string (ETableModel *etm, int col, const void *value);
+static gint ecm_column_count (ETableModel *etm);
+static gint ecm_row_count (ETableModel *etm);
+static gpointer ecm_value_at (ETableModel *etm, gint col, gint row);
+static void ecm_set_value_at (ETableModel *etm, gint col, gint row, gconstpointer value);
+static gboolean ecm_is_cell_editable (ETableModel *etm, gint col, gint row);
+static void ecm_append_row (ETableModel *etm, ETableModel *source, gint row);
+static gpointer ecm_duplicate_value (ETableModel *etm, gint col, gconstpointer value);
+static void ecm_free_value (ETableModel *etm, gint col, gpointer value);
+static gpointer ecm_initialize_value (ETableModel *etm, gint col);
+static gboolean ecm_value_is_empty (ETableModel *etm, gint col, gconstpointer value);
+static gchar *ecm_value_to_string (ETableModel *etm, gint col, gconstpointer value);
 
-static const char *ecm_get_color_for_component (ECalModel *model, ECalModelComponent *comp_data);
+static const gchar *ecm_get_color_for_component (ECalModel *model, ECalModelComponent *comp_data);
 
 static ECalModelClient *add_new_client (ECalModel *model, ECal *client, gboolean do_query);
 static ECalModelClient *find_client_data (ECalModel *model, ECal *client);
@@ -153,7 +153,7 @@ e_cal_model_class_init (ECalModelClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (ECalModelClass, time_range_changed),
 			      NULL, NULL,
-			      e_calendar_marshal_VOID__LONG_LONG,
+			      e_marshal_VOID__LONG_LONG,
 			      G_TYPE_NONE, 2, G_TYPE_LONG, G_TYPE_LONG);
 
 	signals[ROW_APPENDED] =
@@ -180,7 +180,7 @@ e_cal_model_class_init (ECalModelClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (ECalModelClass, cal_view_progress),
 			      NULL, NULL,
-	                      e_calendar_marshal_VOID__STRING_INT_INT,
+			      e_marshal_VOID__STRING_INT_INT,
 			      G_TYPE_NONE, 3, G_TYPE_STRING, G_TYPE_INT, G_TYPE_INT);
 	signals[CAL_VIEW_DONE] =
 		g_signal_new ("cal_view_done",
@@ -188,7 +188,7 @@ e_cal_model_class_init (ECalModelClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (ECalModelClass, cal_view_done),
 			      NULL, NULL,
-			      e_calendar_marshal_VOID__INT_INT,
+			      e_marshal_VOID__INT_INT,
 			      G_TYPE_NONE, 2, G_TYPE_INT, G_TYPE_INT);
 
 }
@@ -298,13 +298,13 @@ e_cal_model_finalize (GObject *object)
 
 /* ETableModel methods */
 
-static int
+static gint
 ecm_column_count (ETableModel *etm)
 {
 	return E_CAL_MODEL_FIELD_LAST;
 }
 
-static int
+static gint
 ecm_row_count (ETableModel *etm)
 {
 	ECalModelPrivate *priv;
@@ -317,19 +317,19 @@ ecm_row_count (ETableModel *etm)
 	return priv->objects->len;
 }
 
-static char *
+static gpointer
 get_categories (ECalModelComponent *comp_data)
 {
 	icalproperty *prop;
 
 	prop = icalcomponent_get_first_property (comp_data->icalcomp, ICAL_CATEGORIES_PROPERTY);
 	if (prop)
-		return (char *) icalproperty_get_categories (prop);
+		return (gpointer) icalproperty_get_categories (prop);
 
-	return "";
+	return (gpointer) "";
 }
 
-static char *
+static gchar *
 get_classification (ECalModelComponent *comp_data)
 {
 	icalproperty *prop;
@@ -355,7 +355,7 @@ get_classification (ECalModelComponent *comp_data)
 	}
 }
 
-static const char *
+static const gchar *
 get_color (ECalModel *model, ECalModelComponent *comp_data)
 {
 	g_return_val_if_fail (E_IS_CAL_MODEL (model), NULL);
@@ -363,7 +363,7 @@ get_color (ECalModel *model, ECalModelComponent *comp_data)
 	return e_cal_model_get_color_for_component (model, comp_data);
 }
 
-static char *
+static gpointer
 get_description (ECalModelComponent *comp_data)
 {
 	icalproperty *prop;
@@ -384,7 +384,7 @@ get_description (ECalModelComponent *comp_data)
 		return str->str;
 	}
 
-	return "";
+	return (gpointer) "";
 }
 
 static ECellDateEditValue*
@@ -435,26 +435,63 @@ get_dtstart (ECalModel *model, ECalModelComponent *comp_data)
 	return comp_data->dtstart;
 }
 
-static char *
+static ECellDateEditValue*
+get_datetime_from_utc (ECalModel *model, ECalModelComponent *comp_data, icalproperty_kind propkind, struct icaltimetype (*get_value)(const icalproperty* prop), ECellDateEditValue **buffer)
+{
+	ECalModelPrivate *priv;
+        struct icaltimetype tt_value;
+	icalproperty *prop;
+	ECellDateEditValue *res;
+
+	g_return_val_if_fail (buffer!= NULL, NULL);
+
+	if (*buffer)
+		return *buffer;
+
+	priv = model->priv;
+
+	prop = icalcomponent_get_first_property (comp_data->icalcomp, propkind);
+	if (!prop)
+		return NULL;
+
+	tt_value = get_value (prop);
+
+	/* these are always in UTC, thus convert to default zone, if any and done */
+	if (priv->zone)
+		icaltimezone_convert_time (&tt_value, icaltimezone_get_utc_timezone (), priv->zone);
+
+	if (!icaltime_is_valid_time (tt_value) || icaltime_is_null_time (tt_value))
+		return NULL;
+
+	res = g_new0 (ECellDateEditValue, 1);
+	res->tt = tt_value;
+	res->zone = NULL;
+
+	*buffer = res;
+
+	return res;
+}
+
+static gpointer
 get_summary (ECalModelComponent *comp_data)
 {
 	icalproperty *prop;
 
 	prop = icalcomponent_get_first_property (comp_data->icalcomp, ICAL_SUMMARY_PROPERTY);
 	if (prop)
-		return (char *) icalproperty_get_summary (prop);
+		return (gpointer) icalproperty_get_summary (prop);
 
-	return "";
+	return (gpointer) "";
 }
 
-static char *
+static gchar *
 get_uid (ECalModelComponent *comp_data)
 {
-	return (char *) icalcomponent_get_uid (comp_data->icalcomp);
+	return (gchar *) icalcomponent_get_uid (comp_data->icalcomp);
 }
 
-static void *
-ecm_value_at (ETableModel *etm, int col, int row)
+static gpointer
+ecm_value_at (ETableModel *etm, gint col, gint row)
 {
 	ECalModelPrivate *priv;
 	ECalModelComponent *comp_data;
@@ -477,13 +514,17 @@ ecm_value_at (ETableModel *etm, int col, int row)
 	case E_CAL_MODEL_FIELD_CLASSIFICATION :
 		return get_classification (comp_data);
 	case E_CAL_MODEL_FIELD_COLOR :
-		return (void *) get_color (model, comp_data);
+		return (gpointer) get_color (model, comp_data);
 	case E_CAL_MODEL_FIELD_COMPONENT :
 		return comp_data->icalcomp;
 	case E_CAL_MODEL_FIELD_DESCRIPTION :
 		return get_description (comp_data);
 	case E_CAL_MODEL_FIELD_DTSTART :
-		return (void *) get_dtstart (model, comp_data);
+		return (gpointer) get_dtstart (model, comp_data);
+	case E_CAL_MODEL_FIELD_CREATED :
+		return (gpointer) get_datetime_from_utc (model, comp_data, ICAL_CREATED_PROPERTY, icalproperty_get_created, &comp_data->created);
+	case E_CAL_MODEL_FIELD_LASTMODIFIED :
+		return (gpointer) get_datetime_from_utc (model, comp_data, ICAL_LASTMODIFIED_PROPERTY, icalproperty_get_lastmodified, &comp_data->lastmodified);
 	case E_CAL_MODEL_FIELD_HAS_ALARMS :
 		return GINT_TO_POINTER ((icalcomponent_get_first_component (comp_data->icalcomp,
 									    ICAL_VALARM_COMPONENT) != NULL));
@@ -511,7 +552,7 @@ ecm_value_at (ETableModel *etm, int col, int row)
 				e_cal_component_get_attendee_list (comp, &attendees);
 				for (sl = attendees; sl != NULL; sl = sl->next) {
 					ECalComponentAttendee *ca = sl->data;
-					const char *text;
+					const gchar *text;
 
 					text = itip_strip_mailto (ca->value);
 					if (e_account_list_find (priv->accounts, E_ACCOUNT_FIND_ID_ADDRESS, text) != NULL) {
@@ -538,11 +579,11 @@ ecm_value_at (ETableModel *etm, int col, int row)
 		return get_uid (comp_data);
 	}
 
-	return "";
+	return (gpointer) "";
 }
 
 static void
-set_categories (ECalModelComponent *comp_data, const char *value)
+set_categories (ECalModelComponent *comp_data, const gchar *value)
 {
 	icalproperty *prop;
 
@@ -562,7 +603,7 @@ set_categories (ECalModelComponent *comp_data, const char *value)
 }
 
 static void
-set_classification (ECalModelComponent *comp_data, const char *value)
+set_classification (ECalModelComponent *comp_data, const gchar *value)
 {
 	icalproperty *prop;
 
@@ -593,7 +634,7 @@ set_classification (ECalModelComponent *comp_data, const char *value)
 }
 
 static void
-set_description (ECalModelComponent *comp_data, const char *value)
+set_description (ECalModelComponent *comp_data, const gchar *value)
 {
 	icalproperty *prop;
 
@@ -619,12 +660,12 @@ set_description (ECalModelComponent *comp_data, const char *value)
 }
 
 static void
-set_dtstart (ECalModel *model, ECalModelComponent *comp_data, const void *value)
+set_dtstart (ECalModel *model, ECalModelComponent *comp_data, gconstpointer value)
 {
 	ECellDateEditValue *dv = (ECellDateEditValue *) value;
 	icalproperty *prop;
 	icalparameter *param;
-	const char *tzid;
+	const gchar *tzid;
 
 	prop = icalcomponent_get_first_property (comp_data->icalcomp, ICAL_DTSTART_PROPERTY);
 	if (prop)
@@ -660,9 +701,9 @@ set_dtstart (ECalModel *model, ECalModelComponent *comp_data, const void *value)
 	/* If the TZID is set to "UTC", we don't want to save the TZID. */
 	if (tzid && strcmp (tzid, "UTC")) {
 		if (param) {
-			icalparameter_set_tzid (param, (char *) tzid);
+			icalparameter_set_tzid (param, (gchar *) tzid);
 		} else {
-			param = icalparameter_new_tzid ((char *) tzid);
+			param = icalparameter_new_tzid ((gchar *) tzid);
 			icalproperty_add_parameter (prop, param);
 		}
 	} else if (param) {
@@ -671,7 +712,7 @@ set_dtstart (ECalModel *model, ECalModelComponent *comp_data, const void *value)
 }
 
 static void
-set_summary (ECalModelComponent *comp_data, const char *value)
+set_summary (ECalModelComponent *comp_data, const gchar *value)
 {
 	icalproperty *prop;
 
@@ -693,7 +734,7 @@ set_summary (ECalModelComponent *comp_data, const char *value)
 }
 
 static void
-ecm_set_value_at (ETableModel *etm, int col, int row, const void *value)
+ecm_set_value_at (ETableModel *etm, gint col, gint row, gconstpointer value)
 {
 	ECalModelPrivate *priv;
 	ECalModelComponent *comp_data;
@@ -744,7 +785,7 @@ ecm_set_value_at (ETableModel *etm, int col, int row, const void *value)
  * @return Whether row is editable or not.
  **/
 gboolean
-e_cal_model_test_row_editable (ECalModel *model, int row)
+e_cal_model_test_row_editable (ECalModel *model, gint row)
 {
 	gboolean readonly;
 	ECal *cal = NULL;
@@ -771,7 +812,7 @@ e_cal_model_test_row_editable (ECalModel *model, int row)
 }
 
 static gboolean
-ecm_is_cell_editable (ETableModel *etm, int col, int row)
+ecm_is_cell_editable (ETableModel *etm, gint col, gint row)
 {
 	ECalModelPrivate *priv;
 	ECalModel *model = (ECalModel *) etm;
@@ -799,7 +840,7 @@ ecm_is_cell_editable (ETableModel *etm, int col, int row)
 }
 
 static void
-ecm_append_row (ETableModel *etm, ETableModel *source, int row)
+ecm_append_row (ETableModel *etm, ETableModel *source, gint row)
 {
 	ECalModelClass *model_class;
 	ECalModelComponent comp_data;
@@ -860,8 +901,8 @@ ecm_append_row (ETableModel *etm, ETableModel *source, int row)
 	g_signal_emit (G_OBJECT (model), signals[ROW_APPENDED], 0);
 }
 
-static void *
-ecm_duplicate_value (ETableModel *etm, int col, const void *value)
+static gpointer
+ecm_duplicate_value (ETableModel *etm, gint col, gconstpointer value)
 {
 	g_return_val_if_fail (col >= 0 && col < E_CAL_MODEL_FIELD_LAST, NULL);
 
@@ -874,10 +915,12 @@ ecm_duplicate_value (ETableModel *etm, int col, const void *value)
 	case E_CAL_MODEL_FIELD_HAS_ALARMS :
 	case E_CAL_MODEL_FIELD_ICON :
 	case E_CAL_MODEL_FIELD_COLOR :
-		return (void *) value;
+		return (gpointer) value;
 	case E_CAL_MODEL_FIELD_COMPONENT :
 		return icalcomponent_new_clone ((icalcomponent *) value);
 	case E_CAL_MODEL_FIELD_DTSTART :
+	case E_CAL_MODEL_FIELD_CREATED :
+	case E_CAL_MODEL_FIELD_LASTMODIFIED :
 		if (value) {
 			ECellDateEditValue *dv, *orig_dv;
 
@@ -894,7 +937,7 @@ ecm_duplicate_value (ETableModel *etm, int col, const void *value)
 }
 
 static void
-ecm_free_value (ETableModel *etm, int col, void *value)
+ecm_free_value (ETableModel *etm, gint col, gpointer value)
 {
 	g_return_if_fail (col >= 0 && col < E_CAL_MODEL_FIELD_LAST);
 
@@ -911,6 +954,8 @@ ecm_free_value (ETableModel *etm, int col, void *value)
 	case E_CAL_MODEL_FIELD_COLOR :
 		break;
 	case E_CAL_MODEL_FIELD_DTSTART :
+	case E_CAL_MODEL_FIELD_CREATED :
+	case E_CAL_MODEL_FIELD_LASTMODIFIED :
 		if (value)
 			g_free (value);
 		break;
@@ -921,8 +966,8 @@ ecm_free_value (ETableModel *etm, int col, void *value)
 	}
 }
 
-static void *
-ecm_initialize_value (ETableModel *etm, int col)
+static gpointer
+ecm_initialize_value (ETableModel *etm, gint col)
 {
 	ECalModelPrivate *priv;
 	ECalModel *model = (ECalModel *) etm;
@@ -940,6 +985,8 @@ ecm_initialize_value (ETableModel *etm, int col)
 	case E_CAL_MODEL_FIELD_SUMMARY :
 		return g_strdup ("");
 	case E_CAL_MODEL_FIELD_DTSTART :
+	case E_CAL_MODEL_FIELD_CREATED :
+	case E_CAL_MODEL_FIELD_LASTMODIFIED :
 	case E_CAL_MODEL_FIELD_HAS_ALARMS :
 	case E_CAL_MODEL_FIELD_ICON :
 	case E_CAL_MODEL_FIELD_COLOR :
@@ -951,7 +998,7 @@ ecm_initialize_value (ETableModel *etm, int col)
 }
 
 static gboolean
-ecm_value_is_empty (ETableModel *etm, int col, const void *value)
+ecm_value_is_empty (ETableModel *etm, gint col, gconstpointer value)
 {
 	ECalModelPrivate *priv;
 	ECalModel *model = (ECalModel *) etm;
@@ -978,6 +1025,8 @@ ecm_value_is_empty (ETableModel *etm, int col, const void *value)
 	case E_CAL_MODEL_FIELD_SUMMARY :
 		return string_is_empty (value);
 	case E_CAL_MODEL_FIELD_DTSTART :
+	case E_CAL_MODEL_FIELD_CREATED :
+	case E_CAL_MODEL_FIELD_LASTMODIFIED :
 		return value ? FALSE : TRUE;
 	case E_CAL_MODEL_FIELD_HAS_ALARMS :
 	case E_CAL_MODEL_FIELD_ICON :
@@ -989,8 +1038,8 @@ ecm_value_is_empty (ETableModel *etm, int col, const void *value)
 	return TRUE;
 }
 
-static char *
-ecm_value_to_string (ETableModel *etm, int col, const void *value)
+static gchar *
+ecm_value_to_string (ETableModel *etm, gint col, gconstpointer value)
 {
 	g_return_val_if_fail (col >= 0 && col < E_CAL_MODEL_FIELD_LAST, g_strdup (""));
 
@@ -1001,6 +1050,8 @@ ecm_value_to_string (ETableModel *etm, int col, const void *value)
 	case E_CAL_MODEL_FIELD_SUMMARY :
 		return g_strdup (value);
 	case E_CAL_MODEL_FIELD_DTSTART :
+	case E_CAL_MODEL_FIELD_CREATED :
+	case E_CAL_MODEL_FIELD_LASTMODIFIED :
 		return e_cal_model_date_value_to_string (E_CAL_MODEL (etm), value);
 	case E_CAL_MODEL_FIELD_ICON :
 		if (GPOINTER_TO_INT (value) == 0)
@@ -1026,7 +1077,7 @@ typedef struct {
 	GList *uris;
 } AssignedColorData;
 
-static const char *
+static const gchar *
 ecm_get_color_for_component (ECalModel *model, ECalModelComponent *comp_data)
 {
 	ESource *source;
@@ -1064,7 +1115,7 @@ ecm_get_color_for_component (ECalModel *model, ECalModelComponent *comp_data)
 		}
 
 		for (l = assigned_colors[i].uris; l != NULL; l = l->next) {
-			if (!strcmp ((const char *) l->data,
+			if (!strcmp ((const gchar *) l->data,
 				     e_cal_get_uri (comp_data->client)))
 			{
 				return assigned_colors[i].color;
@@ -1290,7 +1341,7 @@ e_cal_model_get_client_list (ECalModel *model)
  * @uri: Uri for the client to get.
  */
 ECal *
-e_cal_model_get_client_for_uri (ECalModel *model, const char *uri)
+e_cal_model_get_client_for_uri (ECalModel *model, const gchar *uri)
 {
 	GList *l;
 
@@ -1334,12 +1385,15 @@ search_by_id_and_client (ECalModelPrivate *priv, ECal *client, const ECalCompone
 		ECalModelComponent *comp_data = g_ptr_array_index (priv->objects, i);
 
 		if (comp_data) {
-			const char *uid;
-			char *rid = NULL;
+			const gchar *uid;
+			gchar *rid = NULL;
+			struct icaltimetype icalrid;
 			gboolean has_rid = (id->rid && *id->rid);
 
 			uid = icalcomponent_get_uid (comp_data->icalcomp);
-			rid = icaltime_as_ical_string_r (icalcomponent_get_recurrenceid (comp_data->icalcomp));
+			icalrid = icalcomponent_get_recurrenceid (comp_data->icalcomp);
+			if (!icaltime_is_null_time (icalrid))
+				rid = icaltime_as_ical_string_r (icalrid);
 
 			if (uid && *uid) {
 				if ((!client || comp_data->client == client) && !strcmp (id->uid, uid)) {
@@ -1352,8 +1406,9 @@ search_by_id_and_client (ECalModelPrivate *priv, ECal *client, const ECalCompone
 					g_free (rid);
 					return comp_data;
 				}
-			g_free (rid);
 			}
+
+			g_free (rid);
 		}
 	}
 
@@ -1463,11 +1518,11 @@ e_cal_view_objects_added_cb (ECalView *query, GList *objects, gpointer user_data
 		/* remove the components if they are already present and re-add them */
 		while ((comp_data = search_by_id_and_client (priv, client,
 							      id))) {
-			int pos;
+			gint pos;
 			GSList *list = NULL;
 
 			pos = get_position_in_array (priv->objects, comp_data);
- 			
+
 			if (!g_ptr_array_remove (priv->objects, comp_data))
 				continue;
 
@@ -1479,7 +1534,7 @@ e_cal_view_objects_added_cb (ECalView *query, GList *objects, gpointer user_data
 
 			e_table_model_pre_change (E_TABLE_MODEL (model));
 			e_table_model_row_deleted (E_TABLE_MODEL (model), pos);
- 		}
+		}
 
 		e_cal_component_free_id (id);
 		g_object_unref (comp);
@@ -1521,10 +1576,10 @@ e_cal_view_objects_modified_cb (ECalView *query, GList *objects, gpointer user_d
 
 	/*  re-add only the recurrence objects */
 	for (l = objects; l != NULL; l = g_list_next (l)) {
-		if (!e_cal_util_component_is_instance (l->data) && e_cal_util_component_has_recurrences (l->data) && (priv->flags & E_CAL_MODEL_FLAGS_EXPAND_RECURRENCES)) 
+		if (!e_cal_util_component_is_instance (l->data) && e_cal_util_component_has_recurrences (l->data) && (priv->flags & E_CAL_MODEL_FLAGS_EXPAND_RECURRENCES))
 			list = g_list_prepend (list, l->data);
 		else {
-			int pos;
+			gint pos;
 			ECalModelComponent *comp_data;
 			ECalComponentId *id;
 			ECalComponent *comp = e_cal_component_new ();
@@ -1567,6 +1622,14 @@ e_cal_view_objects_modified_cb (ECalView *query, GList *objects, gpointer user_d
 				g_free (comp_data->completed);
 				comp_data->completed = NULL;
 			}
+			if (comp_data->created) {
+				g_free (comp_data->created);
+				comp_data->created = NULL;
+			}
+			if (comp_data->lastmodified) {
+				g_free (comp_data->lastmodified);
+				comp_data->lastmodified = NULL;
+			}
 			if (comp_data->color) {
 				g_free (comp_data->color);
 				comp_data->color = NULL;
@@ -1576,7 +1639,7 @@ e_cal_view_objects_modified_cb (ECalView *query, GList *objects, gpointer user_d
 			e_cal_model_set_instance_times (comp_data, priv->zone);
 
 			pos = get_position_in_array (priv->objects, comp_data);
-			
+
 			e_table_model_row_changed (E_TABLE_MODEL (model), pos);
 		}
 	}
@@ -1597,7 +1660,7 @@ e_cal_view_objects_removed_cb (ECalView *query, GList *ids, gpointer user_data)
 	for (l = ids; l; l = l->next) {
 		ECalModelComponent *comp_data = NULL;
 		ECalComponentId *id = l->data;
-		int pos;
+		gint pos;
 
 		/* make sure we remove all objects with this UID */
 		while ((comp_data = search_by_id_and_client (priv, e_cal_view_get_client (query), id))) {
@@ -1613,7 +1676,7 @@ e_cal_view_objects_removed_cb (ECalView *query, GList *ids, gpointer user_data)
 
 			g_slist_free (l);
 			g_object_unref (comp_data);
-		
+
 			e_table_model_pre_change (E_TABLE_MODEL (model));
 			e_table_model_row_deleted (E_TABLE_MODEL (model), pos);
 		}
@@ -1624,7 +1687,7 @@ e_cal_view_objects_removed_cb (ECalView *query, GList *ids, gpointer user_data)
 }
 
 static void
-e_cal_view_progress_cb (ECalView *query, const char *message, int percent, gpointer user_data)
+e_cal_view_progress_cb (ECalView *query, const gchar *message, gint percent, gpointer user_data)
 {
 	ECalModel *model = (ECalModel *) user_data;
 	ECal *client = e_cal_view_get_client (query);
@@ -1638,7 +1701,7 @@ e_cal_view_progress_cb (ECalView *query, const char *message, int percent, gpoin
 static void
 e_cal_view_done_cb (ECalView *query, ECalendarStatus status, gpointer user_data)
 {
- 	ECalModel *model = (ECalModel *) user_data;
+	ECalModel *model = (ECalModel *) user_data;
 	ECal *client = e_cal_view_get_client (query);
 
 	g_return_if_fail (E_IS_CAL_MODEL (model));
@@ -1676,15 +1739,15 @@ update_e_cal_view_for_client (ECalModel *model, ECalModelClient *client_data)
 	if (!client_data->do_query)
 		return;
 
-try_again:		
+try_again:
 	if (!e_cal_get_query (client_data->client, priv->full_sexp, &client_data->query, &error)) {
 		if (error->code == E_CALENDAR_STATUS_BUSY && tries != 10) {
 			tries++;
 			/*TODO chose an optimal value */
 			g_usleep (500);
 			g_clear_error (&error);
-			goto try_again;	
-		}	
+			goto try_again;
+		}
 
 		g_warning (G_STRLOC ": Unable to get query, %s", error->message);
 
@@ -1798,7 +1861,7 @@ e_cal_model_add_client (ECalModel *model, ECal *client)
 static void
 remove_client_objects (ECalModel *model, ECalModelClient *client_data)
 {
-	int i;
+	gint i;
 
 	/* remove all objects belonging to this client */
 	for (i = model->priv->objects->len; i > 0; i--) {
@@ -1810,7 +1873,7 @@ remove_client_objects (ECalModel *model, ECalModelClient *client_data)
 			GSList *l = NULL;
 
 			g_ptr_array_remove (model->priv->objects, comp_data);
-		
+
 			l = g_slist_append (l, comp_data);
 			g_signal_emit (G_OBJECT (model), signals[COMPS_DELETED], 0, l);
 
@@ -1918,7 +1981,7 @@ redo_queries (ECalModel *model)
 	ECalModelPrivate *priv;
 	GList *l;
 	GSList *slist;
-	int len;
+	gint len;
 
 	priv = model->priv;
 
@@ -1926,7 +1989,7 @@ redo_queries (ECalModel *model)
 		g_free (priv->full_sexp);
 
 	if (priv->start != -1 && priv->end != -1) {
-		char *iso_start, *iso_end;
+		gchar *iso_start, *iso_end;
 
 		iso_start = isodate_from_time_t (priv->start);
 		iso_end = isodate_from_time_t (priv->end);
@@ -1951,9 +2014,9 @@ redo_queries (ECalModel *model)
 	slist = get_objects_as_list (model);
 	g_ptr_array_set_size (priv->objects, 0);
 	g_signal_emit (G_OBJECT (model), signals[COMPS_DELETED], 0, slist);
-	
+
 	e_table_model_rows_deleted (E_TABLE_MODEL (model), 0, len);
-	
+
 	g_slist_foreach (slist, (GFunc)g_object_unref, NULL);
 	g_slist_free (slist);
 
@@ -2005,7 +2068,7 @@ e_cal_model_set_time_range (ECalModel *model, time_t start, time_t end)
 	redo_queries (model);
 }
 
-const char *
+const gchar *
 e_cal_model_get_search_query (ECalModel *model)
 {
 	ECalModelPrivate *priv;
@@ -2022,7 +2085,7 @@ e_cal_model_get_search_query (ECalModel *model)
  * e_cal_model_set_query
  */
 void
-e_cal_model_set_search_query (ECalModel *model, const char *sexp)
+e_cal_model_set_search_query (ECalModel *model, const gchar *sexp)
 {
 	ECalModelPrivate *priv;
 
@@ -2045,7 +2108,7 @@ e_cal_model_set_search_query (ECalModel *model, const char *sexp)
  * e_cal_model_set_query
  */
 void
-e_cal_model_set_search_query_with_time_range (ECalModel *model, const char *sexp, time_t start, time_t end)
+e_cal_model_set_search_query_with_time_range (ECalModel *model, const gchar *sexp, time_t start, time_t end)
 {
 	ECalModelPrivate *priv;
 	gboolean do_query = FALSE;
@@ -2101,7 +2164,7 @@ e_cal_model_create_component_with_defaults (ECalModel *model)
 		comp = cal_comp_task_new_with_defaults (client);
 		break;
 	case ICAL_VJOURNAL_COMPONENT :
-	        comp = cal_comp_memo_new_with_defaults (client);
+		comp = cal_comp_memo_new_with_defaults (client);
 		break;
 	default:
 		return NULL;
@@ -2115,7 +2178,7 @@ e_cal_model_create_component_with_defaults (ECalModel *model)
 
 	/* make sure the component has an UID */
 	if (!icalcomponent_get_uid (icalcomp)) {
-		char *uid;
+		gchar *uid;
 
 		uid = e_cal_component_gen_uid ();
 		icalcomponent_set_uid (icalcomp, uid);
@@ -2205,14 +2268,14 @@ e_cal_model_get_component_for_uid  (ECalModel *model, const ECalComponentId *id)
 /**
  * e_cal_model_date_value_to_string
  */
-gchar*
-e_cal_model_date_value_to_string (ECalModel *model, const void *value)
+gchar *
+e_cal_model_date_value_to_string (ECalModel *model, gconstpointer value)
 {
 	ECalModelPrivate *priv;
 	ECellDateEditValue *dv = (ECellDateEditValue *) value;
 	struct icaltimetype tt;
 	struct tm tmp_tm;
-	char buffer[64];
+	gchar buffer[64];
 
 	g_return_val_if_fail (E_IS_CAL_MODEL (model), g_strdup (""));
 
@@ -2257,7 +2320,7 @@ copy_ecdv (ECellDateEditValue *ecdv)
 
 
 struct _ECalModelComponentPrivate {
-	char nouse;
+	gchar nouse;
 };
 
 static void e_cal_model_component_finalize (GObject *object);
@@ -2279,7 +2342,7 @@ e_cal_model_component_class_init (ECalModelComponentClass *klass)
 
 
 static void
-e_cal_model_component_finalize (GObject *object) 
+e_cal_model_component_finalize (GObject *object)
 {
 	ECalModelComponent *comp_data = E_CAL_MODEL_COMPONENT(object);
 
@@ -2307,11 +2370,19 @@ e_cal_model_component_finalize (GObject *object)
 		g_free (comp_data->completed);
 		comp_data->completed = NULL;
 	}
+	if (comp_data->created) {
+		g_free (comp_data->created);
+		comp_data->created = NULL;
+	}
+	if (comp_data->lastmodified) {
+		g_free (comp_data->lastmodified);
+		comp_data->lastmodified = NULL;
+	}
 	if (comp_data->color) {
 		g_free (comp_data->color);
 		comp_data->color = NULL;
 	}
-	
+
 	if (G_OBJECT_CLASS (parent_class)->finalize)
 		(* G_OBJECT_CLASS (parent_class)->finalize) (object);
 }
@@ -2324,6 +2395,8 @@ e_cal_model_component_init (ECalModelComponent *comp)
 	comp->dtend = NULL;
 	comp->due = NULL;
 	comp->completed = NULL;
+	comp->created = NULL;
+	comp->lastmodified = NULL;
 	comp->color = NULL;
 }
 
@@ -2367,7 +2440,7 @@ void
 e_cal_model_free_component_data (ECalModelComponent *comp_data)
 {
 	g_return_if_fail (comp_data != NULL);
-	
+
 	g_object_unref (comp_data);
 }
 
@@ -2444,7 +2517,7 @@ e_cal_model_set_instance_times (ECalModelComponent *comp_data, const icaltimezon
 			param = icalproperty_get_first_parameter (prop, ICAL_TZID_PARAMETER);
 
 			if (param) {
-				const char *tzid = NULL;
+				const gchar *tzid = NULL;
 				icaltimezone *st_zone = NULL;
 
 				tzid = icalparameter_get_tzid (param);
@@ -2468,7 +2541,7 @@ e_cal_model_set_instance_times (ECalModelComponent *comp_data, const icaltimezon
 			param = icalproperty_get_first_parameter (prop, ICAL_TZID_PARAMETER);
 
 			if (param) {
-				const char *tzid = NULL;
+				const gchar *tzid = NULL;
 				icaltimezone *end_zone = NULL;
 
 				tzid = icalparameter_get_tzid (param);
