@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -28,6 +28,7 @@
 #include "e-cal-model.h"
 #include "gnome-cal.h"
 #include "e-activity-handler.h"
+#include "dialogs/comp-editor.h"
 
 G_BEGIN_DECLS
 
@@ -67,6 +68,7 @@ typedef enum {
         guint16 start_minute; \
         guint16 end_minute; \
         guint different_timezone : 1; \
+	gboolean is_editable;	\
 	GtkWidget *tooltip; \
 	gint	timeout; \
 	GdkColor *color; \
@@ -88,10 +90,10 @@ struct _ECalendarView {
 };
 
 typedef struct {
-	ECalendarViewEvent * (* get_view_event) (ECalendarView *view, int day, int event_num);
+	ECalendarViewEvent * (* get_view_event) (ECalendarView *view, gint day, gint event_num);
 	ECalendarView *cal_view;
-	int day;
-	int event_num;
+	gint day;
+	gint event_num;
 } ECalendarViewEventData;
 
 struct _ECalendarViewClass {
@@ -123,13 +125,13 @@ ECalModel     *e_calendar_view_get_model (ECalendarView *cal_view);
 void           e_calendar_view_set_model (ECalendarView *cal_view, ECalModel *model);
 icaltimezone  *e_calendar_view_get_timezone (ECalendarView *cal_view);
 void           e_calendar_view_set_timezone (ECalendarView *cal_view, icaltimezone *zone);
-const char    *e_calendar_view_get_default_category (ECalendarView *cal_view);
-void           e_calendar_view_set_default_category (ECalendarView *cal_view, const char *category);
+const gchar    *e_calendar_view_get_default_category (ECalendarView *cal_view);
+void           e_calendar_view_set_default_category (ECalendarView *cal_view, const gchar *category);
 gboolean       e_calendar_view_get_use_24_hour_format (ECalendarView *view);
 void           e_calendar_view_set_use_24_hour_format (ECalendarView *view, gboolean use_24_hour);
 
 void           e_calendar_view_set_activity_handler (ECalendarView *cal_view, EActivityHandler *activity_handler);
-void           e_calendar_view_set_status_message (ECalendarView *cal_view, const gchar *message, int percent);
+void           e_calendar_view_set_status_message (ECalendarView *cal_view, const gchar *message, gint percent);
 
 GList         *e_calendar_view_get_selected_events (ECalendarView *cal_view);
 gboolean       e_calendar_view_get_selected_time_range (ECalendarView *cal_view, time_t *start_time, time_t *end_time);
@@ -143,6 +145,7 @@ void           e_calendar_view_paste_clipboard (ECalendarView *cal_view);
 void           e_calendar_view_delete_selected_event (ECalendarView *cal_view);
 void           e_calendar_view_delete_selected_events (ECalendarView *cal_view);
 void           e_calendar_view_delete_selected_occurrence (ECalendarView *cal_view);
+CompEditor*    e_calendar_view_open_event_with_flags (ECalendarView *cal_view, ECal *client, icalcomponent *icalcomp, guint32 flags);
 
 GtkMenu       *e_calendar_view_create_popup_menu (ECalendarView *cal_view);
 
@@ -173,10 +176,10 @@ void e_calendar_utils_show_info_silent(struct _GtkWidget *widget);
 
 gboolean	e_calendar_view_get_tooltips (ECalendarViewEventData *data);
 
-void           e_calendar_view_move_tip (GtkWidget *widget, int x, int y);
+void           e_calendar_view_move_tip (GtkWidget *widget, gint x, gint y);
 
 const gchar *e_calendar_view_get_icalcomponent_summary (ECal *ecal, icalcomponent *icalcomp, gboolean *free_text);
-char *e_calendar_view_get_attendees_status_info (ECalComponent *comp, ECal *client);
+gchar *e_calendar_view_get_attendees_status_info (ECalComponent *comp, ECal *client);
 
 void           draw_curved_rectangle (cairo_t *cr,
                                       double x0,
