@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -44,20 +44,20 @@ static void e_day_view_top_item_set_property	(GObject	 *object,
 static void e_day_view_top_item_update		(GnomeCanvasItem *item,
 						 double		 *affine,
 						 ArtSVP		 *clip_path,
-						 int		  flags);
+						 gint		  flags);
 static void e_day_view_top_item_draw		(GnomeCanvasItem *item,
 						 GdkDrawable	 *drawable,
-						 int		  x,
-						 int		  y,
-						 int		  width,
-						 int		  height);
+						 gint		  x,
+						 gint		  y,
+						 gint		  width,
+						 gint		  height);
 static void e_day_view_top_item_draw_long_event	(EDayViewTopItem *dvtitem,
 						 gint		  event_num,
 						 GdkDrawable	 *drawable,
-						 int		  x,
-						 int		  y,
-						 int		  width,
-						 int		  height);
+						 gint		  x,
+						 gint		  y,
+						 gint		  width,
+						 gint		  height);
 static void e_day_view_top_item_draw_triangle	(EDayViewTopItem *dvtitem,
 						 GdkDrawable	 *drawable,
 						 gint		  x,
@@ -68,8 +68,8 @@ static void e_day_view_top_item_draw_triangle	(EDayViewTopItem *dvtitem,
 static double e_day_view_top_item_point		(GnomeCanvasItem *item,
 						 double		  x,
 						 double		  y,
-						 int		  cx,
-						 int		  cy,
+						 gint		  cx,
+						 gint		  cy,
 						 GnomeCanvasItem **actual_item);
 static gint e_day_view_top_item_event		(GnomeCanvasItem *item,
 						 GdkEvent	 *event);
@@ -155,7 +155,7 @@ static void
 e_day_view_top_item_update (GnomeCanvasItem *item,
 			    double	    *affine,
 			    ArtSVP	    *clip_path,
-			    int		     flags)
+			    gint		     flags)
 {
 	if (GNOME_CANVAS_ITEM_CLASS (e_day_view_top_item_parent_class)->update)
 		(* GNOME_CANVAS_ITEM_CLASS (e_day_view_top_item_parent_class)->update) (item, affine, clip_path, flags);
@@ -174,10 +174,10 @@ e_day_view_top_item_update (GnomeCanvasItem *item,
 static void
 e_day_view_top_item_draw (GnomeCanvasItem *canvas_item,
 			  GdkDrawable	  *drawable,
-			  int		   x,
-			  int		   y,
-			  int		   width,
-			  int		   height)
+			  gint		   x,
+			  gint		   y,
+			  gint		   width,
+			  gint		   height)
 {
 	EDayViewTopItem *dvtitem;
 	EDayView *day_view;
@@ -358,10 +358,10 @@ static void
 e_day_view_top_item_draw_long_event (EDayViewTopItem *dvtitem,
 				     gint	      event_num,
 				     GdkDrawable     *drawable,
-				     int	      x,
-				     int	      y,
-				     int	      width,
-				     int	      height)
+				     gint	      x,
+				     gint	      y,
+				     gint	      width,
+				     gint	      height)
 {
 	EDayView *day_view;
 	EDayViewEvent *event;
@@ -375,7 +375,7 @@ e_day_view_top_item_draw_long_event (EDayViewTopItem *dvtitem,
 	gchar buffer[16];
 	gint hour, display_hour, minute, offset, time_width, time_x;
 	gint min_end_time_x, suffix_width, max_icon_x;
-	gchar *suffix;
+	const gchar *suffix;
 	gboolean draw_start_triangle, draw_end_triangle;
 	GdkRectangle clip_rect;
 	GSList *categories_list, *elem;
@@ -395,8 +395,8 @@ e_day_view_top_item_draw_long_event (EDayViewTopItem *dvtitem,
 
 	gconf_client = gconf_client_get_default ();
 	alpha = gconf_client_get_float (gconf_client,
-				         "/apps/evolution/calendar/display/events_transparency",
-		 			NULL);
+					 "/apps/evolution/calendar/display/events_transparency",
+					NULL);
 
 	gradient = gconf_client_get_bool (gconf_client,
 					"/apps/evolution/calendar/display/events_gradient",
@@ -687,11 +687,11 @@ e_day_view_top_item_draw_long_event (EDayViewTopItem *dvtitem,
 	/* draw categories icons */
 	e_cal_component_get_categories_list (comp, &categories_list);
 	for (elem = categories_list; elem; elem = elem->next) {
-		char *category;
-		const char *file;
+		gchar *category;
+		const gchar *file;
 		GdkPixbuf *pixbuf;
 
-		category = (char *) elem->data;
+		category = (gchar *) elem->data;
 		file = e_categories_get_icon_file_for (category);
 		if (!file)
 			continue;
@@ -800,7 +800,7 @@ e_day_view_top_item_draw_triangle (EDayViewTopItem *dvtitem,
    This is needed so that we get button/motion events. */
 static double
 e_day_view_top_item_point (GnomeCanvasItem *item, double x, double y,
-			   int cx, int cy,
+			   gint cx, gint cy,
 			   GnomeCanvasItem **actual_item)
 {
 	*actual_item = item;
@@ -831,7 +831,7 @@ e_day_view_top_item_get_day_label (EDayView *day_view, gint day,
 {
 	struct icaltimetype day_start_tt;
 	struct tm day_start = { 0 };
-	gchar *format;
+	const gchar *format;
 
 	day_start_tt = icaltime_from_timet_with_zone (day_view->day_starts[day],
 						      FALSE,
