@@ -1,24 +1,24 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-
 /*
- * Author :
- *  Damon Chaplin <damon@gtk.org>
- *
- * Copyright 1999, Ximian, Inc.
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
+ *
+ * Authors:
+ *		Damon Chaplin <damon@gtk.org>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301
- * USA
  */
 
 /*
@@ -38,9 +38,9 @@ extern "C" {
 #endif /* __cplusplus */
 
 
-#define E_MEETING_TIME_SELECTOR_ITEM(obj)          (GTK_CHECK_CAST((obj), e_meeting_time_selector_item_get_type (), EMeetingTimeSelectorItem))
-#define E_MEETING_TIME_SELECTOR_ITEM_CLASS(k)      (GTK_CHECK_CLASS_CAST ((k), e_meeting_time_selector_item_get_type (), EMeetingTimeSelectorItemClass))
-#define IS_E_MEETING_TIME_SELECTOR_ITEM(o)         (GTK_CHECK_TYPE((o), e_meeting_time_selector_item_get_type ()))
+#define E_MEETING_TIME_SELECTOR_ITEM(obj)          (G_TYPE_CHECK_INSTANCE_CAST((obj), e_meeting_time_selector_item_get_type (), EMeetingTimeSelectorItem))
+#define E_MEETING_TIME_SELECTOR_ITEM_CLASS(k)      (G_TYPE_CHECK_CLASS_CAST ((k), e_meeting_time_selector_item_get_type (), EMeetingTimeSelectorItemClass))
+#define IS_E_MEETING_TIME_SELECTOR_ITEM(o)         (G_TYPE_CHECK_INSTANCE_TYPE((o), e_meeting_time_selector_item_get_type ()))
 
 
 typedef struct _EMeetingTimeSelectorItem       EMeetingTimeSelectorItem;
@@ -73,7 +73,7 @@ struct _EMeetingTimeSelectorItemClass
 	GnomeCanvasItemClass parent_class;
 };
 
-GtkType e_meeting_time_selector_item_get_type (void);
+GType e_meeting_time_selector_item_get_type (void);
 void e_meeting_time_selector_item_set_normal_cursor (EMeetingTimeSelectorItem *mts_item);
 
 
