@@ -1,32 +1,29 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-
 /*
- * Author :
- *  Damon Chaplin <damon@gtk.org>
- *
- * Copyright 1999, Ximian, Inc.
- *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
+ *
+ * Authors:
+ *		Damon Chaplin <damon@gtk.org>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301
- * USA
  */
+
 #ifndef _E_MEETING_TIME_SELECTOR_H_
 #define _E_MEETING_TIME_SELECTOR_H_
 
-#include <glib.h>
-#include <gtk/gtkaccelgroup.h>
-#include <gtk/gtktable.h>
-#include <gtk/gtkwidget.h>
+#include <gtk/gtk.h>
 #include <libgnomecanvas/gnome-canvas.h>
 #include <text/e-text.h>
 #include <table/e-table-model.h>
@@ -385,13 +382,13 @@ void e_meeting_time_selector_calculate_time (EMeetingTimeSelector *mts,
 					     EMeetingTime*time);
 gint e_meeting_time_selector_calculate_time_position (EMeetingTimeSelector *mts,
 						      EMeetingTime *mtstime);
-void e_meeting_time_selector_refresh_free_busy (EMeetingTimeSelector *mts, int row, gboolean all);
+void e_meeting_time_selector_refresh_free_busy (EMeetingTimeSelector *mts, gint row, gboolean all);
 
 /* Debugging function to dump information on all attendees. */
 #ifdef E_MEETING_TIME_SELECTOR_DEBUG
 void e_meeting_time_selector_dump (EMeetingTimeSelector *mts);
-gchar* e_meeting_time_selector_dump_time (EMeetingTime*mtstime);
-gchar* e_meeting_time_selector_dump_date (GDate *date);
+gchar * e_meeting_time_selector_dump_time (EMeetingTime*mtstime);
+gchar * e_meeting_time_selector_dump_date (GDate *date);
 #endif /* E_MEETING_TIME_SELECTOR_DEBUG */
 
 G_END_DECLS
