@@ -1,26 +1,25 @@
-/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
-/* e-memos.h
- *
- * Copyright (C) 2001  Ximian, Inc.
- * Copyright (C) 2001  Ximian, Inc.
- *
+/*
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
- * Authors: Federico Mena Quintero <federico@ximian.com>
+ *
+ * Authors:
+ *		Federico Mena Quintero <federico@ximian.com>
  *	    Damon Chaplin <damon@ximian.com>
- *          Nathan Owens <pianocomp81@yahoo.com>
+ *      Nathan Owens <pianocomp81@yahoo.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
+ *
  */
 
 #ifndef _E_MEMOS_H_
@@ -54,7 +53,7 @@ struct _EMemosClass {
 	GtkTableClass parent_class;
 
 	/* Notification signals */
-	void (* selection_changed) (EMemos *memos, int n_selected);
+	void (* selection_changed) (EMemos *memos, gint n_selected);
         void (* source_added)      (EMemos *memos, ESource *source);
         void (* source_removed)    (EMemos *memos, ESource *source);
 };
@@ -83,5 +82,6 @@ void e_memos_setup_view_menus (EMemos *memos, BonoboUIComponent *uic);
 void e_memos_discard_view_menus (EMemos *memos);
 
 EMemoTable *e_memos_get_calendar_table (EMemos *memos);
+GtkWidget  *e_memos_get_preview (EMemos *memos);
 
 #endif /* _E_MEMOS_H_ */
