@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -79,7 +79,7 @@ static void
 e_timezone_entry_class_init		(ETimezoneEntryClass	*class)
 {
 	GtkObjectClass *object_class = (GtkObjectClass *) class;
-	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (class) ;
+	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (class);
 
 	object_class = (GtkObjectClass*) class;
 
@@ -296,8 +296,8 @@ static void
 e_timezone_entry_set_entry (ETimezoneEntry *tentry)
 {
 	ETimezoneEntryPrivate *priv;
-	const char *display_name;
-	char *name_buffer;
+	const gchar *display_name;
+	gchar *name_buffer;
 
 	priv = tentry->priv;
 
