@@ -1,25 +1,23 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-
 /*
- * Author :
- *  Damon Chaplin <damon@ximian.com>
- *
- * Copyright 1999, Ximian, Inc.
- * Copyright 2001, Ximian, Inc.
- *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
+ *
+ * Authors:
+ *		Damon Chaplin <damon@ximian.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301
- * USA
  */
 
 /*
@@ -35,25 +33,26 @@
 #include "e-util/e-categories-config.h"
 #include "e-week-view-event-item.h"
 
-#include <gtk/gtksignal.h>
+#include <gtk/gtk.h>
 #include "e-calendar-view.h"
 #include "comp-util.h"
 
 #include <text/e-text.h>
 
-static void e_week_view_event_item_set_arg	(GtkObject	 *o,
-						 GtkArg		 *arg,
-						 guint		  arg_id);
+static void e_week_view_event_item_set_property	(GObject	 *object,
+						 guint		  property_id,
+						 const GValue	 *value,
+						 GParamSpec	 *pspec);
 static void e_week_view_event_item_update	(GnomeCanvasItem *item,
 						 double		 *affine,
 						 ArtSVP		 *clip_path,
-						 int		  flags);
+						 gint		  flags);
 static void e_week_view_event_item_draw		(GnomeCanvasItem *item,
 						 GdkDrawable	 *drawable,
-						 int		  x,
-						 int		  y,
-						 int		  width,
-						 int		  height);
+						 gint		  x,
+						 gint		  y,
+						 gint		  width,
+						 gint		  height);
 static void e_week_view_draw_time		(EWeekView	*week_view,
 						 GdkDrawable	*drawable,
 						 gint		 time_x,
@@ -75,8 +74,8 @@ static void e_week_view_event_item_draw_triangle (EWeekViewEventItem *wveitem,
 static double e_week_view_event_item_point	(GnomeCanvasItem *item,
 						 double		  x,
 						 double		  y,
-						 int		  cx,
-						 int		  cy,
+						 gint		  cx,
+						 gint		  cy,
 						 GnomeCanvasItem **actual_item);
 static gint e_week_view_event_item_event	(GnomeCanvasItem *item,
 						 GdkEvent	 *event);
@@ -93,9 +92,9 @@ static ECalendarViewPosition e_week_view_event_item_get_position (EWeekViewEvent
 
 /* The arguments we take */
 enum {
-	ARG_0,
-	ARG_EVENT_NUM,
-	ARG_SPAN_NUM
+	PROP_0,
+	PROP_EVENT_NUM,
+	PROP_SPAN_NUM
 };
 
 G_DEFINE_TYPE (EWeekViewEventItem, e_week_view_event_item, GNOME_TYPE_CANVAS_ITEM)
@@ -103,26 +102,41 @@ G_DEFINE_TYPE (EWeekViewEventItem, e_week_view_event_item, GNOME_TYPE_CANVAS_ITE
 static void
 e_week_view_event_item_class_init (EWeekViewEventItemClass *class)
 {
-	GtkObjectClass  *object_class;
+	GObjectClass  *object_class;
 	GnomeCanvasItemClass *item_class;
 
-	object_class = (GtkObjectClass *) class;
-	item_class = (GnomeCanvasItemClass *) class;
+	object_class = G_OBJECT_CLASS (class);
+	object_class->set_property = e_week_view_event_item_set_property;
 
-	gtk_object_add_arg_type ("EWeekViewEventItem::event_num",
-				 GTK_TYPE_INT, GTK_ARG_WRITABLE,
-				 ARG_EVENT_NUM);
-	gtk_object_add_arg_type ("EWeekViewEventItem::span_num",
-				 GTK_TYPE_INT, GTK_ARG_WRITABLE,
-				 ARG_SPAN_NUM);
+	item_class = GNOME_CANVAS_ITEM_CLASS (class);
+	item_class->update = e_week_view_event_item_update;
+	item_class->draw = e_week_view_event_item_draw;
+	item_class->point = e_week_view_event_item_point;
+	item_class->event = e_week_view_event_item_event;
 
-	object_class->set_arg = e_week_view_event_item_set_arg;
+	g_object_class_install_property (
+		object_class,
+		PROP_EVENT_NUM,
+		g_param_spec_int (
+			"event_num",
+			NULL,
+			NULL,
+			G_MININT,
+			G_MAXINT,
+			-1,
+			G_PARAM_WRITABLE));
 
-	/* GnomeCanvasItem method overrides */
-	item_class->update      = e_week_view_event_item_update;
-	item_class->draw        = e_week_view_event_item_draw;
-	item_class->point       = e_week_view_event_item_point;
-	item_class->event       = e_week_view_event_item_event;
+	g_object_class_install_property (
+		object_class,
+		PROP_SPAN_NUM,
+		g_param_spec_int (
+			"span_num",
+			NULL,
+			NULL,
+			G_MININT,
+			G_MAXINT,
+			-1,
+			G_PARAM_WRITABLE));
 }
 
 
@@ -135,28 +149,29 @@ e_week_view_event_item_init (EWeekViewEventItem *wveitem)
 
 
 static void
-e_week_view_event_item_set_arg (GtkObject *o, GtkArg *arg, guint arg_id)
+e_week_view_event_item_set_property (GObject *object,
+                                     guint property_id,
+                                     const GValue *value,
+                                     GParamSpec *pspec)
 {
 	GnomeCanvasItem *item;
 	EWeekViewEventItem *wveitem;
-	gboolean needs_update = FALSE;
 
-	item = GNOME_CANVAS_ITEM (o);
-	wveitem = E_WEEK_VIEW_EVENT_ITEM (o);
+	item = GNOME_CANVAS_ITEM (object);
+	wveitem = E_WEEK_VIEW_EVENT_ITEM (object);
 
-	switch (arg_id){
-	case ARG_EVENT_NUM:
-		wveitem->event_num = GTK_VALUE_INT (*arg);
-		needs_update = TRUE;
-		break;
-	case ARG_SPAN_NUM:
-		wveitem->span_num = GTK_VALUE_INT (*arg);
-		needs_update = TRUE;
-		break;
+	switch (property_id) {
+	case PROP_EVENT_NUM:
+		wveitem->event_num = g_value_get_int (value);
+		gnome_canvas_item_request_update (item);
+		return;
+	case PROP_SPAN_NUM:
+		wveitem->span_num = g_value_get_int (value);
+		gnome_canvas_item_request_update (item);
+		return;
 	}
 
-	if (needs_update)
-		gnome_canvas_item_request_update (item);
+	G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
 }
 
 
@@ -164,7 +179,7 @@ static void
 e_week_view_event_item_update (GnomeCanvasItem *item,
 			       double	       *affine,
 			       ArtSVP	       *clip_path,
-			       int	        flags)
+			       gint		flags)
 {
 	EWeekViewEventItem *wveitem;
 	EWeekView *week_view;
@@ -211,10 +226,10 @@ e_week_view_event_item_update (GnomeCanvasItem *item,
 static void
 e_week_view_event_item_draw (GnomeCanvasItem  *canvas_item,
 			     GdkDrawable      *drawable,
-			     int	       x,
-			     int	       y,
-			     int	       width,
-			     int	       height)
+			     gint	       x,
+			     gint	       y,
+			     gint	       width,
+			     gint	       height)
 {
 	EWeekViewEventItem *wveitem;
 	EWeekView *week_view;
@@ -621,7 +636,8 @@ e_week_view_draw_time	(EWeekView	*week_view,
 	GdkGC *gc;
 	gint hour_to_display, suffix_width;
 	gint time_y_normal_font, time_y_small_font;
-	gchar buffer[128], *suffix;
+	const gchar *suffix;
+	gchar buffer[128];
 	PangoLayout *layout;
 	PangoFontDescription *small_font_desc;
 
@@ -812,11 +828,11 @@ e_week_view_event_item_draw_icons (EWeekViewEventItem *wveitem,
 
 	/* draw categories icons */
 	for (elem = categories_list; elem; elem = elem->next) {
-		char *category;
+		gchar *category;
 		GdkPixmap *pixmap = NULL;
 		GdkBitmap *mask = NULL;
 
-		category = (char *) elem->data;
+		category = (gchar *) elem->data;
 		if (!e_categories_config_get_icon_for (category, &pixmap, &mask))
 			continue;
 
@@ -928,7 +944,7 @@ e_week_view_event_item_draw_triangle (EWeekViewEventItem *wveitem,
    This is needed so that we get button/motion events. */
 static double
 e_week_view_event_item_point (GnomeCanvasItem *item, double x, double y,
-			      int cx, int cy,
+			      gint cx, gint cy,
 			      GnomeCanvasItem **actual_item)
 {
 	*actual_item = item;
@@ -1021,8 +1037,7 @@ e_week_view_event_item_button_press (EWeekViewEventItem *wveitem,
 		e_week_view_show_popup_menu (week_view,
 					     (GdkEventButton*) bevent,
 					     wveitem->event_num);
-		gtk_signal_emit_stop_by_name (GTK_OBJECT (item->canvas),
-					      "button_press_event");
+		g_signal_stop_emission_by_name (item->canvas, "button_press_event");
 
 		return TRUE;
 	}
@@ -1063,7 +1078,6 @@ e_week_view_event_item_button_release (EWeekViewEventItem *wveitem,
 	return FALSE;
 }
 
-
 static gboolean
 e_week_view_event_item_double_click (EWeekViewEventItem *wveitem,
 				     GdkEvent		*bevent)
@@ -1083,8 +1097,8 @@ e_week_view_event_item_double_click (EWeekViewEventItem *wveitem,
 	if (week_view->editing_event_num >= 0) {
 		EWeekViewEvent *editing = &g_array_index (week_view->events, EWeekViewEvent, week_view->editing_event_num);
 
-		/* do not call edit of the component, if double clicked on the same component - the event is spread into more days */
-		if (editing && event && editing->comp_data == event->comp_data)
+		/* do not call edit of the component, if double clicked on the component, which is not on the server */
+		if (editing && event && editing->comp_data == event->comp_data && (!event->comp_data || !is_icalcomp_on_the_server (event->comp_data->icalcomp, event->comp_data->client)))
 			return TRUE;
 	}
 
