@@ -1,26 +1,26 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-
-/* 
- * Author : 
- *  Damon Chaplin <damon@ximian.com>
+/*
  *
- * Copyright 1999, Ximian, Inc.
- * Copyright 2001, Ximian, Inc.
- *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of version 2 of the GNU General Public 
- * License as published by the Free Software Foundation.
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
+ *
+ * Authors:
+ *		Damon Chaplin <damon@ximian.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
- * USA
  */
+
 #ifndef _E_WEEK_VIEW_EVENT_ITEM_H_
 #define _E_WEEK_VIEW_EVENT_ITEM_H_
 
@@ -36,11 +36,11 @@ extern "C" {
  * edit the text.
  */
 
-#define E_WEEK_VIEW_EVENT_ITEM(obj)     (GTK_CHECK_CAST((obj), \
+#define E_WEEK_VIEW_EVENT_ITEM(obj)     (G_TYPE_CHECK_INSTANCE_CAST((obj), \
         e_week_view_event_item_get_type (), EWeekViewEventItem))
-#define E_WEEK_VIEW_EVENT_ITEM_CLASS(k) (GTK_CHECK_CLASS_CAST ((k),\
+#define E_WEEK_VIEW_EVENT_ITEM_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k),\
 	e_week_view_event_item_get_type ()))
-#define E_IS_WEEK_VIEW_EVENT_ITEM(o)    (GTK_CHECK_TYPE((o), \
+#define E_IS_WEEK_VIEW_EVENT_ITEM(o)    (G_TYPE_CHECK_INSTANCE_TYPE((o), \
 	e_week_view_event_item_get_type ()))
 
 typedef struct {
@@ -59,7 +59,7 @@ typedef struct {
 } EWeekViewEventItemClass;
 
 
-GtkType  e_week_view_event_item_get_type      (void);
+GType    e_week_view_event_item_get_type      (void);
 
 
 
