@@ -13,7 +13,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  * Authors:
  *		Damon Chaplin <damon@ximian.com>
@@ -36,18 +36,18 @@ static void e_week_view_titles_item_set_property(GObject	 *object,
 static void e_week_view_titles_item_update	(GnomeCanvasItem *item,
 						 double		 *affine,
 						 ArtSVP		 *clip_path,
-						 int		  flags);
+						 gint		  flags);
 static void e_week_view_titles_item_draw	(GnomeCanvasItem *item,
 						 GdkDrawable	 *drawable,
-						 int		  x,
-						 int		  y,
-						 int		  width,
-						 int		  height);
+						 gint		  x,
+						 gint		  y,
+						 gint		  width,
+						 gint		  height);
 static double e_week_view_titles_item_point	(GnomeCanvasItem *item,
 						 double		  x,
 						 double		  y,
-						 int		  cx,
-						 int		  cy,
+						 gint		  cx,
+						 gint		  cy,
 						 GnomeCanvasItem **actual_item);
 
 /* The arguments we take */
@@ -114,7 +114,7 @@ static void
 e_week_view_titles_item_update (GnomeCanvasItem *item,
 				double	    *affine,
 				ArtSVP	    *clip_path,
-				int		     flags)
+				gint		     flags)
 {
 	if (GNOME_CANVAS_ITEM_CLASS (e_week_view_titles_item_parent_class)->update)
 		(* GNOME_CANVAS_ITEM_CLASS (e_week_view_titles_item_parent_class)->update) (item, affine, clip_path, flags);
@@ -134,10 +134,10 @@ e_week_view_titles_item_update (GnomeCanvasItem *item,
 static void
 e_week_view_titles_item_draw (GnomeCanvasItem  *canvas_item,
 			      GdkDrawable      *drawable,
-			      int		x,
-			      int		y,
-			      int		width,
-			      int		height)
+			      gint		x,
+			      gint		y,
+			      gint		width,
+			      gint		height)
 {
 	EWeekViewTitlesItem *wvtitem;
 	EWeekView *week_view;
@@ -269,7 +269,7 @@ e_week_view_titles_item_draw (GnomeCanvasItem  *canvas_item,
    This is needed so that we get button/motion events. */
 static double
 e_week_view_titles_item_point (GnomeCanvasItem *item, double x, double y,
-			       int cx, int cy,
+			       gint cx, gint cy,
 			       GnomeCanvasItem **actual_item)
 {
 	*actual_item = item;
