@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -433,7 +433,7 @@ void	   e_week_view_show_popup_menu		(EWeekView	*week_view,
 void	   e_week_view_convert_time_to_display	(EWeekView	*week_view,
 						 gint		 hour,
 						 gint		*display_hour,
-						 gchar	       **suffix,
+						 const gchar	**suffix,
 						 gint		*suffix_width);
 gint	   e_week_view_get_time_string_width	(EWeekView	*week_view);
 
@@ -441,9 +441,9 @@ gint	   e_week_view_event_sort_func		(const void	*arg1,
 						 const void	*arg2);
 
 gboolean e_week_view_find_event_from_item (EWeekView	  *week_view,
- 					   GnomeCanvasItem *item,
- 					   gint		  *event_num_return,
- 					   gint		  *span_num_return);
+					   GnomeCanvasItem *item,
+					   gint		  *event_num_return,
+					   gint		  *span_num_return);
 
 gboolean e_week_view_is_jump_button_visible (EWeekView *week_view,
 					     gint day);
