@@ -12,7 +12,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -93,8 +93,8 @@ struct _GnomeCalendarClass {
 	void (* calendar_focus_change)  (GnomeCalendar *gcal, gboolean in);
 	void (* taskpad_focus_change)   (GnomeCalendar *gcal, gboolean in);
 	void (* memopad_focus_change)   (GnomeCalendar *gcal, gboolean in);
- 	void (* change_view) (GnomeCalendar *gcal,
- 			       GnomeCalendarViewType view_type);
+	void (* change_view) (GnomeCalendar *gcal,
+			       GnomeCalendarViewType view_type);
 
         void (* source_added)           (GnomeCalendar *gcal, ECalSourceType source_type, ESource *source);
         void (* source_removed)         (GnomeCalendar *gcal, ECalSourceType source_type, ESource *source);
@@ -104,7 +104,7 @@ struct _GnomeCalendarClass {
 };
 
 
-GType      gnome_calendar_get_type         	(void);
+GType      gnome_calendar_get_type		(void);
 GtkWidget *gnome_calendar_construct		(GnomeCalendar *gcal);
 
 GtkWidget *gnome_calendar_new			(void);
@@ -112,21 +112,19 @@ GtkWidget *gnome_calendar_new			(void);
 void gnome_calendar_set_activity_handler (GnomeCalendar *cal, EActivityHandler *activity_handler);
 void gnome_calendar_set_ui_component (GnomeCalendar *cal, BonoboUIComponent *ui_component);
 
-ECalendarTable *gnome_calendar_get_task_pad	(GnomeCalendar *gcal);
-
 ECalModel *gnome_calendar_get_calendar_model    (GnomeCalendar *gcal);
 ECal *gnome_calendar_get_default_client    (GnomeCalendar *gcal);
 
 gboolean   gnome_calendar_add_source      (GnomeCalendar *gcal, ECalSourceType source_type, ESource *source);
 gboolean   gnome_calendar_remove_source   (GnomeCalendar *gcal, ECalSourceType source_type, ESource *source);
-gboolean   gnome_calendar_remove_source_by_uid   (GnomeCalendar *gcal, ECalSourceType source_type, const char *uid);
+gboolean   gnome_calendar_remove_source_by_uid   (GnomeCalendar *gcal, ECalSourceType source_type, const gchar *uid);
 gboolean   gnome_calendar_set_default_source (GnomeCalendar *gcal, ECalSourceType source_type, ESource *source);
 
-void       gnome_calendar_next             	(GnomeCalendar *gcal);
-void       gnome_calendar_previous         	(GnomeCalendar *gcal);
-void       gnome_calendar_goto             	(GnomeCalendar *gcal,
+void       gnome_calendar_next		(GnomeCalendar *gcal);
+void       gnome_calendar_previous		(GnomeCalendar *gcal);
+void       gnome_calendar_goto		(GnomeCalendar *gcal,
 						 time_t new_time);
-void       gnome_calendar_dayjump          	(GnomeCalendar *gcal,
+void       gnome_calendar_dayjump		(GnomeCalendar *gcal,
 						 time_t time);
 /* Jumps to the current day */
 void       gnome_calendar_goto_today            (GnomeCalendar *gcal);
@@ -149,7 +147,7 @@ struct _ECalMenu *gnome_calendar_get_memopad_menu (GnomeCalendar *gcal);
 void gnome_calendar_setup_view_menus (GnomeCalendar *gcal, BonoboUIComponent *uic);
 void gnome_calendar_discard_view_menus (GnomeCalendar *gcal);
 
-void gnome_calendar_view_popup_factory (GnomeCalendar *gcal, struct _EPopup *ep, const char *prefix);
+void gnome_calendar_view_popup_factory (GnomeCalendar *gcal, struct _EPopup *ep, const gchar *prefix);
 
 void	   gnome_calendar_set_selected_time_range (GnomeCalendar *gcal,
 						   time_t	  start_time,
@@ -197,11 +195,9 @@ void       gnome_calendar_purge                 (GnomeCalendar  *gcal,
 
 /* Direct calendar component operations */
 void       gnome_calendar_edit_appointment      (GnomeCalendar *gcal,
-						 const char* src_uid,
-						 const char* comp_uid,
-						 const char* comp_rid);
-
-GtkWidget * gnome_calendar_get_tag (GnomeCalendar *gcal);
+						 const gchar * src_uid,
+						 const gchar * comp_uid,
+						 const gchar * comp_rid);
 
 void gnome_calendar_emit_user_created_signal  (gpointer instance, GnomeCalendar *gcal, ECal *calendar);
 
