@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -96,7 +96,8 @@ launch_alarm_daemon_cb (gpointer data)
 
 	/* activate the alarm daemon */
 	CORBA_exception_init (&ev);
-	an = bonobo_activation_activate_from_id ("OAFIID:GNOME_Evolution_Calendar_AlarmNotify:" BASE_VERSION, 0, NULL, &ev);
+	an = bonobo_activation_activate_from_id (
+		(Bonobo_ActivationID) "OAFIID:GNOME_Evolution_Calendar_AlarmNotify:" BASE_VERSION, 0, NULL, &ev);
 
 	if (BONOBO_EX (&ev)) {
 		g_message ("launch_alarm_daemon_cb(): %s", bonobo_exception_get_text (&ev));
@@ -152,8 +153,8 @@ initialize (void)
 
 static BonoboObject *
 factory (BonoboGenericFactory *factory,
-	 const char *component_id,
-	 void *closure)
+	 const gchar *component_id,
+	 gpointer closure)
 {
 	static gboolean initialized = FALSE;
 
