@@ -12,7 +12,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -36,9 +36,6 @@
 #include <glib.h>
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
-#include <libgnomeui/gnome-dialog.h>
-#include <libgnomeui/gnome-uidefs.h>
-#include <libgnomeui/gnome-stock-icons.h>
 #include <libedataserver/e-time-utils.h>
 #include <libedataserver/e-data-server-util.h>
 #include <e-util/e-util.h>
@@ -76,7 +73,7 @@ struct PrintCalItem {
 static double
 evo_calendar_print_renderer_get_width (GtkPrintContext *context,
 				       PangoFontDescription *font,
-				       const char *text)
+				       const gchar *text)
 {
 	PangoLayout *layout;
 	gint layout_width, layout_height;
@@ -156,7 +153,7 @@ get_font_size (PangoFontDescription *font)
 
 /* The weird month of September 1752, where 3 Sep through 13 Sep were
    eliminated due to the Gregorian reformation. */
-static const int sept_1752[42] = {
+static const gint sept_1752[42] = {
 	 0,  0,  1,  2, 14, 15, 16,
 	17, 18, 19, 20, 21, 22, 23,
 	24, 25, 26, 27, 28, 29, 30,
@@ -193,12 +190,12 @@ struct psinfo
 
 	GArray *events;
 
-	int rows_per_cell;
-	int rows_per_compressed_cell;
-	int display_start_weekday;
+	gint rows_per_cell;
+	gint rows_per_compressed_cell;
+	gint display_start_weekday;
 	gboolean multi_week_view;
-	int weeks_shown;
-	int month;
+	gint weeks_shown;
+	gint month;
 	gboolean compress_weekend;
 	gboolean use_24_hour_format;
 	double row_height;
@@ -236,15 +233,15 @@ convert_timet_to_struct_tm (time_t time, icaltimezone *zone)
  * returned in the start and end arguments.
  */
 static void
-build_month (int month, int year, int *days, int *start, int *end)
+build_month (gint month, gint year, gint *days, gint *start, gint *end)
 {
-	int i;
-	int d_month, d_week, week_start_day;
+	gint i;
+	gint d_month, d_week, week_start_day;
 
 	/* Note that months are zero-based, so September is month 8 */
 
 	if ((year == 1752) && (month == 8)) {
-		memcpy (days, sept_1752, 42 * sizeof (int));
+		memcpy (days, sept_1752, 42 * sizeof (gint));
 
 		if (start)
 			*start = SEPT_1752_START;
@@ -415,7 +412,7 @@ print_rectangle (GtkPrintContext *context,
    or PANGO_ALIGN_CENTER. */
 static double
 print_text (GtkPrintContext *context, PangoFontDescription *desc,
-            const char *text, PangoAlignment alignment,
+            const gchar *text, PangoAlignment alignment,
             gdouble x1, gdouble x2, gdouble y1, gdouble y2)
 {
 	PangoLayout *layout;
@@ -458,7 +455,7 @@ print_text (GtkPrintContext *context, PangoFontDescription *desc,
 
 /* gets/frees the font for you, as a normal font */
 static double
-print_text_size (GtkPrintContext *context, const char *text,
+print_text_size (GtkPrintContext *context, const gchar *text,
                  PangoAlignment alignment, gdouble x1, gdouble x2,
                  gdouble y1, gdouble y2)
 {
@@ -474,7 +471,7 @@ print_text_size (GtkPrintContext *context, const char *text,
 
 /* gets/frees the font for you, as a bold font */
 static double
-print_text_size_bold (GtkPrintContext *context, const char *text,
+print_text_size_bold (GtkPrintContext *context, const gchar *text,
                       PangoAlignment alignment, gdouble x1, gdouble x2,
                       gdouble y1, gdouble y2)
 {
@@ -489,7 +486,7 @@ print_text_size_bold (GtkPrintContext *context, const char *text,
 }
 
 static void
-titled_box (GtkPrintContext *context, const char *text,
+titled_box (GtkPrintContext *context, const gchar *text,
             PangoFontDescription *font, PangoAlignment alignment,
             gdouble *x1, gdouble *y1, gdouble *x2, gdouble *y2,
 	    gdouble linewidth)
@@ -513,7 +510,7 @@ enum datefmt {
 	DATE_YEAR	= 1 << 3
 };
 
-static char *days[] = {
+static const gchar *days[] = {
 	N_("1st"), N_("2nd"), N_("3rd"), N_("4th"), N_("5th"),
 	N_("6th"), N_("7th"), N_("8th"), N_("9th"), N_("10th"),
 	N_("11th"), N_("12th"), N_("13th"), N_("14th"), N_("15th"),
@@ -526,11 +523,11 @@ static char *days[] = {
 /*
   format the date 'nicely' and consistently for various headers
 */
-static char *
-format_date(time_t time, int flags, char *buffer, int bufflen)
+static gchar *
+format_date(time_t time, gint flags, gchar *buffer, gint bufflen)
 {
 	icaltimezone *zone = calendar_config_get_icaltimezone ();
-	char fmt[64];
+	gchar fmt[64];
 	struct tm tm;
 
 	tm = *convert_timet_to_struct_tm (time, zone);
@@ -579,24 +576,25 @@ instance_cb (ECalComponent *comp, time_t instance_start, time_t instance_end, gp
 static void
 print_month_small (GtkPrintContext *context, GnomeCalendar *gcal, time_t month,
 		   gdouble x1, gdouble y1, gdouble x2, gdouble y2,
-		   int titleflags, time_t greystart, time_t greyend,
-		   int bordertitle)
+		   gint titleflags, time_t greystart, time_t greyend,
+		   gint bordertitle)
 {
 	icaltimezone *zone = calendar_config_get_icaltimezone ();
 	PangoFontDescription *font, *font_bold, *font_normal;
 	time_t now, next;
-	int x, y;
-	int days[42];
-	int day, weekday, week_start_day;
-	char buf[100];
+	gint x, y;
+	gint days[42];
+	gint day, weekday, week_start_day;
+	gchar buf[100];
 	struct tm tm;
 	double font_size, max_font_size;
 	double header_size, col_width, row_height, text_xpad, w;
 	double cell_top, cell_bottom, cell_left, cell_right, text_right;
 
 	/* Translators: These are workday abbreviations, e.g. Su=Sunday and Th=thursday */
-	char *daynames[] = { N_("Su"), N_("Mo"), N_("Tu"), N_("We"),
-			     N_("Th"), N_("Fr"), N_("Sa") };
+	const gchar *daynames[] =
+		{ N_("Su"), N_("Mo"), N_("Tu"), N_("We"),
+		  N_("Th"), N_("Fr"), N_("Sa") };
 	cairo_t *cr;
 
 	/* Print the title, e.g. 'June 2001', in the top 16% of the area. */
@@ -774,10 +772,10 @@ print_day_background (GtkPrintContext *context, GnomeCalendar *gcal,
 	double yinc, y;
 	double width = DAY_VIEW_TIME_COLUMN_WIDTH;
 	double font_size, max_font_size, hour_font_size, minute_font_size;
-	char buf[20];
-	const char *minute;
+	gchar buf[20];
+	const gchar *minute;
 	gboolean use_24_hour;
-	int i, hour, row;
+	gint i, hour, row;
 	double hour_minute_x;
 	cairo_t *cr;
 
@@ -819,7 +817,7 @@ print_day_background (GtkPrintContext *context, GnomeCalendar *gcal,
 	row = 0;
 	hour_minute_x = left + width * 0.58;
 	for (i = pdi->start_hour; i < pdi->end_hour; i++) {
-		y = top + yinc * (row + 1) ;
+		y = top + yinc * (row + 1);
 		cr = gtk_print_context_get_cairo_context (context);
 		cairo_set_source_rgb (cr, 0, 0, 0);
 
@@ -973,10 +971,10 @@ free_event_array (GArray *array)
 	g_array_set_size (array, 0);
 }
 
-static const char *
+static const gchar *
 get_type_as_string (icalparameter_cutype cutype)
 {
-	const char *res;
+	const gchar *res;
 
 	switch (cutype) {
 		case ICAL_CUTYPE_NONE:       res = NULL;            break;
@@ -990,10 +988,10 @@ get_type_as_string (icalparameter_cutype cutype)
 	return res;
 }
 
-static const char *
+static const gchar *
 get_role_as_string (icalparameter_role role)
 {
-	const char *res;
+	const gchar *res;
 
 	switch (role) {
 		case ICAL_ROLE_NONE:           res = NULL;                      break;
@@ -1025,7 +1023,7 @@ print_attendees (GtkPrintContext *context, PangoFontDescription *font, cairo_t *
 
 		if (attendee && attendee->value && *attendee->value) {
 			GString *text;
-			const char *tmp;
+			const gchar *tmp;
 
 			tmp = get_type_as_string (attendee->cutype);
 			text = g_string_new (tmp ? tmp : "");
@@ -1064,17 +1062,38 @@ print_attendees (GtkPrintContext *context, PangoFontDescription *font, cairo_t *
 	return top;
 }
 
+static gchar *
+get_summary_with_location (icalcomponent *icalcomp)
+{
+	const gchar *summary, *location;
+	gchar *text;
+
+	g_return_val_if_fail (icalcomp != NULL, NULL);
+
+	summary = icalcomponent_get_summary (icalcomp);
+	if (summary == NULL)
+		summary = "";
+
+	location = icalcomponent_get_location (icalcomp);
+	if (location && *location) {
+		text = g_strdup_printf ("%s (%s)", summary, location);
+	} else {
+		text = g_strdup (summary);
+	}
+
+	return text;
+}
+
 static void
 print_day_long_event (GtkPrintContext *context, PangoFontDescription *font,
 		      double left, double right, double top, double bottom,
 		      double row_height, EDayViewEvent *event,
 		      struct pdinfo *pdi, ECalModel *model)
 {
-	const gchar *summary;
 	double x1, x2, y1, y2;
 	double left_triangle_width = -1.0, right_triangle_width = -1.0;
-	char *text;
-	char buffer[32];
+	gchar *text;
+	gchar buffer[32];
 	struct tm date_tm;
 	double red, green, blue;
 
@@ -1136,12 +1155,13 @@ print_day_long_event (GtkPrintContext *context, PangoFontDescription *font,
 	}
 
 	/* Print the text. */
-	summary = icalcomponent_get_summary (event->comp_data->icalcomp);
-	text = summary ? (char*) summary : "";
+	text = get_summary_with_location (event->comp_data->icalcomp);
 
 	x1 += 4;
 	x2 -= 4;
 	print_text (context, font, text, PANGO_ALIGN_CENTER, x1, x2, y1, y2);
+
+	g_free (text);
 }
 
 
@@ -1150,11 +1170,10 @@ print_day_event (GtkPrintContext *context, PangoFontDescription *font,
 		 double left, double right, double top, double bottom,
 		 EDayViewEvent *event, struct pdinfo *pdi, ECalModel *model)
 {
-	const gchar *summary, *location;
 	double x1, x2, y1, y2, col_width, row_height;
-	int start_offset, end_offset, start_row, end_row;
-	char *text, start_buffer[32], end_buffer[32];
-	gboolean display_times = FALSE, free_text = FALSE;
+	gint start_offset, end_offset, start_row, end_row;
+	gchar *text, start_buffer[32], end_buffer[32];
+	gboolean display_times = FALSE;
 	struct tm date_tm;
 	double red, green, blue;
 
@@ -1190,14 +1209,7 @@ print_day_event (GtkPrintContext *context, PangoFontDescription *font,
 	e_cal_model_get_rgb_color_for_component (model, event->comp_data, &red, &green, &blue);
 	print_border_rgb (context, x1, x2, y1, y2, 1.0, red, green, blue);
 
-	summary = icalcomponent_get_summary (event->comp_data->icalcomp);
-	text = summary ? (char*) summary : "";
-
-	location = icalcomponent_get_location (event->comp_data->icalcomp);
-	if (location && *location) {
-		text = g_strdup_printf ("%s (%s)", text, location);
-		free_text = TRUE;
-	}
+	text = get_summary_with_location (event->comp_data->icalcomp);
 
 	if (display_times) {
 		gchar *t = NULL;
@@ -1219,22 +1231,16 @@ print_day_event (GtkPrintContext *context, PangoFontDescription *font,
 		e_time_format_time (&date_tm, pdi->use_24_hour_format, FALSE,
 				    end_buffer, sizeof (end_buffer));
 
-		if (free_text)
-			t = text;
-
+		t = text;
 		text = g_strdup_printf ("%s - %s %s ", start_buffer,
 					end_buffer, text);
 
-		free_text = TRUE;
-
-		if (t)
-			g_free (t);
+		g_free (t);
 	}
 
 	bound_text (context, font, text, -1, x1 + 2, y1, x2 - 2, y2, FALSE, NULL, NULL);
 
-	if (free_text)
-		g_free (text);
+	g_free (text);
 }
 
 
@@ -1338,14 +1344,14 @@ print_day_details (GtkPrintContext *context, GnomeCalendar *gcal, time_t whence,
 
 	/* lay out the short events, within the day. */
 	e_day_view_layout_day_events (pdi.events[0], DAY_VIEW_ROWS,
-				      DAY_VIEW_MINS_PER_ROW, pdi.cols_per_row);
+				      DAY_VIEW_MINS_PER_ROW, pdi.cols_per_row, -1);
 
 	/* print the short events. */
 	if (top > bottom )
 		max_font_size = ((top - bottom) / pdi.rows) - 4;
 	else
 		max_font_size = ((bottom - top ) / pdi.rows) - 4;
- 	font_size = MIN(DAY_NORMAL_FONT_SIZE, max_font_size);
+	font_size = MIN(DAY_NORMAL_FONT_SIZE, max_font_size);
 	font = get_font_for_size (font_size, PANGO_WEIGHT_NORMAL);
 
 	for (i = 0; i < pdi.events[0]->len; i++) {
@@ -1386,11 +1392,11 @@ print_week_long_event (GtkPrintContext *context, PangoFontDescription *font,
 		       struct psinfo *psi,
 		       double x1, double x2, double y1, double y2,
 		       EWeekViewEvent *event, EWeekViewEventSpan *span,
-		       char *text, double red, double green, double blue)
+		       gchar *text, double red, double green, double blue)
 {
 	double left_triangle_width = -1.0, right_triangle_width = -1.0;
 	struct tm date_tm;
-	char buffer[32];
+	gchar buffer[32];
 
 	/* If the event starts before the first day of the span, draw a
 	   triangle to indicate it continues. */
@@ -1453,10 +1459,10 @@ print_week_day_event (GtkPrintContext *context, PangoFontDescription *font,
 		      struct psinfo *psi,
 		      double x1, double x2, double y1, double y2,
 		      EWeekViewEvent *event, EWeekViewEventSpan *span,
-		      char *text, double red, double green, double blue)
+		      gchar *text, double red, double green, double blue)
 {
 	struct tm date_tm;
-	char buffer[32];
+	gchar buffer[32];
 
 	date_tm.tm_year = 2001;
 	date_tm.tm_mon = 0;
@@ -1497,15 +1503,13 @@ print_week_event (GtkPrintContext *context, PangoFontDescription *font,
 {
 	EWeekViewEventSpan *span;
 	gint span_num;
-	const gchar *summary;
-	char *text;
-	int num_days, start_x, start_y, start_h, end_x, end_y, end_h;
+	gchar *text;
+	gint num_days, start_x, start_y, start_h, end_x, end_y, end_h;
 	double x1, x2, y1, y2;
 	double red, green, blue;
 	GdkPixbuf *pixbuf = NULL;
 
-	summary = icalcomponent_get_summary (event->comp_data->icalcomp);
-	text = summary ? (char*) summary : "";
+	text = get_summary_with_location (event->comp_data->icalcomp);
 
 	for (span_num = 0; span_num < event->num_spans; span_num++) {
 		span = &g_array_index (spans, EWeekViewEventSpan,
@@ -1590,12 +1594,12 @@ print_week_event (GtkPrintContext *context, PangoFontDescription *font,
 			}
 
 			if (!pixbuf) {
-				const char **xpm = (const char **)jump_xpm;
+				const gchar **xpm = (const gchar **)jump_xpm;
 
 				/* this ugly thing is here only to get rid of compiler warning
 				   about unused 'jump_xpm_focused' */
 				if (pixbuf)
-					xpm = (const char **)jump_xpm_focused;
+					xpm = (const gchar **)jump_xpm_focused;
 
 				pixbuf = gdk_pixbuf_new_from_xpm_data (xpm);
 			}
@@ -1610,6 +1614,8 @@ print_week_event (GtkPrintContext *context, PangoFontDescription *font,
 
 	if (pixbuf)
 		g_object_unref (pixbuf);
+
+	g_free (text);
 }
 
 
@@ -1622,9 +1628,10 @@ print_week_view_background (GtkPrintContext *context,
 {
 	icaltimezone *zone = calendar_config_get_icaltimezone ();
 	struct tm tm;
-	int day, day_x, day_y, day_h;
+	gint day, day_x, day_y, day_h;
 	double x1, x2, y1, y2, font_size, fillcolor;
-	char *format_string, buffer[128];
+	const gchar *format_string;
+	gchar buffer[128];
 	cairo_t *cr;
 
 	font_size = get_font_size (font);
@@ -1690,13 +1697,13 @@ print_week_summary_cb (ECalComponent *comp,
 		       gpointer	  data)
 
 {
- 	icaltimezone *zone = calendar_config_get_icaltimezone ();
- 	EWeekViewEvent event;
- 	struct icaltimetype start_tt, end_tt;
+	icaltimezone *zone = calendar_config_get_icaltimezone ();
+	EWeekViewEvent event;
+	struct icaltimetype start_tt, end_tt;
 	ECalModelGenerateInstancesData *mdata = (ECalModelGenerateInstancesData *) data;
- 	struct psinfo *psi = (struct psinfo *) mdata->cb_data;
+	struct psinfo *psi = (struct psinfo *) mdata->cb_data;
 
- 	/* Check that the event times are valid. */
+	/* Check that the event times are valid. */
 
 #if 0
 	g_print ("View start:%li end:%li  Event start:%li end:%li\n",
@@ -1704,12 +1711,12 @@ print_week_summary_cb (ECalComponent *comp,
 		 start, end);
 #endif
 
- 	g_return_val_if_fail (start <= end, TRUE);
- 	g_return_val_if_fail (start < psi->day_starts[psi->days_shown], TRUE);
- 	g_return_val_if_fail (end > psi->day_starts[0], TRUE);
+	g_return_val_if_fail (start <= end, TRUE);
+	g_return_val_if_fail (start < psi->day_starts[psi->days_shown], TRUE);
+	g_return_val_if_fail (end > psi->day_starts[0], TRUE);
 
- 	start_tt = icaltime_from_timet_with_zone (start, FALSE, zone);
- 	end_tt = icaltime_from_timet_with_zone (end, FALSE, zone);
+	start_tt = icaltime_from_timet_with_zone (start, FALSE, zone);
+	end_tt = icaltime_from_timet_with_zone (end, FALSE, zone);
 
 	event.comp_data = e_cal_model_copy_component_data (mdata->comp_data);
 
@@ -1730,8 +1737,8 @@ print_week_summary_cb (ECalComponent *comp,
 
 static void
 print_week_summary (GtkPrintContext *context, GnomeCalendar *gcal,
-		    time_t whence, gboolean multi_week_view, int weeks_shown,
-		    int month, double font_size,
+		    time_t whence, gboolean multi_week_view, gint weeks_shown,
+		    gint month, double font_size,
 		    double left, double right, double top, double bottom)
 {
 	icaltimezone *zone = calendar_config_get_icaltimezone ();
@@ -1835,12 +1842,12 @@ print_week_summary (GtkPrintContext *context, GnomeCalendar *gcal,
 static void
 print_year_summary (GtkPrintContext *context, GnomeCalendar *gcal, time_t whence,
 		    double left, double right, double top, double bottom,
-		    int morerows)
+		    gint morerows)
 {
 	icaltimezone *zone = calendar_config_get_icaltimezone ();
 	double row_height, col_width, l, r, t, b;
 	time_t now;
-	int col, row, rows, cols;
+	gint col, row, rows, cols;
 
 	l = left;
 	t = top;
@@ -1884,10 +1891,10 @@ print_month_summary (GtkPrintContext *context, GnomeCalendar *gcal, time_t whenc
 	time_t date;
 	struct tm tm;
 	struct icaltimetype tt;
-	char buffer[100];
+	gchar buffer[100];
 	PangoFontDescription *font;
 	gboolean compress_weekend;
-	int columns, col, weekday, month;
+	gint columns, col, weekday, month;
 	double font_size, cell_width, x1, x2, y1, y2;
 
 	weekday = calendar_config_get_week_start_day ();
@@ -1992,7 +1999,7 @@ print_todo_details (GtkPrintContext *context, GnomeCalendar *gcal,
 		ECalModelComponent *comp_data;
 		ECalComponent *comp;
 		ECalComponentText summary;
-		int model_row;
+		gint model_row;
 
 		model_row = e_table_view_to_model_row (table, row);
 		comp_data = e_cal_model_get_component_at (model, model_row);
@@ -2054,9 +2061,9 @@ print_day_view (GtkPrintContext *context, GnomeCalendar *gcal, time_t date)
 {
 	GtkPageSetup *setup;
 	icaltimezone *zone = calendar_config_get_icaltimezone ();
-	int i, days = 1;
+	gint i, days = 1;
 	double todo, l;
-	char buf[100];
+	gchar buf[100];
 	cairo_t *cr;
 	gdouble width, height;
 
@@ -2124,7 +2131,7 @@ print_week_view (GtkPrintContext *context, GnomeCalendar *gcal, time_t date)
 	GtkPageSetup *setup;
 	icaltimezone *zone = calendar_config_get_icaltimezone ();
 	double l;
-	char buf[100];
+	gchar buf[100];
 	time_t when;
 	gint week_start_day;
 	struct tm tm;
@@ -2198,7 +2205,7 @@ print_month_view (GtkPrintContext *context, GnomeCalendar *gcal, time_t date)
 {
 	GtkPageSetup *setup;
 	icaltimezone *zone = calendar_config_get_icaltimezone ();
-	char buf[100];
+	gchar buf[100];
 	gdouble width, height;
 	double l;
 
@@ -2240,7 +2247,7 @@ static void
 print_year_view (GtkPrintContext *context, GnomeCalendar *gcal, time_t date)
 {
 	GtkPageSetup *setup;
-	char buf[100];
+	gchar buf[100];
 	cairo_t *cr;
 	gdouble width, height;
 
@@ -2267,11 +2274,15 @@ print_year_view (GtkPrintContext *context, GnomeCalendar *gcal, time_t date)
 #endif
 
 static void
-write_label_piece (time_t t, char *buffer, int size, char *stext, char *etext)
+write_label_piece (time_t t,
+                   gchar *buffer,
+                   gint size,
+                   gchar *stext,
+                   const gchar *etext)
 {
 	icaltimezone *zone = calendar_config_get_icaltimezone ();
 	struct tm *tmp_tm;
-	int len;
+	gint len;
 
 	tmp_tm = convert_timet_to_struct_tm (t, zone);
 
@@ -2288,7 +2299,7 @@ write_label_piece (time_t t, char *buffer, int size, char *stext, char *etext)
 }
 
 static icaltimezone*
-get_zone_from_tzid (ECal *client, const char *tzid)
+get_zone_from_tzid (ECal *client, const gchar *tzid)
 {
 	icaltimezone *zone;
 
@@ -2312,7 +2323,7 @@ print_date_label (GtkPrintContext *context, ECalComponent *comp, ECal *client,
 	icaltimezone *start_zone, *end_zone, *due_zone, *completed_zone;
 	ECalComponentDateTime datetime;
 	time_t start = 0, end = 0, complete = 0, due = 0;
-	static char buffer[1024];
+	static gchar buffer[1024];
 
 	e_cal_component_get_dtstart (comp, &datetime);
 	if (datetime.value) {
@@ -2441,8 +2452,8 @@ print_comp_draw_real (GtkPrintOperation *operation,
 	GSList *desc, *l;
 	GSList *contact_list, *elem;
 
-	const char *title, *categories, *location;
-	char *categories_string, *location_string, *summary_string;
+	const gchar *title, *categories, *location;
+	gchar *categories_string, *location_string, *summary_string;
 	double header_size;
 	cairo_t *cr;
 	gdouble width, height, page_start;
@@ -2538,10 +2549,10 @@ print_comp_draw_real (GtkPrintOperation *operation,
 	/* For a VTODO we print the Status, Priority, % Complete and URL. */
 	if (vtype == E_CAL_COMPONENT_TODO) {
 		icalproperty_status status;
-		const char *status_string = NULL;
-		int *percent;
-		int *priority;
-		const char *url;
+		const gchar *status_string = NULL;
+		gint *percent;
+		gint *priority;
+		const gchar *url;
 
 		/* Status */
 		e_cal_component_get_status (comp, &status);
@@ -2564,7 +2575,7 @@ print_comp_draw_real (GtkPrintOperation *operation,
 			}
 
 			if (status_string) {
-				char *status_text = g_strdup_printf (_("Status: %s"),
+				gchar *status_text = g_strdup_printf (_("Status: %s"),
 							      status_string);
 				top = bound_text (context, font, status_text, -1,
 						  0.0, top, width, height, FALSE, &page_start, &pages);
@@ -2576,22 +2587,22 @@ print_comp_draw_real (GtkPrintOperation *operation,
 		/* Priority */
 		e_cal_component_get_priority (comp, &priority);
 		if (priority && *priority >= 0) {
-			char *priority_string, *pri_text;
+			gchar *pri_text;
 
-			priority_string = e_cal_util_priority_to_string (*priority);
-			e_cal_component_free_priority (priority);
-
-			pri_text = g_strdup_printf (_("Priority: %s"), priority_string);
+			pri_text = g_strdup_printf (_("Priority: %s"), e_cal_util_priority_to_string (*priority));
 			top = bound_text (context, font, pri_text, -1,
 					  0.0, top, width, height, FALSE, &page_start, &pages);
 			top += get_font_size (font) - 6;
 			g_free (pri_text);
 		}
 
+		if (priority)
+			e_cal_component_free_priority (priority);
+
 		/* Percent Complete */
 		e_cal_component_get_percent (comp, &percent);
 		if (percent) {
-			char *percent_string;
+			gchar *percent_string;
 
 			percent_string = g_strdup_printf (_("Percent Complete: %i"), *percent);
 			e_cal_component_free_percent (percent);
@@ -2605,7 +2616,7 @@ print_comp_draw_real (GtkPrintOperation *operation,
 		/* URL */
 		e_cal_component_get_url (comp, &url);
 		if (url && url[0]) {
-			char *url_string = g_strdup_printf (_("URL: %s"),
+			gchar *url_string = g_strdup_printf (_("URL: %s"),
 							    url);
 
 			top = bound_text (context, font, url_string, -1,
@@ -2622,7 +2633,7 @@ print_comp_draw_real (GtkPrintOperation *operation,
 						     categories);
 		top = bound_text (context, font, categories_string, -1,
 				  0.0, top, width, height, TRUE, &page_start, &pages);
-		top += get_font_size (font) - 6 ;
+		top += get_font_size (font) - 6;
 		g_free (categories_string);
 	}
 
@@ -2650,7 +2661,7 @@ print_comp_draw_real (GtkPrintOperation *operation,
 	e_cal_component_get_description_list (comp, &desc);
 	for (l = desc; l != NULL; l = l->next) {
 		ECalComponentText *ptext = l->data;
-		const char *line, *next_line;
+		const gchar *line, *next_line;
 
 		for (line = ptext->value; line != NULL; line = next_line) {
 			next_line = strchr (line, '\n');
