@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -55,10 +55,10 @@ static void tasks_control_activate_cb		(BonoboControl		*control,
 						 gpointer		 user_data);
 static void tasks_control_open_task_cmd		(BonoboUIComponent	*uic,
 						 gpointer		 data,
-						 const char		*path);
+						 const gchar		*path);
 static void tasks_control_new_task_cmd		(BonoboUIComponent	*uic,
 						 gpointer		 data,
-						 const char		*path);
+						 const gchar		*path);
 static void tasks_control_cut_cmd               (BonoboUIComponent      *uic,
 						 gpointer                data,
 						 const gchar            *path);
@@ -70,32 +70,32 @@ static void tasks_control_paste_cmd             (BonoboUIComponent      *uic,
 						 const gchar            *path);
 static void tasks_control_delete_cmd		(BonoboUIComponent	*uic,
 						 gpointer		 data,
-						 const char		*path);
+						 const gchar		*path);
 static void tasks_control_complete_cmd		(BonoboUIComponent	*uic,
 						 gpointer		 data,
-						 const char		*path);
+						 const gchar		*path);
 static void tasks_control_purge_cmd		(BonoboUIComponent	*uic,
 						 gpointer		 data,
-						 const char		*path);
+						 const gchar		*path);
 static void tasks_control_print_cmd		(BonoboUIComponent	*uic,
 						 gpointer		 data,
-						 const char		*path);
+						 const gchar		*path);
 static void tasks_control_print_preview_cmd	(BonoboUIComponent	*uic,
 						 gpointer		 data,
-						 const char		*path);
+						 const gchar		*path);
 static void tasks_control_assign_cmd           (BonoboUIComponent      *uic,
                                                 gpointer               data,
-                                                const char             *path);
+                                                const gchar             *path);
 
 static void tasks_control_forward_cmd          (BonoboUIComponent      *uic,
                                                 gpointer               data,
-                                                const char             *path);
+                                                const gchar             *path);
 
 static void tasks_control_view_preview	       (BonoboUIComponent *uic,
-						const char *path,
+						const gchar *path,
 						Bonobo_UIComponent_EventType type,
-						const char *state,
-						void *data);
+						const gchar *state,
+						gpointer data);
 
 struct focus_changed_data {
 	BonoboControl *control;
@@ -154,7 +154,7 @@ tasks_control_activate_cb		(BonoboControl		*control,
 }
 
 struct _tasks_sensitize_item {
-	char *command;
+	const gchar *command;
 	guint32 enable;
 };
 
@@ -162,7 +162,7 @@ static void
 sensitize_items(BonoboUIComponent *uic, struct _tasks_sensitize_item *items, guint32 mask)
 {
 	while (items->command) {
-		char command[32];
+		gchar command[32];
 
 		if (strlen(items->command)>=21) {
 			g_warning ("Size more than 21: %s\n", items->command);
@@ -197,7 +197,7 @@ static struct _tasks_sensitize_item tasks_sensitize_table[] = {
  * selected tasks.
  */
 void
-tasks_control_sensitize_commands (BonoboControl *control, ETasks *tasks, int n_selected)
+tasks_control_sensitize_commands (BonoboControl *control, ETasks *tasks, gint n_selected)
 {
 	BonoboUIComponent *uic;
 	gboolean read_only = TRUE;
@@ -247,7 +247,7 @@ tasks_control_sensitize_commands (BonoboControl *control, ETasks *tasks, int n_s
 
 /* Callback used when the selection in the table changes */
 static void
-selection_changed_cb (ETasks *tasks, int n_selected, gpointer data)
+selection_changed_cb (ETasks *tasks, gint n_selected, gpointer data)
 {
 	BonoboControl *control;
 
@@ -304,11 +304,11 @@ tasks_control_activate (BonoboControl *control, ETasks *tasks)
 {
 	Bonobo_UIContainer remote_uih;
 	BonoboUIComponent *uic;
-	int n_selected;
+	gint n_selected;
 	ECalendarTable *cal_table;
 	ETable *etable;
 	gboolean state;
-	char *xmlfile;
+	gchar *xmlfile;
 
 	uic = bonobo_control_get_ui_component (control);
 	g_return_if_fail (uic != NULL);
@@ -372,12 +372,12 @@ tasks_control_deactivate (BonoboControl *control, ETasks *tasks)
 	g_signal_handlers_disconnect_matched (tasks, G_SIGNAL_MATCH_DATA, 0, 0, NULL, NULL, control);
 
 	bonobo_ui_component_rm (uic, "/", NULL);
- 	bonobo_ui_component_unset_container (uic, NULL);
+	bonobo_ui_component_unset_container (uic, NULL);
 }
 
 static void tasks_control_open_task_cmd		(BonoboUIComponent	*uic,
 						 gpointer		 data,
-						 const char		*path)
+						 const gchar		*path)
 {
 	ETasks *tasks;
 
@@ -388,7 +388,7 @@ static void tasks_control_open_task_cmd		(BonoboUIComponent	*uic,
 static void
 tasks_control_new_task_cmd		(BonoboUIComponent	*uic,
 					 gpointer		 data,
-					 const char		*path)
+					 const gchar		*path)
 {
 	ETasks *tasks;
 
@@ -399,7 +399,7 @@ tasks_control_new_task_cmd		(BonoboUIComponent	*uic,
 static void
 tasks_control_cut_cmd                   (BonoboUIComponent      *uic,
 					 gpointer                data,
-					 const char             *path)
+					 const gchar             *path)
 {
 	ETasks *tasks;
 	ECalendarTable *cal_table;
@@ -412,7 +412,7 @@ tasks_control_cut_cmd                   (BonoboUIComponent      *uic,
 static void
 tasks_control_copy_cmd                  (BonoboUIComponent      *uic,
 					 gpointer                data,
-					 const char             *path)
+					 const gchar             *path)
 {
 	ETasks *tasks;
 	ECalendarTable *cal_table;
@@ -434,7 +434,7 @@ tasks_control_copy_cmd                  (BonoboUIComponent      *uic,
 static void
 tasks_control_paste_cmd                 (BonoboUIComponent      *uic,
 					 gpointer                data,
-					 const char             *path)
+					 const gchar             *path)
 {
 	ETasks *tasks;
 	ECalendarTable *cal_table;
@@ -447,7 +447,7 @@ tasks_control_paste_cmd                 (BonoboUIComponent      *uic,
 static void
 tasks_control_delete_cmd		(BonoboUIComponent	*uic,
 					 gpointer		 data,
-					 const char		*path)
+					 const gchar		*path)
 {
 	ETasks *tasks;
 
@@ -458,7 +458,7 @@ tasks_control_delete_cmd		(BonoboUIComponent	*uic,
 static void
 tasks_control_complete_cmd		(BonoboUIComponent	*uic,
 					 gpointer		 data,
-					 const char		*path)
+					 const gchar		*path)
 {
 	ETasks *tasks;
 
@@ -473,7 +473,7 @@ static gboolean
 confirm_purge (ETasks *tasks)
 {
 	GtkWidget *dialog, *checkbox, *parent;
-	int button;
+	gint button;
 
 	if (!calendar_config_get_confirm_purge ())
 		return TRUE;
@@ -484,7 +484,7 @@ confirm_purge (ETasks *tasks)
 		GTK_DIALOG_DESTROY_WITH_PARENT,
 		GTK_MESSAGE_WARNING,
 		GTK_BUTTONS_YES_NO,
-		"%s", 
+		"%s",
 		_("This operation will permanently erase all tasks marked as completed. If you continue, you will not be able to recover these tasks.\n\nReally erase these tasks?"));
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_NO);
 
@@ -503,7 +503,7 @@ confirm_purge (ETasks *tasks)
 static void
 tasks_control_purge_cmd	(BonoboUIComponent	*uic,
 			 gpointer		 data,
-			 const char		*path)
+			 const gchar		*path)
 {
 	ETasks *tasks;
 
@@ -516,7 +516,7 @@ tasks_control_purge_cmd	(BonoboUIComponent	*uic,
 static void
 tasks_control_print_cmd (BonoboUIComponent *uic,
 			 gpointer data,
-			 const char *path)
+			 const gchar *path)
 {
 	ETasks *tasks = E_TASKS (data);
 	ETable *table;
@@ -532,7 +532,7 @@ tasks_control_print_cmd (BonoboUIComponent *uic,
 static void
 tasks_control_print_preview_cmd (BonoboUIComponent *uic,
 				 gpointer data,
-				 const char *path)
+				 const gchar *path)
 {
 	ETasks *tasks = E_TASKS (data);
 	ETable *table;
@@ -548,7 +548,7 @@ tasks_control_print_preview_cmd (BonoboUIComponent *uic,
 static void
 tasks_control_assign_cmd (BonoboUIComponent *uic,
                          gpointer data,
-                         const char *path)
+                         const gchar *path)
 {
               ETasks *tasks;
               ECalendarTable *cal_table;
@@ -557,16 +557,16 @@ tasks_control_assign_cmd (BonoboUIComponent *uic,
               tasks = E_TASKS (data);
               cal_table = e_tasks_get_calendar_table (tasks);
               comp_data = e_calendar_table_get_selected_comp (cal_table);
- 	       if (comp_data)
+	       if (comp_data)
               e_calendar_table_open_task (cal_table, comp_data->client, comp_data->icalcomp, TRUE);
 }
 
 static void
 tasks_control_forward_cmd (BonoboUIComponent *uic,
                          gpointer data,
-                          const char *path)
+                          const gchar *path)
 {
-	        ETasks *tasks;
+		ETasks *tasks;
                ECalendarTable *cal_table;
                ECalModelComponent *comp_data;
 
@@ -583,7 +583,7 @@ tasks_control_forward_cmd (BonoboUIComponent *uic,
 }
 
 static void
-tasks_control_view_preview (BonoboUIComponent *uic, const char *path, Bonobo_UIComponent_EventType type, const char *state, void *data)
+tasks_control_view_preview (BonoboUIComponent *uic, const gchar *path, Bonobo_UIComponent_EventType type, const gchar *state, gpointer data)
 {
         ETasks *tasks;
 
