@@ -11,7 +11,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
@@ -265,28 +265,26 @@ e_composer_name_header_new (const gchar *label,
 
 EComposerHeader *
 e_composer_name_header_new_with_label (const gchar *label,
-				  ENameSelector *name_selector)
+                                       ENameSelector *name_selector)
 {
 	return g_object_new (
 		E_TYPE_COMPOSER_NAME_HEADER, "label", label,
-		"button", FALSE,  "name-selector", name_selector,
-		"addaction", FALSE, "visible", TRUE,
-		NULL);
+		"button", TRUE,  "name-selector", name_selector,
+		"addaction", FALSE, "visible", TRUE, NULL);
 }
 
 EComposerHeader *
 e_composer_name_header_new_with_action (const gchar *label,
-					const gchar *action_label,
-					ENameSelector *name_selector)
+                                        const gchar *action_label,
+                                        ENameSelector *name_selector)
 {
 	g_return_val_if_fail (E_IS_NAME_SELECTOR (name_selector), NULL);
 
 	return g_object_new (
 		E_TYPE_COMPOSER_NAME_HEADER, "label", label,
-		"button", FALSE, "name-selector", name_selector, 
+		"button", TRUE, "name-selector", name_selector,
 		"addaction_text", action_label,
-		"addaction", action_label != NULL,
-		NULL);
+		"addaction", action_label != NULL, NULL);
 }
 
 ENameSelector *
