@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -41,27 +41,27 @@
 
 struct _e_error_button {
 	struct _e_error_button *next;
-	char *stock;
-	char *label;
-	int response;
+	const gchar *stock;
+	const gchar *label;
+	gint response;
 };
 
 struct _e_error {
 	guint32 flags;
-	char *id;
-	int type;
-	int default_response;
-	char *title;
-	char *primary;
-	char *secondary;
-	char *help_uri;
+	const gchar *id;
+	gint type;
+	gint default_response;
+	const gchar *title;
+	const gchar *primary;
+	const gchar *secondary;
+	const gchar *help_uri;
 	gboolean scroll;
 	struct _e_error_button *buttons;
 };
 
 struct _e_error_table {
-	char *domain;
-	char *translation_domain;
+	const gchar *domain;
+	const gchar *translation_domain;
 	GHashTable *errors;
 };
 
@@ -84,8 +84,8 @@ static struct _e_error default_errors[] = {
 /* ********************************************************************** */
 
 static struct {
-	char *name;
-	int id;
+	const gchar *name;
+	gint id;
 } response_map[] = {
 	{ "GTK_RESPONSE_REJECT", GTK_RESPONSE_REJECT },
 	{ "GTK_RESPONSE_ACCEPT", GTK_RESPONSE_ACCEPT },
@@ -98,10 +98,10 @@ static struct {
 	{ "GTK_RESPONSE_HELP", GTK_RESPONSE_HELP },
 };
 
-static int
-map_response(const char *name)
+static gint
+map_response(const gchar *name)
 {
-	int i;
+	gint i;
 
 	for (i=0;i<sizeof(response_map)/sizeof(response_map[0]);i++)
 		if (!strcmp(name, response_map[i].name))
@@ -111,9 +111,9 @@ map_response(const char *name)
 }
 
 static struct {
-	const char *name;
-	const char *icon;
-	const char *title;
+	const gchar *name;
+	const gchar *icon;
+	const gchar *title;
 } type_map[] = {
 	{ "info", GTK_STOCK_DIALOG_INFO, N_("Evolution Information") },
 	{ "warning", GTK_STOCK_DIALOG_WARNING, N_("Evolution Warning") },
@@ -121,10 +121,10 @@ static struct {
 	{ "error", GTK_STOCK_DIALOG_ERROR, N_("Evolution Error") },
 };
 
-static int
-map_type(const char *name)
+static gint
+map_type(const gchar *name)
 {
-	int i;
+	gint i;
 
 	if (name) {
 		for (i=0;i<sizeof(type_map)/sizeof(type_map[0]);i++)
@@ -151,14 +151,14 @@ map_type(const char *name)
 
 */
 static void
-ee_load(const char *path)
+ee_load(const gchar *path)
 {
 	xmlDocPtr doc = NULL;
 	xmlNodePtr root, error, scan;
 	struct _e_error *e;
 	struct _e_error_button *lastbutton;
 	struct _e_error_table *table;
-	char *tmp;
+	gchar *tmp;
 
 	d(printf("loading error file %s\n", path));
 
@@ -170,8 +170,8 @@ ee_load(const char *path)
 
 	root = xmlDocGetRootElement(doc);
 	if (root == NULL
-	    || strcmp((char *)root->name, "error-list") != 0
-	    || (tmp = (char *)xmlGetProp(root, (const unsigned char *)"domain")) == NULL) {
+	    || strcmp((gchar *)root->name, "error-list") != 0
+	    || (tmp = (gchar *)xmlGetProp(root, (const guchar *)"domain")) == NULL) {
 		g_warning("Error file '%s' invalid format", path);
 		xmlFreeDoc(doc);
 		return;
@@ -179,19 +179,19 @@ ee_load(const char *path)
 
 	table = g_hash_table_lookup(error_table, tmp);
 	if (table == NULL) {
-		char *tmp2;
+		gchar *tmp2;
 
 		table = g_malloc0(sizeof(*table));
 		table->domain = g_strdup(tmp);
 		table->errors = g_hash_table_new(g_str_hash, g_str_equal);
-		g_hash_table_insert(error_table, table->domain, table);
+		g_hash_table_insert(error_table, (gpointer) table->domain, table);
 
-		tmp2 = (char *)xmlGetProp(root, (const unsigned char *)"translation-domain");
+		tmp2 = (gchar *)xmlGetProp(root, (const guchar *)"translation-domain");
 		if (tmp2) {
 			table->translation_domain = g_strdup(tmp2);
 			xmlFree(tmp2);
 
-			tmp2 = (char *)xmlGetProp(root, (const unsigned char *)"translation-localedir");
+			tmp2 = (gchar *)xmlGetProp(root, (const guchar *)"translation-localedir");
 			if (tmp2) {
 				bindtextdomain(table->translation_domain, tmp2);
 				xmlFree(tmp2);
@@ -202,8 +202,8 @@ ee_load(const char *path)
 	xmlFree(tmp);
 
 	for (error = root->children;error;error = error->next) {
-		if (!strcmp((char *)error->name, "error")) {
-			tmp = (char *)xmlGetProp(error, (const unsigned char *)"id");
+		if (!strcmp((gchar *)error->name, "error")) {
+			tmp = (gchar *)xmlGetProp(error, (const guchar *)"id");
 			if (tmp == NULL)
 				continue;
 
@@ -214,25 +214,25 @@ ee_load(const char *path)
 			xmlFree(tmp);
 			lastbutton = (struct _e_error_button *)&e->buttons;
 
-			tmp = (char *)xmlGetProp(error, (const unsigned char *)"modal");
+			tmp = (gchar *)xmlGetProp(error, (const guchar *)"modal");
 			if (tmp) {
 				if (!strcmp(tmp, "true"))
 					e->flags |= GTK_DIALOG_MODAL;
 				xmlFree(tmp);
 			}
 
-			tmp = (char *)xmlGetProp(error, (const unsigned char *)"type");
+			tmp = (gchar *)xmlGetProp(error, (const guchar *)"type");
 			e->type = map_type(tmp);
 			if (tmp)
 				xmlFree(tmp);
 
-			tmp = (char *)xmlGetProp(error, (const unsigned char *)"default");
+			tmp = (gchar *)xmlGetProp(error, (const guchar *)"default");
 			if (tmp) {
 				e->default_response = map_response(tmp);
 				xmlFree(tmp);
 			}
 
-			tmp = (char *)xmlGetProp(error, (const unsigned char *)"scroll");
+			tmp = (gchar *)xmlGetProp(error, (const guchar *)"scroll");
 			if (tmp) {
 				if (!strcmp(tmp, "yes"))
 					e->scroll = TRUE;
@@ -240,51 +240,55 @@ ee_load(const char *path)
 			}
 
 			for (scan = error->children;scan;scan=scan->next) {
-				if (!strcmp((char *)scan->name, "primary")) {
-					if ((tmp = (char *)xmlNodeGetContent(scan))) {
+				if (!strcmp((gchar *)scan->name, "primary")) {
+					if ((tmp = (gchar *)xmlNodeGetContent(scan))) {
 						e->primary = g_strdup(dgettext(table->translation_domain, tmp));
 						xmlFree(tmp);
 					}
-				} else if (!strcmp((char *)scan->name, "secondary")) {
-					if ((tmp = (char *)xmlNodeGetContent(scan))) {
+				} else if (!strcmp((gchar *)scan->name, "secondary")) {
+					if ((tmp = (gchar *)xmlNodeGetContent(scan))) {
 						e->secondary = g_strdup(dgettext(table->translation_domain, tmp));
 						xmlFree(tmp);
 					}
-				} else if (!strcmp((char *)scan->name, "title")) {
-					if ((tmp = (char *)xmlNodeGetContent(scan))) {
+				} else if (!strcmp((gchar *)scan->name, "title")) {
+					if ((tmp = (gchar *)xmlNodeGetContent(scan))) {
 						e->title = g_strdup(dgettext(table->translation_domain, tmp));
 						xmlFree(tmp);
 					}
-				} else if (!strcmp((char *)scan->name, "help")) {
-					tmp = (char *)xmlGetProp(scan, (const unsigned char *)"uri");
+				} else if (!strcmp((gchar *)scan->name, "help")) {
+					tmp = (gchar *)xmlGetProp(scan, (const guchar *)"uri");
 					if (tmp) {
 						e->help_uri = g_strdup(tmp);
 						xmlFree(tmp);
 					}
-				} else if (!strcmp((char *)scan->name, "button")) {
+				} else if (!strcmp((gchar *)scan->name, "button")) {
 					struct _e_error_button *b;
+					gchar *label = NULL;
+					gchar *stock = NULL;
 
 					b = g_malloc0(sizeof(*b));
-					tmp = (char *)xmlGetProp(scan, (const unsigned char *)"stock");
+					tmp = (gchar *)xmlGetProp(scan, (const guchar *)"stock");
 					if (tmp) {
-						b->stock = g_strdup(tmp);
+						stock = g_strdup(tmp);
+						b->stock = stock;
 						xmlFree(tmp);
 					}
-					tmp = (char *)xmlGetProp(scan, (const unsigned char *)"label");
+					tmp = (gchar *)xmlGetProp(scan, (const guchar *)"label");
 					if (tmp) {
-						b->label = g_strdup(dgettext(table->translation_domain, tmp));
+						label = g_strdup(dgettext(table->translation_domain, tmp));
+						b->label = label;
 						xmlFree(tmp);
 					}
-					tmp = (char *)xmlGetProp(scan, (const unsigned char *)"response");
+					tmp = (gchar *)xmlGetProp(scan, (const guchar *)"response");
 					if (tmp) {
 						b->response = map_response(tmp);
 						xmlFree(tmp);
 					}
 
-					if (b->stock == NULL && b->label == NULL) {
+					if (stock == NULL && label == NULL) {
 						g_warning("Error file '%s': missing button details in error '%s'", path, e->id);
-						g_free(b->stock);
-						g_free(b->label);
+						g_free(stock);
+						g_free(label);
 						g_free(b);
 					} else {
 						lastbutton->next = b;
@@ -293,7 +297,7 @@ ee_load(const char *path)
 				}
 			}
 
-			g_hash_table_insert(table->errors, e->id, e);
+			g_hash_table_insert(table->errors, (gpointer) e->id, e);
 		}
 	}
 
@@ -304,10 +308,10 @@ static void
 ee_load_tables(void)
 {
 	GDir *dir;
-	const char *d;
-	char *base;
+	const gchar *d;
+	gchar *base;
 	struct _e_error_table *table;
-	int i;
+	gint i;
 
 	if (error_table != NULL)
 		return;
@@ -319,8 +323,8 @@ ee_load_tables(void)
 	table->domain = "builtin";
 	table->errors = g_hash_table_new(g_str_hash, g_str_equal);
 	for (i=0;i<sizeof(default_errors)/sizeof(default_errors[0]);i++)
-		g_hash_table_insert(table->errors, default_errors[i].id, &default_errors[i]);
-	g_hash_table_insert(error_table, table->domain, table);
+		g_hash_table_insert(table->errors, (gpointer) default_errors[i].id, &default_errors[i]);
+	g_hash_table_insert(error_table, (gpointer) table->domain, table);
 
 	/* look for installed error tables */
 	base = g_build_filename (EVOLUTION_PRIVDATADIR, "errors", NULL);
@@ -331,7 +335,7 @@ ee_load_tables(void)
 	}
 
 	while ( (d = g_dir_read_name(dir)) ) {
-		char *path;
+		gchar *path;
 
 		if (d[0] == '.')
 			continue;
@@ -347,9 +351,9 @@ ee_load_tables(void)
 
 /* unfortunately, gmarkup_escape doesn't expose its gstring based api :( */
 static void
-ee_append_text(GString *out, const char *text)
+ee_append_text(GString *out, const gchar *text)
 {
-	char c;
+	gchar c;
 
 	while ( (c=*text++) ) {
 		if (c == '<')
@@ -368,11 +372,11 @@ ee_append_text(GString *out, const char *text)
 }
 
 static void
-ee_build_label(GString *out, const char *fmt, GPtrArray *args,
+ee_build_label(GString *out, const gchar *fmt, GPtrArray *args,
                gboolean escape_args)
 {
-	const char *end, *newstart;
-	int id;
+	const gchar *end, *newstart;
+	gint id;
 
 	while (fmt
 	       && (newstart = strchr(fmt, '{'))
@@ -402,13 +406,13 @@ ee_response(GtkWidget *w, guint button, struct _e_error *e)
 }
 
 GtkWidget *
-e_error_newv(GtkWindow *parent, const char *tag, const char *arg0, va_list ap)
+e_error_newv(GtkWindow *parent, const gchar *tag, const gchar *arg0, va_list ap)
 {
 	struct _e_error_table *table;
 	struct _e_error *e;
 	struct _e_error_button *b;
 	GtkWidget *hbox, *w, *scroll=NULL;
-	char *tmp, *domain, *id;
+	gchar *tmp, *domain, *id;
 	GString *out, *oerr;
 	GPtrArray *args;
 	GtkDialog *dialog;
@@ -499,10 +503,10 @@ e_error_newv(GtkWindow *parent, const char *tag, const char *arg0, va_list ap)
 	gtk_box_pack_start((GtkBox *)hbox, w, FALSE, FALSE, 12);
 
 	args = g_ptr_array_new();
-	tmp = (char *)arg0;
+	tmp = (gchar *)arg0;
 	while (tmp) {
 		g_ptr_array_add(args, tmp);
-		tmp = va_arg(ap, char *);
+		tmp = va_arg(ap, gchar *);
 	}
 
 	out = g_string_new("");
@@ -525,7 +529,7 @@ e_error_newv(GtkWindow *parent, const char *tag, const char *arg0, va_list ap)
 		g_string_free (oerr, TRUE);
 	} else
 		perr = g_strdup (gtk_window_get_title (GTK_WINDOW (dialog)));
-	
+
 	if (e->secondary) {
 		ee_build_label(out, e->secondary, args, TRUE);
 		oerr = g_string_new("");
@@ -557,7 +561,7 @@ e_error_newv(GtkWindow *parent, const char *tag, const char *arg0, va_list ap)
 	gtk_box_pack_start((GtkBox *)dialog->vbox, hbox, TRUE, TRUE, 0);
 	g_object_set_data_full ((GObject *) dialog, "primary", perr, g_free);
 	g_object_set_data_full ((GObject *) dialog, "secondary", serr, g_free);
-	
+
 	return (GtkWidget *)dialog;
 }
 
@@ -577,7 +581,7 @@ e_error_newv(GtkWindow *parent, const char *tag, const char *arg0, va_list ap)
  * dialog asynchronously.
  **/
 struct _GtkWidget *
-e_error_new(struct _GtkWindow *parent, const char *tag, const char *arg0, ...)
+e_error_new(struct _GtkWindow *parent, const gchar *tag, const gchar *arg0, ...)
 {
 	GtkWidget *w;
 	va_list ap;
@@ -589,11 +593,11 @@ e_error_new(struct _GtkWindow *parent, const char *tag, const char *arg0, ...)
 	return w;
 }
 
-int
-e_error_runv(GtkWindow *parent, const char *tag, const char *arg0, va_list ap)
+gint
+e_error_runv(GtkWindow *parent, const gchar *tag, const gchar *arg0, va_list ap)
 {
 	GtkWidget *w;
-	int res;
+	gint res;
 
 	w = e_error_newv(parent, tag, arg0, ap);
 
@@ -614,12 +618,12 @@ e_error_runv(GtkWindow *parent, const char *tag, const char *arg0, va_list ap)
  *
  * Return value: The response id of the button pressed.
  **/
-int
-e_error_run(GtkWindow *parent, const char *tag, const char *arg0, ...)
+gint
+e_error_run(GtkWindow *parent, const gchar *tag, const gchar *arg0, ...)
 {
 	GtkWidget *w;
 	va_list ap;
-	int res;
+	gint res;
 
 	va_start(ap, arg0);
 	w = e_error_newv(parent, tag, arg0, ap);
