@@ -11,7 +11,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -41,7 +41,7 @@ typedef struct _ESignatureListClass ESignatureListClass;
 /* search options for the find command */
 typedef enum {
 	E_SIGNATURE_FIND_NAME,
-	E_SIGNATURE_FIND_UID,
+	E_SIGNATURE_FIND_UID
 } e_signature_find_t;
 
 struct _ESignatureList {
@@ -71,6 +71,6 @@ void e_signature_list_add (ESignatureList *signature_list, ESignature *signature
 void e_signature_list_change (ESignatureList *signature_list, ESignature *signature);
 void e_signature_list_remove (ESignatureList *signature_list, ESignature *signature);
 
-const ESignature *e_signature_list_find (ESignatureList *signature_list, e_signature_find_t type, const char *key);
+const ESignature *e_signature_list_find (ESignatureList *signature_list, e_signature_find_t type, const gchar *key);
 
 #endif /* __E_SIGNATURE_LIST__ */
