@@ -1,4 +1,4 @@
-/* 
+/*
  * (C) 2005 OpenedHand Ltd.
  *
  * Author: Jorn Baayen <jorn@openedhand.com>
@@ -15,8 +15,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #include <config.h>
@@ -29,7 +29,7 @@
 
 struct _GConfBridge {
         GConfClient *client;
-        
+
         GHashTable *bindings;
 };
 
@@ -43,10 +43,10 @@ typedef enum {
 typedef struct {
         BindingType type;
         guint id;
-        
+
         gboolean delayed_mode;
 
-        char *key;
+        gchar *key;
         guint val_notify_id;
         GSList *val_changes; /* List of changes made to GConf value,
                                 that have not received change notification
@@ -66,7 +66,7 @@ typedef struct {
         gboolean bind_size;
         gboolean bind_pos;
 
-        char *key_prefix;
+        gchar *key_prefix;
 
         GtkWindow *window;
         gulong configure_event_id;
@@ -79,7 +79,7 @@ typedef struct {
         BindingType type;
         guint id;
 
-        char *key;
+        gchar *key;
         guint val_notify_id;
         GSList *val_changes; /* List of changes made to GConf value,
                                 that have not received change notification
@@ -107,11 +107,6 @@ typedef union {
 static void
 unbind (Binding *binding);
 
-#if !HAVE_DECL_GCONF_VALUE_COMPARE /* Not in headers in GConf < 2.13 */
-int gconf_value_compare (const GConfValue *value_a,
-                         const GConfValue *value_b);
-#endif
-
 static GConfBridge *bridge = NULL; /* Global GConfBridge object */
 
 /* Free up all resources allocated by the GConfBridge. Called on exit. */
@@ -154,7 +149,7 @@ gconf_bridge_get (void)
  * gconf_bridge_get_client
  * @bridge: A #GConfBridge
  *
- * Returns the #GConfClient used by @bridge. This is the same #GConfClient 
+ * Returns the #GConfClient used by @bridge. This is the same #GConfClient
  * as returned by gconf_client_get_default().
  *
  * Return value: A #GConfClient.
@@ -188,7 +183,7 @@ prop_binding_sync_pref_to_prop (PropBinding *binding,
                                 GConfValue  *pref_value)
 {
         GValue src_value, value;
-        
+
         /* Make sure we don't enter an infinite synchronizing loop */
         g_signal_handler_block (binding->object, binding->prop_notify_id);
 
@@ -234,7 +229,7 @@ prop_binding_sync_pref_to_prop (PropBinding *binding,
                                    "transform a \"%s\" to a \"%s\".",
                                    g_type_name (src_value.g_type),
                                    g_type_name (value.g_type));
-                        
+
                         goto done;
                 }
 
@@ -244,7 +239,7 @@ prop_binding_sync_pref_to_prop (PropBinding *binding,
                 g_object_set_property (binding->object,
                                        binding->prop->name, &src_value);
         }
-        
+
 done:
         g_value_unset (&src_value);
         g_value_unset (&value);
@@ -326,11 +321,11 @@ prop_binding_sync_prop_to_pref (PropBinding *binding)
         case G_TYPE_DOUBLE:
                 gconf_value = gconf_value_new (GCONF_VALUE_FLOAT);
 #ifdef HAVE_CORBA_GCONF
-                /* FIXME we cast to a float explicitly as CORBA GConf
+                /* FIXME we cast to a gfloat explicitly as CORBA GConf
                  * uses doubles in its API, but treats them as floats
                  * when transporting them over CORBA. See #322837 */
                 gconf_value_set_float (gconf_value,
-                                       (float) g_value_get_double (&value));
+                                       (gfloat) g_value_get_double (&value));
 #else
                 gconf_value_set_float (gconf_value,
                                        g_value_get_double (&value));
@@ -402,7 +397,7 @@ prop_binding_pref_changed (GConfClient *client,
         prop_binding_sync_pref_to_prop (binding, gconf_value);
 }
 
-/* Performs a scheduled prop-to-pref sync for a prop binding in 
+/* Performs a scheduled prop-to-pref sync for a prop binding in
  * delay mode */
 static gboolean
 prop_binding_perform_scheduled_sync (PropBinding *binding)
@@ -412,7 +407,7 @@ prop_binding_perform_scheduled_sync (PropBinding *binding)
         binding->sync_timeout_id = 0;
 
         g_object_unref (binding->object);
-        
+
         return FALSE;
 }
 
@@ -456,7 +451,7 @@ prop_binding_object_destroyed (gpointer user_data,
         binding = (PropBinding *) user_data;
         binding->object = NULL; /* Don't do anything with the object
                                    at unbind() */
-        
+
         g_hash_table_remove (bridge->bindings,
                              GUINT_TO_POINTER (binding->id));
 }
@@ -484,14 +479,14 @@ prop_binding_object_destroyed (gpointer user_data,
  **/
 guint
 gconf_bridge_bind_property_full (GConfBridge *bridge,
-                                 const char  *key,
+                                 const gchar  *key,
                                  GObject     *object,
-                                 const char  *prop,
+                                 const gchar  *prop,
                                  gboolean     delayed_sync)
 {
         GParamSpec *pspec;
         PropBinding *binding;
-        char *signal;
+        gchar *signal;
         GConfValue *val;
 
         g_return_val_if_fail (bridge != NULL, 0);
@@ -521,7 +516,7 @@ gconf_bridge_bind_property_full (GConfBridge *bridge,
         binding->object = object;
         binding->prop = pspec;
         binding->sync_timeout_id = 0;
-        
+
         /* Watch GConf key */
         binding->val_notify_id =
                 gconf_client_notify_add (bridge->client, key,
@@ -562,7 +557,7 @@ prop_binding_unbind (PropBinding *binding)
         if (binding->delayed_mode && binding->sync_timeout_id > 0) {
                 /* Perform any scheduled syncs */
                 g_source_remove (binding->sync_timeout_id);
-                        
+
                 /* The object will still be around as we have
                  * a reference */
                 prop_binding_perform_scheduled_sync (binding);
@@ -598,8 +593,8 @@ static gboolean
 window_binding_perform_scheduled_sync (WindowBinding *binding)
 {
         if (binding->bind_size) {
-                int width, height;
-                char *key;
+                gint width, height;
+                gchar *key;
                 GdkWindowState state;
 
                 state = gdk_window_get_state (GTK_WIDGET (binding->window)->window);
@@ -626,8 +621,8 @@ window_binding_perform_scheduled_sync (WindowBinding *binding)
         }
 
         if (binding->bind_pos) {
-                int x, y;
-                char *key;
+                gint x, y;
+                gchar *key;
 
                 gtk_window_get_position (binding->window, &x, &y);
 
@@ -654,16 +649,16 @@ window_binding_configure_event_cb (GtkWindow         *window,
                                    GdkEventConfigure *event,
                                    WindowBinding     *binding)
 {
-        /* Schedule a sync */
-        if (binding->sync_timeout_id == 0) {
-                binding->sync_timeout_id =
-                        g_timeout_add_seconds (WINDOW_BINDING_SYNC_DELAY,
-                                       (GSourceFunc)
-                                          window_binding_perform_scheduled_sync,
-                                       binding);
-        }
+	/* re-postpone by cancel of the previous request */
+	if (binding->sync_timeout_id > 0)
+		g_source_remove (binding->sync_timeout_id);
 
-        return FALSE;
+	/* Schedule a sync */
+	binding->sync_timeout_id = g_timeout_add_seconds (WINDOW_BINDING_SYNC_DELAY,
+		(GSourceFunc) window_binding_perform_scheduled_sync,
+		binding);
+
+	return FALSE;
 }
 
 /* Called when the window state is being changed */
@@ -672,6 +667,9 @@ window_binding_state_event_cb (GtkWindow           *window,
                                GdkEventWindowState *event,
                                WindowBinding       *binding)
 {
+        if (binding->sync_timeout_id > 0)
+                g_source_remove (binding->sync_timeout_id);
+
         window_binding_perform_scheduled_sync (binding);
 
         return FALSE;
@@ -701,7 +699,10 @@ window_binding_window_destroyed (gpointer user_data,
         binding = (WindowBinding *) user_data;
         binding->window = NULL; /* Don't do anything with the window
                                    at unbind() */
-        
+
+        if (binding->sync_timeout_id > 0)
+                g_source_remove (binding->sync_timeout_id);
+
         g_hash_table_remove (bridge->bindings,
                              GUINT_TO_POINTER (binding->id));
 }
@@ -713,7 +714,7 @@ window_binding_window_destroyed (gpointer user_data,
  * @window: A #GtkWindow
  * @bind_size: TRUE to bind the size of @window
  * @bind_pos: TRUE to bind the position of @window
- * 
+ *
  * On calling this function @window will be resized to the values
  * specified by "@key_prefix<!-- -->_width" and "@key_prefix<!-- -->_height"
  * and maximixed if "@key_prefix<!-- -->_maximized is TRUE if
@@ -726,7 +727,7 @@ window_binding_window_destroyed (gpointer user_data,
  **/
 guint
 gconf_bridge_bind_window (GConfBridge *bridge,
-                          const char  *key_prefix,
+                          const gchar  *key_prefix,
                           GtkWindow   *window,
                           gboolean     bind_size,
                           gboolean     bind_pos)
@@ -750,7 +751,7 @@ gconf_bridge_bind_window (GConfBridge *bridge,
 
         /* Set up GConf keys & sync window to GConf values */
         if (bind_size) {
-                char *key;
+                gchar *key;
                 GConfValue *width_val, *height_val, *maximized_val;
 
                 key = g_strconcat (key_prefix, "_width", NULL);
@@ -787,9 +788,9 @@ gconf_bridge_bind_window (GConfBridge *bridge,
         }
 
         if (bind_pos) {
-                char *key;
+                gchar *key;
                 GConfValue *x_val, *y_val;
-                
+
                 key = g_strconcat (key_prefix, "_x", NULL);
                 x_val = gconf_client_get (bridge->client, key, NULL);
                 g_free (key);
@@ -884,13 +885,13 @@ list_store_binding_sync_pref_to_store (ListStoreBinding *binding,
                                 binding->row_inserted_id);
         g_signal_handler_block (binding->list_store,
                                 binding->row_deleted_id);
-        
+
         gtk_list_store_clear (binding->list_store);
 
         list = gconf_value_get_list (value);
         for (l = list; l; l = l->next) {
                 GConfValue *l_value;
-                const char *string;
+                const gchar *string;
 
                 l_value = (GConfValue *) l->data;
                 string = gconf_value_get_string (l_value);
@@ -914,7 +915,7 @@ list_store_binding_sync_store_to_pref (ListStoreBinding *binding)
         GtkTreeModel *tree_model;
         GtkTreeIter iter;
         GSList *list;
-        int res;
+        gint res;
         GConfValue *gconf_value;
 
         tree_model = GTK_TREE_MODEL (binding->list_store);
@@ -923,7 +924,7 @@ list_store_binding_sync_store_to_pref (ListStoreBinding *binding)
         list = NULL;
         res = gtk_tree_model_get_iter_first (tree_model, &iter);
         while (res) {
-                char *string;
+                gchar *string;
                 GConfValue *tmp_value;
 
                 gtk_tree_model_get (tree_model, &iter,
@@ -1001,7 +1002,7 @@ list_store_binding_store_destroyed (gpointer user_data,
         binding = (ListStoreBinding *) user_data;
         binding->list_store = NULL; /* Don't do anything with the store
                                        at unbind() */
-        
+
         g_hash_table_remove (bridge->bindings,
                              GUINT_TO_POINTER (binding->id));
 }
@@ -1024,7 +1025,7 @@ list_store_binding_store_changed_cb (ListStoreBinding *binding)
  * @bridge: A #GConfBridge
  * @key: A GConf key to be bound
  * @list_store: A #GtkListStore
- * 
+ *
  * On calling this function single string column #GtkListStore @list_store
  * will be kept synchronized with the GConf string list value pointed to by
  * @key. On calling this function @list_store will be populated with the
@@ -1034,7 +1035,7 @@ list_store_binding_store_changed_cb (ListStoreBinding *binding)
  **/
 guint
 gconf_bridge_bind_string_list_store (GConfBridge  *bridge,
-                                     const char   *key,
+                                     const gchar   *key,
                                      GtkListStore *list_store)
 {
         GtkTreeModel *tree_model;
@@ -1197,7 +1198,7 @@ gconf_bridge_unbind (GConfBridge *bridge,
 
         /* This will trigger the hash tables value destruction
          * function, which will take care of further cleanup */
-        g_hash_table_remove (bridge->bindings, 
+        g_hash_table_remove (bridge->bindings,
                              GUINT_TO_POINTER (binding_id));
 }
 
@@ -1215,7 +1216,7 @@ error_handler (GConfClient *client,
         g_warning ("GConf error:\n  %s", error->message);
 
         if (!shown_dialog) {
-                char *message;
+                gchar *message;
                 GtkWidget *dlg;
 
                 message = g_strdup_printf (_("GConf error: %s"),
