@@ -1,26 +1,26 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- *  Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
- *
- *  Authors: Not Zed <notzed@lostzed.mmc.com.au>
- *           Jeffrey Stedfast <fejj@ximian.com>
- *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
+ *
+ * Authors:
+ *		Not Zed <notzed@lostzed.mmc.com.au>
+ *      Jeffrey Stedfast <fejj@ximian.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
  */
 
-
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -32,10 +32,10 @@
 
 #define d(x)
 
-static int colour_eq (FilterElement *fe, FilterElement *cm);
+static gint colour_eq (FilterElement *fe, FilterElement *cm);
 static void xml_create (FilterElement *fe, xmlNodePtr node);
 static xmlNodePtr xml_encode (FilterElement *fe);
-static int xml_decode (FilterElement *fe, xmlNodePtr node);
+static gint xml_decode (FilterElement *fe, xmlNodePtr node);
 static GtkWidget *get_widget (FilterElement *fe);
 static void build_code (FilterElement *fe, GString *out, struct _FilterPart *ff);
 static void format_sexp (FilterElement *, GString *);
@@ -116,7 +116,7 @@ filter_colour_new (void)
 	return (FilterColour *) g_object_new (FILTER_TYPE_COLOUR, NULL, NULL);
 }
 
-static int
+static gint
 colour_eq (FilterElement *fe, FilterElement *cm)
 {
 	FilterColour *fc = (FilterColour *) fe;
@@ -143,37 +143,37 @@ xml_encode (FilterElement *fe)
 	g_snprintf (spec, sizeof (spec), "#%04x%04x%04x",
 		fc->color.red, fc->color.green, fc->color.blue);
 
-	value = xmlNewNode(NULL, (const unsigned char *)"value");
-	xmlSetProp(value, (const unsigned char *)"type", (const unsigned char *)"colour");
-	xmlSetProp(value, (const unsigned char *)"name", (unsigned char *)fe->name);
-	xmlSetProp(value, (const unsigned char *)"spec", (unsigned char *)spec);
+	value = xmlNewNode(NULL, (const guchar *)"value");
+	xmlSetProp(value, (const guchar *)"type", (const guchar *)"colour");
+	xmlSetProp(value, (const guchar *)"name", (guchar *)fe->name);
+	xmlSetProp(value, (const guchar *)"spec", (guchar *)spec);
 
 	return value;
 }
 
-static int
+static gint
 xml_decode (FilterElement *fe, xmlNodePtr node)
 {
 	FilterColour *fc = (FilterColour *)fe;
 	xmlChar *prop;
 
 	xmlFree (fe->name);
-	fe->name = (char *)xmlGetProp(node, (const unsigned char *)"name");
+	fe->name = (gchar *)xmlGetProp(node, (const guchar *)"name");
 
-	prop = xmlGetProp(node, (const unsigned char *)"spec");
+	prop = xmlGetProp(node, (const guchar *)"spec");
 	if (prop != NULL) {
-		gdk_color_parse((char *)prop, &fc->color);
+		gdk_color_parse((gchar *)prop, &fc->color);
 		xmlFree (prop);
 	} else {
 		/* try reading the old RGB properties */
-		prop = xmlGetProp(node, (const unsigned char *)"red");
-		sscanf((char *)prop, "%" G_GINT16_MODIFIER "x", &fc->color.red);
+		prop = xmlGetProp(node, (const guchar *)"red");
+		sscanf((gchar *)prop, "%" G_GINT16_MODIFIER "x", &fc->color.red);
 		xmlFree (prop);
-		prop = xmlGetProp(node, (const unsigned char *)"green");
-		sscanf((char *)prop, "%" G_GINT16_MODIFIER "x", &fc->color.green);
+		prop = xmlGetProp(node, (const guchar *)"green");
+		sscanf((gchar *)prop, "%" G_GINT16_MODIFIER "x", &fc->color.green);
 		xmlFree (prop);
-		prop = xmlGetProp(node, (const unsigned char *)"blue");
-		sscanf((char *)prop, "%" G_GINT16_MODIFIER "x", &fc->color.blue);
+		prop = xmlGetProp(node, (const guchar *)"blue");
+		sscanf((gchar *)prop, "%" G_GINT16_MODIFIER "x", &fc->color.blue);
 		xmlFree (prop);
 	}
 
