@@ -1,26 +1,25 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- *  Authors: Jeffrey Stedfast <fejj@ximian.com>
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
- *  Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * Authors:
+ *		Jeffrey Stedfast <fejj@ximian.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  */
 
-
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -33,11 +32,11 @@
 
 #define d(x)
 
-static int int_eq (FilterElement *fe, FilterElement *cm);
+static gint int_eq (FilterElement *fe, FilterElement *cm);
 static FilterElement *int_clone(FilterElement *fe);
 static void xml_create (FilterElement *fe, xmlNodePtr node);
 static xmlNodePtr xml_encode (FilterElement *fe);
-static int xml_decode (FilterElement *fe, xmlNodePtr node);
+static gint xml_decode (FilterElement *fe, xmlNodePtr node);
 static GtkWidget *get_widget (FilterElement *fe);
 static void build_code (FilterElement *fe, GString *out, struct _FilterPart *ff);
 static void format_sexp (FilterElement *fe, GString *out);
@@ -126,7 +125,7 @@ filter_int_new (void)
 }
 
 FilterInt *
-filter_int_new_type (const char *type, int min, int max)
+filter_int_new_type (const gchar *type, gint min, gint max)
 {
 	FilterInt *fi;
 
@@ -140,12 +139,12 @@ filter_int_new_type (const char *type, int min, int max)
 }
 
 void
-filter_int_set_value (FilterInt *fi, int val)
+filter_int_set_value (FilterInt *fi, gint val)
 {
 	fi->val = val;
 }
 
-static int
+static gint
 int_eq (FilterElement *fe, FilterElement *cm)
 {
         return FILTER_ELEMENT_CLASS (parent_class)->eq (fe, cm)
@@ -177,44 +176,44 @@ xml_encode (FilterElement *fe)
 {
 	xmlNodePtr value;
 	FilterInt *fs = (FilterInt *)fe;
-	char intval[32];
-	const char *type;
+	gchar intval[32];
+	const gchar *type;
 
 	type = fs->type?fs->type:"integer";
 
 	d(printf("Encoding %s as xml\n", type));
 
-	value = xmlNewNode (NULL, (const unsigned char *)"value");
-	xmlSetProp (value, (const unsigned char *)"name", (unsigned char *)fe->name);
-	xmlSetProp (value, (const unsigned char *)"type", (unsigned char *)type);
+	value = xmlNewNode (NULL, (const guchar *)"value");
+	xmlSetProp (value, (const guchar *)"name", (guchar *)fe->name);
+	xmlSetProp (value, (const guchar *)"type", (guchar *)type);
 
 	sprintf(intval, "%d", fs->val);
-	xmlSetProp (value, (unsigned char *)type, (unsigned char *)intval);
+	xmlSetProp (value, (guchar *)type, (guchar *)intval);
 
 	return value;
 }
 
-static int
+static gint
 xml_decode (FilterElement *fe, xmlNodePtr node)
 {
 	FilterInt *fs = (FilterInt *)fe;
-	char *name, *type;
-	char *intval;
+	gchar *name, *type;
+	gchar *intval;
 
 	d(printf("Decoding integer from xml %p\n", fe));
 
-	name = (char *)xmlGetProp (node, (const unsigned char *)"name");
+	name = (gchar *)xmlGetProp (node, (const guchar *)"name");
 	d(printf ("Name = %s\n", name));
 	xmlFree (fe->name);
 	fe->name = name;
 
-	type = (char *)xmlGetProp(node, (const unsigned char *)"type");
+	type = (gchar *)xmlGetProp(node, (const guchar *)"type");
 	d(printf ("Type = %s\n", type));
 	g_free(fs->type);
 	fs->type = g_strdup(type);
 	xmlFree(type);
 
-	intval = (char *)xmlGetProp (node, (unsigned char *)(fs->type ? fs->type : "integer"));
+	intval = (gchar *)xmlGetProp (node, (guchar *)(fs->type ? fs->type : "integer"));
 	if (intval) {
 		d(printf ("Value = %s\n", intval));
 		fs->val = atoi (intval);
@@ -242,7 +241,7 @@ get_widget (FilterElement *fe)
 	GtkObject *adjustment;
 	FilterInt *fs = (FilterInt *)fe;
 
-	adjustment = gtk_adjustment_new (0.0, (gfloat)fs->min, (gfloat)fs->max, 1.0, 1.0, 1.0);
+	adjustment = gtk_adjustment_new (0.0, (gfloat)fs->min, (gfloat)fs->max, 1.0, 1.0, 0);
 	spin = gtk_spin_button_new (GTK_ADJUSTMENT (adjustment), fs->max>fs->min+1000?5.0:1.0, 0);
 	gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spin), TRUE);
 
