@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -46,20 +46,20 @@
 #include "mail-config.h"
 
 struct _prop_data {
-	void *object;
+	gpointer object;
 	CamelArgV *argv;
 	GtkWidget **widgets;
 
 	GSList *properties;
-	char *name;
-	int total;
-	int unread;
+	gchar *name;
+	gint total;
+	gint unread;
 	EMConfig *config;
 	CamelFolderQuotaInfo *quota;
 };
 
 static void
-emfp_dialog_response (GtkWidget *dialog, int response, struct _prop_data *prop_data)
+emfp_dialog_response (GtkWidget *dialog, gint response, struct _prop_data *prop_data)
 {
 	if (response == GTK_RESPONSE_OK)
 		e_config_commit((EConfig *)prop_data->config);
@@ -70,11 +70,11 @@ emfp_dialog_response (GtkWidget *dialog, int response, struct _prop_data *prop_d
 }
 
 static void
-emfp_commit(EConfig *ec, GSList *items, void *data)
+emfp_commit(EConfig *ec, GSList *items, gpointer data)
 {
 	struct _prop_data *prop_data = data;
 	CamelArgV *argv = prop_data->argv;
-	int i;
+	gint i;
 
 	for (i = 0; i < argv->argc; i++) {
 		CamelArg *arg = &argv->argv[i];
@@ -85,7 +85,7 @@ emfp_commit(EConfig *ec, GSList *items, void *data)
 			break;
 		case CAMEL_ARG_STR:
 			g_free (arg->ca_str);
-			arg->ca_str = (char *) gtk_entry_get_text ((GtkEntry *) prop_data->widgets[i]);
+			arg->ca_str = (gchar *) gtk_entry_get_text ((GtkEntry *) prop_data->widgets[i]);
 			break;
 		case CAMEL_ARG_INT:
 			arg->ca_int = gtk_spin_button_get_value_as_int ((GtkSpinButton *) prop_data->widgets[i]);
@@ -103,10 +103,10 @@ emfp_commit(EConfig *ec, GSList *items, void *data)
 }
 
 static void
-emfp_free(EConfig *ec, GSList *items, void *data)
+emfp_free(EConfig *ec, GSList *items, gpointer data)
 {
 	struct _prop_data *prop_data = data;
-	int i;
+	gint i;
 
 	g_slist_free(items);
 
@@ -126,10 +126,10 @@ emfp_free(EConfig *ec, GSList *items, void *data)
 	g_free (prop_data);
 }
 
-static int
-add_numbered_row (GtkTable *table, int row, const char *description, const char *format, int num)
+static gint
+add_numbered_row (GtkTable *table, gint row, const gchar *description, const gchar *format, gint num)
 {
-	char *str;
+	gchar *str;
 	GtkWidget *label;
 
 	g_return_val_if_fail (table != NULL, row);
@@ -154,11 +154,11 @@ add_numbered_row (GtkTable *table, int row, const char *description, const char
 }
 
 static GtkWidget *
-emfp_get_folder_item(EConfig *ec, EConfigItem *item, struct _GtkWidget *parent, struct _GtkWidget *old, void *data)
+emfp_get_folder_item(EConfig *ec, EConfigItem *item, struct _GtkWidget *parent, struct _GtkWidget *old, gpointer data)
 {
 	GtkWidget *w, *table, *label;
 	struct _prop_data *prop_data = data;
-	int row = 0, i;
+	gint row = 0, i;
 	GSList *l;
 
 	if (old)
@@ -182,8 +182,8 @@ emfp_get_folder_item(EConfig *ec, EConfigItem *item, struct _GtkWidget *parent,
 		CamelFolderQuotaInfo *quota = prop_data->quota;
 
 		for (info = quota; info; info = info->next) {
-			char *descr;
-			int procs;
+			gchar *descr;
+			gint procs;
 
 			/* should not happen, but anyway... */
 			if (!info->total)
@@ -197,7 +197,7 @@ emfp_get_folder_item(EConfig *ec, EConfigItem *item, struct _GtkWidget *parent,
 			else
 				descr = g_strdup_printf (_("Quota usage"));
 
-			procs = (int) ((((double) info->used) / ((double) info->total)) * 100.0 + 0.5);
+			procs = (gint) ((((double) info->used) / ((double) info->total)) * 100.0 + 0.5);
 
 			row = add_numbered_row (GTK_TABLE (table), row, descr, "%d%%", procs);
 
@@ -240,7 +240,7 @@ emfp_get_folder_item(EConfig *ec, EConfigItem *item, struct _GtkWidget *parent,
 			gtk_misc_set_alignment ((GtkMisc *) label, 0.0, 0.5);
 			gtk_widget_show (label);
 			gtk_table_attach ((GtkTable *) table, label, 0, 1, row, row + 1, GTK_FILL, 0, 0, 0);
-			
+
 			w = gtk_spin_button_new_with_range (G_MININT, G_MAXINT, 1.0);
 			gtk_spin_button_set_value ((GtkSpinButton *) w, (double) prop_data->argv->argv[i].ca_int);
 			gtk_spin_button_set_numeric ((GtkSpinButton *) w, TRUE);
@@ -254,7 +254,7 @@ emfp_get_folder_item(EConfig *ec, EConfigItem *item, struct _GtkWidget *parent,
 			gtk_misc_set_alignment ((GtkMisc *) label, 0.0, 0.5);
 			gtk_widget_show (label);
 			gtk_table_attach ((GtkTable *) table, label, 0, 1, row, row + 1, GTK_FILL, 0, 0, 0);
-			
+
 			w = gtk_spin_button_new_with_range (G_MININT, G_MAXINT, 1.0);
 			gtk_spin_button_set_value ((GtkSpinButton *) w, prop_data->argv->argv[i].ca_double);
 			gtk_spin_button_set_numeric ((GtkSpinButton *) w, TRUE);
@@ -279,15 +279,15 @@ emfp_get_folder_item(EConfig *ec, EConfigItem *item, struct _GtkWidget *parent,
 #define EMFP_FOLDER_SECTION (2)
 
 static EMConfigItem emfp_items[] = {
-	{ E_CONFIG_BOOK,  "", NULL },
-	{ E_CONFIG_PAGE, "00.general", N_("General") },
-	{ E_CONFIG_SECTION, "00.general/00.folder", NULL /* set by code */ },
-	{ E_CONFIG_ITEM, "00.general/00.folder/00.info", NULL, emfp_get_folder_item },
+	{ E_CONFIG_BOOK, (gchar *) "", NULL },
+	{ E_CONFIG_PAGE, (gchar *) "00.general", (gchar *) N_("General") },
+	{ E_CONFIG_SECTION, (gchar *) "00.general/00.folder", NULL /* set by code */ },
+	{ E_CONFIG_ITEM, (gchar *) "00.general/00.folder/00.info", NULL, emfp_get_folder_item },
 };
 static gboolean emfp_items_translated = FALSE;
 
 static void
-emfp_dialog_got_folder_quota (CamelFolder *folder, CamelFolderQuotaInfo *quota, void *data)
+emfp_dialog_got_folder_quota (CamelFolder *folder, CamelFolderQuotaInfo *quota, gpointer data)
 {
 	GtkWidget *dialog, *w;
 	struct _prop_data *prop_data;
@@ -300,7 +300,7 @@ emfp_dialog_got_folder_quota (CamelFolder *folder, CamelFolderQuotaInfo *quota,
 	gboolean hide_deleted;
 	GConfClient *gconf;
 	CamelStore *store;
-	char *uri = (char *)data;
+	gchar *uri = (gchar *)data;
 
 	if (folder == NULL) {
 		g_free (uri);
@@ -426,7 +426,7 @@ emfp_dialog_got_folder_quota (CamelFolder *folder, CamelFolderQuotaInfo *quota,
 }
 
 static void
-emfp_dialog_got_folder (char *uri, CamelFolder *folder, void *data)
+emfp_dialog_got_folder (gchar *uri, CamelFolder *folder, gpointer data)
 {
 	/* this should be called in a thread too */
 	mail_get_folder_quota (folder, emfp_dialog_got_folder_quota, g_strdup (uri), mail_msg_unordered_push);
@@ -442,7 +442,7 @@ emfp_dialog_got_folder (char *uri, CamelFolder *folder, void *data)
  * as NULL, then the folder @uri will be loaded first.
  **/
 void
-em_folder_properties_show(GtkWindow *parent, CamelFolder *folder, const char *uri)
+em_folder_properties_show(GtkWindow *parent, CamelFolder *folder, const gchar *uri)
 {
 	/* HACK: its the old behaviour, not very 'neat' but it works */
 	if (!strncmp(uri, "vfolder:", 8)) {
@@ -464,5 +464,5 @@ em_folder_properties_show(GtkWindow *parent, CamelFolder *folder, const char *ur
 	if (folder == NULL)
 		mail_get_folder(uri, 0, emfp_dialog_got_folder, NULL, mail_msg_unordered_push);
 	else
-		emfp_dialog_got_folder((char *)uri, folder, NULL);
+		emfp_dialog_got_folder((gchar *)uri, folder, NULL);
 }
