@@ -1,31 +1,29 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- *  Authors: Jeffrey Stedfast <fejj@ximian.com>
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
- *  Copyright 2003 Ximian, Inc. (www.ximian.com)
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * Authors:
+ *		Jeffrey Stedfast <fejj@ximian.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  */
 
-
 #ifndef __EM_FOLDER_TREE_MODEL_H__
 #define __EM_FOLDER_TREE_MODEL_H__
 
-#include <gtk/gtktreednd.h>
-#include <gtk/gtktreestore.h>
+#include <gtk/gtk.h>
 
 #include <libxml/tree.h>
 
@@ -53,14 +51,17 @@ enum {
 	COL_STRING_DISPLAY_NAME,  /* string that appears in the tree */
 	COL_POINTER_CAMEL_STORE,  /* CamelStore object */
 	COL_STRING_FULL_NAME,   /* if node is a folder, the full path name of the folder, no leading / */
+	COL_STRING_ICON_NAME,     /* icon name for the folder */
 	COL_STRING_URI,           /* the uri to get the store or folder object */
 	COL_UINT_UNREAD,          /* unread count */
 	COL_UINT_FLAGS,		/* FolderInfo.flags */
 
 	COL_BOOL_IS_STORE,        /* toplevel store node? */
+	COL_BOOL_IS_FOLDER,       /* folder (not a store) */
 	COL_BOOL_LOAD_SUBDIRS,    /* %TRUE only if the store/folder
 				   * has subfolders which have not yet
 				   * been added to the tree */
+	COL_UINT_UNREAD_LAST_SEL, /* last known unread count */
 	NUM_COLUMNS
 };
 
@@ -71,19 +72,19 @@ struct _EMFolderTreeModelStoreInfo {
 	GHashTable *full_hash;  /* maps CamelFolderInfo::full_name's to GtkTreeRowReferences */
 	EAccount *account;
 
-	char *display_name;
+	gchar *display_name;
 
-	unsigned int created_id;
-	unsigned int deleted_id;
-	unsigned int renamed_id;
-	unsigned int subscribed_id;
-	unsigned int unsubscribed_id;
+	guint created_id;
+	guint deleted_id;
+	guint renamed_id;
+	guint subscribed_id;
+	guint unsubscribed_id;
 };
 
 struct _EMFolderTreeModel {
 	GtkTreeStore parent_object;
 
-	char *filename;            /* state filename */
+	gchar *filename;            /* state filename */
 	xmlDocPtr state;           /* saved expanded state from previous session */
 
 	GHashTable *store_hash;    /* maps CamelStore's to store-info's */
@@ -108,47 +109,46 @@ struct _EMFolderTreeModelClass {
 					 GtkTreeIter *iter);
 
 	void     (* folder_added)       (EMFolderTreeModel *model,
-					 const char *path,
-					 const char *uri);
+					 const gchar *path,
+					 const gchar *uri);
 
 	void     (* store_added)        (EMFolderTreeModel *model,
-					 const char *uri);
+					 const gchar *uri);
 };
 
 
 GType em_folder_tree_model_get_type (void);
 
 
-EMFolderTreeModel *em_folder_tree_model_new (const char *evolution_dir);
+EMFolderTreeModel *em_folder_tree_model_new (const gchar *evolution_dir);
 
 
 void em_folder_tree_model_set_folder_info (EMFolderTreeModel *model, GtkTreeIter *iter,
 					   struct _EMFolderTreeModelStoreInfo *si,
-					   CamelFolderInfo *fi, int fully_loaded);
+					   CamelFolderInfo *fi, gint fully_loaded);
 
-void em_folder_tree_model_add_store (EMFolderTreeModel *model, CamelStore *store, const char *display_name);
+void em_folder_tree_model_add_store (EMFolderTreeModel *model, CamelStore *store, const gchar *display_name);
 void em_folder_tree_model_remove_store (EMFolderTreeModel *model, CamelStore *store);
 void em_folder_tree_model_remove_folders (EMFolderTreeModel *model, struct _EMFolderTreeModelStoreInfo *si,
 					  GtkTreeIter *toplevel);
 
-char *em_folder_tree_model_get_selected (EMFolderTreeModel *model);
-void em_folder_tree_model_set_selected (EMFolderTreeModel *model, const char *uri);
+gchar *em_folder_tree_model_get_selected (EMFolderTreeModel *model);
+void em_folder_tree_model_set_selected (EMFolderTreeModel *model, const gchar *uri);
 
-gboolean em_folder_tree_model_get_expanded (EMFolderTreeModel *model, const char *key);
-void em_folder_tree_model_set_expanded (EMFolderTreeModel *model, const char *key, gboolean expanded);
+gboolean em_folder_tree_model_get_expanded (EMFolderTreeModel *model, const gchar *key);
+void em_folder_tree_model_set_expanded (EMFolderTreeModel *model, const gchar *key, gboolean expanded);
 
-gboolean em_folder_tree_model_get_expanded_uri (EMFolderTreeModel *model, const char *uri);
-void em_folder_tree_model_set_expanded_uri (EMFolderTreeModel *model, const char *uri, gboolean expanded);
+gboolean em_folder_tree_model_get_expanded_uri (EMFolderTreeModel *model, const gchar *uri);
+void em_folder_tree_model_set_expanded_uri (EMFolderTreeModel *model, const gchar *uri, gboolean expanded);
 
 void em_folder_tree_model_save_state (EMFolderTreeModel *model);
 
-typedef void (* EMFTModelExpandFunc) (EMFolderTreeModel *model, const char *path, void *user_data);
-void em_folder_tree_model_expand_foreach (EMFolderTreeModel *model, EMFTModelExpandFunc func, void *user_data);
+typedef void (* EMFTModelExpandFunc) (EMFolderTreeModel *model, const gchar *path, gpointer user_data);
+void em_folder_tree_model_expand_foreach (EMFolderTreeModel *model, EMFTModelExpandFunc func, gpointer user_data);
 
-void em_folder_tree_model_set_unread_count (EMFolderTreeModel *model, CamelStore *store, const char *path, int unread);
-gboolean em_folder_tree_model_is_type_inbox (EMFolderTreeModel *model, CamelStore *store, const char *full);
-char * em_folder_tree_model_get_folder_name (EMFolderTreeModel *model, CamelStore *store, const char *full);
-void em_folder_tree_model_signal_block (EMFolderTreeModel *model, CamelStore *store, gboolean block);
+void em_folder_tree_model_set_unread_count (EMFolderTreeModel *model, CamelStore *store, const gchar *path, gint unread);
+gboolean em_folder_tree_model_is_type_inbox (EMFolderTreeModel *model, CamelStore *store, const gchar *full);
+gchar * em_folder_tree_model_get_folder_name (EMFolderTreeModel *model, CamelStore *store, const gchar *full);
 
 #ifdef __cplusplus
 }
