@@ -1,22 +1,22 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- *  Authors: Michael Zucchi <notzed@ximian.com>
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
- *  Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * Authors:
+ *		Michael Zucchi <notzed@ximian.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  */
 
@@ -67,11 +67,11 @@ enum {
 	EM_FOLDER_VIEW_SELECT_SELECTION = EM_POPUP_SELECT_LAST<<6,
 	EM_FOLDER_VIEW_SELECT_NOSELECTION = EM_POPUP_SELECT_LAST<<7,
 	EM_FOLDER_VIEW_PREVIEW_PRESENT = EM_POPUP_SELECT_LAST<<8,
-	EM_FOLDER_VIEW_SELECT_LAST = EM_POPUP_SELECT_LAST<<9,
+	EM_FOLDER_VIEW_SELECT_LAST = EM_POPUP_SELECT_LAST<<9
 };
 
 struct _EMFolderViewEnable {
-	const char *name;	/* bonobo name, relative to /commands/ */
+	const gchar *name;	/* bonobo name, relative to /commands/ */
 	guint32 mask;		/* disable mask, see EM_FOLDER_VIEW_CAN* flags */
 };
 
@@ -85,13 +85,13 @@ struct _EMFolderView {
 	struct _EMFormatHTMLDisplay *preview;
 
 	struct _CamelFolder *folder;
-	char *folder_uri;
+	gchar *folder_uri;
 
-	char *displayed_uid;	/* only used to stop re-loads, don't use it to represent any selection state */
+	gchar *displayed_uid;	/* only used to stop re-loads, don't use it to represent any selection state */
 
 	/* used to load ui from base activate implementation */
-	GSList *ui_files;	/* const char * list, TODO: should this be on class? */
-	const char *ui_app_name;
+	GSList *ui_files;	/* const gchar * list, TODO: should this be on class? */
+	const gchar *ui_app_name;
 
 	/* used to manage some menus, particularly plugins */
 	struct _EMMenu *menu;
@@ -103,7 +103,7 @@ struct _EMFolderView {
 	GSList *enable_map;	/* bonobo menu enable map, entries are 0-terminated EMFolderViewEnable arryas
 				   TODO: should this be on class? */
 
-	int mark_seen_timeout;	/* local copy of gconf stuff */
+	gint mark_seen_timeout;	/* local copy of gconf stuff */
 	guint mark_seen:1;
 	guint preview_active:1;	/* is preview being used */
 	guint statusbar_active:1; /* should we manage the statusbar messages ourselves? */
@@ -118,14 +118,16 @@ struct _EMFolderViewClass {
 	guint update_message_style:1;
 
 	/* if used as a control, used to activate/deactivate custom menu's */
-	void (*activate)(EMFolderView *, struct _BonoboUIComponent *uic, int state);
+	void (*activate)(EMFolderView *, struct _BonoboUIComponent *uic, gint state);
 
-	void (*set_folder_uri)(EMFolderView *emfv, const char *uri);
-	void (*set_folder)(EMFolderView *emfv, struct _CamelFolder *folder, const char *uri);
-	void (*set_message)(EMFolderView *emfv, const char *uid, int nomarkseen);
+	void (*set_folder_uri)(EMFolderView *emfv, const gchar *uri);
+	void (*set_folder)(EMFolderView *emfv, struct _CamelFolder *folder, const gchar *uri);
+	void (*set_message)(EMFolderView *emfv, const gchar *uid, gint nomarkseen);
+
+	void (*show_search_bar)(EMFolderView *emfv);
 
 	/* Signals */
-	void (*on_url)(EMFolderView *emfv, const char *uri, const char *nice_uri);
+	void (*on_url)(EMFolderView *emfv, const gchar *uri, const gchar *nice_uri);
 
 	void (*loaded)(EMFolderView *emfv);
 	void (*changed)(EMFolderView *emfv);
@@ -140,12 +142,12 @@ GtkWidget *em_folder_view_new(void);
 #define em_folder_view_set_folder_uri(emfv, uri) EM_FOLDER_VIEW_GET_CLASS (emfv)->set_folder_uri((emfv), (uri))
 #define em_folder_view_set_message(emfv, uid, nomarkseen) EM_FOLDER_VIEW_GET_CLASS (emfv)->set_message((emfv), (uid), (nomarkseen))
 
-EMPopupTargetSelect *em_folder_view_get_popup_target(EMFolderView *emfv, EMPopup *emp, int on_display);
+EMPopupTargetSelect *em_folder_view_get_popup_target(EMFolderView *emfv, EMPopup *emp, gint on_display);
 
-int em_folder_view_mark_selected(EMFolderView *emfv, guint32 mask, guint32 set);
-int em_folder_view_open_selected(EMFolderView *emfv);
+gint em_folder_view_mark_selected(EMFolderView *emfv, guint32 mask, guint32 set);
+gint em_folder_view_open_selected(EMFolderView *emfv);
 
-int em_folder_view_print(EMFolderView *emfv, GtkPrintOperationAction action);
+gint em_folder_view_print(EMFolderView *emfv, GtkPrintOperationAction action);
 
 /* this could be on message-list */
 guint32 em_folder_view_disable_mask(EMFolderView *emfv);
@@ -153,6 +155,7 @@ guint32 em_folder_view_disable_mask(EMFolderView *emfv);
 void em_folder_view_set_statusbar(EMFolderView *emfv, gboolean statusbar);
 void em_folder_view_set_hide_deleted(EMFolderView *emfv, gboolean status);
 void em_folder_view_setup_view_instance (EMFolderView *emfv);
+void em_folder_view_show_search_bar (EMFolderView *emfv);
 
 G_END_DECLS
 
