@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -65,9 +65,9 @@ struct _EMFormatCache {
 	struct _CamelCipherValidity *valid; /* validity copy */
 	struct _CamelMimePart *secured;	/* encrypted subpart */
 
-	unsigned int state:2;		/* inline state */
+	guint state:2;		/* inline state */
 
-	char partid[1];
+	gchar partid[1];
 };
 
 #define INLINE_UNSET (0)
@@ -76,15 +76,17 @@ struct _EMFormatCache {
 
 static void emf_builtin_init(EMFormatClass *);
 
-static const EMFormatHandler *emf_find_handler(EMFormat *emf, const char *mime_type);
-static void emf_format_clone(EMFormat *emf, CamelFolder *folder, const char *uid, CamelMimeMessage *msg, EMFormat *emfsource);
+static const EMFormatHandler *emf_find_handler(EMFormat *emf, const gchar *mime_type);
+static void emf_format_clone(EMFormat *emf, CamelFolder *folder, const gchar *uid, CamelMimeMessage *msg, EMFormat *emfsource);
 static void emf_format_secure(EMFormat *emf, CamelStream *stream, CamelMimePart *part, CamelCipherValidity *valid);
 static gboolean emf_busy(EMFormat *emf);
 enum {
 	EMF_COMPLETE,
-	EMF_LAST_SIGNAL,
+	EMF_LAST_SIGNAL
 };
 
+extern CamelSession *session;
+
 static guint emf_signals[EMF_LAST_SIGNAL];
 static GObjectClass *emf_parent;
 
@@ -99,7 +101,7 @@ emf_free_cache(struct _EMFormatCache *efc)
 }
 
 static struct _EMFormatCache *
-emf_insert_cache(EMFormat *emf, const char *partid)
+emf_insert_cache(EMFormat *emf, const gchar *partid)
 {
 	struct _EMFormatCache *new;
 
@@ -120,6 +122,7 @@ emf_init(GObject *o)
 		(GDestroyNotify) NULL,
 		(GDestroyNotify) emf_free_cache);
 	emf->composer = FALSE;
+	emf->print = FALSE;
 	emf->show_photo = TRUE;
 	emf->photo_local = TRUE;
 	e_dlist_init(&emf->header_list);
@@ -217,9 +220,9 @@ em_format_get_type(void)
 void
 em_format_class_add_handler(EMFormatClass *emfc, EMFormatHandler *info)
 {
-	d(printf("adding format handler to '%s' '%s'\n", 	g_type_name_from_class((GTypeClass *)emfc), info->mime_type));
+	d(printf("adding format handler to '%s' '%s'\n",	g_type_name_from_class((GTypeClass *)emfc), info->mime_type));
 	info->old = g_hash_table_lookup(emfc->type_handlers, info->mime_type);
-	g_hash_table_insert(emfc->type_handlers, info->mime_type, info);
+	g_hash_table_insert(emfc->type_handlers, (gpointer) info->mime_type, info);
 }
 
 struct _class_handlers {
@@ -273,7 +276,7 @@ em_format_class_remove_handler(EMFormatClass *emfc, EMFormatHandler *info)
 	if (current == info) {
 		current = info->old;
 		if (current)
-			g_hash_table_insert(emfc->type_handlers, current->mime_type, current);
+			g_hash_table_insert(emfc->type_handlers, (gpointer) current->mime_type, current);
 		else
 			g_hash_table_remove(emfc->type_handlers, info->mime_type);
 	} else {
@@ -294,7 +297,7 @@ em_format_class_remove_handler(EMFormatClass *emfc, EMFormatHandler *info)
  * Return value: NULL if no handler is available.
  **/
 static const EMFormatHandler *
-emf_find_handler(EMFormat *emf, const char *mime_type)
+emf_find_handler(EMFormat *emf, const gchar *mime_type)
 {
 	EMFormatClass *emfc = (EMFormatClass *)G_OBJECT_GET_CLASS(emf);
 
@@ -313,15 +316,15 @@ emf_find_handler(EMFormat *emf, const char *mime_type)
  * Return value:
  **/
 const EMFormatHandler *
-em_format_fallback_handler(EMFormat *emf, const char *mime_type)
+em_format_fallback_handler(EMFormat *emf, const gchar *mime_type)
 {
-	char *mime, *s;
+	gchar *mime, *s;
 
 	s = strchr(mime_type, '/');
 	if (s == NULL)
-		mime = (char *)mime_type;
+		mime = (gchar *)mime_type;
 	else {
-		size_t len = (s-mime_type)+1;
+		gsize len = (s-mime_type)+1;
 
 		mime = alloca(len+2);
 		strncpy(mime, mime_type, len);
@@ -356,10 +359,10 @@ em_format_fallback_handler(EMFormat *emf, const char *mime_type)
  * are resolved by forgetting the old PURI in the global index.
  **/
 EMFormatPURI *
-em_format_add_puri(EMFormat *emf, size_t size, const char *cid, CamelMimePart *part, EMFormatPURIFunc func)
+em_format_add_puri(EMFormat *emf, gsize size, const gchar *cid, CamelMimePart *part, EMFormatPURIFunc func)
 {
 	EMFormatPURI *puri;
-	const char *tmp;
+	const gchar *tmp;
 
 	d(printf("adding puri for part: %s\n", emf->part_id->str));
 
@@ -476,7 +479,7 @@ em_format_pull_level(EMFormat *emf)
  * Return value:
  **/
 EMFormatPURI *
-em_format_find_visible_puri(EMFormat *emf, const char *uri)
+em_format_find_visible_puri(EMFormat *emf, const gchar *uri)
 {
 	EMFormatPURI *pw;
 	struct _EMFormatPURITree *ptree;
@@ -510,7 +513,7 @@ em_format_find_visible_puri(EMFormat *emf, const char *uri)
  **/
 EMFormatPURI *
 
-em_format_find_puri(EMFormat *emf, const char *uri)
+em_format_find_puri(EMFormat *emf, const gchar *uri)
 {
 	return g_hash_table_lookup(emf->pending_uri_table, uri);
 }
@@ -579,12 +582,12 @@ em_format_clear_puri_tree(EMFormat *emf)
 
 /* use mime_type == NULL  to force showing as application/octet-stream */
 void
-em_format_part_as(EMFormat *emf, CamelStream *stream, CamelMimePart *part, const char *mime_type)
+em_format_part_as(EMFormat *emf, CamelStream *stream, CamelMimePart *part, const gchar *mime_type)
 {
 	const EMFormatHandler *handle = NULL;
-	const char *snoop_save = emf->snoop_mime_type, *tmp;
+	const gchar *snoop_save = emf->snoop_mime_type, *tmp;
 	CamelURL *base_save = emf->base, *base = NULL;
-	char *basestr = NULL;
+	gchar *basestr = NULL;
 
 	d(printf("format_part_as()\n"));
 
@@ -642,7 +645,7 @@ finish:
 void
 em_format_part(EMFormat *emf, CamelStream *stream, CamelMimePart *part)
 {
-	char *mime_type;
+	gchar *mime_type;
 	CamelDataWrapper *dw;
 
 	dw = camel_medium_get_content_object((CamelMedium *)part);
@@ -656,7 +659,7 @@ em_format_part(EMFormat *emf, CamelStream *stream, CamelMimePart *part)
 }
 
 static void
-emf_clone_inlines(void *key, void *val, void *data)
+emf_clone_inlines(gpointer key, gpointer val, gpointer data)
 {
 	struct _EMFormatCache *emfc = val, *new;
 
@@ -669,7 +672,7 @@ emf_clone_inlines(void *key, void *val, void *data)
 }
 
 static void
-emf_format_clone(EMFormat *emf, CamelFolder *folder, const char *uid, CamelMimeMessage *msg, EMFormat *emfsource)
+emf_format_clone(EMFormat *emf, CamelFolder *folder, const gchar *uid, CamelMimeMessage *msg, EMFormat *emfsource)
 {
 	em_format_clear_puri_tree(emf);
 
@@ -717,7 +720,7 @@ emf_format_clone(EMFormat *emf, CamelFolder *folder, const char *uid, CamelMimeM
 	g_string_truncate(emf->part_id, 0);
 	if (folder != NULL)
 		/* TODO build some string based on the folder name/location? */
-		g_string_append_printf(emf->part_id, ".%p", folder);
+		g_string_append_printf(emf->part_id, ".%p", (gpointer) folder);
 	if (uid != NULL)
 		g_string_append_printf(emf->part_id, ".%s", uid);
 }
@@ -726,7 +729,7 @@ static void
 emf_format_secure(EMFormat *emf, CamelStream *stream, CamelMimePart *part, CamelCipherValidity *valid)
 {
 	CamelCipherValidity *save = emf->valid_parent;
-	int len;
+	gint len;
 
 	/* Note that this also requires support from higher up in the class chain
 	    - validity needs to be cleared when you start output
@@ -771,7 +774,43 @@ emf_busy(EMFormat *emf)
  * a display refresh, or it can be used to generate an identical layout,
  * e.g. to print what the user has shown inline.
  **/
-/* e_format_format_clone is a macro */
+void
+em_format_format_clone (EMFormat *emf,
+                        CamelFolder *folder,
+                        const gchar *uid,
+                        CamelMimeMessage *message,
+                        EMFormat *source)
+{
+	EMFormatClass *class;
+
+	g_return_if_fail (EM_IS_FORMAT (emf));
+	g_return_if_fail (folder == NULL || CAMEL_IS_FOLDER (folder));
+	g_return_if_fail (message == NULL || CAMEL_IS_MIME_MESSAGE (message));
+	g_return_if_fail (source == NULL || EM_IS_FORMAT (source));
+
+	class = EM_FORMAT_GET_CLASS (emf);
+	g_return_if_fail (class->format_clone != NULL);
+	class->format_clone (emf, folder, uid, message, source);
+}
+
+void
+em_format_format (EMFormat *emf,
+                  CamelFolder *folder,
+                  const gchar *uid,
+                  CamelMimeMessage *message)
+{
+	/* em_format_format_clone() will check the arguments. */
+	em_format_format_clone (emf, folder, uid, message, NULL);
+}
+
+void
+em_format_redraw (EMFormat *emf)
+{
+	g_return_if_fail (EM_IS_FORMAT (emf));
+
+	em_format_format_clone (
+		emf, emf->folder, emf->uid, emf->message, emf);
+}
 
 /**
  * em_format_set_session:
@@ -822,7 +861,7 @@ em_format_set_mode(EMFormat *emf, em_format_mode_t type)
  * required.
  **/
 void
-em_format_set_charset(EMFormat *emf, const char *charset)
+em_format_set_charset(EMFormat *emf, const gchar *charset)
 {
 	if ((emf->charset && charset && g_ascii_strcasecmp(emf->charset, charset) == 0)
 	    || (emf->charset == NULL && charset == NULL)
@@ -846,7 +885,7 @@ em_format_set_charset(EMFormat *emf, const char *charset)
  * when it isn't).
  **/
 void
-em_format_set_default_charset(EMFormat *emf, const char *charset)
+em_format_set_default_charset(EMFormat *emf, const gchar *charset)
 {
 	if ((emf->default_charset && charset && g_ascii_strcasecmp(emf->default_charset, charset) == 0)
 	    || (emf->default_charset == NULL && charset == NULL)
@@ -878,7 +917,7 @@ em_format_clear_headers(EMFormat *emf)
 
 /* note: also copied in em-mailer-prefs.c */
 static const struct {
-	const char *name;
+	const gchar *name;
 	guint32 flags;
 } default_headers[] = {
 	{ N_("From"), EM_FORMAT_HEADER_BOLD },
@@ -903,7 +942,7 @@ static const struct {
 void
 em_format_default_headers(EMFormat *emf)
 {
-	int i;
+	gint i;
 
 	em_format_clear_headers(emf);
 	for (i=0; i<sizeof(default_headers)/sizeof(default_headers[0]); i++)
@@ -921,7 +960,7 @@ em_format_default_headers(EMFormat *emf)
  * headers included in this list will be shown using special
  * formatting routines.
  **/
-void em_format_add_header(EMFormat *emf, const char *name, guint32 flags)
+void em_format_add_header(EMFormat *emf, const gchar *name, guint32 flags)
 {
 	EMFormatHeader *h;
 
@@ -947,11 +986,14 @@ void em_format_add_header(EMFormat *emf, const char *name, guint32 flags)
  *
  * Return value: TRUE/FALSE
  **/
-int em_format_is_attachment(EMFormat *emf, CamelMimePart *part)
+gint em_format_is_attachment(EMFormat *emf, CamelMimePart *part)
 {
 	/*CamelContentType *ct = camel_mime_part_get_content_type(part);*/
 	CamelDataWrapper *dw = camel_medium_get_content_object((CamelMedium *)part);
 
+	if (!dw)
+		return 0;
+
 	/*printf("checking is attachment %s/%s\n", ct->type, ct->subtype);*/
 	return !(camel_content_type_is (dw->mime_type, "multipart", "*")
 		 || camel_content_type_is(dw->mime_type, "application", "x-pkcs7-mime")
@@ -979,10 +1021,10 @@ int em_format_is_attachment(EMFormat *emf, CamelMimePart *part)
  *
  * Return value:
  **/
-int em_format_is_inline(EMFormat *emf, const char *partid, CamelMimePart *part, const EMFormatHandler *handle)
+gint em_format_is_inline(EMFormat *emf, const gchar *partid, CamelMimePart *part, const EMFormatHandler *handle)
 {
 	struct _EMFormatCache *emfc;
-	const char *tmp;
+	const gchar *tmp;
 
 	if (handle == NULL)
 		return FALSE;
@@ -1013,7 +1055,7 @@ int em_format_is_inline(EMFormat *emf, const char *partid, CamelMimePart *part,
  * @state.  This is used only to record the change for a redraw or
  * cloned layout render and does not force a redraw.
  **/
-void em_format_set_inline(EMFormat *emf, const char *partid, int state)
+void em_format_set_inline(EMFormat *emf, const gchar *partid, gint state)
 {
 	struct _EMFormatCache *emfc;
 
@@ -1029,10 +1071,10 @@ void em_format_set_inline(EMFormat *emf, const char *partid, int state)
 		em_format_redraw(emf);
 }
 
-void em_format_format_error(EMFormat *emf, CamelStream *stream, const char *fmt, ...)
+void em_format_format_error(EMFormat *emf, CamelStream *stream, const gchar *fmt, ...)
 {
 	va_list ap;
-	char *txt;
+	gchar *txt;
 
 	va_start(ap, fmt);
 	txt = g_strdup_vprintf(fmt, ap);
@@ -1076,11 +1118,11 @@ em_format_format_text(EMFormat *emf, CamelStream *stream, CamelDataWrapper *dw)
 {
 	CamelStreamFilter *filter_stream;
 	CamelMimeFilterCharset *filter;
-	const char *charset = NULL;
+	const gchar *charset = NULL;
 	CamelMimeFilterWindows *windows = NULL;
 	CamelStream *mem_stream = NULL;
-	size_t size;
-	size_t max;
+	gsize size;
+	gsize max;
 
 	if (emf->charset) {
 		charset = emf->charset;
@@ -1124,7 +1166,7 @@ em_format_format_text(EMFormat *emf, CamelStream *stream, CamelDataWrapper *dw)
 	camel_object_unref(filter_stream);
 	camel_stream_reset (mem_stream);
 
-	if (max == -1 || size < (max * 1024) || emf->composer) {
+	if (max == -1 || size == -1 || size < (max * 1024) || emf->composer) {
 		camel_stream_write_to_stream(mem_stream, (CamelStream *)stream);
 		camel_stream_flush((CamelStream *)stream);
 	} else {
@@ -1145,16 +1187,17 @@ em_format_format_text(EMFormat *emf, CamelStream *stream, CamelDataWrapper *dw)
  *
  * Return value:
  **/
-char *
-em_format_describe_part(CamelMimePart *part, const char *mime_type)
+gchar *
+em_format_describe_part(CamelMimePart *part, const gchar *mime_type)
 {
 	GString *stext;
-	const char *filename, *description;
-	char *out, *desc;
+	const gchar *filename, *description;
+	gchar *content_type, *desc;
 
 	stext = g_string_new("");
-	/* TODO: mime_type isn't content_type on some systems (Win32), thus this will not work there. */
-	desc = g_content_type_get_description (mime_type);
+	content_type = g_content_type_from_mime_type (mime_type);
+	desc = g_content_type_get_description (content_type ? content_type : mime_type);
+	g_free (content_type);
 	g_string_append_printf (stext, _("%s attachment"), desc ? desc : mime_type);
 	g_free (desc);
 	if ((filename = camel_mime_part_get_filename (part)))
@@ -1164,10 +1207,7 @@ em_format_describe_part(CamelMimePart *part, const char *mime_type)
 		!(filename && (strcmp(filename, description) == 0)))
 		g_string_append_printf(stext, ", \"%s\"", description);
 
-	out = stext->str;
-	g_string_free(stext, FALSE);
-
-	return out;
+	return g_string_free (stext, FALSE);
 }
 
 /* ********************************************************************** */
@@ -1178,7 +1218,6 @@ emf_application_xpkcs7mime(EMFormat *emf, CamelStream *stream, CamelMimePart *pa
 {
 	CamelCipherContext *context;
 	CamelException *ex;
-	extern CamelSession *session;
 	CamelMimePart *opart;
 	CamelCipherValidity *valid;
 	struct _EMFormatCache *emfc;
@@ -1221,7 +1260,7 @@ emf_multipart_appledouble(EMFormat *emf, CamelStream *stream, CamelMimePart *par
 {
 	CamelMultipart *mp = (CamelMultipart *)camel_medium_get_content_object((CamelMedium *)part);
 	CamelMimePart *mime_part;
-	int len;
+	gint len;
 
 	if (!CAMEL_IS_MULTIPART(mp)) {
 		em_format_format_source(emf, stream, part);
@@ -1245,7 +1284,7 @@ static void
 emf_multipart_mixed(EMFormat *emf, CamelStream *stream, CamelMimePart *part, const EMFormatHandler *info)
 {
 	CamelMultipart *mp = (CamelMultipart *)camel_medium_get_content_object((CamelMedium *)part);
-	int i, nparts, len;
+	gint i, nparts, len;
 
 	if (!CAMEL_IS_MULTIPART(mp)) {
 		em_format_format_source(emf, stream, part);
@@ -1267,7 +1306,7 @@ static void
 emf_multipart_alternative(EMFormat *emf, CamelStream *stream, CamelMimePart *part, const EMFormatHandler *info)
 {
 	CamelMultipart *mp = (CamelMultipart *)camel_medium_get_content_object((CamelMedium *)part);
-	int i, nparts, bestid = 0;
+	gint i, nparts, bestid = 0;
 	CamelMimePart *best = NULL;
 
 	if (!CAMEL_IS_MULTIPART(mp)) {
@@ -1279,7 +1318,7 @@ emf_multipart_alternative(EMFormat *emf, CamelStream *stream, CamelMimePart *par
 	nparts = camel_multipart_get_number(mp);
 	for (i = 0; i < nparts; i++) {
 		CamelContentType *type;
-		char *mime_type;
+		gchar *mime_type;
 
 		/* is it correct to use the passed in *part here? */
 		part = camel_multipart_get_part(mp, i);
@@ -1305,7 +1344,7 @@ emf_multipart_alternative(EMFormat *emf, CamelStream *stream, CamelMimePart *par
 	}
 
 	if (best) {
-		int len = emf->part_id->len;
+		gint len = emf->part_id->len;
 
 		g_string_append_printf(emf->part_id, ".alternative.%d", bestid);
 		em_format_part(emf, stream, best);
@@ -1319,7 +1358,7 @@ emf_multipart_encrypted(EMFormat *emf, CamelStream *stream, CamelMimePart *part,
 {
 	CamelCipherContext *context;
 	CamelException *ex;
-	const char *protocol;
+	const gchar *protocol;
 	CamelMimePart *opart;
 	CamelCipherValidity *valid;
 	CamelMultipartEncrypted *mpe;
@@ -1386,9 +1425,9 @@ emf_multipart_related(EMFormat *emf, CamelStream *stream, CamelMimePart *part, c
 	CamelMultipart *mp = (CamelMultipart *)camel_medium_get_content_object((CamelMedium *)part);
 	CamelMimePart *body_part, *display_part = NULL;
 	CamelContentType *content_type;
-	const char *start;
-	int i, nparts, partidlen, displayid = 0;
-	char *oldpartid;
+	const gchar *start;
+	gint i, nparts, partidlen, displayid = 0;
+	gchar *oldpartid;
 	struct _EMFormatPURITree *ptree;
 	EMFormatPURI *puri, *purin;
 
@@ -1402,8 +1441,8 @@ emf_multipart_related(EMFormat *emf, CamelStream *stream, CamelMimePart *part, c
 	content_type = camel_mime_part_get_content_type(part);
 	start = camel_content_type_param (content_type, "start");
 	if (start && strlen(start)>2) {
-		int len;
-		const char *cid;
+		gint len;
+		const gchar *cid;
 
 		/* strip <>'s */
 		len = strlen (start) - 2;
@@ -1459,8 +1498,9 @@ emf_multipart_related(EMFormat *emf, CamelStream *stream, CamelMimePart *part, c
 			if (puri->func == emf_write_related) {
 				g_string_printf(emf->part_id, "%s", puri->part_id);
 				em_format_part(emf, stream, puri->part);
-			} else
+			} else {
 				d(printf("unreferenced uri generated by format code: %s\n", puri->uri?puri->uri:puri->cid));
+			}
 		}
 		puri = purin;
 		purin = purin->next;
@@ -1541,7 +1581,7 @@ emf_message_rfc822(EMFormat *emf, CamelStream *stream, CamelMimePart *part, cons
 {
 	CamelDataWrapper *dw = camel_medium_get_content_object((CamelMedium *)part);
 	const EMFormatHandler *handle;
-	int len;
+	gint len;
 
 	if (!CAMEL_IS_MIME_MESSAGE(dw)) {
 		em_format_format_source(emf, stream, part);
@@ -1576,7 +1616,7 @@ emf_inlinepgp_signed(EMFormat *emf, CamelStream *stream, CamelMimePart *ipart, E
 	CamelMimePart *opart;
 	CamelStream *ostream;
 	CamelException *ex;
-	char *type;
+	gchar *type;
 
 	if (!ipart) {
 		em_format_format_error(emf, stream, _("Unknown error verifying signature"));
@@ -1596,7 +1636,7 @@ emf_inlinepgp_signed(EMFormat *emf, CamelStream *stream, CamelMimePart *ipart, E
 		camel_exception_free(ex);
 		camel_object_unref(cipher);
 		return;
-    	}
+	}
 
 	/* Setup output stream */
 	ostream = camel_stream_mem_new();
@@ -1654,7 +1694,7 @@ emf_inlinepgp_encrypted(EMFormat *emf, CamelStream *stream, CamelMimePart *ipart
 	CamelException *ex;
 	CamelMimePart *opart;
 	CamelDataWrapper *dw;
-	char *mime_type;
+	gchar *mime_type;
 
 	cipher = camel_gpg_context_new(emf->session);
 	ex = camel_exception_new();
@@ -1678,7 +1718,7 @@ emf_inlinepgp_encrypted(EMFormat *emf, CamelStream *stream, CamelMimePart *ipart
 
 	/* this ensures to show the 'opart' as inlined, if possible */
 	if (mime_type && g_ascii_strcasecmp (mime_type, "application/octet-stream") == 0) {
-		const char *snoop = em_utils_snoop_type (opart);
+		const gchar *snoop = em_utils_snoop_type (opart);
 
 		if (snoop)
 			camel_data_wrapper_set_mime_type (dw, snoop);
@@ -1697,35 +1737,35 @@ emf_inlinepgp_encrypted(EMFormat *emf, CamelStream *stream, CamelMimePart *ipart
 
 static EMFormatHandler type_builtin_table[] = {
 #ifdef ENABLE_SMIME
-	{ "application/x-pkcs7-mime", (EMFormatFunc)emf_application_xpkcs7mime, EM_FORMAT_HANDLER_INLINE_DISPOSITION },
+	{ (gchar *) "application/x-pkcs7-mime", (EMFormatFunc)emf_application_xpkcs7mime, EM_FORMAT_HANDLER_INLINE_DISPOSITION },
 #endif
-	{ "multipart/alternative", emf_multipart_alternative },
-	{ "multipart/appledouble", emf_multipart_appledouble },
-	{ "multipart/encrypted", emf_multipart_encrypted },
-	{ "multipart/mixed", emf_multipart_mixed },
-	{ "multipart/signed", emf_multipart_signed },
-	{ "multipart/related", emf_multipart_related },
-	{ "multipart/*", emf_multipart_mixed },
-	{ "message/rfc822", emf_message_rfc822, EM_FORMAT_HANDLER_INLINE },
-	{ "message/news", emf_message_rfc822, EM_FORMAT_HANDLER_INLINE },
-	{ "message/delivery-status", emf_message_deliverystatus },
-	{ "message/*", emf_message_rfc822, EM_FORMAT_HANDLER_INLINE },
+	{ (gchar *) "multipart/alternative", emf_multipart_alternative },
+	{ (gchar *) "multipart/appledouble", emf_multipart_appledouble },
+	{ (gchar *) "multipart/encrypted", emf_multipart_encrypted },
+	{ (gchar *) "multipart/mixed", emf_multipart_mixed },
+	{ (gchar *) "multipart/signed", emf_multipart_signed },
+	{ (gchar *) "multipart/related", emf_multipart_related },
+	{ (gchar *) "multipart/*", emf_multipart_mixed },
+	{ (gchar *) "message/rfc822", emf_message_rfc822, EM_FORMAT_HANDLER_INLINE },
+	{ (gchar *) "message/news", emf_message_rfc822, EM_FORMAT_HANDLER_INLINE },
+	{ (gchar *) "message/delivery-status", emf_message_deliverystatus },
+	{ (gchar *) "message/*", emf_message_rfc822, EM_FORMAT_HANDLER_INLINE },
 
 	/* Insert brokenly-named parts here */
 #ifdef ENABLE_SMIME
-	{ "application/pkcs7-mime", (EMFormatFunc)emf_application_xpkcs7mime, EM_FORMAT_HANDLER_INLINE_DISPOSITION },
+	{ (gchar *) "application/pkcs7-mime", (EMFormatFunc)emf_application_xpkcs7mime, EM_FORMAT_HANDLER_INLINE_DISPOSITION },
 #endif
 
 	/* internal types */
-	{ "application/x-inlinepgp-signed", (EMFormatFunc)emf_inlinepgp_signed },
-	{ "application/x-inlinepgp-encrypted", (EMFormatFunc)emf_inlinepgp_encrypted },
+	{ (gchar *) "application/x-inlinepgp-signed", (EMFormatFunc)emf_inlinepgp_signed },
+	{ (gchar *) "application/x-inlinepgp-encrypted", (EMFormatFunc)emf_inlinepgp_encrypted },
 };
 
 static void
 emf_builtin_init(EMFormatClass *klass)
 {
-	int i;
+	gint i;
 
 	for (i=0;i<sizeof(type_builtin_table)/sizeof(type_builtin_table[0]);i++)
-		g_hash_table_insert(klass->type_handlers, type_builtin_table[i].mime_type, &type_builtin_table[i]);
+		g_hash_table_insert(klass->type_handlers, (gpointer) type_builtin_table[i].mime_type, &type_builtin_table[i]);
 }
