@@ -1,22 +1,22 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- *
- *
- *  Authors: Michael Zucchi <notzed@ximian.com>
- *
- *  Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
- *
+/*
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
+ *
+ * Authors:
+ *		Michael Zucchi <notzed@ximian.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  */
 
@@ -39,8 +39,8 @@ static void em_inline_filter_class_init (EMInlineFilterClass *klass);
 static void em_inline_filter_init (CamelObject *object);
 static void em_inline_filter_finalize (CamelObject *object);
 
-static void emif_filter(CamelMimeFilter *f, char *in, size_t len, size_t prespace, char **out, size_t *outlen, size_t *outprespace);
-static void emif_complete(CamelMimeFilter *f, char *in, size_t len, size_t prespace, char **out, size_t *outlen, size_t *outprespace);
+static void emif_filter(CamelMimeFilter *f, const gchar *in, gsize len, gsize prespace, gchar **out, gsize *outlen, gsize *outprespace);
+static void emif_complete(CamelMimeFilter *f, const gchar *in, gsize len, gsize prespace, gchar **out, gsize *outlen, gsize *outprespace);
 static void emif_reset(CamelMimeFilter *f);
 
 static CamelMimeFilterClass *parent_class = NULL;
@@ -102,12 +102,12 @@ enum {
 	EMIF_BINHEX,
 	EMIF_POSTSCRIPT,
 	EMIF_PGPSIGNED,
-	EMIF_PGPENCRYPTED,
+	EMIF_PGPENCRYPTED
 };
 
 static const struct {
-	const char *type;
-	const char *subtype;
+	const gchar *type;
+	const gchar *subtype;
 	CamelTransferEncoding encoding;
 	guint plain:1;
 } emif_types[] = {
@@ -120,22 +120,22 @@ static const struct {
 };
 
 static void
-emif_add_part(EMInlineFilter *emif, const char *data, int len)
+emif_add_part(EMInlineFilter *emif, const gchar *data, gint len)
 {
 	CamelTransferEncoding encoding;
 	CamelContentType *content_type;
 	CamelDataWrapper *dw;
-	const char *mimetype;
+	const gchar *mimetype;
 	CamelMimePart *part;
 	CamelStream *mem;
-	char *type;
+	gchar *type;
 
 	if (emif->state == EMIF_PLAIN || emif->state == EMIF_PGPSIGNED || emif->state == EMIF_PGPENCRYPTED)
 		encoding = emif->base_encoding;
 	else
 		encoding = emif_types[emif->state].encoding;
 
-	g_byte_array_append(emif->data, (unsigned char *)data, len);
+	g_byte_array_append(emif->data, (guchar *)data, len);
 	/* check the part will actually have content */
 	if (emif->data->len <= 0) {
 		return;
@@ -190,13 +190,13 @@ emif_add_part(EMInlineFilter *emif, const char *data, int len)
 	emif->parts = g_slist_append(emif->parts, part);
 }
 
-static int
-emif_scan(CamelMimeFilter *f, char *in, size_t len, int final)
+static gint
+emif_scan(CamelMimeFilter *f, gchar *in, gsize len, gint final)
 {
 	EMInlineFilter *emif = (EMInlineFilter *)f;
-	char *inptr = in, *inend = in+len;
-	char *data_start = in;
-	char *start = in;
+	gchar *inptr = in, *inend = in+len;
+	gchar *data_start = in;
+	gchar *start = in;
 
 	while (inptr < inend) {
 		start = inptr;
@@ -219,8 +219,8 @@ emif_scan(CamelMimeFilter *f, char *in, size_t len, int final)
 			/* This could use some funky plugin shit, but this'll do for now */
 			if (strncmp(start, "begin ", 6) == 0
 			    && start[6] >= '0' && start[6] <= '7') {
-				int i = 7;
-				char *name;
+				gint i = 7;
+				gchar *name;
 
 				while (start[i] >='0' && start[i] <='7')
 					i++;
@@ -267,7 +267,7 @@ emif_scan(CamelMimeFilter *f, char *in, size_t len, int final)
 				data_start = inptr;
 				emif->state = EMIF_PLAIN;
 			} else {
-				int linelen;
+				gint linelen;
 
 				/* check the length byte matches the data, if not, output what we have and re-scan this line */
 				len = ((start[0] - ' ') & 077);
@@ -325,30 +325,33 @@ emif_scan(CamelMimeFilter *f, char *in, size_t len, int final)
 	}
 
 	if (final) {
+		/* always stop as plain, especially when not read those tags fully */
+		emif->state = EMIF_PLAIN;
+
 		emif_add_part(emif, data_start, inend-data_start);
 	} else {
-		g_byte_array_append(emif->data, (unsigned char *)data_start, inend-data_start);
+		g_byte_array_append(emif->data, (guchar *)data_start, inend-data_start);
 	}
 
 	return 0;
 }
 
 static void
-emif_filter(CamelMimeFilter *f, char *in, size_t len, size_t prespace, char **out, size_t *outlen, size_t *outprespace)
+emif_filter(CamelMimeFilter *f, const gchar *in, gsize len, gsize prespace, gchar **out, gsize *outlen, gsize *outprespace)
 {
-	emif_scan(f, in, len, FALSE);
+	emif_scan(f, (gchar *)in, len, FALSE);
 
-	*out = in;
+	*out = (gchar *)in;
 	*outlen = len;
 	*outprespace = prespace;
 }
 
 static void
-emif_complete(CamelMimeFilter *f, char *in, size_t len, size_t prespace, char **out, size_t *outlen, size_t *outprespace)
+emif_complete(CamelMimeFilter *f, const gchar *in, gsize len, gsize prespace, gchar **out, gsize *outlen, gsize *outprespace)
 {
-	emif_scan(f, in, len, TRUE);
+	emif_scan(f, (gchar *)in, len, TRUE);
 
-	*out = in;
+	*out = (gchar *)in;
 	*outlen = len;
 	*outprespace = prespace;
 }
