@@ -1,23 +1,22 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
- * em-subscribe-editor.c *
- *
- * Authors: Michael Zucchi <notzed@ximian.com>
- *
- * Copyright 2003 Ximian, Inc. (www.ximian.com)
- *
+/*
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
+ *
+ * Authors:
+ *		Michael Zucchi <notzed@ximian.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  */
 
@@ -37,6 +36,7 @@
 #include "camel/camel-store.h"
 #include "camel/camel-session.h"
 #include "libedataserver/e-account-list.h"
+#include "libedataserver/e-msgport.h"
 #include "e-util/e-util-private.h"
 
 #include "em-subscribe-editor.h"
@@ -46,35 +46,21 @@
 #include <glade/glade.h>
 #include <glib/gi18n.h>
 
-#include <gtk/gtkdialog.h>
-#include <gtk/gtkscrolledwindow.h>
-#include <gtk/gtkbox.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtktreeview.h>
-#include <gtk/gtktreestore.h>
-#include <gtk/gtktreeselection.h>
-#include <gtk/gtkcellrenderertoggle.h>
-#include <gtk/gtkcellrenderertext.h>
-#include <gtk/gtkoptionmenu.h>
-#include <gtk/gtkprogressbar.h>
-#include <gtk/gtkmenuitem.h>
-
 #define d(x)
 
 typedef struct _EMSubscribeEditor EMSubscribeEditor;
 struct _EMSubscribeEditor {
 	EDList stores;
 
-	int busy;
+	gint busy;
 	guint busy_id;
 
 	struct _EMSubscribe *current; /* the current one, if any */
 
 	GtkDialog *dialog;
 	GtkWidget *vbox;	/* where new stores are added */
-	GtkWidget *optionmenu;
+	GtkWidget *combobox;
 	GtkWidget *none_selected; /* 'please select a xxx' message */
-	GtkWidget *none_selected_item;
 	GtkWidget *progress;
 };
 
@@ -83,14 +69,14 @@ struct _EMSubscribe {
 	struct _EMSubscribe *next;
 	struct _EMSubscribe *prev;
 
-	int ref_count;
-	int cancel;
-	int seq;		/* upped every time we refresh */
+	gint ref_count;
+	gint cancel;
+	gint seq;		/* upped every time we refresh */
 
 	struct _EMSubscribeEditor *editor; /* parent object*/
 
-	char *store_uri;
-	int store_id;		/* looking up a store */
+	gchar *store_uri;
+	gint store_id;		/* looking up a store */
 
 	CamelStore *store;
 	GHashTable *folders;
@@ -102,16 +88,16 @@ struct _EMSubscribe {
 	GSList *info_list;
 
 	/* pending LISTs, EMSubscribeNode's */
-	int pending_id;
+	gint pending_id;
 	EDList pending;
 
 	/* queue of pending UN/SUBSCRIBEs, EMsg's */
-	int subscribe_id;
+	gint subscribe_id;
 	EDList subscribe;
 
 	/* working variables at runtime */
-	int selected_count;
-	int selected_subscribed_count;
+	gint selected_count;
+	gint selected_subscribed_count;
 	guint subscribed_state:1; /* for setting the selection*/
 };
 
@@ -124,8 +110,14 @@ struct _EMSubscribeNode {
 	GtkTreePath *path;
 };
 
-static void sub_editor_busy(EMSubscribeEditor *se, int dir);
-static int sub_queue_fill_level(EMSubscribe *sub, EMSubscribeNode *node);
+typedef struct _MailMsgListNode MailMsgListNode;
+struct _MailMsgListNode {
+	EDListNode node;
+	MailMsg *msg;
+};
+
+static void sub_editor_busy(EMSubscribeEditor *se, gint dir);
+static gint sub_queue_fill_level(EMSubscribe *sub, EMSubscribeNode *node);
 static void sub_selection_changed(GtkTreeSelection *selection, EMSubscribe *sub);
 
 static void
@@ -177,8 +169,8 @@ struct _zsubscribe_msg {
 
 	EMSubscribe *sub;
 	EMSubscribeNode *node;
-	int subscribe;
-	char *path;
+	gint subscribe;
+	gchar *path;
 };
 
 static void
@@ -198,6 +190,7 @@ sub_folder_done (struct _zsubscribe_msg *m)
 	GtkTreeModel *model;
 	EMSubscribeNode *node;
 	gboolean subscribed, issub;
+	MailMsgListNode *msgListNode;
 
 	m->sub->subscribe_id = -1;
 	if (m->sub->cancel)
@@ -217,15 +210,19 @@ sub_folder_done (struct _zsubscribe_msg *m)
 		gtk_tree_model_get(model, &iter, 0, &subscribed, 2, &node, -1);
 		if (node == m->node)
 			gtk_tree_store_set((GtkTreeStore *)model, &iter, 0, issub, -1);
-		else
+		else {
 			d(printf("node mismatch, or subscribe state changed failed\n"));
+		}
 	}
 
 	/* queue any further ones, or if out, update the ui */
-	next = (struct _zsubscribe_msg *)e_dlist_remhead(&m->sub->subscribe);
-	if (next) {
+	msgListNode = (MailMsgListNode *) e_dlist_remhead(&m->sub->subscribe);
+	if (msgListNode) {
+		next = (struct _zsubscribe_msg *) msgListNode->msg;
+		/* Free the memory of the MailMsgListNode which won't be used anymore. */
+		g_free(msgListNode);
 		next->sub->subscribe_id = next->base.seq;
-		mail_msg_unordered_push (next);
+                mail_msg_unordered_push (next);
 	} else {
 		/* should it go off the model instead? */
 		sub_selection_changed(gtk_tree_view_get_selection(m->sub->tree), m->sub);
@@ -248,11 +245,12 @@ static MailMsgInfo sub_subscribe_folder_info = {
 };
 
 /* spath is tree path in string form */
-static int
-sub_subscribe_folder (EMSubscribe *sub, EMSubscribeNode *node, int state, const char *spath)
+static gint
+sub_subscribe_folder (EMSubscribe *sub, EMSubscribeNode *node, gint state, const gchar *spath)
 {
 	struct _zsubscribe_msg *m;
-	int id;
+	MailMsgListNode *msgListNode;
+	gint id;
 
 	m = mail_msg_new (&sub_subscribe_folder_info);
 	m->sub = sub;
@@ -267,8 +265,10 @@ sub_subscribe_folder (EMSubscribe *sub, EMSubscribeNode *node, int state, const
 		d(printf("running subscribe folder '%s'\n", spath));
 		mail_msg_unordered_push (m);
 	} else {
+		msgListNode = g_malloc0(sizeof(MailMsgListNode));
+		msgListNode->msg = (MailMsg *) m;
 		d(printf("queueing subscribe folder '%s'\n", spath));
-		e_dlist_addtail(&sub->subscribe, (EDListNode *)m);
+		e_dlist_addtail(&sub->subscribe, (EDListNode *)msgListNode);
 	}
 
 	return id;
@@ -276,7 +276,7 @@ sub_subscribe_folder (EMSubscribe *sub, EMSubscribeNode *node, int state, const
 
 /* ********************************************************************** */
 static void
-sub_fill_level(EMSubscribe *sub, CamelFolderInfo *info,  GtkTreeIter *parent, int pending)
+sub_fill_level(EMSubscribe *sub, CamelFolderInfo *info,  GtkTreeIter *parent, gint pending)
 {
 	CamelFolderInfo *fi;
 	GtkTreeStore *treestore;
@@ -288,6 +288,8 @@ sub_fill_level(EMSubscribe *sub, CamelFolderInfo *info,  GtkTreeIter *parent, in
 	/* first, fill a level up */
 	fi = info;
 	while (fi) {
+		gboolean known = FALSE;
+
 		if ((node = g_hash_table_lookup(sub->folders, fi->full_name)) == NULL) {
 			gboolean state;
 
@@ -301,6 +303,7 @@ sub_fill_level(EMSubscribe *sub, CamelFolderInfo *info,  GtkTreeIter *parent, in
 			g_hash_table_insert(sub->folders, fi->full_name, node);
 		} else if (node->path) {
 			gtk_tree_model_get_iter(gtk_tree_view_get_model(sub->tree), &iter, node->path);
+			known = TRUE;
 		}
 
 		d(printf("flags & CAMEL_FOLDER_NOCHILDREN=%d, f & CAMEL_FOLDER_NOINFERIORS=%d\t fi->full_name=[%s], node->path=%p\n",
@@ -315,17 +318,19 @@ sub_fill_level(EMSubscribe *sub, CamelFolderInfo *info,  GtkTreeIter *parent, in
 				sub_fill_level(sub, fi->child, &iter, FALSE);
 			} else if (!(fi->flags & CAMEL_FOLDER_NOCHILDREN)) {
 				GtkTreeIter new_iter;
-				d(printf("flags: CAMEL_FOLDER_NOCHILDREN is not set '%s'\n", fi->full_name));
-				gtk_tree_store_append(treestore, &new_iter, &iter);
-				gtk_tree_store_set(treestore, &new_iter, 0, 0, 1, "Loading...", 2, NULL, -1);
+				d(printf("flags: CAMEL_FOLDER_NOCHILDREN is not set '%s', known:%d\n", fi->full_name, known?1:0));
+				if (!known) {
+					gtk_tree_store_append(treestore, &new_iter, &iter);
+					gtk_tree_store_set(treestore, &new_iter, 0, 0, 1, "Loading...", 2, NULL, -1);
+				}
 			}
 			else {
 				if (pending)
 					e_dlist_addtail(&sub->pending, (EDListNode *)node);
 			}
 		} else {
-			d(printf("%s:%d:%s: fi->flags & CAMEL_FOLDER_NOINFERIORS=%d\t node->path=[%p]\n",
-				 __FILE__, __LINE__, __GNUC_PRETTY_FUNCTION__, fi->flags & CAMEL_FOLDER_NOINFERIORS,
+			d(printf("%s:%s: fi->flags & CAMEL_FOLDER_NOINFERIORS=%d\t node->path=[%p]\n",
+				 G_STRLOC, G_STRFUNC, fi->flags & CAMEL_FOLDER_NOINFERIORS,
 				 node->path));
 		}
 
@@ -338,7 +343,7 @@ sub_fill_level(EMSubscribe *sub, CamelFolderInfo *info,  GtkTreeIter *parent, in
 struct _emse_folderinfo_msg {
 	MailMsg base;
 
-	int seq;
+	gint seq;
 
 	EMSubscribe *sub;
 	EMSubscribeNode *node;
@@ -348,11 +353,12 @@ struct _emse_folderinfo_msg {
 static void
 sub_folderinfo_exec (struct _emse_folderinfo_msg *m)
 {
-	char *pub_full_name=NULL;
+	gchar *pub_full_name=NULL;
 
 	if (m->seq == m->sub->seq) {
 		camel_operation_register(m->base.cancel);
-		m->info = camel_store_get_folder_info(m->sub->store, m->node?m->node->info->full_name:pub_full_name, CAMEL_STORE_FOLDER_INFO_FAST | CAMEL_STORE_FOLDER_INFO_NO_VIRTUAL, &m->base.ex);
+		m->info = camel_store_get_folder_info(m->sub->store, m->node?m->node->info->full_name:pub_full_name,
+						      CAMEL_STORE_FOLDER_INFO_NO_VIRTUAL | CAMEL_STORE_FOLDER_INFO_SUBSCRIPTION_LIST, &m->base.ex);
 		camel_operation_unregister(m->base.cancel);
 	}
 }
@@ -414,13 +420,13 @@ static MailMsgInfo sub_folderinfo_info = {
 	(MailMsgFreeFunc) sub_folderinfo_free
 };
 
-static int
+static gint
 sub_queue_fill_level(EMSubscribe *sub, EMSubscribeNode *node)
 {
 	struct _emse_folderinfo_msg *m;
-	int id;
+	gint id;
 
-	d(printf("%s:%d:%s: Starting get folderinfo of '%s'\n", __FILE__, __LINE__, __GNUC_PRETTY_FUNCTION__,
+	d(printf("%s:%s: Starting get folderinfo of '%s'\n", G_STRLOC, G_STRFUNC,
 		 node?node->info->full_name:"<root>"));
 
 	m = mail_msg_new (&sub_folderinfo_info);
@@ -444,7 +450,7 @@ sub_queue_fill_level(EMSubscribe *sub, EMSubscribeNode *node)
 /* (un) subscribes the current selection */
 
 static void
-sub_subscribe_toggled(GtkCellRendererToggle *render, const char *spath, EMSubscribe *sub)
+sub_subscribe_toggled(GtkCellRendererToggle *render, const gchar *spath, EMSubscribe *sub)
 {
 	GtkTreeIter iter;
 	GtkTreeModel *model = gtk_tree_view_get_model(sub->tree);
@@ -462,7 +468,7 @@ sub_subscribe_toggled(GtkCellRendererToggle *render, const char *spath, EMSubscr
 	}
 }
 
-static void sub_do_changed(GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter, void *data)
+static void sub_do_changed(GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter, gpointer data)
 {
 	EMSubscribe *sub = data;
 	EMSubscribeNode *node;
@@ -478,7 +484,7 @@ static void sub_do_changed(GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *
 static void
 sub_selection_changed(GtkTreeSelection *selection, EMSubscribe *sub)
 {
-	int dosub = TRUE, dounsub = TRUE;
+	gint dosub = TRUE, dounsub = TRUE;
 
 	sub->selected_count = 0;
 	sub->selected_subscribed_count = 0;
@@ -510,10 +516,10 @@ sub_row_expanded(GtkTreeView *tree, GtkTreeIter *iter, GtkTreePath *path, EMSubs
 	EMSubscribeNode *node;
 	GtkTreeIter child;
 	GtkTreeModel *model = (GtkTreeModel *)gtk_tree_view_get_model(tree);
-	char *row_name;
+	gchar *row_name;
 
 	gtk_tree_model_get(model, iter, 1, &row_name, -1);
-	d(printf("%s:%d:%s: row-expanded '%s'\n", __FILE__, __LINE__, __GNUC_PRETTY_FUNCTION__,
+	d(printf("%s:%s: row-expanded '%s'\n", G_STRLOC, G_STRFUNC,
 		 row_name?row_name:"<root>"));
 
 	/* Do we really need to fetch the children for this row? */
@@ -554,6 +560,7 @@ static void
 sub_destroy(GtkWidget *w, EMSubscribe *sub)
 {
 	struct _zsubscribe_msg *m;
+	MailMsgListNode *msgListNode;
 
 	d(printf("subscribe closed\n"));
 	sub->cancel = TRUE;
@@ -564,14 +571,18 @@ sub_destroy(GtkWidget *w, EMSubscribe *sub)
 	if (sub->subscribe_id != -1)
 		mail_msg_cancel(sub->subscribe_id);
 
-	while ( (m = (struct _zsubscribe_msg *)e_dlist_remhead(&sub->subscribe)) )
+	while ( (msgListNode = (MailMsgListNode *)e_dlist_remhead(&sub->subscribe))) {
+		m = (struct _zsubscribe_msg *) msgListNode->msg;
+		/* Free the memory of MailMsgListNode which won't be used anymore. */
+		g_free(msgListNode);
 		mail_msg_unref(m);
+	}
 
 	sub_unref(sub);
 }
 
 static EMSubscribe *
-subscribe_new(EMSubscribeEditor *se, const char *uri)
+subscribe_new(EMSubscribeEditor *se, const gchar *uri)
 {
 	EMSubscribe *sub;
 
@@ -709,7 +720,7 @@ sub_editor_refresh(GtkWidget *w, EMSubscribeEditor *se)
 }
 
 static void
-sub_editor_got_store(char *uri, CamelStore *store, void *data)
+sub_editor_got_store(gchar *uri, CamelStore *store, gpointer data)
 {
 	struct _EMSubscribe *sub = data;
 
@@ -719,20 +730,31 @@ sub_editor_got_store(char *uri, CamelStore *store, void *data)
 }
 
 static void
-sub_editor_menu_changed(GtkWidget *w, EMSubscribeEditor *se)
+sub_editor_combobox_changed (GtkWidget *w, EMSubscribeEditor *se)
 {
-	int i, n;
+	gint i, n;
 	struct _EMSubscribe *sub;
 
-	d(printf("menu changed\n"));
+	d(printf("combobox changed\n"));
 
 	i = 1;
-	n = gtk_option_menu_get_history((GtkOptionMenu *)se->optionmenu);
-	if (n == 0)
-		gtk_widget_show(se->none_selected);
-	else {
-		gtk_widget_hide(se->none_selected);
-		gtk_widget_hide(se->none_selected_item);
+	n = gtk_combo_box_get_active (GTK_COMBO_BOX (se->combobox));
+	if (n == 0) {
+		gtk_widget_show (se->none_selected);
+	} else {
+		GtkTreeIter iter;
+		GtkTreeModel *model;
+
+		gtk_widget_hide (se->none_selected);
+
+		model = gtk_combo_box_get_model (GTK_COMBO_BOX (se->combobox));
+		if (gtk_tree_model_get_iter_first (model, &iter)) {
+			/* hide the first item */
+			gtk_list_store_set (
+				GTK_LIST_STORE (model), &iter,
+				1, FALSE,
+				-1);
+		}
 	}
 
 	se->current = NULL;
@@ -762,9 +784,9 @@ static gboolean sub_editor_timeout(EMSubscribeEditor *se)
 	return TRUE;
 }
 
-static void sub_editor_busy(EMSubscribeEditor *se, int dir)
+static void sub_editor_busy(EMSubscribeEditor *se, gint dir)
 {
-	int was;
+	gint was;
 
 	was = se->busy != 0;
 	se->busy += dir;
@@ -805,8 +827,11 @@ GtkDialog *em_subscribe_editor_new(void)
 	EAccountList *accounts;
 	EIterator *iter;
 	GladeXML *xml;
-	GtkWidget *menu, *w;
-	char *gladefile;
+	GtkWidget *w;
+	GtkCellRenderer *cell;
+	GtkListStore *store;
+	GtkTreeIter gtiter;
+	gchar *gladefile;
 
 	se = g_malloc0(sizeof(*se));
 	e_dlist_init(&se->stores);
@@ -849,12 +874,27 @@ GtkDialog *em_subscribe_editor_new(void)
 	w = glade_xml_get_widget(xml, "refresh_button");
 	g_signal_connect(w, "clicked", G_CALLBACK(sub_editor_refresh), se);
 
-	/* setup stores menu */
-	se->optionmenu = glade_xml_get_widget(xml, "store_menu");
-	menu = gtk_menu_new();
-	se->none_selected_item = w = gtk_menu_item_new_with_label(_("No server has been selected"));
-	gtk_widget_show(w);
-	gtk_menu_shell_append ((GtkMenuShell *)menu, w);
+	/* setup stores combobox */
+	se->combobox = glade_xml_get_widget (xml, "store_combobox");
+	store = gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_BOOLEAN);
+	gtk_combo_box_set_model (GTK_COMBO_BOX (se->combobox), GTK_TREE_MODEL (store));
+	g_object_unref (store);
+
+	gtk_cell_layout_clear (GTK_CELL_LAYOUT (se->combobox));
+
+	cell = gtk_cell_renderer_text_new ();
+	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (se->combobox), cell, TRUE);
+	gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (se->combobox), cell,
+                                  "text", 0,
+                                  "visible", 1,
+                                  NULL);
+
+	gtk_list_store_append (store, &gtiter);
+	gtk_list_store_set (
+		store, &gtiter,
+		0, _("No server has been selected"),
+		1, TRUE,
+		-1);
 
 	accounts = mail_config_get_accounts ();
 	for (iter = e_list_get_iterator ((EList *) accounts);
@@ -865,9 +905,12 @@ GtkDialog *em_subscribe_editor_new(void)
 		/* setup url table, and store table? */
 		if (account->enabled && account->source->url) {
 			d(printf("adding account '%s'\n", account->name));
-			w = gtk_menu_item_new_with_label(account->name);
-			gtk_menu_shell_append ((GtkMenuShell *)menu, w);
-			gtk_widget_show(w);
+			gtk_list_store_append (store, &gtiter);
+			gtk_list_store_set (
+				store, &gtiter,
+				0, account->name,
+				1, TRUE,
+				-1);
 			e_dlist_addtail(&se->stores, (EDListNode *)subscribe_new(se, account->source->url));
 		} else {
 			d(printf("not adding account '%s'\n", account->name));
@@ -875,8 +918,8 @@ GtkDialog *em_subscribe_editor_new(void)
 	}
 	g_object_unref(iter);
 
-	gtk_option_menu_set_menu((GtkOptionMenu *)se->optionmenu, menu);
-	g_signal_connect(se->optionmenu, "changed", G_CALLBACK(sub_editor_menu_changed), se);
+	gtk_combo_box_set_active (GTK_COMBO_BOX (se->combobox), 0);
+	g_signal_connect(se->combobox, "changed", G_CALLBACK(sub_editor_combobox_changed), se);
 
 	if (window_size.width == 0) {
 		/* initialize @window_size with the previous session's size */
