@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -44,7 +44,7 @@ struct _GtkAdjustment;
 struct _CamelException;
 struct _EMFormat;
 
-gboolean em_utils_prompt_user(struct _GtkWindow *parent, const char *promptkey, const char *tag, const char *arg0, ...);
+gboolean em_utils_prompt_user(struct _GtkWindow *parent, const gchar *promptkey, const gchar *tag, const gchar *arg0, ...);
 
 GPtrArray *em_utils_uids_copy (GPtrArray *uids);
 void em_utils_uids_free (GPtrArray *uids);
@@ -56,12 +56,12 @@ void em_utils_edit_filters (struct _GtkWidget *parent);
 void em_filename_make_safe (gchar *string);
 void em_utils_edit_vfolders (struct _GtkWidget *parent);
 
-void em_utils_save_part(struct _GtkWidget *parent, const char *prompt, struct _CamelMimePart *part);
-gboolean em_utils_save_part_to_file(struct _GtkWidget *parent, const char *filename, struct _CamelMimePart *part);
+void em_utils_save_part(struct _GtkWidget *parent, const gchar *prompt, struct _CamelMimePart *part);
+gboolean em_utils_save_part_to_file(struct _GtkWidget *parent, const gchar *filename, struct _CamelMimePart *part);
 void em_utils_save_messages (struct _GtkWidget *parent, struct _CamelFolder *folder, GPtrArray *uids);
 
-void em_utils_add_address(struct _GtkWidget *parent, const char *email);
-void em_utils_add_vcard(struct _GtkWidget *parent, const char *vcard);
+void em_utils_add_address(struct _GtkWidget *parent, const gchar *email);
+void em_utils_add_vcard(struct _GtkWidget *parent, const gchar *vcard);
 
 void em_utils_flag_for_followup (struct _GtkWidget *parent, struct _CamelFolder *folder, GPtrArray *uids);
 void em_utils_flag_for_followup_clear (struct _GtkWidget *parent, struct _CamelFolder *folder, GPtrArray *uids);
@@ -73,36 +73,36 @@ void em_utils_selection_set_mailbox(struct _GtkSelectionData *data, struct _Came
 void em_utils_selection_get_mailbox(struct _GtkSelectionData *data, struct _CamelFolder *folder);
 void em_utils_selection_get_message(struct _GtkSelectionData *data, struct _CamelFolder *folder);
 /* FIXME: be nice if these also worked on struct _CamelFolder's, no easy way to get uri from folder yet tho */
-void em_utils_selection_set_uidlist(struct _GtkSelectionData *data, const char *uri, GPtrArray *uids);
-void em_utils_selection_get_uidlist(struct _GtkSelectionData *data, struct _CamelFolder *dest, int move, struct _CamelException *ex);
+void em_utils_selection_set_uidlist(struct _GtkSelectionData *data, const gchar *uri, GPtrArray *uids);
+void em_utils_selection_get_uidlist(struct _GtkSelectionData *data, struct _CamelFolder *dest, gint move, struct _CamelException *ex);
 void em_utils_selection_set_urilist(struct _GtkSelectionData *data, struct _CamelFolder *folder, GPtrArray *uids);
 void em_utils_selection_get_urilist(struct _GtkSelectionData *data, struct _CamelFolder *folder);
 
-char *em_utils_temp_save_part(struct _GtkWidget *parent, struct _CamelMimePart *part, gboolean mode);
-void em_utils_save_parts (struct _GtkWidget *parent, const char *prompt, GSList * parts);
+gchar *em_utils_temp_save_part(struct _GtkWidget *parent, struct _CamelMimePart *part, gboolean mode);
+void em_utils_save_parts (struct _GtkWidget *parent, const gchar *prompt, GSList * parts);
 
-gboolean em_utils_folder_is_drafts(struct _CamelFolder *folder, const char *uri);
-gboolean em_utils_folder_is_templates(struct _CamelFolder *folder, const char *uri);
-gboolean em_utils_folder_is_sent(struct _CamelFolder *folder, const char *uri);
-gboolean em_utils_folder_is_outbox(struct _CamelFolder *folder, const char *uri);
+gboolean em_utils_folder_is_drafts(struct _CamelFolder *folder, const gchar *uri);
+gboolean em_utils_folder_is_templates(struct _CamelFolder *folder, const gchar *uri);
+gboolean em_utils_folder_is_sent(struct _CamelFolder *folder, const gchar *uri);
+gboolean em_utils_folder_is_outbox(struct _CamelFolder *folder, const gchar *uri);
 
 void em_utils_adjustment_page(struct _GtkAdjustment *adj, gboolean down);
 
-char *em_utils_get_proxy_uri (const char *uri);
+gchar *em_utils_get_proxy_uri (const gchar *uri);
 
 /* FIXME: should this have an override charset? */
-char *em_utils_part_to_html(struct _CamelMimePart *part, ssize_t *len, struct _EMFormat *source);
-char *em_utils_message_to_html(struct _CamelMimeMessage *msg, const char *credits, guint32 flags, ssize_t *len, struct _EMFormat *source, const char *append);
+gchar *em_utils_part_to_html(struct _CamelMimePart *part, gssize *len, struct _EMFormat *source);
+gchar *em_utils_message_to_html(struct _CamelMimeMessage *msg, const gchar *credits, guint32 flags, gssize *len, struct _EMFormat *source, const gchar *append);
 
 void em_utils_expunge_folder (struct _GtkWidget *parent, struct _CamelFolder *folder);
 void em_utils_empty_trash (struct _GtkWidget *parent);
 
 /* returns the folder name portion of an URI */
-char *em_utils_folder_name_from_uri (const char *uri);
+gchar *em_utils_folder_name_from_uri (const gchar *uri);
 
 /* internal/camel uri translation */
-char *em_uri_from_camel (const char *curi);
-char *em_uri_to_camel (const char *euri);
+gchar *em_uri_from_camel (const gchar *curi);
+gchar *em_uri_to_camel (const gchar *euri);
 
 /* Run errors silently on the status bar */
 void em_utils_show_error_silent (struct _GtkWidget *widget);
@@ -112,14 +112,11 @@ void em_utils_show_info_silent (struct _GtkWidget *widget);
 gboolean em_utils_in_addressbook (struct _CamelInternetAddress *addr, gboolean local_only);
 struct _CamelMimePart *em_utils_contact_photo (struct _CamelInternetAddress *addr, gboolean local);
 
-const char *em_utils_snoop_type(struct _CamelMimePart *part);
+const gchar *em_utils_snoop_type(struct _CamelMimePart *part);
 
 /* clears flag 'get_password_canceled' at every known accounts, so if needed, get_password will show dialog */
 void em_utils_clear_get_password_canceled_accounts_flag (void);
 
-/* Unescapes &amp; back to a real & in URIs */
-gchar *em_utils_url_unescape_amp (const gchar *url);
-
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
