@@ -1,22 +1,23 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- *  Authors: Jeffrey Stedfast <fejj@ximian.com>
  *
- *  Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *
+ * Authors:
+ *		Jeffrey Stedfast <fejj@ximian.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  */
 
@@ -32,7 +33,6 @@
 #include <gconf/gconf.h>
 #include <gconf/gconf-client.h>
 
-#include <libgnomeui/gnome-pixmap.h>
 #include <glib/gi18n.h>
 
 #include "e-util/e-util-private.h"
@@ -51,7 +51,7 @@ static void set_tag_list (MessageTagEditor *editor, CamelTag *tags);
 
 
 #define DEFAULT_FLAG  2  /* Follow-Up */
-static char *available_flags[] = {
+static const gchar *available_flags[] = {
 	N_("Call"),
 	N_("Do Not Forward"),
 	N_("Follow-Up"),
@@ -65,7 +65,7 @@ static char *available_flags[] = {
 	N_("Review"),
 };
 
-static int num_available_flags = sizeof (available_flags) / sizeof (available_flags[0]);
+static gint num_available_flags = sizeof (available_flags) / sizeof (available_flags[0]);
 
 
 static MessageTagEditorClass *parent_class = NULL;
@@ -112,7 +112,7 @@ message_tag_followup_class_init (MessageTagFollowUpClass *klass)
 static void
 message_tag_followup_init (MessageTagFollowUp *editor)
 {
-	editor->combo = NULL;
+	editor->combo_entry = NULL;
 	editor->target_date = NULL;
 	editor->completed = NULL;
 	editor->clear = NULL;
@@ -137,9 +137,9 @@ get_tag_list (MessageTagEditor *editor)
 	MessageTagFollowUp *followup = (MessageTagFollowUp *) editor;
 	CamelTag *tags = NULL;
 	time_t date;
-	char *text;
+	gchar *text;
 
-	camel_tag_set (&tags, "follow-up", gtk_entry_get_text (GTK_ENTRY (followup->combo->entry)));
+	camel_tag_set (&tags, "follow-up", gtk_entry_get_text (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (followup->combo_entry)))));
 
 	date = e_date_edit_get_time (followup->target_date);
 	if (date != (time_t) -1) {
@@ -165,12 +165,12 @@ static void
 set_tag_list (MessageTagEditor *editor, CamelTag *tags)
 {
 	MessageTagFollowUp *followup = (MessageTagFollowUp *) editor;
-	const char *text;
+	const gchar *text;
 	time_t date;
 
 	text = camel_tag_get (&tags, "follow-up");
 	if (text)
-		gtk_entry_set_text (GTK_ENTRY (followup->combo->entry), text);
+		gtk_entry_set_text (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (followup->combo_entry))), text);
 
 	text = camel_tag_get (&tags, "due-by");
 	if (text && *text) {
@@ -195,7 +195,7 @@ clear_clicked (GtkButton *button, gpointer user_data)
 {
 	MessageTagFollowUp *followup = user_data;
 
-	gtk_list_select_item (GTK_LIST (followup->combo->list), DEFAULT_FLAG);
+	gtk_combo_box_set_active (followup->combo_entry, DEFAULT_FLAG);
 
 	e_date_edit_set_time (followup->target_date, (time_t) -1);
 	gtk_toggle_button_set_active (followup->completed, FALSE);
@@ -212,7 +212,7 @@ completed_toggled (GtkToggleButton *button, gpointer user_data)
 		followup->completed_date = 0;
 }
 
-static int
+static gint
 get_week_start_day (void)
 {
 	GConfClient *gconf;
@@ -224,22 +224,22 @@ get_week_start_day (void)
 static gboolean
 locale_supports_12_hour_format (void)
 {
-	char s[16];
+	gchar s[16];
 	time_t t = 0;
 
 	strftime(s, sizeof s, "%p", gmtime (&t));
 	return s[0] != '\0';
 }
 
-GtkWidget *target_date_new (const char *s1, const char *s2, int i1, int i2);
+GtkWidget *target_date_new (const gchar *s1, const gchar *s2, gint i1, gint i2);
 
 GtkWidget *
-target_date_new (const char *s1, const char *s2, int i1, int i2)
+target_date_new (const gchar *s1, const gchar *s2, gint i1, gint i2)
 {
 	gboolean time_24hour = TRUE;
 	GConfClient *gconf;
 	GtkWidget *widget;
-	int start;
+	gint start;
 
 	widget = e_date_edit_new ();
 	e_date_edit_set_show_date (E_DATE_EDIT (widget), TRUE);
@@ -268,10 +268,9 @@ construct (MessageTagEditor *editor)
 	GtkCellRenderer *renderer;
 	GtkListStore *model;
 	GtkWidget *widget;
-	GList *strings;
 	GladeXML *gui;
-	int i;
-	char *gladefile;
+	gint i;
+	gchar *gladefile;
 
 	gtk_window_set_title (GTK_WINDOW (editor), _("Flag to Follow Up"));
 
@@ -294,11 +293,6 @@ construct (MessageTagEditor *editor)
 	gtk_widget_reparent (widget, GTK_DIALOG (editor)->vbox);
 	gtk_box_set_child_packing (GTK_BOX (GTK_DIALOG (editor)->vbox), widget, TRUE, TRUE, 6, GTK_PACK_START);
 
-	widget = glade_xml_get_widget (gui, "pixmap");
-	gtk_image_set_from_icon_name (
-		GTK_IMAGE (widget), "stock_mail-flag-for-followup",
-		GTK_ICON_SIZE_DIALOG);
-
 	followup->message_list = GTK_TREE_VIEW (glade_xml_get_widget (gui, "message_list"));
 	model = gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_STRING);
 	gtk_tree_view_set_model (followup->message_list, (GtkTreeModel *) model);
@@ -311,14 +305,11 @@ construct (MessageTagEditor *editor)
 	gtk_tree_view_insert_column_with_attributes (followup->message_list, -1, _("Subject"),
 						     renderer, "text", 1, NULL);
 
-	followup->combo = GTK_COMBO (glade_xml_get_widget (gui, "combo"));
-	gtk_combo_set_case_sensitive (followup->combo, FALSE);
-	strings = NULL;
+	followup->combo_entry = GTK_COMBO_BOX (glade_xml_get_widget (gui, "combo"));
+	gtk_list_store_clear (GTK_LIST_STORE (gtk_combo_box_get_model (followup->combo_entry)));
 	for (i = 0; i < num_available_flags; i++)
-		strings = g_list_append (strings, (char *) _(available_flags[i]));
-	gtk_combo_set_popdown_strings (followup->combo, strings);
-	g_list_free (strings);
-	gtk_list_select_item (GTK_LIST (followup->combo->list), DEFAULT_FLAG);
+		gtk_combo_box_append_text (followup->combo_entry, (gchar *) _(available_flags[i]));
+	gtk_combo_box_set_active (followup->combo_entry, DEFAULT_FLAG);
 
 	followup->target_date = E_DATE_EDIT (glade_xml_get_widget (gui, "target_date"));
 	/* glade bug, need to show this ourselves */
@@ -346,7 +337,7 @@ message_tag_followup_new (void)
 }
 
 void
-message_tag_followup_append_message (MessageTagFollowUp *editor, const char *from, const char *subject)
+message_tag_followup_append_message (MessageTagFollowUp *editor, const gchar *from, const gchar *subject)
 {
 	GtkTreeIter iter;
 	GtkListStore *model;
