@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -42,10 +42,9 @@
 #define d(x)
 
 /* Plugin hooks */
-int e_plugin_lib_enable (EPluginLib *ep, int enable);
+gint e_plugin_lib_enable (EPluginLib *ep, gint enable);
 void bbdb_handle_send (EPlugin *ep, EMEventTargetComposer *target);
 GtkWidget *bbdb_page_factory (EPlugin *ep, EConfigHookItemFactoryData *hook_data);
-GtkWidget *bbdb_page_factory (EPlugin *ep, EConfigHookItemFactoryData *hook_data);
 
 /* For internal use */
 struct bbdb_stuff {
@@ -60,11 +59,11 @@ struct bbdb_stuff {
 
 /* Static forward declarations */
 static gboolean bbdb_timeout (gpointer data);
-static void bbdb_do_it (EBook *book, const char *name, const char *email);
-static void add_email_to_contact (EContact *contact, const char *email);
+static void bbdb_do_it (EBook *book, const gchar *name, const gchar *email);
+static void add_email_to_contact (EContact *contact, const gchar *email);
 static void enable_toggled_cb (GtkWidget *widget, gpointer data);
 static void source_changed_cb (ESourceComboBox *source_combo_box, struct bbdb_stuff *stuff);
-static GtkWidget *create_addressbook_option_menu (struct bbdb_stuff *stuff, int type);
+static GtkWidget *create_addressbook_option_menu (struct bbdb_stuff *stuff, gint type);
 static void cleanup_cb (GObject *o, gpointer data);
 
 static ESource *
@@ -106,10 +105,10 @@ find_esource_by_uri (ESourceList *source_list, const gchar *target_uri)
 	return NULL;
 }
 
-int
-e_plugin_lib_enable (EPluginLib *ep, int enable)
+gint
+e_plugin_lib_enable (EPluginLib *ep, gint enable)
 {
- 	/* Start up the plugin. */
+	/* Start up the plugin. */
 	if (enable) {
 		d(fprintf (stderr, "BBDB spinning up...\n"));
 
@@ -135,8 +134,8 @@ bbdb_timeout (gpointer data)
 
 typedef struct
 {
-	char *name;
-	char *email;
+	gchar *name;
+	gchar *email;
 } todo_struct;
 
 static void
@@ -193,7 +192,7 @@ bbdb_do_in_thread (gpointer data)
 }
 
 static void
-bbdb_do_thread (const char *name, const char *email)
+bbdb_do_thread (const gchar *name, const gchar *email)
 {
 	todo_struct *td;
 
@@ -228,49 +227,53 @@ bbdb_do_thread (const char *name, const char *email)
 	G_UNLOCK (todo);
 }
 
+static void
+walk_destinations_and_free (EDestination **dests)
+{
+	gint i;
+
+	if (!dests)
+		return;
+
+	for (i = 0; dests[i] != NULL; i++) {
+		const gchar *name, *addr;
+
+		name = e_destination_get_name (dests[i]);
+		addr = e_destination_get_email (dests[i]);
+
+		if (name || addr)
+			bbdb_do_thread (name, addr);
+	}
+
+	e_destination_freev (dests);
+}
+
 void
 bbdb_handle_send (EPlugin *ep, EMEventTargetComposer *target)
 {
+	EComposerHeaderTable *table;
 	GConfClient *gconf;
-	CamelMimeMessage *message = NULL;
-	const CamelInternetAddress *to, *cc;
-	gint i, len, enable;
+	gboolean enable;
+
 	gconf = gconf_client_get_default ();
-
 	enable = gconf_client_get_bool (gconf, GCONF_KEY_ENABLE, NULL);
-	g_object_unref (G_OBJECT (gconf));
+	g_object_unref (gconf);
 
-	if (!enable) 
+	if (!enable)
 		return;
 
-	message = e_msg_composer_get_message(target->composer, 1);
+	table = e_msg_composer_get_header_table (target->composer);
+	g_return_if_fail (table);
 
-	to = camel_mime_message_get_recipients (message, CAMEL_RECIPIENT_TYPE_TO);
-
-	len = CAMEL_ADDRESS (to)->addresses->len;
-        for (i = 0; i < len; i++) {
-                const gchar *name, *addr;
-                if (!(camel_internet_address_get (to, i, &name, &addr)))
-			continue;
-		bbdb_do_thread (name, addr);
-        }
-
-
-	cc = camel_mime_message_get_recipients (message, CAMEL_RECIPIENT_TYPE_CC);
-
-	len = CAMEL_ADDRESS (cc)->addresses->len;
-        for (i = 0; i < len; i++) {
-                const gchar *name, *addr;
-                if (!(camel_internet_address_get (cc, i, &name, &addr)))
-			continue;
-		bbdb_do_thread (name, addr);
-        }
+	/* read information from the composer, not from a generated message */
+	walk_destinations_and_free (e_composer_header_table_get_destinations_to (table));
+	walk_destinations_and_free (e_composer_header_table_get_destinations_cc (table));
 }
 
 static void
-bbdb_do_it (EBook *book, const char *name, const char *email)
+bbdb_do_it (EBook *book, const gchar *name, const gchar *email)
 {
-	char *query_string, *delim, *temp_name = NULL;
+	gchar *query_string, *delim, *temp_name = NULL;
 	EBookQuery *query;
 	GList *contacts, *l;
 	EContact *contact;
@@ -372,10 +375,10 @@ bbdb_do_it (EBook *book, const char *name, const char *email)
 }
 
 EBook *
-bbdb_open_addressbook (int type)
+bbdb_open_addressbook (gint type)
 {
 	GConfClient *gconf;
-	char        *uri;
+	gchar        *uri;
 	EBook       *book = NULL;
 
 	gboolean     status;
@@ -436,7 +439,7 @@ bbdb_check_gaim_enabled (void)
 }
 
 static void
-add_email_to_contact (EContact *contact, const char *email)
+add_email_to_contact (EContact *contact, const gchar *email)
 {
 	GList *emails;
 
@@ -462,7 +465,7 @@ enable_toggled_cb (GtkWidget *widget, gpointer data)
 	/* Save the new setting to gconf */
 	gconf_client_set_bool (stuff->target->gconf, GCONF_KEY_ENABLE, active, NULL);
 
-       	gtk_widget_set_sensitive (stuff->option_menu, active);
+	gtk_widget_set_sensitive (stuff->option_menu, active);
 
 	addressbook = gconf_client_get_string (stuff->target->gconf, GCONF_KEY_WHICH_ADDRESSBOOK, NULL);
 
@@ -494,7 +497,7 @@ enable_gaim_toggled_cb (GtkWidget *widget, gpointer data)
 	struct bbdb_stuff *stuff = (struct bbdb_stuff *) data;
 	gboolean active;
 	ESource *selected_source;
-	char *addressbook_gaim;
+	gchar *addressbook_gaim;
 
 	active = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
 
@@ -559,12 +562,12 @@ gaim_source_changed_cb (ESourceComboBox *source_combo_box,
 }
 
 static GtkWidget *
-create_addressbook_option_menu (struct bbdb_stuff *stuff, int type)
+create_addressbook_option_menu (struct bbdb_stuff *stuff, gint type)
 {
 	GtkWidget   *combo_box;
 	ESourceList *source_list;
 	ESource     *selected_source;
-	char        *selected_source_uri;
+	gchar        *selected_source_uri;
 
 	GConfClient *gconf = stuff->target->gconf;
 
