@@ -1,12 +1,29 @@
-/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
-/* Copyright (C) 2002-2004 Novell, Inc. */
+/*
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
+ *
+ */
 
 #ifndef __EXCHANGE_DELEGATES_USER_H__
 #define __EXCHANGE_DELEGATES_USER_H__
 
 #include <exchange-types.h>
 #include <e2k-security-descriptor.h>
-#include <gtk/gtkwidget.h>
+#include <gtk/gtk.h>
 
 #ifdef __cplusplus
 extern "C" {
@@ -35,7 +52,7 @@ enum {
 struct _ExchangeDelegatesUser {
 	GObject parent;
 
-	char *display_name, *dn;
+	gchar *display_name, *dn;
 	GByteArray *entryid;
 
 	E2kSid *sid;
@@ -54,14 +71,14 @@ struct _ExchangeDelegatesUserClass {
 
 GType    exchange_delegates_user_get_type (void);
 
-ExchangeDelegatesUser *exchange_delegates_user_new         (const char            *display_name);
+ExchangeDelegatesUser *exchange_delegates_user_new         (const gchar            *display_name);
 ExchangeDelegatesUser *exchange_delegates_user_new_from_gc (E2kGlobalCatalog      *gc,
-							    const char            *email,
+							    const gchar            *email,
 							    GByteArray            *creator_entryid);
 
-gboolean  exchange_delegates_user_edit (ExchangeAccount  *account, ExchangeDelegatesUser *user, 
+gboolean  exchange_delegates_user_edit (ExchangeAccount  *account, ExchangeDelegatesUser *user,
 					GtkWidget *parent_window);
- 
+
 
 
 #ifdef __cplusplus
