@@ -1,21 +1,24 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
+/*
  *
- *  Shakti Sen <shprasad@novell.com>
- *  Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
+ *
+ * Authors:
+ *		Shakti Sen <shprasad@novell.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -91,11 +94,10 @@ setup_name_selector (GladeXML *glade_xml, ENameSelector **name_selector_ret)
 }
 
 static void
-setup_folder_name_combo (GladeXML *glade_xml, gchar *fname)
+setup_folder_name_combo (GladeXML *glade_xml, const gchar *fname)
 {
-	GtkWidget *combo;
-	GList *string_list;
-	char *strings[] = {
+	GtkComboBox *combo;
+	const gchar *strings[] = {
 		"Calendar",
 		"Inbox",
 		"Contacts",
@@ -103,26 +105,25 @@ setup_folder_name_combo (GladeXML *glade_xml, gchar *fname)
 		NULL
 		/* FIXME: Should these be translated?  */
 	};
-	int i;
+	gint i;
 
-	combo = glade_xml_get_widget (glade_xml, "folder-name-combo");
-	g_assert (GTK_IS_COMBO (combo));
+	combo = GTK_COMBO_BOX (glade_xml_get_widget (glade_xml, "folder-name-combo"));
+	g_assert (GTK_IS_COMBO_BOX_ENTRY (combo));
+
+	gtk_list_store_clear (GTK_LIST_STORE (gtk_combo_box_get_model (combo)));
 
-	string_list = NULL;
 	for (i = 0; strings[i] != NULL; i ++)
-		string_list = g_list_append (string_list, strings[i]);
-	gtk_combo_set_popdown_strings (GTK_COMBO (combo), string_list);
-	g_list_free (string_list);
+		gtk_combo_box_append_text (combo, strings[i]);
 
-	gtk_entry_set_text (GTK_ENTRY (GTK_COMBO (combo)->entry), fname);
+	gtk_entry_set_text (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (combo))), fname);
 }
 
 static void
 folder_name_entry_changed_callback (GtkEditable *editable,
-                                    void *data)
+                                    gpointer data)
 {
 	GtkDialog *dialog = GTK_DIALOG (data);
-	const char *folder_name_text = gtk_entry_get_text (GTK_ENTRY (editable));
+	const gchar *folder_name_text = gtk_entry_get_text (GTK_ENTRY (editable));
 
 	if (*folder_name_text == '\0')
 		gtk_dialog_set_response_sensitive (dialog, GTK_RESPONSE_OK, FALSE);
@@ -131,10 +132,10 @@ folder_name_entry_changed_callback (GtkEditable *editable,
 }
 
 static void
-user_name_entry_changed_callback (GtkEditable *editable, void *data)
+user_name_entry_changed_callback (GtkEditable *editable, gpointer data)
 {
 	GtkDialog *dialog = GTK_DIALOG (data);
-	const char *user_name_text = gtk_entry_get_text (GTK_ENTRY (editable));
+	const gchar *user_name_text = gtk_entry_get_text (GTK_ENTRY (editable));
 
 	if (*user_name_text == '\0')
 		gtk_dialog_set_response_sensitive (dialog, GTK_RESPONSE_OK, FALSE);
@@ -143,25 +144,17 @@ user_name_entry_changed_callback (GtkEditable *editable, void *data)
 }
 
 static void
-setup_server_option_menu (GladeXML *glade_xml, gchar *mail_account)
+setup_server_combobox (GladeXML *glade_xml, gchar *mail_account)
 {
 	GtkWidget *widget;
-	GtkWidget *menu;
-	GtkWidget *menu_item;
 
-	widget = glade_xml_get_widget (glade_xml, "server-option-menu");
-	g_return_if_fail (GTK_IS_OPTION_MENU (widget));
+	widget = glade_xml_get_widget (glade_xml, "server-combobox");
+	g_return_if_fail (GTK_IS_COMBO_BOX (widget));
 
-	menu = gtk_menu_new ();
-	gtk_widget_show (menu);
+	gtk_list_store_clear (GTK_LIST_STORE (gtk_combo_box_get_model (GTK_COMBO_BOX (widget))));
 
-	menu_item = gtk_menu_item_new_with_label (mail_account);
-
-	gtk_widget_show (menu_item);
-	gtk_menu_shell_append(GTK_MENU_SHELL(menu), menu_item);
-
-
-	gtk_option_menu_set_menu (GTK_OPTION_MENU (widget), menu);
+	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), mail_account);
+	gtk_combo_box_set_active (GTK_COMBO_BOX (widget), 0);
 
 	/* FIXME: Default to the current storage in the shell view.  */
 }
@@ -188,7 +181,7 @@ subscribe_to_folder (GtkWidget *dialog, gint response, gpointer data)
 {
 	SubscriptionInfo *subscription_info = data;
 	gchar *user_email_address = NULL, *folder_name = NULL, *path = NULL;
-	char *subscriber_email;
+	gchar *subscriber_email;
 	EFolder *folder = NULL;
 	EDestinationStore *destination_store;
 	GList *destinations;
@@ -226,8 +219,8 @@ subscribe_to_folder (GtkWidget *dialog, gint response, gpointer data)
 			}
 
 			/* It would be nice to insensitivize the OK button appropriately
-		   	instead of doing this, but unfortunately we can't do this for the
-		   	Bonobo control.  */
+			instead of doing this, but unfortunately we can't do this for the
+			Bonobo control.  */
 			e_error_run (GTK_WINDOW (dialog), ERROR_DOMAIN ":select-user", NULL);
 		}
 
@@ -293,13 +286,13 @@ subscribe_to_folder (GtkWidget *dialog, gint response, gpointer data)
 }
 
 gboolean
-create_folder_subscription_dialog (ExchangeAccount *account, gchar *fname)
+create_folder_subscription_dialog (ExchangeAccount *account, const gchar *fname)
 {
 	ENameSelector *name_selector;
 	GladeXML *glade_xml;
 	GtkWidget *dialog, *ok_button;
 	SubscriptionInfo *subscription_info;
-	int mode;
+	gint mode;
 
 	exchange_account_is_offline (account, &mode);
 	if (mode == OFFLINE_MODE)
@@ -326,9 +319,9 @@ create_folder_subscription_dialog (ExchangeAccount *account, gchar *fname)
 	g_signal_connect (subscription_info->name_selector_widget, "changed",
 			  G_CALLBACK (user_name_entry_changed_callback), dialog);
 
-	setup_server_option_menu (glade_xml, account->account_name);
+	setup_server_combobox (glade_xml, account->account_name);
 	setup_folder_name_combo (glade_xml, fname);
-	subscription_info->folder_name_entry = glade_xml_get_widget (glade_xml, "folder-name-entry");
+	subscription_info->folder_name_entry = gtk_bin_get_child (GTK_BIN (glade_xml_get_widget (glade_xml, "folder-name-combo")));
 	g_signal_connect (dialog, "response", G_CALLBACK (subscribe_to_folder), subscription_info);
 	gtk_widget_show (dialog);
 
