@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -44,7 +44,7 @@ append_to_header (ExchangeSendOptionsDialog *dialog, gint state, gpointer data)
 {
 	EMsgComposer *composer;
 	CamelAddress *sender_address;
-	const char *sender_id, *recipient_id;
+	const gchar *sender_id, *recipient_id;
 	struct _camel_header_address *addr;
 	struct _camel_header_address *sender_addr;
 
@@ -86,12 +86,12 @@ append_to_header (ExchangeSendOptionsDialog *dialog, gint state, gpointer data)
 			e_msg_composer_remove_header (composer, "Sensitivity");
 
 		sender_address = (CamelAddress *) e_msg_composer_get_from (composer);
-		sender_id = (const char*) camel_address_encode (sender_address);
+		sender_id = (const gchar *) camel_address_encode (sender_address);
 
 		addr = camel_header_address_decode (dialog->options->delegate_address, NULL);
 		sender_addr = camel_header_address_decode (sender_id, NULL);
 
- 		if(dialog->options->send_as_del_enabled &&
+		if(dialog->options->send_as_del_enabled &&
 			dialog->options->delegate_address &&
 				g_ascii_strcasecmp(addr->v.addr, sender_addr->v.addr)) {
 
@@ -109,7 +109,7 @@ append_to_header (ExchangeSendOptionsDialog *dialog, gint state, gpointer data)
 			}
 
 			else
-		       		e_msg_composer_add_header (composer, "From",
+				e_msg_composer_add_header (composer, "From",
 							dialog->options->delegate_address);
 		}
 
@@ -122,7 +122,7 @@ append_to_header (ExchangeSendOptionsDialog *dialog, gint state, gpointer data)
 		if (dialog->options->delivery_enabled) {
 			EComposerHeaderTable *table;
 			EAccount *account;
-			char *mdn_address;
+			gchar *mdn_address;
 
 			table = e_msg_composer_get_header_table (composer);
 			account = e_composer_header_table_get_account (table);
@@ -137,7 +137,7 @@ append_to_header (ExchangeSendOptionsDialog *dialog, gint state, gpointer data)
 		if (dialog->options->read_enabled) {
 			EComposerHeaderTable *table;
 			EAccount *account;
-			char *mdn_address;
+			gchar *mdn_address;
 
 			table = e_msg_composer_get_header_table (composer);
 			account = e_composer_header_table_get_account (table);
@@ -171,7 +171,7 @@ org_gnome_exchange_send_options (EPlugin *ep, EMEventTargetComposer *target)
 	EMsgComposer *composer = target->composer;
 	EComposerHeaderTable *table;
 	EAccount *account = NULL;
-	char *temp = NULL;
+	gchar *temp = NULL;
 
 	table = e_msg_composer_get_header_table (composer);
 	account = e_composer_header_table_get_account (table);
@@ -183,10 +183,10 @@ org_gnome_exchange_send_options (EPlugin *ep, EMEventTargetComposer *target)
 		return;
 	}
 	e_msg_composer_set_send_options (composer, TRUE);
- 	/*disply the send options dialog*/
+	/*disply the send options dialog*/
 	if (!dialog) {
-		g_print ("New dialog\n\n") ;
-		dialog = exchange_sendoptions_dialog_new () ;
+		g_print ("New dialog\n\n");
+		dialog = exchange_sendoptions_dialog_new ();
 	}
 	exchange_sendoptions_dialog_run (dialog, GTK_WIDGET (composer));
 	g_signal_connect (dialog, "sod_response", G_CALLBACK (append_to_header), GTK_WIDGET (composer));
