@@ -1,30 +1,26 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
+/*
  *
- *  Sivaiah Nallagatla <snallagatla@novell.com>
- *  Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
- *  Permission is hereby granted, free of charge, to any person
- *  obtaining a copy of this software and associated documentation
- *  files (the "Software"), to deal in the Software without
- *  restriction, including without limitation the rights to use, copy,
- *  modify, merge, publish, distribute, sublicense, and/or sell copies
- *  of the Software, and to permit persons to whom the Software is
- *  furnished to do so, subject to the following conditions:
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- *  The above copyright notice and this permission notice shall be
- *  included in all copies or substantial portions of the Software.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
+ *
+ * Authors:
+ *		Sivaiah Nallagatla <snallagatla@novell.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
- *  EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
- *  MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
- *  NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
- *  HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
- *  WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
- *  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
- *  DEALINGS IN THE SOFTWARE.
  */
 
-
 #include "camel-gw-listener.h"
 #include <gtk/gtk.h>
 #include "mail/em-config.h"
@@ -36,7 +32,7 @@
 
 static CamelGwListener *config_listener = NULL;
 
-int e_plugin_lib_enable (EPluginLib *ep, int enable);
+gint e_plugin_lib_enable (EPluginLib *ep, gint enable);
 GtkWidget* org_gnome_gw_account_setup(struct _EPlugin *epl, struct _EConfigHookItemFactoryData *data);
 void ensure_mandatory_esource_properties (EPlugin *ep, ESEventTargetUpgrade *target);
 
@@ -51,35 +47,27 @@ is_groupwise_account (EAccount *account)
 }
 
 static void
-set_esource_props (const char *path, EAccount *a, GConfClient *client, const char *name)
+set_esource_props (const gchar *path, EAccount *a, GConfClient *client, const gchar *name)
 {
 	ESourceList *list;
         GSList *groups;
-	char *old_relative_uri;
-	const char *poa_address;
-	CamelURL *url = camel_url_new (a->source->url, NULL);
-	
-	old_relative_uri =  g_strdup_printf ("%s@%s/", url->user, poa_address);
+
         list = e_source_list_new_for_gconf (client, path);
 	groups = e_source_list_peek_groups (list);
-	poa_address = url->host;
 
-	if (!poa_address || !*poa_address)
-		return;
-
-	for ( ; groups != NULL; groups = g_slist_next (groups)) {
+	for (; groups != NULL; groups = g_slist_next (groups)) {
 		ESourceGroup *group = E_SOURCE_GROUP (groups->data);
 
 		if (strcmp (e_source_group_peek_name (group), name) == 0 &&
 		    strcmp (e_source_group_peek_base_uri (group), GROUPWISE_BASE_URI) == 0) {
 			GSList *sources = e_source_group_peek_sources (group);
 
-			for ( ; sources != NULL; sources = g_slist_next (sources)) {
+			for (; sources != NULL; sources = g_slist_next (sources)) {
 				ESource *source = E_SOURCE (sources->data);
 
 				if (a->source->auto_check) {
-					char *str = g_strdup_printf ("%d",a->source->auto_check_time);
-				
+					gchar *str = g_strdup_printf ("%d",a->source->auto_check_time);
+
 					e_source_set_property (source, "refresh", str);
 					g_free (str);
 				} else
@@ -91,9 +79,6 @@ set_esource_props (const char *path, EAccount *a, GConfClient *client, const cha
 	e_source_list_sync (list, NULL);
 
 	g_object_unref (list);
-	g_free (old_relative_uri);
-	camel_url_free (url);
-
 }
 
 void
@@ -128,12 +113,12 @@ free_groupwise_listener ( void )
 	g_object_unref (config_listener);
 }
 
-int
-e_plugin_lib_enable (EPluginLib *ep, int enable)
+gint
+e_plugin_lib_enable (EPluginLib *ep, gint enable)
 {
 	if (!config_listener) {
 		config_listener = camel_gw_listener_new ();
-	 	g_atexit ( free_groupwise_listener );
+		g_atexit ( free_groupwise_listener );
 	}
 
 	return 0;
