@@ -10,12 +10,12 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
  *		Shreyas Srinivasan <sshreyas@novell.com>
- *  	Sankar P <psankar@novell.com>
+ *	Sankar P <psankar@novell.com>
  *
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
@@ -62,7 +62,7 @@
 
 static GObjectClass *parent_class = NULL;
 
-static gboolean proxy_page_changed_cb (GtkNotebook *notebook, GtkNotebookPage *page, int num, EAccount *account);
+static gboolean proxy_page_changed_cb (GtkNotebook *notebook, GtkNotebookPage *page, gint num, EAccount *account);
 
 struct _proxyDialogPrivate {
 	/* Glade XML data for the Add/Edit Proxy dialog*/
@@ -94,7 +94,7 @@ struct _proxyDialogPrivate {
 	GtkWidget *notifications;
 	GtkWidget *options;
 	GtkWidget *private;
-        char *help_section;
+        gchar *help_section;
 
 	GList *proxy_list;
 };
@@ -230,7 +230,7 @@ proxy_dialog_get_type (void)
       sizeof (proxyDialog),
      0,      /* n_preallocs */
      (GInstanceInitFunc) proxy_dialog_init,
- 	NULL    /* instance_init */
+	NULL    /* instance_init */
     };
 
     type = g_type_register_static (G_TYPE_OBJECT,
@@ -251,10 +251,10 @@ proxy_dialog_new (void)
 	return prd;
 }
 
-static int
+static gint
 proxy_get_permissions_from_dialog (EAccount *account)
 {
-	int permissions;
+	gint permissions;
 	proxyDialogPrivate *priv;
 	proxyDialog *prd = NULL;
 
@@ -301,7 +301,7 @@ proxy_get_permissions_from_dialog (EAccount *account)
 	return permissions;
 }
 
-static int
+static gint
 proxy_dialog_store_widgets_data (EAccount *account, gint32 dialog)
 {
 	GtkTreeIter iter;
@@ -309,7 +309,7 @@ proxy_dialog_store_widgets_data (EAccount *account, gint32 dialog)
 	GtkTreeModel *model;
 	proxyHandler *new_proxy = NULL;
 	proxyDialogPrivate *priv;
-	char *account_mailid;
+	gchar *account_mailid;
 	proxyDialog *prd = NULL;
 
 	prd = g_object_get_data ((GObject *)account, "prd");
@@ -322,7 +322,7 @@ proxy_dialog_store_widgets_data (EAccount *account, gint32 dialog)
 				ENameSelectorEntry *name_selector_entry;
 				EDestinationStore *destination_store;
 				GList *destinations, *tmp;
-				char *name, *email;
+				gchar *name, *email;
 				GList *existing_list;
 				name_selector_entry = e_name_selector_peek_section_entry (priv->proxy_name_selector, "Add User");
 				destination_store = e_name_selector_entry_peek_destination_store (E_NAME_SELECTOR_ENTRY (
@@ -337,7 +337,7 @@ proxy_dialog_store_widgets_data (EAccount *account, gint32 dialog)
 
 				for (; tmp != NULL; tmp = g_list_next (tmp)) {
 					email = NULL;
-					email = (char *)e_destination_get_email (tmp->data);
+					email = (gchar *)e_destination_get_email (tmp->data);
 
 					if (g_str_equal(email, ""))
 						continue;
@@ -376,12 +376,12 @@ proxy_dialog_store_widgets_data (EAccount *account, gint32 dialog)
 
 				for (; tmp != NULL; tmp = g_list_next (tmp)) {
 					name = NULL; email = NULL;
-					email = (char *) e_destination_get_email (tmp->data);
+					email = (gchar *) e_destination_get_email (tmp->data);
 
 					if (g_str_equal(email, ""))
 						continue;
 
-					name = (char *) e_destination_get_name (tmp->data);
+					name = (gchar *) e_destination_get_name (tmp->data);
 					new_proxy = (proxyHandler *) g_malloc0 (sizeof (proxyHandler));
 
 					if (name)
@@ -459,9 +459,10 @@ static EGwConnection *
 proxy_get_cnc (EAccount *account, GtkWindow *parent_window)
 {
 	EGwConnection *cnc;
-	char *uri, *failed_auth, *key, *prompt, *password = NULL;
+	const gchar *failed_auth;
+	gchar *uri, *key, *prompt, *password = NULL;
 	CamelURL *url;
-	const char *poa_address, *use_ssl, *soap_port;
+	const gchar *poa_address, *use_ssl, *soap_port;
 	gboolean remember;
 
 	url = camel_url_new (account->source->url, NULL);
@@ -497,7 +498,7 @@ proxy_get_cnc (EAccount *account, GtkWindow *parent_window)
 
 	cnc = e_gw_connection_new (uri, url->user, password);
 	if (!E_IS_GW_CONNECTION(cnc) && use_ssl && g_str_equal (use_ssl, "when-possible")) {
-		char *http_uri = g_strconcat ("http://", uri + 8, NULL);
+		gchar *http_uri = g_strconcat ("http://", uri + 8, NULL);
 		cnc = e_gw_connection_new (http_uri, url->user, password);
 		g_free (http_uri);
 	}
@@ -550,7 +551,7 @@ proxy_commit (GtkWidget *button, EConfigHookItemFactoryData *data)
 		/* Handle case where the structure is new and deleted*/
 		if ( !((aclInstance->flags & E_GW_PROXY_NEW) && (aclInstance->flags & E_GW_PROXY_DELETED))) {
 
-			if ( !E_IS_GW_CONNECTION(prd->cnc)) 	/* Add check in case the connection request fails*/
+			if ( !E_IS_GW_CONNECTION(prd->cnc))	/* Add check in case the connection request fails*/
 				prd->cnc = proxy_get_cnc (account, GTK_WINDOW (gtk_widget_get_toplevel (button)));
 
 			if (aclInstance->flags & E_GW_PROXY_NEW )
@@ -598,11 +599,11 @@ static void
 proxy_update_tree_view (EAccount *account)
 {
 	proxyDialog *prd = NULL;
-    	GtkTreeIter iter;
+	GtkTreeIter iter;
 	GdkPixbuf *broken_image = NULL;
 	GList *list_iter;
 	proxyHandler *aclInstance;
-	gchar *file_name = e_icon_factory_get_icon_filename ("stock_person", E_ICON_SIZE_DIALOG);
+	gchar *file_name = e_icon_factory_get_icon_filename ("stock_person", GTK_ICON_SIZE_DIALOG);
 	proxyDialogPrivate *priv;
 
 	prd = g_object_get_data ((GObject *)account, "prd");
@@ -613,7 +614,7 @@ proxy_update_tree_view (EAccount *account)
 	list_iter = priv->proxy_list;
 
 	for (;list_iter; list_iter = g_list_next(list_iter)) {
-	        aclInstance = (proxyHandler *) list_iter->data;
+		aclInstance = (proxyHandler *) list_iter->data;
 
 		if(! (aclInstance->flags & E_GW_PROXY_DELETED )) {
 			gtk_tree_store_append (priv->store, &iter, NULL);
@@ -621,7 +622,7 @@ proxy_update_tree_view (EAccount *account)
 		}
 	}
 
-   	g_free (file_name);
+	g_free (file_name);
 	if (broken_image)
 		g_object_unref (broken_image);
 
@@ -639,8 +640,8 @@ org_gnome_proxy (EPlugin *epl, EConfigHookItemFactoryData *data)
 	proxyDialogPrivate *priv;
 	CamelOfflineStore *store;
 	CamelException ex;
-	int pag_num;
-	char *gladefile;
+	gint pag_num;
+	gchar *gladefile;
 
 	target_account = (EMConfigTargetAccount *)data->config->target;
 	account = target_account->account;
@@ -722,7 +723,7 @@ org_gnome_proxy (EPlugin *epl, EConfigHookItemFactoryData *data)
 }
 
 static gboolean
-proxy_page_changed_cb (GtkNotebook *notebook, GtkNotebookPage *page, int num, EAccount *account)
+proxy_page_changed_cb (GtkNotebook *notebook, GtkNotebookPage *page, gint num, EAccount *account)
 {
 	proxyDialog *prd;
 	proxyDialogPrivate *priv;
@@ -822,7 +823,7 @@ proxy_edit_ok (GtkWidget *button, EAccount *account)
 }
 
 static proxyHandler *
-proxy_get_item_from_list (EAccount *account, char *account_name)
+proxy_get_item_from_list (EAccount *account, gchar *account_name)
 {
 	proxyDialogPrivate *priv;
 	proxyDialog *prd = NULL;
@@ -834,7 +835,7 @@ proxy_get_item_from_list (EAccount *account, char *account_name)
 	list_iter = priv->proxy_list;
 
 	for (;list_iter; list_iter = g_list_next(list_iter)) {
-	        iter = (proxyHandler *) list_iter->data;
+		iter = (proxyHandler *) list_iter->data;
 
 		if ( g_str_equal (iter->proxy_email,account_name))
 			return iter;
@@ -851,7 +852,7 @@ proxy_remove_account (GtkWidget *button, EAccount *account)
 	proxyDialogPrivate *priv;
 	proxyHandler *deleted;
 	GtkTreeSelection* account_select;
-	char *account_mailid;
+	gchar *account_mailid;
 	proxyDialog *prd = NULL;
 
 	prd = g_object_get_data ((GObject *)account, "prd");
@@ -905,7 +906,7 @@ proxy_add_account (GtkWidget *button, EAccount *account)
 	ENameSelectorEntry *name_selector_entry;
 	GtkWidget *proxy_name, *name_box;
 	proxyDialog *prd = NULL;
-	char *gladefile;
+	gchar *gladefile;
 
 	prd = g_object_get_data ((GObject *)account, "prd");
 	priv = prd->priv;
@@ -1003,10 +1004,10 @@ proxy_edit_account (GtkWidget *button, EAccount *account)
 	GtkTreeSelection* account_select;
 	proxyHandler *edited;
 	GtkButton *okButton, *proxyCancel;
-	char *account_mailid;
+	gchar *account_mailid;
 	GtkWidget *contacts;
 	proxyDialog *prd = NULL;
-	char *gladefile;
+	gchar *gladefile;
 
 	prd = g_object_get_data ((GObject *)account, "prd");
 	priv = prd->priv;
