@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -55,9 +55,10 @@ static EGwConnection *
 get_cnc (GtkWindow *parent_window)
 {
 	EGwConnection *cnc;
-	char *uri, *failed_auth, *key, *prompt, *password = NULL;
+	const gchar *failed_auth;
+	gchar *uri, *key, *prompt, *password = NULL;
 	CamelURL *url;
-	const char *poa_address, *use_ssl, *soap_port;
+	const gchar *poa_address, *use_ssl, *soap_port;
 	gboolean remember;
 
 	url = camel_url_new (account->source->url, NULL);
@@ -93,7 +94,7 @@ get_cnc (GtkWindow *parent_window)
 
 	cnc = e_gw_connection_new (uri, url->user, password);
 	if (!E_IS_GW_CONNECTION(cnc) && use_ssl && g_str_equal (use_ssl, "when-possible")) {
-		char *http_uri = g_strconcat ("http://", uri + 8, NULL);
+		gchar *http_uri = g_strconcat ("http://", uri + 8, NULL);
 		cnc = e_gw_connection_new (http_uri, url->user, password);
 		g_free (http_uri);
 	}
@@ -121,7 +122,7 @@ e_send_options_load_general_opts (ESendOptionsGeneral *gopts, EGwSendOptionsGene
 
 	gopts->delay_enabled = ggopts->delay_enabled;
 
-	/* TODO convert int to timet comparing the current day */
+	/* TODO convert gint to timet comparing the current day */
 	if (ggopts->delay_until) {
 		gopts->delay_until = time_add_day_with_zone (temp, ggopts->delay_until, NULL);
 	} else
@@ -190,7 +191,7 @@ e_sendoptions_clicked_cb (GtkWidget *button, gpointer data)
 	if (n_cnc)
 		e_sendoptions_dialog_run (sod, parent ? parent : NULL, E_ITEM_NONE);
 	else
-	       	return;
+		return;
 }
 
 GtkWidget *
@@ -272,7 +273,7 @@ e_send_options_copy_general_opts (ESendOptionsGeneral *gopts, EGwSendOptionsGene
 	ggopts->delay_enabled = gopts->delay_enabled;
 
 	if (gopts->delay_until) {
-		int diff;
+		gint diff;
 		icaltimetype temp, current;
 
 		temp = icaltime_from_timet (gopts->delay_until, 0);
@@ -327,7 +328,7 @@ static void
 send_options_copy_check_changed (EGwSendOptions *n_opts)
 {
 	EGwSendOptionsGeneral *ggopts, *o_gopts;
-	EGwSendOptionsStatusTracking *gmopts, *o_gmopts ;
+	EGwSendOptionsStatusTracking *gmopts, *o_gmopts;
 	EGwSendOptionsStatusTracking *gcopts, *o_gcopts;
 	EGwSendOptionsStatusTracking *gtopts, *o_gtopts;
 
@@ -360,14 +361,14 @@ static ESource *
 get_source (ESourceList *list)
 {
 	GSList *p, *l;
-	char **temp = g_strsplit (account->source->url, ";", -1);
-	char *uri = temp [0];
+	gchar **temp = g_strsplit (account->source->url, ";", -1);
+	gchar *uri = temp [0];
 
 
 	l = e_source_list_peek_groups (list);
 
 	for (p = l; p != NULL; p = p->next) {
-		char *so_uri;
+		gchar *so_uri;
 		GSList *r, *s;
 		ESourceGroup *group = E_SOURCE_GROUP (p->data);
 
@@ -393,9 +394,11 @@ get_source (ESourceList *list)
 }
 
 static void
-add_return_value (EGwSendOptionsReturnNotify track, ESource *source, char *notify)
+add_return_value (EGwSendOptionsReturnNotify track,
+                  ESource *source,
+                  const gchar *notify)
 {
-	char *value;
+	gchar *value;
 
 	switch (track) {
 		case E_GW_RETURN_NOTIFY_MAIL:
@@ -412,8 +415,8 @@ add_return_value (EGwSendOptionsReturnNotify track, ESource *source, char *notif
 static void
 put_options_in_source (ESource *source, EGwSendOptionsGeneral *gopts, EGwSendOptionsStatusTracking *sopts)
 {
-	char *value;
-	const char *val;
+	gchar *value;
+	const gchar *val;
 	icaltimetype tt;
 	CamelURL  *url;
 
