@@ -1,34 +1,31 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
+/*
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
- *  Authors: Philip Van Hoof <pvanhoof@gnome.org>
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- *  Copyright 2004 Novell, Inc. (www.novell.com)
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
- *  This program is free software; you can redistribute it and/or
- *  modify it under the terms of version 2 of the GNU General Public
- *  License as published by the Free Software Foundation.
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ * Authors:
+ *		Philip Van Hoof <pvanhoof@gnome.org>
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
-#include <glib.h>
-#include <glib/gi18n.h>
-#include <gtk/gtkfilechooser.h>
-#include <gtk/gtkfilechooserdialog.h>
-#include <gtk/gtkmessagedialog.h>
-#include <gtk/gtkstock.h>
+
 #include <gtk/gtk.h>
+#include <glib/gi18n.h>
 #include <libedataserver/e-source.h>
 #include <libecal/e-cal-time-util.h>
 #include <libedataserver/e-data-server-util.h>
@@ -50,7 +47,7 @@ struct _CsvConfig {
 	gboolean header;
 };
 
-static gboolean string_needsquotes (const char *value, CsvConfig *config);
+static gboolean string_needsquotes (const gchar *value, CsvConfig *config);
 
 typedef struct _CsvPluginData CsvPluginData;
 struct _CsvPluginData
@@ -96,7 +93,7 @@ add_list_to_csv (GString *line, GSList *list_in, CsvConfig *config, gint type)
 		GString *tmp = NULL;
 		gint cnt=0;
 		while (list) {
-			const char *str = NULL;
+			const gchar *str = NULL;
 			if (cnt == 0)
 				tmp = g_string_new ("");
 			if (cnt > 0)
@@ -116,7 +113,7 @@ add_list_to_csv (GString *line, GSList *list_in, CsvConfig *config, gint type)
 			if (!needquotes)
 				needquotes = string_needsquotes (str, config);
 			if (str)
-				tmp = g_string_append (tmp, (const gchar*)str);
+				tmp = g_string_append (tmp, (const gchar *)str);
 			list = g_slist_next (list); cnt++;
 			if (list)
 				tmp = g_string_append (tmp, config->delimiter);
@@ -157,7 +154,7 @@ add_time_to_csv (GString *line, icaltimetype *time, CsvConfig *config)
 	if (time) {
 		gboolean needquotes = FALSE;
 		struct tm mytm =  icaltimetype_to_tm (time);
-		gchar *str = (gchar*) g_malloc (sizeof (gchar) * 200);
+		gchar *str = (gchar *) g_malloc (sizeof (gchar) * 200);
 
 		/*
 		 * Translator: the %F %T is the thirth argument for a strftime function.
@@ -185,7 +182,7 @@ add_time_to_csv (GString *line, icaltimetype *time, CsvConfig *config)
 }
 
 static gboolean
-string_needsquotes (const char *value, CsvConfig *config)
+string_needsquotes (const gchar *value, CsvConfig *config)
 {
 
 	/* This is the actual need for quotes-checker */
@@ -246,7 +243,7 @@ string_needsquotes (const char *value, CsvConfig *config)
 }
 
 static GString *
-add_string_to_csv (GString *line, const char *value, CsvConfig *config)
+add_string_to_csv (GString *line, const gchar *value, CsvConfig *config)
 {
 	/* Will add a string to the record and will check for the need for quotes */
 
@@ -255,7 +252,7 @@ add_string_to_csv (GString *line, const char *value, CsvConfig *config)
 
 		if (needquotes)
 			line = g_string_append (line, config->quote);
-		line = g_string_append (line, (const gchar*)value);
+		line = g_string_append (line, (const gchar *)value);
 		if (needquotes)
 			line = g_string_append (line, config->quote);
 	}
@@ -306,7 +303,7 @@ userstring_to_systemstring (const gchar *userstring)
 }
 
 static void
-do_save_calendar_csv (FormatHandler *handler, EPlugin *ep, ECalPopupTargetSource *target, ECalSourceType type, char *dest_uri)
+do_save_calendar_csv (FormatHandler *handler, EPlugin *ep, ECalPopupTargetSource *target, ECalSourceType type, gchar *dest_uri)
 {
 
 	/*
@@ -360,7 +357,7 @@ do_save_calendar_csv (FormatHandler *handler, EPlugin *ep, ECalPopupTargetSource
 
 			gint i=0;
 
-			static gchar *labels[] = {
+			static const gchar *labels[] = {
 				 N_("UID"),
 				 N_("Summary"),
 				 N_("Description List"),
@@ -396,11 +393,11 @@ do_save_calendar_csv (FormatHandler *handler, EPlugin *ep, ECalPopupTargetSource
 		while (objects != NULL) {
 			ECalComponent *comp = objects->data;
 			gchar *delimiter_temp = NULL;
-			const char *temp_constchar;
+			const gchar *temp_constchar;
 			GSList *temp_list;
 			ECalComponentDateTime temp_dt;
 			struct icaltimetype *temp_time;
-			int *temp_int;
+			gint *temp_int;
 			ECalComponentText temp_comptext;
 
 			line = g_string_new ("");
