@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -68,21 +68,21 @@ typedef struct {
     EMPopupTargetSelect *t;
 } UserData;
 
-static char* get_content	(CamelMimeMessage *message);
+static gchar * get_content	(CamelMimeMessage *message);
 
-static void reply_with_template	(EPopup *ep, EPopupItem *item, void *data);
+static void reply_with_template	(EPopup *ep, EPopupItem *item, gpointer data);
 
-static void popup_free		(EPopup *ep, GSList *l, void *data);
+static void popup_free		(EPopup *ep, GSList *l, gpointer data);
 
-static GSList *fill_submenu	(CamelStore *store, 
-                             	CamelFolderInfo *info, 
-                              	GSList *list, 
-                              	EMPopupTargetSelect *t);
+static GSList *fill_submenu	(CamelStore *store,
+				CamelFolderInfo *info,
+				GSList *list,
+				EMPopupTargetSelect *t);
 
-static GSList *append_to_menu 	(CamelFolder *folder, 
-                             	GPtrArray *uids, 
-                             	GSList *list, 
-                             	EMPopupTargetSelect *t);
+static GSList *append_to_menu	(CamelFolder *folder,
+				GPtrArray *uids,
+				GSList *list,
+				EMPopupTargetSelect *t);
 
 void org_gnome_templates_popup	(EPlugin *ep, EMPopupTargetSelect *t);
 
@@ -98,7 +98,7 @@ static void  key_cell_edited_callback (GtkCellRendererText *cell, gchar *path_st
 				   gchar *new_text,UIData *ui);
 
 static void  value_cell_edited_callback (GtkCellRendererText *cell, gchar *path_string,
-				   gchar *new_text,UIData *ui);				   
+				   gchar *new_text,UIData *ui);
 
 static gboolean clue_foreach_check_isempty (GtkTreeModel *model, GtkTreePath
 					*path, GtkTreeIter *iter, UIData *ui);
@@ -143,18 +143,18 @@ commit_changes (UIData *ui)
 	valid = gtk_tree_model_get_iter_first (model, &iter);
 
 	while (valid) {
-		char *keyword, *value;
-		char *key;
-		
+		gchar *keyword, *value;
+		gchar *key;
+
 		gtk_tree_model_get (model, &iter, CLUE_KEYWORD_COLUMN, &keyword, -1);
 		gtk_tree_model_get (model, &iter, CLUE_VALUE_COLUMN, &value, -1);
 
 		/* Check if the keyword and value are not empty */
-		if ((keyword) && (value) && (g_utf8_strlen(g_strstrip(keyword), -1) > 0) 
+		if ((keyword) && (value) && (g_utf8_strlen(g_strstrip(keyword), -1) > 0)
 			&& (g_utf8_strlen(g_strstrip(value), -1) > 0)) {
 			key = g_strdup_printf("%s=%s", keyword, value);
 			clue_list = g_slist_append (clue_list, key);
-		}	
+		}
 		valid = gtk_tree_model_iter_next (model, &iter);
 	}
 
@@ -168,7 +168,7 @@ static void
 clue_check_isempty (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter, UIData *ui)
 {
 	GtkTreeSelection *selection;
-	char *keyword = NULL;
+	gchar *keyword = NULL;
 	gboolean valid;
 
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (ui->treeview));
@@ -201,7 +201,7 @@ clue_foreach_check_isempty (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter
 
 	valid = gtk_tree_model_get_iter_first (model, iter);
 	while (valid && gtk_list_store_iter_is_valid (ui->store, iter)) {
-		char *keyword = NULL;
+		gchar *keyword = NULL;
 		gtk_tree_model_get (model, iter, CLUE_KEYWORD_COLUMN, &keyword, -1);
 		/* Check if the keyword is not empty and then emit the row-changed
 		signal (if we delete the row, then the iter gets corrupted) */
@@ -223,13 +223,13 @@ key_cell_edited_callback (GtkCellRendererText *cell,
 {
 	GtkTreeModel *model;
 	GtkTreeIter iter;
-	char *value;
+	gchar *value;
 
 	model = gtk_tree_view_get_model (GTK_TREE_VIEW (ui->treeview));
 
 	gtk_tree_model_get_iter_from_string (model, &iter, path_string);
 
-	gtk_tree_model_get (model, &iter, CLUE_VALUE_COLUMN, &value, -1);	
+	gtk_tree_model_get (model, &iter, CLUE_VALUE_COLUMN, &value, -1);
 	gtk_list_store_set (GTK_LIST_STORE (model), &iter,
 				    CLUE_KEYWORD_COLUMN, new_text, CLUE_VALUE_COLUMN, value, -1);
 
@@ -244,12 +244,12 @@ value_cell_edited_callback (GtkCellRendererText *cell,
 {
 	GtkTreeModel *model;
 	GtkTreeIter iter;
-	char *keyword;
+	gchar *keyword;
 
 	model = gtk_tree_view_get_model (GTK_TREE_VIEW (ui->treeview));
 
 	gtk_tree_model_get_iter_from_string (model, &iter, path_string);
-	
+
 	gtk_tree_model_get (model, &iter, CLUE_KEYWORD_COLUMN, &keyword, -1);
 
 	gtk_list_store_set (GTK_LIST_STORE (model), &iter,
@@ -370,7 +370,7 @@ e_plugin_lib_get_configure_widget (EPlugin *epl)
 
 	UIData *ui = g_new0 (UIData, 1);
 
-	char *gladefile;
+	gchar *gladefile;
 
 	gladefile = g_build_filename (EVOLUTION_PLUGINDIR,
 			"templates.glade",
@@ -421,7 +421,7 @@ e_plugin_lib_get_configure_widget (EPlugin *epl)
 	clue_list = gconf_client_get_list ( gconf, GCONF_KEY_TEMPLATE_PLACEHOLDERS, GCONF_VALUE_STRING, NULL );
 
 	for (list = clue_list; list; list = g_slist_next (list)) {
-		char **temp = g_strsplit (list->data, "=", 2);
+		gchar **temp = g_strsplit (list->data, "=", 2);
 		gtk_list_store_append (ui->store, &iter);
 		gtk_list_store_set (ui->store, &iter, CLUE_KEYWORD_COLUMN, temp[0], CLUE_VALUE_COLUMN, temp[1], -1);
 		g_strfreev(temp);
@@ -445,14 +445,14 @@ e_plugin_lib_get_configure_widget (EPlugin *epl)
 }
 
 /* borrowed from plugins/mail-to-task/ */
-static char *
+static gchar *
 get_content (CamelMimeMessage *message)
 {
 	CamelDataWrapper *content;
 	CamelStream *mem;
 	CamelContentType *type;
 	CamelMimePart *mime_part = CAMEL_MIME_PART (message);
-	char *str, *convert_str = NULL;
+	gchar *str, *convert_str = NULL;
 	gsize bytes_read, bytes_written;
 	gint count = 2;
 
@@ -477,7 +477,7 @@ get_content (CamelMimeMessage *message)
 	mem = camel_stream_mem_new ();
 	camel_data_wrapper_decode_to_stream (content, mem);
 
-	str = g_strndup ((const gchar*)((CamelStreamMem *) mem)->buffer->data, ((CamelStreamMem *) mem)->buffer->len);
+	str = g_strndup ((const gchar *)((CamelStreamMem *) mem)->buffer->data, ((CamelStreamMem *) mem)->buffer->len);
 	camel_object_unref (mem);
 
 	/* convert to UTF-8 string */
@@ -491,26 +491,26 @@ get_content (CamelMimeMessage *message)
 		g_free (str);
 		return convert_str;
 	}
-	else 
+	else
 		return str;
-			
+
 }
 
 static void
-reply_with_template (EPopup *ep, EPopupItem *item, void *data)
+reply_with_template (EPopup *ep, EPopupItem *item, gpointer data)
 {
 	CamelMimeMessage *new, *template, *reply_to;
 	CamelFolder *templates_folder;
 	struct _camel_header_raw *header;
 	UserData *userdata = item->user_data;
-	char *cont;
+	gchar *cont;
 
 	/* We get the templates folder and all the uids of the messages in there */
 	templates_folder = mail_component_get_folder(NULL, MAIL_COMPONENT_FOLDER_TEMPLATES);
 
 	/* Get from the currently selected folder, the currently selected message */
-	reply_to = camel_folder_get_message (userdata->t->folder, 
-			g_ptr_array_index (userdata->t->uids, 0), 
+	reply_to = camel_folder_get_message (userdata->t->folder,
+			g_ptr_array_index (userdata->t->uids, 0),
 			NULL);
 
 	/* The message we'll be using has been stored when building the menu */
@@ -525,8 +525,8 @@ reply_with_template (EPopup *ep, EPopupItem *item, void *data)
 	header = ((CamelMimePart *)reply_to)->headers;
 	while (header) {
 		if (g_ascii_strncasecmp (header->name, "content-", 8) != 0) {
-			camel_medium_add_header((CamelMedium *) new, 
-					header->name, 
+			camel_medium_add_header((CamelMedium *) new,
+					header->name,
 					header->value);
 		}
 		header = header->next;
@@ -538,19 +538,19 @@ reply_with_template (EPopup *ep, EPopupItem *item, void *data)
 	cont = get_content (template);
 
 	/* Set the To: field to the same To: field of the message we are replying to. */
-	camel_mime_message_set_recipients (new, CAMEL_RECIPIENT_TYPE_TO, 
+	camel_mime_message_set_recipients (new, CAMEL_RECIPIENT_TYPE_TO,
 			camel_mime_message_get_from (reply_to));
 
 
 	/* Copy the CC and BCC from the template.*/
-	camel_mime_message_set_recipients (new, CAMEL_RECIPIENT_TYPE_CC, 
+	camel_mime_message_set_recipients (new, CAMEL_RECIPIENT_TYPE_CC,
 			camel_mime_message_get_recipients (template, CAMEL_RECIPIENT_TYPE_CC));
 
-	camel_mime_message_set_recipients (new, CAMEL_RECIPIENT_TYPE_BCC, 
+	camel_mime_message_set_recipients (new, CAMEL_RECIPIENT_TYPE_BCC,
 			camel_mime_message_get_recipients (template, CAMEL_RECIPIENT_TYPE_BCC));
 
 	camel_mime_part_set_content((CamelMimePart *)new,
-			cont, (int) g_utf8_strlen(cont, -1), "text");
+			cont, (gint) g_utf8_strlen(cont, -1), "text");
 
 	/* Create the composer */
 	em_utils_edit_message (new, templates_folder);
@@ -558,8 +558,8 @@ reply_with_template (EPopup *ep, EPopupItem *item, void *data)
 	camel_object_unref(new);
 }
 
-static void 
-popup_free (EPopup *ep, GSList *l, void *data)
+static void
+popup_free (EPopup *ep, GSList *l, gpointer data)
 {
 	g_slist_free (l);
 }
@@ -567,15 +567,15 @@ popup_free (EPopup *ep, GSList *l, void *data)
 static GSList
 *append_to_menu (CamelFolder *folder, GPtrArray *uids, GSList *list, EMPopupTargetSelect *t)
 {
-	int i;
+	gint i;
 
 	for (i = 0; i < uids->len; i++) {
-		const char *subject;
-		char *path;
+		const gchar *subject;
+		gchar *path;
 		EPopupItem *item;
 		CamelMimeMessage *message;
 		UserData *user_data;
-		const char *uid;
+		const gchar *uid;
 
 		uid = g_strdup (g_ptr_array_index (uids, i));
 
@@ -583,15 +583,15 @@ static GSList
 		if (!g_str_has_suffix (folder->name, "Templates"))
 			path = g_strdup_printf ("80.%s", folder->full_name);
 		else
-			path = "80.Templates";
+			path = g_strdup ("80.Templates");
 
 		/* If this uid is trashed, ignore it */
 		if (camel_folder_get_message_flags (folder, uid) & CAMEL_MESSAGE_DELETED)
 			continue;
-		
+
 		/* Get the message for this uid */
-		message = camel_folder_get_message (folder, 
-				uid, 
+		message = camel_folder_get_message (folder,
+				uid,
 				NULL);
 
 		subject = camel_mime_message_get_subject (message);
@@ -617,7 +617,7 @@ static GSList
 	return list;
 }
 
-static GSList 
+static GSList
 *fill_submenu (CamelStore *store, CamelFolderInfo *info, GSList *list, EMPopupTargetSelect *t)
 {
 	while (info) {
@@ -629,14 +629,14 @@ static GSList
 
 		item = g_slice_alloc0(sizeof(*item));
 		item->type = E_POPUP_SUBMENU;
-		item->label = folder->name; 
+		item->label = folder->name;
 		item->visible = EM_POPUP_SELECT_MANY | EM_POPUP_SELECT_ONE;
 
 		/* To avoid having a Templates dir, we ignore the top level */
 		if (!g_str_has_suffix (folder->name, "Templates"))
 			item->path = g_strdup_printf ("80.%s", folder->full_name);
 		else
-			item->path = "80.Templates";
+			item->path = g_strdup ("80.Templates");
 
 		list = g_slist_prepend (list, item);
 
@@ -670,9 +670,9 @@ org_gnome_templates_popup (EPlugin *ep, EMPopupTargetSelect *t)
 
 	templates_folder = mail_component_get_folder(NULL, MAIL_COMPONENT_FOLDER_TEMPLATES);
 
-	templates_info = camel_store_get_folder_info (store, 
-			templates_folder->full_name, 
-			CAMEL_STORE_FOLDER_INFO_RECURSIVE | CAMEL_STORE_FOLDER_INFO_FAST, 
+	templates_info = camel_store_get_folder_info (store,
+			templates_folder->full_name,
+			CAMEL_STORE_FOLDER_INFO_RECURSIVE | CAMEL_STORE_FOLDER_INFO_FAST,
 			NULL);
 
 	/* Get subfolders and fill it */
@@ -709,7 +709,7 @@ static GtkActionEntry entries[] = {
 	{ "Template",
 	  GTK_STOCK_SAVE,
 	  N_("Save as _Template"),
-  	  "<Shift><Control>t",
+	  "<Shift><Control>t",
 	  N_("Save as Template"),
 	  G_CALLBACK (action_template_cb) }
 };
