@@ -1,23 +1,23 @@
-/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
-/* importer.c
- *
- * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
- *
+/*
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
+ *
+ * Authors:
+ *		Iain Holmes  <iain@ximian.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * Author: Iain Holmes  <iain@ximian.com>
  */
 
 #include <config.h>
@@ -56,9 +56,6 @@ typedef struct _ImportDialogFilePage {
 	GtkWidget *vbox;
 	GtkWidget *filename;
 	GtkWidget *filetype;
-	GtkWidget *menu;
-
-	GSList *items;
 
 	EImportTargetURI *target;
 	EImportImporter *importer;
@@ -124,17 +121,15 @@ typedef struct _ImportData {
 #endif
 
 static struct {
-	char *name;
-	char *text;
+	const gchar *name;
+	const gchar *text;
 } info[] = {
 	{ "type_html",
 	  N_("Choose the type of importer to run:")
 	},
 	{ "file_html",
 	  N_("Choose the file that you want to import into Evolution, "
-	     "and select what type of file it is from the list.\n\n"
-	     "You can select \"Automatic\" if you do not know, and "
-	     "Evolution will attempt to work it out.")
+	     "and select what type of file it is from the list.")
 	},
 	{ "dest_html",
 	  N_("Choose the destination for this import")
@@ -152,10 +147,10 @@ static struct {
 #define num_info (sizeof (info) / sizeof (info[0]))
 
 static GtkWidget *
-create_help (const char *name)
+create_help (const gchar *name)
 {
 	GtkWidget *label;
-	int i;
+	gint i;
 
 	for (i = 0; i < num_info; i++) {
 		if (!strcmp (name, info[i].name))
@@ -180,8 +175,8 @@ filename_changed (GtkWidget *widget,
 		  ImportData *data)
 {
 	ImportDialogFilePage *page;
-	const char *filename;
-	int fileok;
+	const gchar *filename;
+	gint fileok;
 
 	page = data->filepage;
 
@@ -189,66 +184,81 @@ filename_changed (GtkWidget *widget,
 
 	fileok = filename && filename[0] && g_file_test(filename, G_FILE_TEST_IS_REGULAR);
 	if (fileok) {
-		GSList *l, *item;
+		GtkTreeIter iter;
+		GtkTreeModel *model;
+		gboolean valid;
+		GSList *l;
 		EImportImporter *first = NULL;
-		int i=0, firstitem=0;
+		gint i=0, firstitem=0;
 
 		g_free(page->target->uri_src);
 		page->target->uri_src = g_filename_to_uri(filename, NULL, NULL);
 
 		l = e_import_get_importers(data->import, (EImportTarget *)page->target);
-		item = page->items;
-		while (item) {
-			EImportImporter *eii = g_object_get_data(item->data, "importer");
+		model = gtk_combo_box_get_model (GTK_COMBO_BOX (page->filetype));
+		valid = gtk_tree_model_get_iter_first (model, &iter);
+		while (valid) {
+			gpointer eii = NULL;
 
-			if (g_slist_find(l, eii) != NULL) {
+			gtk_tree_model_get (model, &iter, 2, &eii, -1);
+
+			if (g_slist_find (l, eii) != NULL) {
 				if (first == NULL) {
 					firstitem = i;
 					first = eii;
 				}
-				gtk_widget_set_sensitive(item->data, TRUE);
+				gtk_list_store_set (GTK_LIST_STORE (model), &iter, 1, TRUE, -1);
 				fileok = TRUE;
 			} else {
 				if (page->importer == eii)
 					page->importer = NULL;
-				gtk_widget_set_sensitive(item->data, FALSE);
+				gtk_list_store_set (GTK_LIST_STORE (model), &iter, 1, FALSE, -1);
 			}
 			i++;
-			item = item->next;
+			valid = gtk_tree_model_iter_next (model, &iter);
 		}
 		g_slist_free(l);
 
 		if (page->importer == NULL && first) {
 			page->importer = first;
-			gtk_option_menu_set_history((GtkOptionMenu *)page->filetype, firstitem);
+			gtk_combo_box_set_active (GTK_COMBO_BOX (page->filetype), firstitem);
 		}
 		fileok = first != NULL;
 	} else {
-		GSList *item;
+		GtkTreeIter iter;
+		GtkTreeModel *model;
+		gboolean valid;
 
-		for (item = page->items;item;item=item->next)
-			gtk_widget_set_sensitive(item->data, FALSE);
+		model = gtk_combo_box_get_model (GTK_COMBO_BOX (page->filetype));
+		for (valid = gtk_tree_model_get_iter_first (model, &iter);
+		     valid;
+		     valid = gtk_tree_model_iter_next (model, &iter)) {
+			gtk_list_store_set (GTK_LIST_STORE (model), &iter, 1, FALSE, -1);
+		}
 	}
 
 	gnome_druid_set_buttons_sensitive(GNOME_DRUID (data->druid), TRUE, fileok, TRUE, FALSE);
 }
 
 static void
-item_selected (GtkWidget *item,
-	       ImportData *data)
+filetype_changed_cb (GtkWidget *combobox, ImportData *data)
 {
-	data->filepage->importer = g_object_get_data((GObject *)item, "importer");
-	filename_changed(data->filepage->filename, data);
+	GtkTreeIter iter;
+
+	g_return_if_fail (gtk_combo_box_get_active_iter (GTK_COMBO_BOX (combobox), &iter));
+
+	gtk_tree_model_get (gtk_combo_box_get_model (GTK_COMBO_BOX (combobox)), &iter, 2, &data->filepage->importer, -1);
+	filename_changed (data->filepage->filename, data);
 }
 
 #if 0
-static int
-compare_info_name (const void *data1, const void  *data2)
+static gint
+compare_info_name (gconstpointer data1, const void  *data2)
 {
 	const Bonobo_ServerInfo *info1 = (Bonobo_ServerInfo *)data1;
 	const Bonobo_ServerInfo *info2 = (Bonobo_ServerInfo *)data2;
-	const char *name1 = get_name_from_component_info (info1);
-	const char *name2 = get_name_from_component_info (info2);
+	const gchar *name1 = get_name_from_component_info (info1);
+	const gchar *name2 = get_name_from_component_info (info2);
 
 	/* If we can't find a name for a plug-in, its iid will be used
 	 * for display. Put such plug-ins at the end of the list since
@@ -269,7 +279,9 @@ importer_file_page_new (ImportData *data)
 {
 	ImportDialogFilePage *page;
 	GtkWidget *table, *label;
-	int row = 0;
+	GtkCellRenderer *cell;
+	GtkListStore *store;
+	gint row = 0;
 
 	page = g_new0 (ImportDialogFilePage, 1);
 
@@ -300,7 +312,19 @@ importer_file_page_new (ImportData *data)
 			  GTK_FILL, 0, 0, 0);
 	gtk_misc_set_alignment (GTK_MISC (label), 1, 0.5);
 
-	page->filetype = gtk_option_menu_new ();
+	store = gtk_list_store_new (3, G_TYPE_STRING, G_TYPE_BOOLEAN, G_TYPE_POINTER);
+	page->filetype = gtk_combo_box_new_with_model (GTK_TREE_MODEL (store));
+	g_object_unref (store);
+
+	gtk_cell_layout_clear (GTK_CELL_LAYOUT (page->filetype));
+
+	cell = gtk_cell_renderer_text_new ();
+	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (page->filetype), cell, TRUE);
+	gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (page->filetype), cell,
+                                  "text", 0,
+                                  "sensitive", 1,
+                                  NULL);
+
 	gtk_table_attach (GTK_TABLE (table), page->filetype, 1, 2,
 			  row, row + 1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
 	gtk_label_set_mnemonic_widget(GTK_LABEL(label), page->filetype);
@@ -366,7 +390,7 @@ prepare_intelligent_page (GnomeDruidPage *dpage,
 {
 	GSList *l;
 	GtkWidget *table;
-	int row;
+	gint row;
 	ImportDialogImporterPage *page = data->importerpage;
 
 	if (page->target != NULL)
@@ -388,7 +412,7 @@ prepare_intelligent_page (GnomeDruidPage *dpage,
 	row = 0;
 	for (;l;l=l->next) {
 		EImportImporter *eii = l->data;
-		char *str;
+		gchar *str;
 		GtkWidget *w, *label;
 
 		w = e_import_get_widget(data->import, (EImportTarget *)page->target, eii);
@@ -416,7 +440,7 @@ static void
 import_druid_cancel (GnomeDruid *druid,
 		     ImportData *data)
 {
-  	gtk_widget_destroy (GTK_WIDGET (data->dialog));
+	gtk_widget_destroy (GTK_WIDGET (data->dialog));
 }
 
 static gboolean
@@ -432,7 +456,7 @@ import_druid_esc (GnomeDruid *druid,
 }
 
 static void
-import_druid_weak_notify (void *blah,
+import_druid_weak_notify (gpointer blah,
 			  GObject *where_the_object_was)
 {
 	ImportData *data = (ImportData *) blah;
@@ -443,7 +467,6 @@ import_druid_weak_notify (void *blah,
 
 	if (data->filepage->target)
 		e_import_target_free(data->import, data->filepage->target);
-	g_slist_free(data->filepage->items);
 
 	g_object_unref(data->import);
 
@@ -452,7 +475,7 @@ import_druid_weak_notify (void *blah,
 }
 
 static void
-import_status(EImport *import, const char *what, int pc, void *d)
+import_status(EImport *import, const gchar *what, gint pc, gpointer d)
 {
 	ImportData *data = d;
 
@@ -468,7 +491,7 @@ import_dialog_response(GtkDialog *d, guint button, ImportData *data)
 }
 
 static void
-import_done(EImport *ei, void *d)
+import_done(EImport *ei, gpointer d)
 {
 	ImportData *data = d;
 
@@ -477,7 +500,7 @@ import_done(EImport *ei, void *d)
 }
 
 static void
-import_intelligent_done(EImport *ei, void *d)
+import_intelligent_done(EImport *ei, gpointer d)
 {
 	ImportData *data = d;
 
@@ -496,7 +519,7 @@ import_druid_finish (GnomeDruidPage *page,
 		     ImportData *data)
 {
 	EImportCompleteFunc done = NULL;
-	char *msg = NULL;
+	gchar *msg = NULL;
 
 	if (gtk_toggle_button_get_active((GtkToggleButton *)data->typepage->intelligent)) {
 		data->importerpage->current = data->importerpage->importers;
@@ -537,8 +560,8 @@ prepare_file_page (GnomeDruidPage *dpage,
 		   GnomeDruid *druid,
 		   ImportData *data)
 {
-	GtkWidget *item, *menu;
-	GSList *importers;
+	GSList *importers, *imp;
+	GtkListStore *store;
 	ImportDialogFilePage *page = data->filepage;
 
 	if (page->target != NULL) {
@@ -547,27 +570,31 @@ prepare_file_page (GnomeDruidPage *dpage,
 	}
 
 	page->target = e_import_target_new_uri(data->import, NULL, NULL);
-	importers = e_import_get_importers(data->import, (EImportTarget *)page->target);
+	importers = e_import_get_importers (data->import, (EImportTarget *)page->target);
 
-	menu = gtk_menu_new();
-	while (importers) {
-		EImportImporter *eii = importers->data;
+	store = GTK_LIST_STORE (gtk_combo_box_get_model (GTK_COMBO_BOX (page->filetype)));
+	gtk_list_store_clear (store);
 
-		item = gtk_menu_item_new_with_label(eii->name);
-		gtk_widget_show(item);
-		g_object_set_data((GObject *)item, "importer", eii);
-		g_signal_connect(item, "activate", G_CALLBACK(item_selected), data);
-		gtk_menu_shell_append((GtkMenuShell *)menu, item);
+	for (imp = importers; imp; imp = imp->next) {
+		GtkTreeIter iter;
+		EImportImporter *eii = imp->data;
 
-		data->filepage->items = g_slist_append(data->filepage->items, item);
-		importers = importers->next;
+		gtk_list_store_append (store, &iter);
+		gtk_list_store_set (
+			store, &iter,
+			0, eii->name,
+			1, TRUE,
+			2, eii,
+			-1);
 	}
-	g_slist_free(importers);
 
-	data->filepage->menu = menu;
-	gtk_option_menu_set_menu((GtkOptionMenu *)data->filepage->filetype, menu);
+	g_slist_free (importers);
 
-	filename_changed(data->filepage->filename, data);
+	gtk_combo_box_set_active (GTK_COMBO_BOX (page->filetype), 0);
+
+	filename_changed (data->filepage->filename, data);
+
+	g_signal_connect (page->filetype, "changed", G_CALLBACK (filetype_changed_cb), data);
 
 	return FALSE;
 }
@@ -650,7 +677,7 @@ back_intelligent_page (GnomeDruidPage *page,
 }
 
 static void
-dialog_weak_notify (void *data,
+dialog_weak_notify (gpointer data,
 		    GObject *where_the_dialog_was)
 {
 	gboolean *dialog_open = (gboolean *) data;
@@ -665,7 +692,7 @@ e_shell_importer_start_import (EShellWindow *shell_window)
 	GtkWidget *html;
 	static gboolean dialog_open = FALSE;
 	GdkPixbuf *icon;
-	char *gladefile;
+	gchar *gladefile;
 
 	if (dialog_open) {
 		return;
@@ -673,7 +700,7 @@ e_shell_importer_start_import (EShellWindow *shell_window)
 
 	data->import = e_import_new("org.gnome.evolution.shell.importer");
 
-	icon = e_icon_factory_get_icon ("stock_mail-import", E_ICON_SIZE_DIALOG);
+	icon = e_icon_factory_get_icon ("stock_mail-import", GTK_ICON_SIZE_DIALOG);
 
 	dialog_open = TRUE;
 	data->window = shell_window;
