@@ -1,36 +1,34 @@
-/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
-/* e-shell.c
- *
- * Copyright (C) 2000, 2001, 2002, 2003 Ximian, Inc.
- *
+/*
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
+ *
+ * Authors:
+ *		Ettore Perazzoli <ettore@ximian.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * Author: Ettore Perazzoli
  */
 
 #include <config.h>
 
 #include <string.h>
+#include <unistd.h>
 #include <sys/types.h>
 
-#include <glib.h>
+#include <gtk/gtk.h>
 #include <glib/gstdio.h>
 
-#include <gtk/gtkmain.h>
-#include <gtk/gtksignal.h>
-
 #ifdef GDK_WINDOWING_X11
 #include <gdk/gdkprivate.h>
 #include <gdk/gdkx.h>
@@ -45,7 +43,6 @@
 #endif
 
 #include <glib/gi18n.h>
-#include <libgnome/gnome-util.h>
 
 #include <gconf/gconf-client.h>
 
@@ -64,7 +61,6 @@
 
 #include "Evolution.h"
 #include "e-shell-constants.h"
-#include "e-shell-marshal.h"
 #include "e-shell-settings-dialog.h"
 #include "e-shell.h"
 #include "e-shell-view.h"
@@ -72,7 +68,7 @@
 #include "evolution-listener.h"
 #include "evolution-shell-component-utils.h"
 
-static void set_line_status_complete(EvolutionListener *el, void *data);
+static void set_line_status_complete(EvolutionListener *el, gpointer data);
 
 #define PARENT_TYPE bonobo_object_get_type ()
 static BonoboObjectClass *parent_class = NULL;
@@ -80,7 +76,7 @@ static gboolean session_started = FALSE;
 
 struct _EShellPrivate {
 	/* IID for registering the object on OAF.  */
-	char *iid;
+	gchar *iid;
 
 	GList *windows;
 
@@ -89,11 +85,11 @@ struct _EShellPrivate {
 
 	/* Names for the types of the folders that have maybe crashed.  */
 	/* FIXME TODO */
-	GList *crash_type_names; /* char * */
+	GList *crash_type_names; /* gchar * */
 
 	/* Line status and controllers  */
 	EShellLineStatus line_status;
-	int line_status_pending;
+	gint line_status_pending;
 	EShellLineStatus line_status_working;
 	EvolutionListener *line_status_listener;
 
@@ -109,16 +105,19 @@ struct _EShellPrivate {
 	/* Whether the shell is succesfully initialized.  This is needed during
 	   the start-up sequence, to avoid CORBA calls to do make wrong things
 	   to happen while the shell is initializing.  */
-	unsigned int is_initialized : 1;
+	guint is_initialized : 1;
 
 	/* Wether the shell is working in "interactive" mode or not.
 	   (Currently, it's interactive IIF there is at least one active
 	   view.)  */
-	unsigned int is_interactive : 1;
+	guint is_interactive : 1;
 
 	/* Whether quit has been requested, and the shell is now waiting for
 	   permissions from all the components to quit.  */
-	unsigned int preparing_to_quit : 1;
+	guint preparing_to_quit : 1;
+
+	/* Whether we are recovering from a crash in the previous session. */
+	guint crash_recovery : 1;
 };
 
 
@@ -161,7 +160,7 @@ set_interactive (EShell *shell,
 	GSList *component_list;
 	GSList *p;
 	GList *first_element;
-	int num_windows;
+	gint num_windows;
 	GtkWidget *view;
 
 	g_return_if_fail (E_IS_SHELL (shell));
@@ -261,8 +260,8 @@ impl_Shell_handleURI (PortableServer_Servant servant,
 {
 	EShell *shell = E_SHELL (bonobo_object_from_servant (servant));
 	EComponentInfo *component_info;
-	char *schema, *p;
-	int show = FALSE;
+	gchar *schema, *p;
+	gint show = FALSE;
 
 	schema = g_alloca(strlen(uri)+1);
 	strcpy(schema, uri);
@@ -270,7 +269,7 @@ impl_Shell_handleURI (PortableServer_Servant servant,
 	if (p)
 		*p = 0;
 
- 	component_info = e_component_registry_peek_info(shell->priv->component_registry, ECR_FIELD_SCHEMA, schema);
+	component_info = e_component_registry_peek_info(shell->priv->component_registry, ECR_FIELD_SCHEMA, schema);
 	if (component_info == NULL) {
 		show = TRUE;
 		component_info = e_component_registry_peek_info(shell->priv->component_registry, ECR_FIELD_ALIAS, schema);
@@ -315,9 +314,9 @@ impl_Shell_setLineStatus (PortableServer_Servant servant,
 	e_passwords_set_online(online);
 
 	if (online)
-		e_shell_go_online (shell, NULL, GNOME_Evolution_USER_ONLINE);
+		e_shell_set_line_status (shell, GNOME_Evolution_USER_ONLINE);
 	else
-		e_shell_go_offline (shell, NULL, GNOME_Evolution_USER_OFFLINE);
+		e_shell_set_line_status (shell, GNOME_Evolution_USER_OFFLINE);
 }
 /*
 static GNOME_Evolution_Component
@@ -347,10 +346,10 @@ impl_Shell_findComponent(PortableServer_Servant servant,
 
 /* EShellWindow handling and bookkeeping.  */
 
-static int
+static gint
 window_delete_event_cb (GtkWidget *widget,
 		      GdkEventAny *ev,
-		      void *data)
+		      gpointer data)
 {
 	EShell *shell;
 
@@ -361,7 +360,7 @@ window_delete_event_cb (GtkWidget *widget,
 }
 
 static gboolean
-notify_no_windows_left_idle_cb (void *data)
+notify_no_windows_left_idle_cb (gpointer data)
 {
 	EShell *shell;
 	EShellPrivate *priv;
@@ -382,11 +381,11 @@ notify_no_windows_left_idle_cb (void *data)
 }
 
 static void
-window_weak_notify (void *data,
+window_weak_notify (gpointer data,
 		    GObject *where_the_object_was)
 {
 	EShell *shell;
-	int num_windows;
+	gint num_windows;
 
 	shell = E_SHELL (data);
 
@@ -552,9 +551,9 @@ e_shell_init (EShell *shell)
 }
 
 static void
-detect_version (GConfClient *gconf, int *major, int *minor, int *revision)
+detect_version (GConfClient *gconf, gint *major, gint *minor, gint *revision)
 {
-	char *val, *evolution_dir;
+	gchar *val, *evolution_dir;
 	struct stat st;
 
 	evolution_dir = g_build_filename (g_get_home_dir (), "evolution", NULL);
@@ -572,7 +571,7 @@ detect_version (GConfClient *gconf, int *major, int *minor, int *revision)
 	} else {
 		xmlDocPtr config_doc;
 		xmlNodePtr source;
-		char *tmp;
+		gchar *tmp;
 
 		tmp = g_build_filename (evolution_dir, "config.xmldb", NULL);
 		config_doc = e_xml_parse_file (tmp);
@@ -601,11 +600,11 @@ detect_version (GConfClient *gconf, int *major, int *minor, int *revision)
 
 /* calls components to perform upgrade */
 static gboolean
-attempt_upgrade (EShell *shell, int major, int minor, int revision)
+attempt_upgrade (EShell *shell, gint major, gint minor, gint revision)
 {
 	GSList *component_infos, *p;
 	gboolean success;
-	int res;
+	gint res;
 
 	success = TRUE;
 
@@ -619,7 +618,7 @@ attempt_upgrade (EShell *shell, int major, int minor, int revision)
 		GNOME_Evolution_Component_upgradeFromVersion (info->iface, major, minor, revision, &ev);
 
 		if (BONOBO_EX (&ev)) {
-			char *exception_text;
+			gchar *exception_text;
 			CORBA_char *id = CORBA_exception_id(&ev);
 
 			if (strcmp (id, ex_CORBA_NO_IMPLEMENT) == 0) {
@@ -661,7 +660,7 @@ attempt_upgrade (EShell *shell, int major, int minor, int revision)
  **/
 EShellConstructResult
 e_shell_construct (EShell *shell,
-		   const char *iid,
+		   const gchar *iid,
 		   EShellStartupLineMode startup_line_mode)
 {
 	EShellPrivate *priv;
@@ -715,9 +714,9 @@ e_shell_construct (EShell *shell,
 	e_passwords_set_online(start_online);
 
 	if (start_online)
-		e_shell_go_online (shell, NULL, GNOME_Evolution_USER_ONLINE);
+		e_shell_set_line_status (shell, GNOME_Evolution_USER_ONLINE);
 	else
-		e_shell_go_online (shell, NULL, GNOME_Evolution_USER_OFFLINE);
+		e_shell_set_line_status (shell, GNOME_Evolution_USER_OFFLINE);
 
 	return E_SHELL_CONSTRUCT_RESULT_OK;
 }
@@ -753,13 +752,13 @@ e_shell_new (EShellStartupLineMode startup_line_mode,
 	return new;
 }
 
-static int
-remove_dir(const char *root, const char *path)
+static gint
+remove_dir(const gchar *root, const gchar *path)
 {
 	GDir *dir;
-	const char *dname;
-	int res = -1;
-	char *new = NULL;
+	const gchar *dname;
+	gint res = -1;
+	gchar *new = NULL;
 	struct stat st;
 
 	dir = g_dir_open(path, 0, NULL);
@@ -805,12 +804,12 @@ gboolean
 e_shell_attempt_upgrade (EShell *shell)
 {
 	GConfClient *gconf_client;
-	int major = 0, minor = 0, revision = 0;
-	int lmajor, lminor, lrevision;
-	int cmajor, cminor, crevision;
-	char *version_string, *last_version = NULL;
-	int done_upgrade = FALSE;
-	char *oldpath;
+	gint major = 0, minor = 0, revision = 0;
+	gint lmajor, lminor, lrevision;
+	gint cmajor, cminor, crevision;
+	gchar *version_string, *last_version = NULL;
+	gint done_upgrade = FALSE;
+	gchar *oldpath;
 	struct stat st;
 	ESEvent *ese;
 
@@ -835,8 +834,8 @@ e_shell_attempt_upgrade (EShell *shell)
 		size = e_fsutils_usage(oldpath);
 		space = e_fsutils_avail(g_get_home_dir());
 		if (size != -1 && space != -1 && space < size) {
-			char *required = g_strdup_printf(_("%ld KB"), size);
-			char *have = g_strdup_printf(_("%ld KB"), space);
+			gchar *required = g_strdup_printf(_("%ld KB"), size);
+			gchar *have = g_strdup_printf(_("%ld KB"), space);
 
 			e_error_run(NULL, "shell:upgrade-nospace", required, have, NULL);
 			g_free(required);
@@ -856,7 +855,7 @@ e_shell_attempt_upgrade (EShell *shell)
 check_old:
 	/* if the last upgraded version was old, check for stuff to remove */
 	if (done_upgrade
-	    || 	(last_version = gconf_client_get_string (gconf_client, "/apps/evolution/last_version", NULL)) == NULL
+	    ||	(last_version = gconf_client_get_string (gconf_client, "/apps/evolution/last_version", NULL)) == NULL
 	    ||  sscanf(last_version, "%d.%d.%d", &lmajor, &lminor, &lrevision) != 3) {
 		lmajor = major;
 		lminor = minor;
@@ -867,7 +866,7 @@ check_old:
 	if (lmajor == 1 && lminor < 5
 	    && g_stat(oldpath, &st) == 0
 	    && S_ISDIR(st.st_mode)) {
-		int res;
+		gint res;
 
 		last_version = g_strdup_printf("%d.%d.%d", lmajor, lminor, lrevision);
 		res = e_error_run(NULL, "shell:upgrade-remove-1-4", last_version, NULL);
@@ -928,7 +927,7 @@ check_old:
  **/
 EShellWindow *
 e_shell_create_window (EShell *shell,
-		       const char *component_id,
+		       const gchar *component_id,
 		       EShellWindow *template_window)
 {
 	EShellWindow *window;
@@ -1112,7 +1111,7 @@ set_line_status_finished(EShell *shell)
 }
 
 static void
-set_line_status_complete(EvolutionListener *el, void *data)
+set_line_status_complete(EvolutionListener *el, gpointer data)
 {
 	EShell *shell = data;
 	EShellPrivate *priv = shell->priv;
@@ -1124,8 +1123,9 @@ set_line_status_complete(EvolutionListener *el, void *data)
 	}
 }
 
-static void
-set_line_status(EShell *shell, GNOME_Evolution_ShellState shell_state)
+void
+e_shell_set_line_status (EShell *shell,
+                         GNOME_Evolution_ShellState shell_state)
 {
 	EShellPrivate *priv;
 	GSList *component_infos;
@@ -1179,41 +1179,21 @@ set_line_status(EShell *shell, GNOME_Evolution_ShellState shell_state)
 		set_line_status_finished(shell);
 }
 
-/**
- * e_shell_go_offline:
- * @shell:
- * @action_window: Obsolete/unused.
- *
- * Make the shell go into off-line mode.
- **/
-void
-e_shell_go_offline (EShell *shell,
-		    EShellWindow *action_window, GNOME_Evolution_ShellState shell_state)
+gboolean
+e_shell_get_crash_recovery (EShell *shell)
 {
-	g_return_if_fail (shell != NULL);
-	g_return_if_fail (E_IS_SHELL (shell));
-	g_return_if_fail (action_window != NULL);
-	g_return_if_fail (action_window == NULL || E_IS_SHELL_WINDOW (action_window));
+	g_return_val_if_fail (E_IS_SHELL (shell), FALSE);
 
-	set_line_status(shell, shell_state);
+	return shell->priv->crash_recovery;
 }
 
-/**
- * e_shell_go_online:
- * @shell:
- * @action_window: Obsolete/unused.
- *
- * Make the shell go into on-line mode.
- **/
 void
-e_shell_go_online (EShell *shell,
-		   EShellWindow *action_window, GNOME_Evolution_ShellState shell_state)
+e_shell_set_crash_recovery (EShell *shell,
+                            gboolean crash_recovery)
 {
-	g_return_if_fail (shell != NULL);
 	g_return_if_fail (E_IS_SHELL (shell));
-	g_return_if_fail (action_window == NULL || E_IS_SHELL_WINDOW (action_window));
 
-	set_line_status(shell, shell_state);
+	shell->priv->crash_recovery = crash_recovery;
 }
 
 void
@@ -1244,7 +1224,7 @@ e_shell_send_receive (EShell *shell)
 
 void
 e_shell_show_settings (EShell *shell,
-		       const char *type,
+		       const gchar *type,
 		       EShellWindow *shell_window)
 {
 	EShellPrivate *priv;
@@ -1272,7 +1252,7 @@ e_shell_show_settings (EShell *shell,
 }
 
 
-const char *
+const gchar *
 e_shell_construct_result_to_string (EShellConstructResult result)
 {
 	switch (result) {
