@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -106,8 +106,8 @@ static gboolean disable_eplugin = FALSE;
 static gboolean disable_preview = FALSE;
 static gboolean idle_cb (gchar **uris);
 
-static char *default_component_id = NULL;
-static char *evolution_debug_log = NULL;
+static gchar *default_component_id = NULL;
+static gchar *evolution_debug_log = NULL;
 static gchar **remaining_args;
 
 static void
@@ -118,7 +118,7 @@ no_windows_left_cb (EShell *shell, gpointer data)
 }
 
 static void
-shell_weak_notify (void *data,
+shell_weak_notify (gpointer data,
 		   GObject *where_the_object_was)
 {
 	bonobo_main_quit ();
@@ -155,7 +155,8 @@ kill_old_dataserver (void)
 	CORBA_exception_init (&ev);
 
 	/* FIXME Should we really kill it off?  We also shouldn't hard code the version */
-	iface = bonobo_activation_activate_from_id ("OAFIID:GNOME_Evolution_DataServer_InterfaceCheck", 0, NULL, &ev);
+	iface = bonobo_activation_activate_from_id (
+		(Bonobo_ActivationID) "OAFIID:GNOME_Evolution_DataServer_InterfaceCheck", 0, NULL, &ev);
 	if (BONOBO_EX (&ev) || iface == CORBA_OBJECT_NIL) {
 		kill_dataserver ();
 		CORBA_exception_free (&ev);
@@ -198,7 +199,7 @@ show_development_warning(void)
 	GtkWidget *checkbox;
 	GtkWidget *alignment;
 	gboolean skip;
-	char *text;
+	gchar *text;
 
 	warning_dialog = gtk_dialog_new ();
 	gtk_window_set_title (GTK_WINDOW (warning_dialog), "Evolution " VERSION);
@@ -345,7 +346,8 @@ idle_cb (gchar **uris)
 		break;
 
 	case E_SHELL_CONSTRUCT_RESULT_CANNOTREGISTER:
-		corba_shell = bonobo_activation_activate_from_id (E_SHELL_OAFIID, 0, NULL, &ev);
+		corba_shell = bonobo_activation_activate_from_id (
+			(Bonobo_ActivationID) E_SHELL_OAFIID, 0, NULL, &ev);
 		if (ev._major != CORBA_NO_EXCEPTION || corba_shell == CORBA_OBJECT_NIL) {
 			e_error_run(NULL, "shell:noshell", NULL);
 			CORBA_exception_free (&ev);
@@ -396,7 +398,7 @@ idle_cb (gchar **uris)
 		bonobo_main_quit ();
 	}
 
-	/* This must be done after Bonobo has created all the components. For 
+	/* This must be done after Bonobo has created all the components. For
 	 * example the mail component makes the global variable `session` which
 	 * is being used by several EPlugins */
 
@@ -415,12 +417,12 @@ idle_cb (gchar **uris)
    thread. So if we have to redirect the signal if the crash happens in another
    thread.  */
 
-static void (*gnome_segv_handler) (int);
+static void (*gnome_segv_handler) (gint);
 static GStaticMutex segv_mutex = G_STATIC_MUTEX_INIT;
 static pthread_t main_thread;
 
 static void
-segv_redirect (int sig)
+segv_redirect (gint sig)
 {
 	if (pthread_self () == main_thread)
 		gnome_segv_handler (sig);
@@ -560,8 +562,8 @@ set_paths (void)
 }
 #endif
 
-int
-main (int argc, char **argv)
+gint
+main (gint argc, gchar **argv)
 {
 #ifdef G_OS_WIN32
 	extern void link_shutdown (void);
@@ -574,7 +576,7 @@ main (int argc, char **argv)
 	GnomeProgram *program;
 	GnomeClient *master_client;
 	GOptionContext *context;
-	char *filename;
+	gchar *filename;
 
 	/* Make ElectricFence work.  */
 	free (malloc (10));
@@ -628,7 +630,7 @@ main (int argc, char **argv)
 	client = gconf_client_get_default ();
 
 #ifdef DEVELOPMENT
-	
+
 	if (force_migrate) {
 		destroy_config (client);
 	}
@@ -643,7 +645,7 @@ main (int argc, char **argv)
 	setup_segv_redirect ();
 
 	if (evolution_debug_log) {
-		int fd;
+		gint fd;
 
 		fd = g_open (evolution_debug_log, O_WRONLY | O_CREAT | O_TRUNC, 0600);
 		if (fd != -1) {
