@@ -1,61 +1,44 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/* e-cert.c
- *
- * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
- *
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- *
- * Author: Chris Toshok (toshok@ximian.com)
- */
-
 /* The following is the mozilla license blurb, as the bodies some of
    these functions were derived from the mozilla source. */
-
 /*
- * The contents of this file are subject to the Mozilla Public
- * License Version 1.1 (the "License"); you may not use this file
- * except in compliance with the License. You may obtain a copy of
- * the License at http://www.mozilla.org/MPL/
+ * Version: MPL 1.1/GPL 2.0/LGPL 2.1
  *
- * Software distributed under the License is distributed on an "AS
- * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
- * implied. See the License for the specific language governing
- * rights and limitations under the License.
+ * The contents of this file are subject to the Mozilla Public License Version
+ * 1.1 (the "License"); you may not use this file except in compliance with
+ * the License. You may obtain a copy of the License at
+ * http://www.mozilla.org/MPL/
+ *
+ * Software distributed under the License is distributed on an "AS IS" basis,
+ * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
+ * for the specific language governing rights and limitations under the
+ * License.
  *
  * The Original Code is the Netscape security libraries.
  *
- * The Initial Developer of the Original Code is Netscape
- * Communications Corporation.  Portions created by Netscape are
- * Copyright (C) 2000 Netscape Communications Corporation.  All
- * Rights Reserved.
- *
- * Alternatively, the contents of this file may be used under the
- * terms of the GNU General Public License Version 2 or later (the
- * "GPL"), in which case the provisions of the GPL are applicable
- * instead of those above.  If you wish to allow use of your
- * version of this file only under the terms of the GPL and not to
- * allow others to use your version of this file under the MPL,
- * indicate your decision by deleting the provisions above and
- * replace them with the notice and other provisions required by
- * the GPL.  If you do not delete the provisions above, a recipient
- * may use your version of this file under either the MPL or the
- * GPL.
+ * The Initial Developer of the Original Code is
+ * Netscape Communications Corporation.
+ * Portions created by the Initial Developer are Copyright (C) 1994-2000
+ * the Initial Developer. All Rights Reserved.
  *
+ * Alternatively, the contents of this file may be used under the terms of
+ * either the GNU General Public License Version 2 or later (the "GPL"), or
+ * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
+ * in which case the provisions of the GPL or the LGPL are applicable instead
+ * of those above. If you wish to allow use of your version of this file only
+ * under the terms of either the GPL or the LGPL, and not to allow others to
+ * use your version of this file under the terms of the MPL, indicate your
+ * decision by deleting the provisions above and replace them with the notice
+ * and other provisions required by the GPL or the LGPL. If you do not delete
+ * the provisions above, a recipient may use your version of this file under
+ * the terms of any one of the MPL, the GPL or the LGPL.
  */
 
-
+/*
+ * Author: Chris Toshok (toshok@ximian.com)
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
+ */
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -71,10 +54,10 @@ struct _EASN1ObjectPrivate {
 
 	GList *children;
 
-	char *display_name;
-	char *value;
+	gchar *display_name;
+	gchar *value;
 
-	char *data;
+	gchar *data;
 	guint data_len;
 };
 
@@ -153,10 +136,10 @@ e_asn1_object_get_type (void)
    as defined by the DER (Distinguised Encoding Rules) of
    ASN1.
 */
-static int
-get_integer_256 (unsigned char *data, unsigned int nb)
+static gint
+get_integer_256 (guchar *data, guint nb)
 {
-	int val;
+	gint val;
 
 	switch (nb) {
 	case 1:
@@ -188,10 +171,10 @@ get_integer_256 (unsigned char *data, unsigned int nb)
    <tag><length<data consisting of lenght bytes>
 */
 static guint32
-get_der_item_length (unsigned char *data, unsigned char *end,
+get_der_item_length (guchar *data, guchar *end,
 		     unsigned long *bytesUsed, gboolean *indefinite)
 {
-	unsigned char lbyte = *data++;
+	guchar lbyte = *data++;
 	PRInt32 length = -1;
 
 	*indefinite = FALSE;
@@ -222,13 +205,13 @@ get_der_item_length (unsigned char *data, unsigned char *end,
 }
 
 static gboolean
-build_from_der (EASN1Object *parent, char *data, char *end)
+build_from_der (EASN1Object *parent, gchar *data, gchar *end)
 {
 	unsigned long bytesUsed;
 	gboolean indefinite;
 	PRInt32 len;
 	PRUint32 type;
-	unsigned char code, tagnum;
+	guchar code, tagnum;
 	EASN1Object *asn1object = NULL;
 
 	if (data >= end)
@@ -238,7 +221,7 @@ build_from_der (EASN1Object *parent, char *data, char *end)
 	  A DER item has the form of |tag|len|data
 	  tag is one byte and describes the type of elment
 	  we are dealing with.
-	  len is a DER encoded int telling us how long the data is
+	  len is a DER encoded gint telling us how long the data is
 	  data is a buffer that is len bytes long and has to be
 	  interpreted according to its type.
 	*/
@@ -254,7 +237,7 @@ build_from_der (EASN1Object *parent, char *data, char *end)
 			return FALSE;
 		}
 		data++;
-		len = get_der_item_length ((unsigned char *)data, (unsigned char *)end, &bytesUsed, &indefinite);
+		len = get_der_item_length ((guchar *)data, (guchar *)end, &bytesUsed, &indefinite);
 		data += bytesUsed;
 		if ((len < 0) || ((data+len) > end))
 			return FALSE;
@@ -294,7 +277,7 @@ build_from_der (EASN1Object *parent, char *data, char *end)
 			asn1object->priv->type = tagnum;
 			asn1object->priv->tag = tagnum;
 
-			/*printableItem->SetData((char*)data, len);*/
+			/*printableItem->SetData((gchar *)data, len);*/
 		}
 		data += len;
 
@@ -305,7 +288,7 @@ build_from_der (EASN1Object *parent, char *data, char *end)
 }
 
 EASN1Object*
-e_asn1_object_new_from_der (char *data, guint32 len)
+e_asn1_object_new_from_der (gchar *data, guint32 len)
 {
 	EASN1Object *obj = g_object_new (E_TYPE_ASN1_OBJECT, NULL);
 
@@ -365,33 +348,33 @@ e_asn1_object_append_child (EASN1Object *parent, EASN1Object *child)
 }
 
 void
-e_asn1_object_set_display_name (EASN1Object *obj, const char *name)
+e_asn1_object_set_display_name (EASN1Object *obj, const gchar *name)
 {
 	g_free (obj->priv->display_name);
 	obj->priv->display_name = g_strdup (name);
 }
 
-const char*
+const gchar *
 e_asn1_object_get_display_name (EASN1Object *obj)
 {
 	return obj->priv->display_name;
 }
 
 void
-e_asn1_object_set_display_value (EASN1Object *obj, const char *value)
+e_asn1_object_set_display_value (EASN1Object *obj, const gchar *value)
 {
 	g_free (obj->priv->value);
 	obj->priv->value = g_strdup (value);
 }
 
-const char*
+const gchar *
 e_asn1_object_get_display_value (EASN1Object *obj)
 {
 	return obj->priv->value;
 }
 
 void
-e_asn1_object_get_data (EASN1Object *obj, char **data, guint32 *len)
+e_asn1_object_get_data (EASN1Object *obj, gchar **data, guint32 *len)
 {
 	*data = obj->priv->data;
 	*len = obj->priv->data_len;
