@@ -1,24 +1,24 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * gal-define-views-dialog.c
- * Copyright 2000, 2001, Ximian, Inc.
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
  *
  * Authors:
- *   Chris Lahey <clahey@ximian.com>
+ *		Chris Lahey <clahey@ximian.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License, version 2, as published by the Free Software Foundation.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This library is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301, USA.
  */
 
 #include <config.h>
@@ -32,8 +32,6 @@
 #include "gal-define-views-model.h"
 #include "gal-view-new-dialog.h"
 
-static void gal_define_views_dialog_init	 (GalDefineViewsDialog		 *card);
-static void gal_define_views_dialog_class_init	 (GalDefineViewsDialogClass	 *klass);
 static void gal_define_views_dialog_set_property (GObject *object, guint prop_id, const GValue *value, GParamSpec *pspec);
 static void gal_define_views_dialog_get_property (GObject *object, guint prop_id, GValue *value, GParamSpec *pspec);
 static void gal_define_views_dialog_dispose	 (GObject *object);
@@ -50,7 +48,7 @@ enum {
 };
 
 typedef struct {
-	char         *title;
+	gchar         *title;
 
 	GtkTreeView *treeview;
 	GtkTreeModel *model;
@@ -82,7 +80,7 @@ gal_define_views_dialog_class_init (GalDefineViewsDialogClass *klass)
 /* Button callbacks */
 
 static void
-gdvd_button_new_dialog_callback (GtkWidget *widget, int id, GalDefineViewsDialog *dialog)
+gdvd_button_new_dialog_callback (GtkWidget *widget, gint id, GalDefineViewsDialog *dialog)
 {
 	gchar *name;
 	GtkTreeIter iter;
@@ -148,7 +146,7 @@ gdvd_button_modify_callback(GtkWidget *widget, GalDefineViewsDialog *dialog)
 static void
 gdvd_button_delete_callback(GtkWidget *widget, GalDefineViewsDialog *dialog)
 {
-	int row;
+	gint row;
 	GtkTreeIter iter;
 	GtkTreePath *path;
 	GtkTreeSelection *selection;
@@ -169,7 +167,7 @@ gdvd_button_delete_callback(GtkWidget *widget, GalDefineViewsDialog *dialog)
 
 				if (gtk_tree_path_prev (path)) {
 					gtk_tree_model_get_iter (dialog->model, &iter, path);
-			 	} else {
+				} else {
 					gtk_tree_model_get_iter_first (dialog->model, &iter);
 				}
 
@@ -184,7 +182,7 @@ gdvd_button_delete_callback(GtkWidget *widget, GalDefineViewsDialog *dialog)
 static void
 gdvd_button_copy_callback(GtkWidget *widget, GalDefineViewsDialog *dialog)
 {
-	int row;
+	gint row;
 	GtkWidget *scrolled;
 	ETable *etable;
 
@@ -221,7 +219,7 @@ gdvd_cursor_changed_callback (GtkWidget *widget, GalDefineViewsDialog *dialog)
 }
 
 static void
-gdvd_connect_signal(GalDefineViewsDialog *dialog, char *widget_name, char *signal, GCallback handler)
+gdvd_connect_signal(GalDefineViewsDialog *dialog, const gchar *widget_name, const gchar *signal, GCallback handler)
 {
 	GtkWidget *widget;
 
@@ -232,7 +230,7 @@ gdvd_connect_signal(GalDefineViewsDialog *dialog, char *widget_name, char *signa
 }
 
 static void
-dialog_response (GalDefineViewsDialog *dialog, int response_id, gpointer data)
+dialog_response (GalDefineViewsDialog *dialog, gint response_id, gpointer data)
 {
 	gal_view_collection_save (dialog->collection);
 }
@@ -305,7 +303,7 @@ static void
 gal_define_views_dialog_set_collection(GalDefineViewsDialog *dialog,
 				       GalViewCollection *collection)
 {
-	int i;
+	gint i;
 	GtkListStore *store;
 	GtkCellRenderer *renderer;
 	dialog->collection = collection;
@@ -320,7 +318,7 @@ gal_define_views_dialog_set_collection(GalDefineViewsDialog *dialog,
 		/*if (item->built_in == 1)
 			continue;*/
 
-		char *title = NULL;
+		gchar *title = NULL;
 		title = e_str_without_underscores (item->title);
 
 		gtk_list_store_append (store, &iter);
@@ -355,7 +353,7 @@ gal_define_views_dialog_set_collection(GalDefineViewsDialog *dialog,
 		GtkWidget *widget = glade_xml_get_widget(dialog->gui, "label-views");
 		if (widget && GTK_IS_LABEL (widget)) {
 			if (collection->title) {
-				char *text = g_strdup_printf (_("Define Views for %s"),
+				gchar *text = g_strdup_printf (_("Define Views for %s"),
 							      collection->title);
 				gtk_label_set_text (GTK_LABEL (widget),
 						    text);
