@@ -1,24 +1,24 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * gal-view-instance.h
- * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
  *
  * Authors:
- *   Chris Lahey <clahey@ximian.com>
+ *		Chris Lahey <clahey@ximian.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License, version 2, as published by the Free Software Foundation.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This library is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301, USA.
  */
 
 #ifndef _GAL_VIEW_INSTANCE_H_
@@ -41,13 +41,13 @@ typedef struct {
 
 	GalViewCollection *collection;
 
-	char *instance_id;
-	char *current_view_filename;
-	char *custom_filename;
+	gchar *instance_id;
+	gchar *current_view_filename;
+	gchar *custom_filename;
 
-	char *current_title;
-	char *current_type;
-	char *current_id;
+	gchar *current_title;
+	gchar *current_type;
+	gchar *current_id;
 
 	GalView *current_view;
 
@@ -55,7 +55,7 @@ typedef struct {
 	guint collection_changed_id;
 
 	guint loaded : 1;
-	char *default_view;
+	gchar *default_view;
 } GalViewInstance;
 
 typedef struct {
@@ -76,15 +76,15 @@ GType            gal_view_instance_get_type             (void);
 /*collection should be loaded when you call this.
   instance_id: Which instance of this type of object is this (for most of evo, this is the folder id.) */
 GalViewInstance *gal_view_instance_new                  (GalViewCollection *collection,
-							 const char        *instance_id);
+							 const gchar        *instance_id);
 GalViewInstance *gal_view_instance_construct            (GalViewInstance   *instance,
 							 GalViewCollection *collection,
-							 const char        *instance_id);
+							 const gchar        *instance_id);
 
 /* Manipulate the current view. */
-char            *gal_view_instance_get_current_view_id  (GalViewInstance   *instance);
+gchar            *gal_view_instance_get_current_view_id  (GalViewInstance   *instance);
 void             gal_view_instance_set_current_view_id  (GalViewInstance   *instance,
-							 const char        *view_id);
+							 const gchar        *view_id);
 GalView         *gal_view_instance_get_current_view     (GalViewInstance   *instance);
 
 /* Sets the current view to the given custom view. */
@@ -103,9 +103,9 @@ void             gal_view_instance_save_as              (GalViewInstance   *inst
 void             gal_view_instance_load                 (GalViewInstance   *instance);
 
 /* These only mean anything before gal_view_instance_load is called the first time.  */
-const char      *gal_view_instance_get_default_view     (GalViewInstance   *instance);
+const gchar      *gal_view_instance_get_default_view     (GalViewInstance   *instance);
 void             gal_view_instance_set_default_view     (GalViewInstance   *instance,
-							 const char        *id);
+							 const gchar        *id);
 
 EPopupMenu      *gal_view_instance_get_popup_menu       (GalViewInstance   *instance);
 void             gal_view_instance_free_popup_menu      (GalViewInstance   *instance,
