@@ -1,25 +1,27 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-
-/* 
- * Author : 
- *  Damon Chaplin <damon@ximian.com>
+/*
  *
- * Copyright 2000, Ximian, Inc.
- *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of version 2 of the GNU General Public 
- * License as published by the Free Software Foundation.
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
+ *
+ * Authors:
+ *		Damon Chaplin <damon@ximian.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
- * USA
  */
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
+
 #ifndef _E_CALENDAR_ITEM_H_
 #define _E_CALENDAR_ITEM_H_
 
@@ -78,7 +80,7 @@ typedef enum
 	E_CALENDAR_ITEM_COLOR_SELECTION_BG_FOCUSED,
 	E_CALENDAR_ITEM_COLOR_SELECTION_BG,
 	E_CALENDAR_ITEM_COLOR_PREV_OR_NEXT_MONTH_FG,
-	
+
 	E_CALENDAR_ITEM_COLOR_LAST
 } ECalendarItemColors;
 
@@ -124,7 +126,7 @@ struct _ECalendarItem
 	gint year;
 	gint month;	/* 0 to 11 */
 
-	/* Points to an array of styles, one char for each day. We use 32
+	/* Points to an array of styles, one gchar for each day. We use 32
 	   chars for each month, with n + 2 months, where n is the number of
 	   complete months shown (since we show some days before the first
 	   month and after the last month grayes out).
@@ -168,7 +170,7 @@ struct _ECalendarItem
 	   be changed when the user explicitly selects a day. */
 	gboolean move_selection_when_moving;
 
-	/* Whether the selection day is preserved when we  move back/forward 
+	/* Whether the selection day is preserved when we  move back/forward
 	   one month. Used for the work week and week view. */
 	gboolean preserve_day_when_moving;
 
@@ -216,15 +218,14 @@ struct _ECalendarItem
 	gint selection_real_start_month_offset;
 	gint selection_real_start_day;
 
-	/* The first character of each day of the week, e.g. 'MTWTFSS'. */
-	gchar *days;
-
 	/* Widths of the day characters. */
 	gint day_widths[7];
+	gint max_day_width;
 
 	/* Widths of the digits, '0' .. '9'. */
 	gint digit_widths[10];
 	gint max_digit_width;
+
 	gint week_number_digit_widths[10];
 	gint max_week_number_digit_width;
 
@@ -235,11 +236,11 @@ struct _ECalendarItem
 
 	ECalendarItemStyleCallback style_callback;
 	gpointer style_callback_data;
-	GtkDestroyNotify style_callback_destroy;
+	GDestroyNotify style_callback_destroy;
 
 	ECalendarItemGetTimeCallback time_callback;
 	gpointer time_callback_data;
-	GtkDestroyNotify time_callback_destroy;
+	GDestroyNotify time_callback_destroy;
 
 	/* Colors for drawing. */
 	GdkColor colors[E_CALENDAR_ITEM_COLOR_LAST];
@@ -265,7 +266,7 @@ struct _ECalendarItemClass
 };
 
 
-GtkType  e_calendar_item_get_type		(void);
+GType    e_calendar_item_get_type		(void);
 
 /* FIXME: months are 0-11 throughout, but 1-12 may be better. */
 
@@ -286,7 +287,7 @@ void	 e_calendar_item_set_max_days_sel       (ECalendarItem	*calitem,
 /* Get the maximum number of days selectable */
 gint     e_calendar_item_get_days_start_week_sel(ECalendarItem	*calitem);
 
-/* Get the maximum number of days before whole weeks are selected */
+/* Set the maximum number of days selectable */
 void	 e_calendar_item_set_days_start_week_sel(ECalendarItem	*calitem,
 						 gint            days);
 
@@ -297,13 +298,6 @@ gboolean e_calendar_item_get_display_popup      (ECalendarItem	*calitem);
 void	 e_calendar_item_set_display_popup      (ECalendarItem	*calitem,
 						 gboolean        display);
 
-/* Set the maximum number of days before whole weeks are selected */
-gint     e_calendar_item_get_days_start_week_sel(ECalendarItem	*calitem);
-
-/* Set the maximum number of days selectable */
-void	 e_calendar_item_set_days_start_week_sel(ECalendarItem	*calitem,
-						 gint            days);
-
 /* Gets the range of dates actually shown. Months are 0 to 11.
    This also includes the last days of the previous month and the first days
    of the following month, which are normally shown in gray.
@@ -354,7 +348,7 @@ void	 e_calendar_item_mark_days		(ECalendarItem	*calitem,
 void	 e_calendar_item_set_style_callback	(ECalendarItem	*calitem,
 						 ECalendarItemStyleCallback cb,
 						 gpointer	 data,
-						 GtkDestroyNotify destroy);
+						 GDestroyNotify  destroy);
 
 /* Sets a callback to use to get the current time. This is useful if the
    application needs to use its own timezone data rather than rely on the
@@ -362,7 +356,7 @@ void	 e_calendar_item_set_style_callback	(ECalendarItem	*calitem,
 void	 e_calendar_item_set_get_time_callback	(ECalendarItem	*calitem,
 						 ECalendarItemGetTimeCallback cb,
 						 gpointer	 data,
-						 GtkDestroyNotify destroy);
+						 GDestroyNotify  destroy);
 void e_calendar_item_normalize_date	(ECalendarItem	*calitem,
 					 gint		*year,
 					 gint		*month);
@@ -370,6 +364,7 @@ gint e_calendar_item_get_week_number	(ECalendarItem *calitem,
 					 gint		day,
 					 gint		month,
 					 gint		year);
+void e_calendar_item_style_set (GtkWidget *widget, ECalendarItem *calitem);
 
 
 #ifdef __cplusplus
