@@ -1,25 +1,24 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-
 /*
- * Author :
- *  Damon Chaplin <damon@ximian.com>
- *  Bolian Yin <bolian.yin@sun.com>
- *
- * Copyright 2000, Ximian, Inc.
- *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
+ *
+ * Authors:
+ *		Damon Chaplin <damon@ximian.com>
+ *		Bolian Yin <bolian.yin@sun.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
- * USA
  */
 
 /*
@@ -36,12 +35,7 @@
 
 #include "e-calendar.h"
 
-#include <glib.h>
-#include <gtk/gtkarrow.h>
-#include <gtk/gtkbutton.h>
-#include <gtk/gtkmain.h>
-#include <gtk/gtkpixmap.h>
-#include <gtk/gtksignal.h>
+#include <gtk/gtk.h>
 #include <libgnomecanvas/gnome-canvas-widget.h>
 #include <glib/gi18n.h>
 
@@ -89,7 +83,7 @@ static void e_calendar_drag_leave	(GtkWidget      *widget,
 					 guint           time);
 static gboolean e_calendar_button_has_focus (ECalendar	*cal);
 static gboolean e_calendar_focus (GtkWidget *widget,
- 				  GtkDirectionType direction);
+				  GtkDirectionType direction);
 
 static void e_calendar_on_prev_pressed	(ECalendar	*cal);
 static void e_calendar_on_prev_released	(ECalendar	*cal);
@@ -119,11 +113,11 @@ e_calendar_class_init (ECalendarClass *class)
 
 	widget_class->realize		   = e_calendar_realize;
 	widget_class->style_set		   = e_calendar_style_set;
- 	widget_class->size_request	   = e_calendar_size_request;
- 	widget_class->size_allocate	   = e_calendar_size_allocate;
+	widget_class->size_request	   = e_calendar_size_request;
+	widget_class->size_allocate	   = e_calendar_size_allocate;
 	widget_class->drag_motion	   = e_calendar_drag_motion;
 	widget_class->drag_leave	   = e_calendar_drag_leave;
- 	widget_class->focus                = e_calendar_focus;
+	widget_class->focus                = e_calendar_focus;
 }
 
 
@@ -357,7 +351,7 @@ e_calendar_size_allocate	(GtkWidget	*widget,
 	gnome_canvas_item_set (cal->prev_item,
 			       "x", (gtk_widget_get_direction (widget) == GTK_TEXT_DIR_RTL)
 			       ? new_x2 + 1 - xthickness * 2 - E_CALENDAR_ARROW_BUTTON_X_PAD
-			         - arrow_button_size
+				 - arrow_button_size
 			       : xthickness * 2 + E_CALENDAR_ARROW_BUTTON_X_PAD,
 			       "y", ythickness * 2
 			       + E_CALENDAR_ARROW_BUTTON_Y_PAD,
@@ -369,7 +363,7 @@ e_calendar_size_allocate	(GtkWidget	*widget,
 			       "x", (gtk_widget_get_direction (widget) == GTK_TEXT_DIR_RTL)
 			       ? xthickness * 2 + E_CALENDAR_ARROW_BUTTON_X_PAD
 			       : new_x2 + 1 - xthickness * 2 - E_CALENDAR_ARROW_BUTTON_X_PAD
-			         - arrow_button_size,
+				 - arrow_button_size,
 			       "y", ythickness * 2
 			       + E_CALENDAR_ARROW_BUTTON_Y_PAD,
 			       "width", arrow_button_size,
