@@ -1,24 +1,25 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/* 
+/*
  * e-canvas-background.c - background color for canvas.
- * Copyright 2001, Ximian, Inc.
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
  *
  * Authors:
- *   Chris Lahey <clahey@ximian.com>
+ *		Chris Lahey <clahey@ximian.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License, version 2, as published by the Free Software Foundation.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This library is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301, USA.
  */
 
 #include <config.h>
@@ -73,7 +74,7 @@ enum {
 	PROP_X1,
 	PROP_X2,
 	PROP_Y1,
-	PROP_Y2,
+	PROP_Y2
 };
 
 static void
@@ -96,7 +97,7 @@ ecb_bounds (GnomeCanvasItem *item, double *x1, double *y1, double *x2, double *y
 	/* Wrong BBox's are the source of redraw nightmares */
 
 	gnome_canvas_item_i2c_affine (GNOME_CANVAS_ITEM (ecb), i2c);
-	
+
 	i1.x = ecb->priv->x1;
 	i1.y = ecb->priv->y1;
 	i2.x = ecb->priv->x2;
@@ -126,7 +127,7 @@ ecb_bounds (GnomeCanvasItem *item, double *x1, double *y1, double *x2, double *y
  * GnomeCanvasItem::update method
  */
 static void
-ecb_update (GnomeCanvasItem *item, double *affine, ArtSVP *clip_path, int flags)
+ecb_update (GnomeCanvasItem *item, double *affine, ArtSVP *clip_path, gint flags)
 {
 	ArtPoint o1, o2;
 	ECanvasBackground *ecb = E_CANVAS_BACKGROUND (item);
@@ -157,7 +158,7 @@ ecb_update (GnomeCanvasItem *item, double *affine, ArtSVP *clip_path, int flags)
 
 /* Sets the stipple pattern for the text */
 static void
-set_stipple (ECanvasBackground *ecb, GdkBitmap *stipple, int use_value)
+set_stipple (ECanvasBackground *ecb, GdkBitmap *stipple, gint use_value)
 {
 	if (use_value) {
 		if (ecb->priv->stipple)
@@ -336,7 +337,7 @@ static void
 ecb_realize (GnomeCanvasItem *item)
 {
 	ECanvasBackground *ecb = E_CANVAS_BACKGROUND (item);
-	
+
 	if (GNOME_CANVAS_ITEM_CLASS (ecb_parent_class)->realize)
                 GNOME_CANVAS_ITEM_CLASS (ecb_parent_class)->realize (item);
 
@@ -346,7 +347,7 @@ ecb_realize (GnomeCanvasItem *item)
 		gdk_gc_set_foreground (ecb->priv->gc, &ecb->priv->color);
 
 	set_stipple (ecb, NULL, FALSE);
-	
+
 	ecb->priv->needs_redraw = 1;
 	gnome_canvas_item_request_update (GNOME_CANVAS_ITEM (ecb));
 }
@@ -364,13 +365,13 @@ ecb_unrealize (GnomeCanvasItem *item)
 }
 
 static void
-ecb_draw (GnomeCanvasItem *item, GdkDrawable *drawable, int x, int y, int width, int height)
+ecb_draw (GnomeCanvasItem *item, GdkDrawable *drawable, gint x, gint y, gint width, gint height)
 {
 	ECanvasBackground *ecb = E_CANVAS_BACKGROUND (item);
-	int x1, x2, y1, y2;
+	gint x1, x2, y1, y2;
 	double i2c [6];
 	ArtPoint upper_left, lower_right, ecb_base_point;
-	
+
 	/*
 	 * Find out our real position after grouping
 	 */
@@ -401,7 +402,7 @@ ecb_draw (GnomeCanvasItem *item, GdkDrawable *drawable, int x, int y, int width,
 }
 
 static double
-ecb_point (GnomeCanvasItem *item, double x, double y, int cx, int cy,
+ecb_point (GnomeCanvasItem *item, double x, double y, gint cx, gint cy,
 	   GnomeCanvasItem **actual_item)
 {
 	ECanvasBackground *ecb = E_CANVAS_BACKGROUND (item);
@@ -423,7 +424,7 @@ static void
 ecb_style_set (ECanvasBackground *ecb, GtkStyle *previous_style)
 {
 	GnomeCanvasItem *item = GNOME_CANVAS_ITEM (ecb);
-		
+
 	if (GTK_WIDGET_REALIZED (item->canvas)) {
 		gdk_gc_set_foreground (ecb->priv->gc, &GTK_WIDGET(item->canvas)->style->base[GTK_STATE_NORMAL]);
 		gnome_canvas_item_request_update (GNOME_CANVAS_ITEM (ecb));
@@ -435,7 +436,7 @@ ecb_class_init (ECanvasBackgroundClass *ecb_class)
 {
 	GnomeCanvasItemClass *item_class = GNOME_CANVAS_ITEM_CLASS (ecb_class);
 	GObjectClass *object_class = G_OBJECT_CLASS (ecb_class);
-	
+
 	object_class->dispose       = ecb_dispose;
 	object_class->set_property  = ecb_set_property;
 	object_class->get_property  = ecb_get_property;
@@ -509,7 +510,7 @@ ecb_class_init (ECanvasBackgroundClass *ecb_class)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (ECanvasBackgroundClass, style_set),
 			      NULL, NULL,
-			      e_util_marshal_NONE__OBJECT,
+			      g_cclosure_marshal_VOID__OBJECT,
 			      G_TYPE_NONE, 1, GTK_TYPE_STYLE);
 }
 
