@@ -1,24 +1,24 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * e-canvas-utils.c
- * Copyright 2000, 2001, Ximian, Inc.
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
  *
  * Authors:
- *   Chris Lahey <clahey@ximian.com>
+ *		Chris Lahey <clahey@ximian.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License, version 2, as published by the Free Software Foundation.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This library is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301, USA.
  */
 
 #include "e-canvas-utils.h"
@@ -37,10 +37,10 @@ e_canvas_item_move_absolute (GnomeCanvasItem *item, double dx, double dy)
 }
 
 static double
-compute_offset(int top, int bottom, int page_top, int page_bottom)
+compute_offset(gint top, gint bottom, gint page_top, gint page_bottom)
 {
-	int size = bottom - top;
-	int offset = 0;
+	gint size = bottom - top;
+	gint offset = 0;
 
 	if (top <= page_top && bottom >= page_bottom)
 		return 0;
@@ -68,7 +68,7 @@ static void
 e_canvas_show_area (GnomeCanvas *canvas, double x1, double y1, double x2, double y2)
 {
 	GtkAdjustment *h, *v;
-	int dx = 0, dy = 0;
+	gint dx = 0, dy = 0;
 
 	g_return_if_fail (canvas != NULL);
 	g_return_if_fail (GNOME_IS_CANVAS (canvas));
@@ -101,7 +101,7 @@ static gboolean
 e_canvas_area_shown (GnomeCanvas *canvas, double x1, double y1, double x2, double y2)
 {
 	GtkAdjustment *h, *v;
-	int dx = 0, dy = 0;
+	gint dx = 0, dy = 0;
 
 	g_return_val_if_fail (canvas != NULL, FALSE);
 	g_return_val_if_fail (GNOME_IS_CANVAS (canvas), FALSE);
