@@ -1,26 +1,25 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * e-popup-menu.c
- * Copyright 2000, 2001, Ximian, Inc.
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
  *
  * Authors:
- *   Miguel de Icaza <miguel@ximian.com>
- *   Jody Goldberg (jgoldberg@home.com)
- *   Jeffrey Stedfast <fejj@ximian.com>
+ *		Miguel de Icaza <miguel@ximian.com>
+ *		Jody Goldberg (jgoldberg@home.com)
+ *		Jeffrey Stedfast <fejj@ximian.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License, version 2, as published by the Free Software Foundation.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This library is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301, USA.
  */
 
 #include <config.h>
@@ -38,7 +37,7 @@
  * Creates an item with an optional icon
  */
 static void
-make_item (GtkMenu *menu, GtkMenuItem *item, const char *name, GtkWidget *pixmap)
+make_item (GtkMenu *menu, GtkMenuItem *item, const gchar *name, GtkWidget *pixmap)
 {
 	GtkWidget *label;
 
@@ -51,9 +50,9 @@ make_item (GtkMenu *menu, GtkMenuItem *item, const char *name, GtkWidget *pixmap
 	label = gtk_label_new_with_mnemonic (name);
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_widget_show (label);
-	
+
 	gtk_container_add (GTK_CONTAINER (item), label);
-	
+
 	if (pixmap && GTK_IS_IMAGE_MENU_ITEM (item)){
 		gtk_widget_show (pixmap);
 		gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), pixmap);
@@ -64,7 +63,7 @@ GtkMenu *
 e_popup_menu_create (EPopupMenu *menu_list,
 		     guint32 disable_mask,
 		     guint32 hide_mask,
-		     void *default_closure)
+		     gpointer default_closure)
 {
 	return e_popup_menu_create_with_domain (menu_list,
 						disable_mask,
@@ -78,14 +77,14 @@ GtkMenu *
 e_popup_menu_create_with_domain (EPopupMenu *menu_list,
 				 guint32 disable_mask,
 				 guint32 hide_mask,
-				 void *default_closure,
-				 const char *domain)
+				 gpointer default_closure,
+				 const gchar *domain)
 {
 	GtkMenu *menu = GTK_MENU (gtk_menu_new ());
 	GSList *group = NULL;
 	gboolean last_item_separator = TRUE;
-	int last_non_separator = -1;
-	int i;
+	gint last_non_separator = -1;
+	gint i;
 
 	for (i = 0; menu_list[i].name; i++) {
 		if (strcmp ("", menu_list[i].name) && !(menu_list [i].disable_mask & hide_mask)) {
@@ -148,15 +147,15 @@ e_popup_menu_create_with_domain (EPopupMenu *menu_list,
 }
 
 void
-e_popup_menu_run (EPopupMenu *menu_list, GdkEvent *event, guint32 disable_mask, guint32 hide_mask, void *default_closure)
+e_popup_menu_run (EPopupMenu *menu_list, GdkEvent *event, guint32 disable_mask, guint32 hide_mask, gpointer default_closure)
 {
 	GtkMenu *menu;
-	
+
 	g_return_if_fail (menu_list != NULL);
 	g_return_if_fail (event != NULL);
-	
+
 	menu = e_popup_menu_create (menu_list, disable_mask, hide_mask, default_closure);
-	
+
 	e_popup_menu (menu, event);
 }
 
@@ -196,7 +195,7 @@ e_popup_menu_free_1 (EPopupMenu *menu_item)
 EPopupMenu *
 e_popup_menu_copy (const EPopupMenu *menu_list)
 {
-	int i;
+	gint i;
 	EPopupMenu *ret_val;
 
 	if (menu_list == NULL)
@@ -221,7 +220,7 @@ e_popup_menu_copy (const EPopupMenu *menu_list)
 void
 e_popup_menu_free (EPopupMenu *menu_list)
 {
-	int i;
+	gint i;
 
 	if (menu_list == NULL)
 		return;
