@@ -1,24 +1,24 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * e-selection-model-array.h
- * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
  *
  * Authors:
- *   Chris Lahey <clahey@ximian.com>
+ *		Chris Lahey <clahey@ximian.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License, version 2, as published by the Free Software Foundation.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This library is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301, USA.
  */
 
 #ifndef _E_SELECTION_MODEL_ARRAY_H_
@@ -76,14 +76,14 @@ GType    e_selection_model_array_get_type           (void);
 
 /* Protected Functions */
 void     e_selection_model_array_insert_rows        (ESelectionModelArray *esm,
-						     int                   row,
-						     int                   count);
+						     gint                   row,
+						     gint                   count);
 void     e_selection_model_array_delete_rows        (ESelectionModelArray *esm,
-						     int                   row,
-						     int                   count);
+						     gint                   row,
+						     gint                   count);
 void     e_selection_model_array_move_row           (ESelectionModelArray *esm,
-						     int                   old_row,
-						     int                   new_row);
+						     gint                   old_row,
+						     gint                   new_row);
 void     e_selection_model_array_confirm_row_count  (ESelectionModelArray *esm);
 
 /* Protected Virtual Function */
