@@ -12,7 +12,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -74,21 +74,19 @@
 /* The height to make the popup list if there aren't any items in it. */
 #define	E_CELL_COMBO_LIST_EMPTY_HEIGHT	15
 
-static void e_cell_combo_class_init	(ECellComboClass *klass);
-static void e_cell_combo_init		(ECellCombo	*ecc);
 static void e_cell_combo_dispose	(GObject	*object);
 
 static gint e_cell_combo_do_popup	(ECellPopup	*ecp,
 					 GdkEvent	*event,
-					 int             row,
-					 int             view_col);
+					 gint             row,
+					 gint             view_col);
 static void e_cell_combo_select_matching_item	(ECellCombo	*ecc);
 static void e_cell_combo_show_popup	(ECellCombo	*ecc,
-					 int             row,
-					 int             view_col);
+					 gint             row,
+					 gint             view_col);
 static void e_cell_combo_get_popup_pos	(ECellCombo	*ecc,
-					 int             row,
-					 int             view_col,
+					 gint             row,
+					 gint             view_col,
 					 gint		*x,
 					 gint		*y,
 					 gint		*height,
@@ -102,7 +100,7 @@ static gint e_cell_combo_button_press	(GtkWidget	*popup_window,
 static gint e_cell_combo_button_release	(GtkWidget	*popup_window,
 					 GdkEventButton	*event,
 					 ECellCombo	*ecc);
-static int e_cell_combo_key_press	(GtkWidget	*popup_window,
+static gint e_cell_combo_key_press	(GtkWidget	*popup_window,
 					 GdkEventKey	*event,
 					 ECellCombo	*ecc);
 
@@ -242,7 +240,7 @@ e_cell_combo_set_popdown_strings	(ECellCombo	*ecc,
 
 	for (elem = strings; elem; elem = elem->next) {
 		GtkTreeIter iter;
-		char *utf8_text = elem->data;
+		gchar *utf8_text = elem->data;
 
 		gtk_list_store_append (store, &iter);
 		gtk_list_store_set (store, &iter, 0, utf8_text, -1);
@@ -253,8 +251,8 @@ e_cell_combo_set_popdown_strings	(ECellCombo	*ecc,
 static gint
 e_cell_combo_do_popup			(ECellPopup	*ecp,
 					 GdkEvent	*event,
-					 int             row,
-					 int             view_col)
+					 gint             row,
+					 gint             view_col)
 {
 	ECellCombo *ecc = E_CELL_COMBO (ecp);
 	guint32 time;
@@ -299,7 +297,7 @@ e_cell_combo_select_matching_item	(ECellCombo	*ecc)
 	ETableItem *eti = E_TABLE_ITEM (ecp->popup_cell_view->cell_view.e_table_item_view);
 	ETableCol *ecol;
 	gboolean found = FALSE;
-	char *cell_text;
+	gchar *cell_text;
 	gboolean valid;
 	GtkTreeSelection *selection;
 	GtkTreeIter iter;
@@ -315,7 +313,7 @@ e_cell_combo_select_matching_item	(ECellCombo	*ecc)
 	for (valid = gtk_tree_model_get_iter_first (model, &iter);
 	     valid && !found;
 	     valid = gtk_tree_model_iter_next (model, &iter)) {
-		char *str = NULL;
+		gchar *str = NULL;
 
 		gtk_tree_model_get (model, &iter, 0, &str, -1);
 
@@ -338,7 +336,7 @@ e_cell_combo_select_matching_item	(ECellCombo	*ecc)
 }
 
 static void
-e_cell_combo_show_popup			(ECellCombo	*ecc, int row, int view_col)
+e_cell_combo_show_popup			(ECellCombo	*ecc, gint row, gint view_col)
 {
 	gint x, y, width, height, old_width, old_height;
 
@@ -368,8 +366,8 @@ e_cell_combo_show_popup			(ECellCombo	*ecc, int row, int view_col)
 /* Calculates the size and position of the popup window (like GtkCombo). */
 static void
 e_cell_combo_get_popup_pos		(ECellCombo	*ecc,
-					 int             row,
-					 int             view_col,
+					 gint             row,
+					 gint             view_col,
 					 gint		*x,
 					 gint		*y,
 					 gint		*height,
@@ -413,7 +411,7 @@ e_cell_combo_get_popup_pos		(ECellCombo	*ecc,
 	*x += x1;
 	/* The ETable positions don't include the grid lines, I think, so we add 1. */
 	*y += y1 + 1
-		- (int)((GnomeCanvas *)canvas)->layout.vadjustment->value
+		- (gint)((GnomeCanvas *)canvas)->layout.vadjustment->value
 		+ ((GnomeCanvas *)canvas)->zoom_yofs;
 
 	scrollbar_width = popup->vscrollbar->requisition.width
@@ -597,7 +595,7 @@ e_cell_combo_button_release		(GtkWidget	*popup_window,
 
 /* This handles key press events in the popup window. If the Escape key is
    pressed we hide the popup, and do not change the cell contents. */
-static int
+static gint
 e_cell_combo_key_press			(GtkWidget	*popup_window,
 					 GdkEventKey	*event,
 					 ECellCombo	*ecc)
