@@ -1,26 +1,26 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * e-table-config.c
- * Copyright 2000, 2001, Ximian, Inc.
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
  *
  * Authors:
- *   Chris Lahey <clahey@ximian.com>
- *   Miguel de Icaza <miguel@ximian.com>
+ *		Chris Lahey <clahey@ximian.com>
+ *		Miguel de Icaza <miguel@ximian.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License, version 2, as published by the Free Software Foundation.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This library is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301, USA.
  */
+
 /*
  * FIXME:
  *    Sort Dialog: when text is selected, the toggle button switches state.
@@ -54,7 +54,7 @@ enum {
 
 enum {
 	PROP_0,
-	PROP_STATE,
+	PROP_STATE
 };
 
 enum {
@@ -131,8 +131,8 @@ config_get_property (GObject *object,
 static void
 e_table_config_class_init (ETableConfigClass *klass)
 {
-	GObjectClass *object_class = G_OBJECT_CLASS (klass);	
-	
+	GObjectClass *object_class = G_OBJECT_CLASS (klass);
+
 	klass->changed        = NULL;
 
 	object_class->finalize = config_finalize;
@@ -233,7 +233,7 @@ configure_combo_box_set_active (GtkComboBox *combo_box, const gchar *value)
 }
 
 static ETableColumnSpecification *
-find_column_in_spec (ETableSpecification *spec, int model_col)
+find_column_in_spec (ETableSpecification *spec, gint model_col)
 {
 	ETableColumnSpecification **column;
 
@@ -249,8 +249,8 @@ find_column_in_spec (ETableSpecification *spec, int model_col)
 	return NULL;
 }
 
-static int
-find_model_column_by_name (ETableSpecification *spec, const char *s)
+static gint
+find_model_column_by_name (ETableSpecification *spec, const gchar *s)
 {
 	ETableColumnSpecification **column;
 
@@ -268,7 +268,7 @@ static void
 update_sort_and_group_config_dialog (ETableConfig *config, gboolean is_sort)
 {
 	ETableConfigSortWidgets *widgets;
-	int count, i;
+	gint count, i;
 
 	if (is_sort){
 		count = e_table_sort_info_sorting_get_count (
@@ -279,11 +279,11 @@ update_sort_and_group_config_dialog (ETableConfig *config, gboolean is_sort)
 			config->temp_state->sort_info);
 		widgets = &config->group [0];
 	}
-	
+
 	for (i = 0; i < 4; i++){
 		gboolean sensitive = (i <= count);
-		char *text = "";
-		
+		const gchar *text = "";
+
 		gtk_widget_set_sensitive (widgets [i].frames, sensitive);
 
 		/*
@@ -295,7 +295,7 @@ update_sort_and_group_config_dialog (ETableConfig *config, gboolean is_sort)
 		g_signal_handler_block (
 			widgets [i].combo,
 			widgets [i].changed_id);
-		
+
 		if (i < count){
 			GtkToggleButton *a, *d;
 			ETableSortColumn col =
@@ -306,7 +306,7 @@ update_sort_and_group_config_dialog (ETableConfig *config, gboolean is_sort)
 				:  e_table_sort_info_grouping_get_nth (
 					config->temp_state->sort_info,
 					i);
-			
+
 			ETableColumnSpecification *column =
 				find_column_in_spec (config->source_spec, col.column);
 
@@ -329,11 +329,11 @@ update_sort_and_group_config_dialog (ETableConfig *config, gboolean is_sort)
 				widgets [i].radio_ascending);
 			d = GTK_TOGGLE_BUTTON (
 				widgets [i].radio_descending);
-			
+
 			gtk_toggle_button_set_active (col.ascending ? a:d, 1);
 		} else {
 			GtkToggleButton *t;
-			
+
 			t = GTK_TOGGLE_BUTTON (
 				widgets [i].radio_ascending);
 
@@ -362,7 +362,7 @@ config_sort_info_update (ETableConfig *config)
 {
 	ETableSortInfo *info = config->state->sort_info;
 	GString *res;
-	int count, i;
+	gint count, i;
 
 	count = e_table_sort_info_sorting_get_count (info);
 	res = g_string_new ("");
@@ -370,13 +370,13 @@ config_sort_info_update (ETableConfig *config)
 	for (i = 0; i < count; i++) {
 		ETableSortColumn col = e_table_sort_info_sorting_get_nth (info, i);
 		ETableColumnSpecification *column;
-		
+
 		column = find_column_in_spec (config->source_spec, col.column);
 		if (!column){
 			g_warning ("Could not find column model in specification");
 			continue;
 		}
-		
+
 		g_string_append (res, dgettext (config->domain, (column)->title));
 		g_string_append_c (res, ' ');
 		g_string_append (
@@ -387,10 +387,10 @@ config_sort_info_update (ETableConfig *config)
 		if ((i + 1) != count)
 			g_string_append (res, ", ");
 	}
-	
+
 	if (res->str [0] == 0)
 		g_string_append (res, _("Not sorted"));
-	
+
 	gtk_label_set_text (GTK_LABEL(config->sort_label), res->str);
 
 	g_string_free (res, TRUE);
@@ -401,7 +401,7 @@ config_group_info_update (ETableConfig *config)
 {
 	ETableSortInfo *info = config->state->sort_info;
 	GString *res;
-	int count, i;
+	gint count, i;
 
 	if (!e_table_sort_info_get_can_group (info))
 		return;
@@ -439,7 +439,7 @@ config_group_info_update (ETableConfig *config)
 static void
 setup_fields (ETableConfig *config)
 {
-	int i;
+	gint i;
 
 	e_table_model_freeze ((ETableModel *)config->available_model);
 	e_table_model_freeze ((ETableModel *)config->shown_model);
@@ -466,7 +466,7 @@ config_fields_info_update (ETableConfig *config)
 {
 	ETableColumnSpecification **column;
 	GString *res = g_string_new ("");
-	int i, j;
+	gint i, j;
 
 	for (i = 0; i < config->state->col_count; i++){
 		for (j = 0, column = config->source_spec->columns; *column; column++, j++){
@@ -484,7 +484,7 @@ config_fields_info_update (ETableConfig *config)
 			break;
 		}
 	}
-	
+
 	gtk_label_set_text (GTK_LABEL (config->fields_label), res->str);
 	g_string_free (res, TRUE);
 }
@@ -493,7 +493,7 @@ static void
 do_sort_and_group_config_dialog (ETableConfig *config, gboolean is_sort)
 {
 	GtkDialog *dialog;
-	int response, running = 1;
+	gint response, running = 1;
 
 	config->temp_state = e_table_state_duplicate (config->state);
 
@@ -503,13 +503,13 @@ do_sort_and_group_config_dialog (ETableConfig *config, gboolean is_sort)
 		is_sort
 		? config->sort [0].combo
 		: config->group [0].combo));
-		
+
 
 	if (is_sort)
 		dialog = GTK_DIALOG (config->dialog_sort);
 	else
 		dialog = GTK_DIALOG (config->dialog_group_by);
-	
+
 	gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (config->dialog_toplevel));
 
 	do {
@@ -529,7 +529,7 @@ do_sort_and_group_config_dialog (ETableConfig *config, gboolean is_sort)
 		case GTK_RESPONSE_OK:
 			g_object_unref (config->state);
 			config->state = config->temp_state;
-			config->temp_state = 0;
+			config->temp_state = NULL;
 			running = 0;
 			config_dialog_changed (config);
 			break;
@@ -537,14 +537,14 @@ do_sort_and_group_config_dialog (ETableConfig *config, gboolean is_sort)
 		case GTK_RESPONSE_DELETE_EVENT:
 		case GTK_RESPONSE_CANCEL:
 			g_object_unref (config->temp_state);
-			config->temp_state = 0;
+			config->temp_state = NULL;
 			running = 0;
 			break;
 		}
-		
+
 	} while (running);
 	gtk_widget_hide (GTK_WIDGET (dialog));
-	
+
 	if (is_sort)
 		config_sort_info_update (config);
 	else
@@ -554,7 +554,7 @@ do_sort_and_group_config_dialog (ETableConfig *config, gboolean is_sort)
 static void
 do_fields_config_dialog (ETableConfig *config)
 {
-	int response, running = 1;
+	gint response, running = 1;
 
 	gtk_widget_ensure_style (config->dialog_show_fields);
 	gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (config->dialog_show_fields)->vbox), 0);
@@ -573,7 +573,7 @@ do_fields_config_dialog (ETableConfig *config)
 		case GTK_RESPONSE_OK:
 			g_object_unref (config->state);
 			config->state = config->temp_state;
-			config->temp_state = 0;
+			config->temp_state = NULL;
 			running = 0;
 			config_dialog_changed (config);
 			break;
@@ -581,11 +581,11 @@ do_fields_config_dialog (ETableConfig *config)
 		case GTK_RESPONSE_DELETE_EVENT:
 		case GTK_RESPONSE_CANCEL:
 			g_object_unref (config->temp_state);
-			config->temp_state = 0;
+			config->temp_state = NULL;
 			running = 0;
 			break;
 		}
-		
+
 	} while (running);
 	gtk_widget_hide (GTK_WIDGET (config->dialog_show_fields));
 
@@ -604,12 +604,12 @@ static ETableModel *global_store;  /* Glade better not be reentrant any time soo
 static void
 create_global_store (ETableConfig *config)
 {
-	int i;
+	gint i;
 
 	global_store = e_table_memory_store_new (store_columns);
 	for (i = 0; config->source_spec->columns[i]; i++) {
 
-		char *text;
+		gchar *text;
 
 		if (config->source_spec->columns[i]->disabled)
 			continue;
@@ -619,51 +619,52 @@ create_global_store (ETableConfig *config)
 	}
 }
 
-char *spec = "<ETableSpecification gettext-domain=\"" GETTEXT_PACKAGE "\" no-headers=\"true\" cursor-mode=\"line\" " 	 
-" draw-grid=\"false\" draw-focus=\"true\" selection-mode=\"browse\">" 	 
-"<ETableColumn model_col= \"0\" _title=\"Name\" minimum_width=\"30\" resizable=\"true\" cell=\"string\" compare=\"string\"/>" 	 
-"<ETableState> <column source=\"0\"/>" 	 
-"<grouping/>" 	 
-"</ETableState>" 	 
-"</ETableSpecification>"; 	 
-  	 
-GtkWidget *e_table_proxy_etable_shown_new (void); 	 
-  	 
-GtkWidget * 	 
-e_table_proxy_etable_shown_new (void) 	 
-{ 	 
-	ETableModel *model = NULL; 	 
-	GtkWidget *widget; 	 
-	ETableScrolled *ets; 	 
-  	 
-	model = e_table_subset_variable_new (global_store); 	 
-  	 
-	widget = e_table_scrolled_new (model, NULL, spec, NULL); 	 
-	ets = E_TABLE_SCROLLED (widget); 	 
-	atk_object_set_name (gtk_widget_get_accessible ((GtkWidget *)ets->table), _("Show Fields")); 	 
-  	 
-	return widget; 	 
-} 	 
-  	 
-GtkWidget *e_table_proxy_etable_available_new (void); 	 
-  	 
-GtkWidget * 	 
-e_table_proxy_etable_available_new (void) 	 
-{ 	 
-	ETableModel *model; 	 
-	GtkWidget *widget; 	 
-	ETableScrolled *ets; 	 
-  	 
-	model = e_table_without_new (global_store, 	 
-				     NULL, NULL, NULL, NULL, NULL, NULL, NULL); 	 
-  	 
-	e_table_without_show_all (E_TABLE_WITHOUT (model)); 	 
-  	 
-	widget = e_table_scrolled_new (model, NULL, spec, NULL); 	 
-	ets = E_TABLE_SCROLLED (widget); 	 
-	atk_object_set_name (gtk_widget_get_accessible ((GtkWidget *)ets->table), _("Available Fields")); 	 
-  	 
-	return widget; 	 
+static const gchar *spec =
+"<ETableSpecification gettext-domain=\"" GETTEXT_PACKAGE "\" no-headers=\"true\" cursor-mode=\"line\" "
+" draw-grid=\"false\" draw-focus=\"true\" selection-mode=\"browse\">"
+"<ETableColumn model_col= \"0\" _title=\"Name\" minimum_width=\"30\" resizable=\"true\" cell=\"string\" compare=\"string\"/>"
+"<ETableState> <column source=\"0\"/>"
+"<grouping/>"
+"</ETableState>"
+"</ETableSpecification>";
+
+GtkWidget *e_table_proxy_etable_shown_new (void);
+
+GtkWidget *
+e_table_proxy_etable_shown_new (void)
+{
+	ETableModel *model = NULL;
+	GtkWidget *widget;
+	ETableScrolled *ets;
+
+	model = e_table_subset_variable_new (global_store);
+
+	widget = e_table_scrolled_new (model, NULL, spec, NULL);
+	ets = E_TABLE_SCROLLED (widget);
+	atk_object_set_name (gtk_widget_get_accessible ((GtkWidget *)ets->table), _("Show Fields"));
+
+	return widget;
+}
+
+GtkWidget *e_table_proxy_etable_available_new (void);
+
+GtkWidget *
+e_table_proxy_etable_available_new (void)
+{
+	ETableModel *model;
+	GtkWidget *widget;
+	ETableScrolled *ets;
+
+	model = e_table_without_new (global_store,
+				     NULL, NULL, NULL, NULL, NULL, NULL, NULL);
+
+	e_table_without_show_all (E_TABLE_WITHOUT (model));
+
+	widget = e_table_scrolled_new (model, NULL, spec, NULL);
+	ets = E_TABLE_SCROLLED (widget);
+	atk_object_set_name (gtk_widget_get_accessible ((GtkWidget *)ets->table), _("Available Fields"));
+
+	return widget;
 }
 
 static void
@@ -692,7 +693,7 @@ dialog_destroyed (gpointer data, GObject *where_object_was)
 }
 
 static void
-dialog_response (GtkWidget *dialog, int response_id, ETableConfig *config)
+dialog_response (GtkWidget *dialog, gint response_id, ETableConfig *config)
 {
 	if (response_id == GTK_RESPONSE_APPLY
 	    || response_id == GTK_RESPONSE_OK) {
@@ -703,7 +704,7 @@ dialog_response (GtkWidget *dialog, int response_id, ETableConfig *config)
 	    || response_id == GTK_RESPONSE_OK) {
 		gtk_widget_destroy (dialog);
 	}
-}	
+}
 
 /*
  * Invoked by the Glade auto-connect code
@@ -740,10 +741,10 @@ e_table_proxy_gtk_combo_text_new (void)
 
 #if 0
 static GtkWidget *
-configure_dialog (GladeXML *gui, const char *widget_name, ETableConfig *config)
+configure_dialog (GladeXML *gui, const gchar *widget_name, ETableConfig *config)
 {
 	GtkWidget *w;
-	
+
 	w = glade_xml_get_widget (gui, widget_name);
 
 	return w;
@@ -751,7 +752,7 @@ configure_dialog (GladeXML *gui, const char *widget_name, ETableConfig *config)
 #endif
 
 static void
-connect_button (ETableConfig *config, GladeXML *gui, const char *widget_name, GCallback cback)
+connect_button (ETableConfig *config, GladeXML *gui, const gchar *widget_name, GCallback cback)
 {
 	GtkWidget *button = glade_xml_get_widget (gui, widget_name);
 
@@ -768,7 +769,7 @@ get_source_model_col_index (ETableConfig *config, gint idx)
 	ETableModel *src_model = E_TABLE_SUBSET (config->available_model)->source;
 
         visible_index = e_table_subset_view_to_model_row (E_TABLE_SUBSET (config->available_model), idx);
-	
+
 	return GPOINTER_TO_INT (e_table_model_value_at (src_model, 1, visible_index));
 }
 
@@ -778,15 +779,15 @@ sort_combo_changed (GtkComboBox *combo_box, ETableConfigSortWidgets *sort)
 	ETableConfig *config = sort->e_table_config;
 	ETableSortInfo *sort_info = config->temp_state->sort_info;
 	ETableConfigSortWidgets *base = &config->sort[0];
-	int idx = sort - base;
+	gint idx = sort - base;
 	gchar *s;
 
 	s = configure_combo_box_get_active (combo_box);
 
 	if (s != NULL) {
 		ETableSortColumn c;
-		int col;
-		
+		gint col;
+
 		col = find_model_column_by_name (config->source_spec, s);
 		if (col == -1){
 			g_warning ("sort: This should not happen (%s)", s);
@@ -798,7 +799,7 @@ sort_combo_changed (GtkComboBox *combo_box, ETableConfigSortWidgets *sort)
 			config->sort [idx].radio_ascending)->active;
 		c.column = col;
 		e_table_sort_info_sorting_set_nth (sort_info, idx, c);
-		  
+
 		update_sort_and_group_config_dialog (config, TRUE);
 	}  else {
 		e_table_sort_info_sorting_truncate (sort_info, idx);
@@ -814,9 +815,9 @@ sort_ascending_toggled (GtkToggleButton *t, ETableConfigSortWidgets *sort)
 	ETableConfig *config = sort->e_table_config;
 	ETableSortInfo *si = config->temp_state->sort_info;
 	ETableConfigSortWidgets *base = &config->sort[0];
-	int idx = sort - base;
+	gint idx = sort - base;
 	ETableSortColumn c;
-	
+
 	c = e_table_sort_info_sorting_get_nth (si, idx);
 	c.ascending = t->active;
 	e_table_sort_info_sorting_set_nth (si, idx, c);
@@ -826,10 +827,10 @@ static void
 configure_sort_dialog (ETableConfig *config, GladeXML *gui)
 {
 	GSList *l;
-	int i;
-	
+	gint i;
+
 	for (i = 0; i < 4; i++){
-		char buffer [80];
+		gchar buffer [80];
 
 		snprintf (buffer, sizeof (buffer), "sort-combo-%d", i + 1);
 		config->sort [i].combo = glade_xml_get_widget (gui, buffer);
@@ -838,7 +839,7 @@ configure_sort_dialog (ETableConfig *config, GladeXML *gui)
 			GTK_COMBO_BOX (config->sort[i].combo), "", "");
 
 		snprintf (buffer, sizeof (buffer), "frame-sort-%d", i + 1);
-		config->sort [i].frames = 
+		config->sort [i].frames =
 			glade_xml_get_widget (gui, buffer);
 
 		snprintf (
@@ -857,7 +858,7 @@ configure_sort_dialog (ETableConfig *config, GladeXML *gui)
 	}
 
 	for (l = config->column_names; l; l = l->next){
-		char *label = l->data;
+		gchar *label = l->data;
 
 		for (i = 0; i < 4; i++){
 			configure_combo_box_add (
@@ -888,15 +889,15 @@ group_combo_changed (GtkComboBox *combo_box, ETableConfigSortWidgets *group)
 	ETableConfig *config = group->e_table_config;
 	ETableSortInfo *sort_info = config->temp_state->sort_info;
 	ETableConfigSortWidgets *base = &config->group[0];
-	int idx = group - base;
+	gint idx = group - base;
 	gchar *s;
 
 	s = configure_combo_box_get_active (combo_box);
 
 	if (s != NULL) {
 		ETableSortColumn c;
-		int col;
-		
+		gint col;
+
 		col = find_model_column_by_name (config->source_spec, s);
 		if (col == -1){
 			g_warning ("grouping: this should not happen, %s", s);
@@ -908,7 +909,7 @@ group_combo_changed (GtkComboBox *combo_box, ETableConfigSortWidgets *group)
 			config->group [idx].radio_ascending)->active;
 		c.column = col;
 		e_table_sort_info_grouping_set_nth (sort_info, idx, c);
-		  
+
 		update_sort_and_group_config_dialog (config, FALSE);
 	}  else {
 		e_table_sort_info_grouping_truncate (sort_info, idx);
@@ -924,9 +925,9 @@ group_ascending_toggled (GtkToggleButton *t, ETableConfigSortWidgets *group)
 	ETableConfig *config = group->e_table_config;
 	ETableSortInfo *si = config->temp_state->sort_info;
 	ETableConfigSortWidgets *base = &config->group[0];
-	int idx = group - base;
+	gint idx = group - base;
 	ETableSortColumn c;
-	
+
 	c = e_table_sort_info_grouping_get_nth (si, idx);
 	c.ascending = t->active;
 	e_table_sort_info_grouping_set_nth (si, idx, c);
@@ -936,10 +937,10 @@ static void
 configure_group_dialog (ETableConfig *config, GladeXML *gui)
 {
 	GSList *l;
-	int i;
-	
+	gint i;
+
 	for (i = 0; i < 4; i++){
-		char buffer [80];
+		gchar buffer [80];
 
 		snprintf (buffer, sizeof (buffer), "group-combo-%d", i + 1);
 		config->group [i].combo = glade_xml_get_widget (gui, buffer);
@@ -949,7 +950,7 @@ configure_group_dialog (ETableConfig *config, GladeXML *gui)
 			GTK_COMBO_BOX (config->group[i].combo), "", "");
 
 		snprintf (buffer, sizeof (buffer), "frame-group-%d", i + 1);
-		config->group [i].frames = 
+		config->group [i].frames =
 			glade_xml_get_widget (gui, buffer);
 
 		snprintf (
@@ -969,13 +970,13 @@ configure_group_dialog (ETableConfig *config, GladeXML *gui)
 			"checkbutton-group-%d", i+1);
 		config->group [i].view_check = glade_xml_get_widget (
 			gui, buffer);
-		
+
 		config->group [i].e_table_config = config;
 	}
 
-	
+
 	for (l = config->column_names; l; l = l->next){
-		char *label = l->data;
+		gchar *label = l->data;
 
 		for (i = 0; i < 4; i++){
 			configure_combo_box_add (
@@ -1001,7 +1002,7 @@ configure_group_dialog (ETableConfig *config, GladeXML *gui)
 }
 
 static void
-add_column (int model_row, gpointer closure)
+add_column (gint model_row, gpointer closure)
 {
 	GList **columns = closure;
 	*columns = g_list_prepend (*columns, GINT_TO_POINTER (model_row));
@@ -1012,8 +1013,8 @@ config_button_add (GtkWidget *widget, ETableConfig *config)
 {
 	GList *columns = NULL;
 	GList *column;
-	int count;
-	int i;
+	gint count;
+	gint i;
 
 	e_table_selected_row_foreach (config->available, add_column, &columns);
 	columns = g_list_reverse (columns);
@@ -1044,9 +1045,9 @@ config_button_remove (GtkWidget *widget, ETableConfig *config)
 	e_table_selected_row_foreach (config->shown, add_column, &columns);
 
 	for (column = columns; column; column = column->next) {
-		int row = GPOINTER_TO_INT (column->data);
+		gint row = GPOINTER_TO_INT (column->data);
 
-		memmove (config->temp_state->columns + row, config->temp_state->columns + row + 1, sizeof (int) * (config->temp_state->col_count - row - 1));
+		memmove (config->temp_state->columns + row, config->temp_state->columns + row + 1, sizeof (gint) * (config->temp_state->col_count - row - 1));
 		memmove (config->temp_state->expansions + row, config->temp_state->expansions + row + 1, sizeof (double) * (config->temp_state->col_count - row - 1));
 		config->temp_state->col_count --;
 	}
@@ -1063,11 +1064,11 @@ config_button_up (GtkWidget *widget, ETableConfig *config)
 {
 	GList *columns = NULL;
 	GList *column;
-	int *new_shown;
+	gint *new_shown;
 	double *new_expansions;
-	int next_col;
+	gint next_col;
 	double next_expansion;
-	int i;
+	gint i;
 
 	e_table_selected_row_foreach (config->shown, add_column, &columns);
 
@@ -1118,11 +1119,11 @@ config_button_down (GtkWidget *widget, ETableConfig *config)
 {
 	GList *columns = NULL;
 	GList *column;
-	int *new_shown;
+	gint *new_shown;
 	double *new_expansions;
-	int next_col;
+	gint next_col;
 	double next_expansion;
-	int i;
+	gint i;
 
 	e_table_selected_row_foreach (config->shown, add_column, &columns);
 
@@ -1211,7 +1212,7 @@ setup_gui (ETableConfig *config)
 	g_free (filename);
 
 	g_object_unref (global_store);
-	
+
 	config->dialog_toplevel = glade_xml_get_widget (
 		gui, "e-table-config");
 
@@ -1273,7 +1274,7 @@ e_table_config_init (ETableConfig *config)
 
 ETableConfig *
 e_table_config_construct (ETableConfig        *config,
-			  const char          *header,
+			  const gchar          *header,
 			  ETableSpecification *spec,
 			  ETableState         *state,
 			  GtkWindow           *parent_window)
@@ -1284,7 +1285,7 @@ e_table_config_construct (ETableConfig        *config,
 	g_return_val_if_fail (header != NULL, NULL);
 	g_return_val_if_fail (spec != NULL, NULL);
 	g_return_val_if_fail (state != NULL, NULL);
-	
+
 	config->source_spec = spec;
 	config->source_state = state;
 	config->header = g_strdup (header);
@@ -1297,7 +1298,7 @@ e_table_config_construct (ETableConfig        *config,
 	config->domain = g_strdup (spec->domain);
 
 	for (column = config->source_spec->columns; *column; column++){
-		char *label = (*column)->title;
+		gchar *label = (*column)->title;
 
 		if ((*column)->disabled)
 			continue;
@@ -1314,7 +1315,7 @@ e_table_config_construct (ETableConfig        *config,
 	config_sort_info_update   (config);
 	config_group_info_update  (config);
 	config_fields_info_update (config);
-	
+
 	return E_TABLE_CONFIG (config);
 }
 
@@ -1329,7 +1330,7 @@ e_table_config_construct (ETableConfig        *config,
  * Returns: The config object.
  */
 ETableConfig *
-e_table_config_new (const char          *header,
+e_table_config_new (const gchar          *header,
 		    ETableSpecification *spec,
 		    ETableState         *state,
 		    GtkWindow           *parent_window)
