@@ -1,24 +1,23 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * e-table-memory.h
- * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
  *
  * Authors:
- *   Chris Lahey <clahey@ximian.com>
+ *		Chris Lahey <clahey@ximian.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License, version 2, as published by the Free Software Foundation.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This library is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301, USA.
  */
 
 #ifndef _E_TABLE_MEMORY_H_
@@ -56,19 +55,19 @@ ETableMemory *e_table_memory_new          (void);
 
 /* row operations */
 void          e_table_memory_insert  (ETableMemory *etable,
-				      int           row,
+				      gint           row,
 				      gpointer      data);
 gpointer      e_table_memory_remove  (ETableMemory *etable,
-				      int           row);
+				      gint           row);
 void          e_table_memory_clear   (ETableMemory *etable);
 
 /* Freeze and thaw */
 void          e_table_memory_freeze       (ETableMemory *etable);
 void          e_table_memory_thaw         (ETableMemory *etable);
 gpointer      e_table_memory_get_data     (ETableMemory *etm,
-					   int           row);
+					   gint           row);
 void          e_table_memory_set_data     (ETableMemory *etm,
-					   int           row,
+					   gint           row,
 					   gpointer      data);
 
 G_END_DECLS
