@@ -1,24 +1,23 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * e-table-sort-info.c
- * Copyright 2000, 2001, Ximian, Inc.
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
  *
  * Authors:
- *   Chris Lahey <clahey@ximian.com>
+ *		Chris Lahey <clahey@ximian.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License, version 2, as published by the Free Software Foundation.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This library is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
  */
 
 #include <config.h>
@@ -32,7 +31,7 @@
 
 #define ETM_CLASS(e) (E_TABLE_SORT_INFO_GET_CLASS (e))
 
-static GObjectClass *e_table_sort_info_parent_class;
+G_DEFINE_TYPE (ETableSortInfo , e_table_sort_info, G_TYPE_OBJECT)
 
 enum {
 	SORT_INFO_CHANGED,
@@ -46,7 +45,7 @@ static void
 etsi_finalize (GObject *object)
 {
 	ETableSortInfo *etsi = E_TABLE_SORT_INFO (object);
-	
+
 	if (etsi->groupings)
 		g_free(etsi->groupings);
 	etsi->groupings = NULL;
@@ -102,15 +101,12 @@ e_table_sort_info_class_init (ETableSortInfoClass *klass)
 	klass->group_info_changed = NULL;
 }
 
-E_MAKE_TYPE(e_table_sort_info, "ETableSortInfo", ETableSortInfo,
-	    e_table_sort_info_class_init, e_table_sort_info_init, G_TYPE_OBJECT)
-
 static void
 e_table_sort_info_sort_info_changed (ETableSortInfo *info)
 {
 	g_return_if_fail (info != NULL);
 	g_return_if_fail (E_IS_TABLE_SORT_INFO (info));
-	
+
 	if (info->frozen) {
 		info->sort_info_changed = 1;
 	} else {
@@ -123,7 +119,7 @@ e_table_sort_info_group_info_changed (ETableSortInfo *info)
 {
 	g_return_if_fail (info != NULL);
 	g_return_if_fail (E_IS_TABLE_SORT_INFO (info));
-	
+
 	if (info->frozen) {
 		info->group_info_changed = 1;
 	} else {
@@ -142,7 +138,7 @@ e_table_sort_info_group_info_changed (ETableSortInfo *info)
  * To thaw, invoke the e_table_sort_info_thaw() function, which will
  * trigger any signals that might have been queued.
  */
-void 
+void
 e_table_sort_info_freeze             (ETableSortInfo *info)
 {
 	info->frozen++;
@@ -165,7 +161,7 @@ e_table_sort_info_thaw               (ETableSortInfo *info)
 	info->frozen--;
 	if (info->frozen != 0)
 		return;
-	
+
 	if (info->sort_info_changed) {
 		info->sort_info_changed = 0;
 		e_table_sort_info_sort_info_changed(info);
@@ -192,7 +188,7 @@ e_table_sort_info_grouping_get_count (ETableSortInfo *info)
 }
 
 static void
-e_table_sort_info_grouping_real_truncate  (ETableSortInfo *info, int length)
+e_table_sort_info_grouping_real_truncate  (ETableSortInfo *info, gint length)
 {
 	if (length < info->group_count) {
 		info->group_count = length;
@@ -209,10 +205,10 @@ e_table_sort_info_grouping_real_truncate  (ETableSortInfo *info, int length)
  * @lenght: position where the truncation happens.
  *
  * This routine can be used to reduce or grow the number of grouping
- * criteria in the object.  
+ * criteria in the object.
  */
 void
-e_table_sort_info_grouping_truncate  (ETableSortInfo *info, int length)
+e_table_sort_info_grouping_truncate  (ETableSortInfo *info, gint length)
 {
 	e_table_sort_info_grouping_real_truncate(info, length);
 	e_table_sort_info_group_info_changed(info);
@@ -226,7 +222,7 @@ e_table_sort_info_grouping_truncate  (ETableSortInfo *info, int length)
  * Returns: the description of the @n-th grouping criteria in the @info object.
  */
 ETableSortColumn
-e_table_sort_info_grouping_get_nth   (ETableSortInfo *info, int n)
+e_table_sort_info_grouping_get_nth   (ETableSortInfo *info, gint n)
 {
 	if (info->can_group && n < info->group_count) {
 		return info->groupings[n];
@@ -246,7 +242,7 @@ e_table_sort_info_grouping_get_nth   (ETableSortInfo *info, int n)
  * whether it is ascending or descending).
  */
 void
-e_table_sort_info_grouping_set_nth   (ETableSortInfo *info, int n, ETableSortColumn column)
+e_table_sort_info_grouping_set_nth   (ETableSortInfo *info, gint n, ETableSortColumn column)
 {
 	if (n >= info->group_count) {
 		e_table_sort_info_grouping_real_truncate(info, n + 1);
@@ -269,7 +265,7 @@ e_table_sort_info_sorting_get_count (ETableSortInfo *info)
 }
 
 static void
-e_table_sort_info_sorting_real_truncate  (ETableSortInfo *info, int length)
+e_table_sort_info_sorting_real_truncate  (ETableSortInfo *info, gint length)
 {
 	if (length < info->sort_count) {
 		info->sort_count = length;
@@ -286,10 +282,10 @@ e_table_sort_info_sorting_real_truncate  (ETableSortInfo *info, int length)
  * @lenght: position where the truncation happens.
  *
  * This routine can be used to reduce or grow the number of sort
- * criteria in the object.  
+ * criteria in the object.
  */
 void
-e_table_sort_info_sorting_truncate  (ETableSortInfo *info, int length)
+e_table_sort_info_sorting_truncate  (ETableSortInfo *info, gint length)
 {
 	e_table_sort_info_sorting_real_truncate  (info, length);
 	e_table_sort_info_sort_info_changed(info);
@@ -303,7 +299,7 @@ e_table_sort_info_sorting_truncate  (ETableSortInfo *info, int length)
  * Returns: the description of the @n-th grouping criteria in the @info object.
  */
 ETableSortColumn
-e_table_sort_info_sorting_get_nth   (ETableSortInfo *info, int n)
+e_table_sort_info_sorting_get_nth   (ETableSortInfo *info, gint n)
 {
 	if (n < info->sort_count) {
 		return info->sortings[n];
@@ -323,7 +319,7 @@ e_table_sort_info_sorting_get_nth   (ETableSortInfo *info, int n)
  * column number and whether it is ascending or descending).
  */
 void
-e_table_sort_info_sorting_set_nth   (ETableSortInfo *info, int n, ETableSortColumn column)
+e_table_sort_info_sorting_set_nth   (ETableSortInfo *info, gint n, ETableSortColumn column)
 {
 	if (n >= info->sort_count) {
 		e_table_sort_info_sorting_real_truncate(info, n + 1);
@@ -338,7 +334,7 @@ e_table_sort_info_sorting_set_nth   (ETableSortInfo *info, int n, ETableSortColu
  * This creates a new e_table_sort_info object that contains no
  * grouping and no sorting defined as of yet.  This object is used
  * to keep track of multi-level sorting and multi-level grouping of
- * the ETable.  
+ * the ETable.
  *
  * Returns: A new %ETableSortInfo object
  */
@@ -362,22 +358,22 @@ e_table_sort_info_load_from_node (ETableSortInfo *info,
 				  xmlNode        *node,
 				  gdouble         state_version)
 {
-	int i;
+	gint i;
 	xmlNode *grouping;
 
 	if (state_version <= 0.05) {
 		i = 0;
-		for (grouping = node->xmlChildrenNode; grouping && !strcmp (grouping->name, "group"); grouping = grouping->xmlChildrenNode) {
+		for (grouping = node->xmlChildrenNode; grouping && !strcmp ((gchar *)grouping->name, "group"); grouping = grouping->xmlChildrenNode) {
 			ETableSortColumn column;
-			column.column = e_xml_get_integer_prop_by_name (grouping, "column");
-			column.ascending = e_xml_get_bool_prop_by_name (grouping, "ascending");
+			column.column = e_xml_get_integer_prop_by_name (grouping, (const guchar *)"column");
+			column.ascending = e_xml_get_bool_prop_by_name (grouping, (const guchar *)"ascending");
 			e_table_sort_info_grouping_set_nth(info, i++, column);
 		}
 		i = 0;
-		for (; grouping && !strcmp (grouping->name, "leaf"); grouping = grouping->xmlChildrenNode) {
+		for (; grouping && !strcmp ((gchar *)grouping->name, "leaf"); grouping = grouping->xmlChildrenNode) {
 			ETableSortColumn column;
-			column.column = e_xml_get_integer_prop_by_name (grouping, "column");
-			column.ascending = e_xml_get_bool_prop_by_name (grouping, "ascending");
+			column.column = e_xml_get_integer_prop_by_name (grouping, (const guchar *)"column");
+			column.ascending = e_xml_get_bool_prop_by_name (grouping, (const guchar *)"ascending");
 			e_table_sort_info_sorting_set_nth(info, i++, column);
 		}
 	} else {
@@ -389,13 +385,13 @@ e_table_sort_info_load_from_node (ETableSortInfo *info,
 			if (grouping->type != XML_ELEMENT_NODE)
 				continue;
 
-			if (!strcmp (grouping->name, "group")) {
-				column.column = e_xml_get_integer_prop_by_name (grouping, "column");
-				column.ascending = e_xml_get_bool_prop_by_name (grouping, "ascending");
+			if (!strcmp ((gchar *)grouping->name, "group")) {
+				column.column = e_xml_get_integer_prop_by_name (grouping, (const guchar *)"column");
+				column.ascending = e_xml_get_bool_prop_by_name (grouping, (const guchar *)"ascending");
 				e_table_sort_info_grouping_set_nth(info, gcnt++, column);
-			} else if (!strcmp (grouping->name, "leaf")) {
-				column.column = e_xml_get_integer_prop_by_name (grouping, "column");
-				column.ascending = e_xml_get_bool_prop_by_name (grouping, "ascending");
+			} else if (!strcmp ((gchar *)grouping->name, "leaf")) {
+				column.column = e_xml_get_integer_prop_by_name (grouping, (const guchar *)"column");
+				column.ascending = e_xml_get_bool_prop_by_name (grouping, (const guchar *)"ascending");
 				e_table_sort_info_sorting_set_nth(info, scnt++, column);
 			}
 		}
@@ -418,26 +414,26 @@ e_table_sort_info_save_to_node (ETableSortInfo *info,
 				xmlNode        *parent)
 {
 	xmlNode *grouping;
-	int i;
-	const int sort_count = e_table_sort_info_sorting_get_count (info);
-	const int group_count = e_table_sort_info_grouping_get_count (info);
-	
-	grouping = xmlNewChild (parent, NULL, "grouping", NULL);
+	gint i;
+	const gint sort_count = e_table_sort_info_sorting_get_count (info);
+	const gint group_count = e_table_sort_info_grouping_get_count (info);
+
+	grouping = xmlNewChild (parent, NULL, (const guchar *)"grouping", NULL);
 
 	for (i = 0; i < group_count; i++) {
 		ETableSortColumn column = e_table_sort_info_grouping_get_nth(info, i);
-		xmlNode *new_node = xmlNewChild(grouping, NULL, "group", NULL);
+		xmlNode *new_node = xmlNewChild(grouping, NULL, (const guchar *)"group", NULL);
 
-		e_xml_set_integer_prop_by_name (new_node, "column", column.column);
-		e_xml_set_bool_prop_by_name (new_node, "ascending", column.ascending);
+		e_xml_set_integer_prop_by_name (new_node, (const guchar *)"column", column.column);
+		e_xml_set_bool_prop_by_name (new_node, (const guchar *)"ascending", column.ascending);
 	}
 
 	for (i = 0; i < sort_count; i++) {
 		ETableSortColumn column = e_table_sort_info_sorting_get_nth(info, i);
-		xmlNode *new_node = xmlNewChild(grouping, NULL, "leaf", NULL);
-		
-		e_xml_set_integer_prop_by_name (new_node, "column", column.column);
-		e_xml_set_bool_prop_by_name (new_node, "ascending", column.ascending);
+		xmlNode *new_node = xmlNewChild(grouping, NULL, (const guchar *)"leaf", NULL);
+
+		e_xml_set_integer_prop_by_name (new_node, (const guchar *)"column", column.column);
+		e_xml_set_bool_prop_by_name (new_node, (const guchar *)"ascending", column.ascending);
 	}
 
 	return grouping;
