@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -53,7 +53,7 @@ etsv_dispose (GObject *object)
 
 	if (etsv->sort_info_changed_id)
 		g_signal_handler_disconnect (G_OBJECT (etsv->sort_info),
-				             etsv->sort_info_changed_id);
+					     etsv->sort_info_changed_id);
 	etsv->sort_info_changed_id = 0;
 
 	if (etsv->sort_idle_id) {
@@ -127,13 +127,13 @@ etsv_add       (ETableSubsetVariable *etssv,
 	ETableModel *etm = E_TABLE_MODEL(etssv);
 	ETableSubset *etss = E_TABLE_SUBSET(etssv);
 	ETableSortedVariable *etsv = E_TABLE_SORTED_VARIABLE (etssv);
-	int i;
+	gint i;
 
 	e_table_model_pre_change (etm);
 
 	if (etss->n_map + 1 > etssv->n_vals_allocated) {
 		etssv->n_vals_allocated += INCREMENT_AMOUNT;
-		etss->map_table = g_realloc (etss->map_table, (etssv->n_vals_allocated) * sizeof(int));
+		etss->map_table = g_realloc (etss->map_table, (etssv->n_vals_allocated) * sizeof(gint));
 	}
 	i = etss->n_map;
 	if (etsv->sort_idle_id == 0) {
@@ -149,7 +149,7 @@ etsv_add       (ETableSubsetVariable *etssv,
 				etsv->insert_idle_id = g_idle_add_full(40, (GSourceFunc) etsv_insert_idle, etsv, NULL);
 			}
 			i = e_table_sorting_utils_insert(etss->source, etsv->sort_info, etsv->full_header, etss->map_table, etss->n_map, row);
-			memmove(etss->map_table + i + 1, etss->map_table + i, (etss->n_map - i) * sizeof(int));
+			memmove(etss->map_table + i + 1, etss->map_table + i, (etss->n_map - i) * sizeof(gint));
 		}
 	}
 	etss->map_table[i] = row;
@@ -164,8 +164,8 @@ etsv_add_all   (ETableSubsetVariable *etssv)
 	ETableModel *etm = E_TABLE_MODEL(etssv);
 	ETableSubset *etss = E_TABLE_SUBSET(etssv);
 	ETableSortedVariable *etsv = E_TABLE_SORTED_VARIABLE (etssv);
-	int rows;
-	int i;
+	gint rows;
+	gint i;
 
 	e_table_model_pre_change(etm);
 
@@ -173,7 +173,7 @@ etsv_add_all   (ETableSubsetVariable *etssv)
 
 	if (etss->n_map + rows > etssv->n_vals_allocated){
 		etssv->n_vals_allocated += MAX(INCREMENT_AMOUNT, rows);
-		etss->map_table = g_realloc (etss->map_table, etssv->n_vals_allocated * sizeof(int));
+		etss->map_table = g_realloc (etss->map_table, etssv->n_vals_allocated * sizeof(gint));
 	}
 	for (i = 0; i < rows; i++)
 		etss->map_table[etss->n_map++] = i;
@@ -217,7 +217,7 @@ static void
 etsv_sort(ETableSortedVariable *etsv)
 {
 	ETableSubset *etss = E_TABLE_SUBSET(etsv);
-	static int reentering = 0;
+	static gint reentering = 0;
 	if (reentering)
 		return;
 	reentering = 1;
