@@ -1,25 +1,25 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * e-tree-memory.h
- * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
  *
  * Authors:
- *   Chris Lahey <clahey@ximian.com>
- *   Chris Toshok <toshok@ximian.com>
+ *		Chris Lahey <clahey@ximian.com>
+ *		Chris Toshok <toshok@ximian.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License, version 2, as published by the Free Software Foundation.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This library is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301, USA.
  */
 
 #ifndef _E_TREE_MEMORY_H_
@@ -41,7 +41,7 @@ typedef struct ETreeMemory ETreeMemory;
 typedef struct ETreeMemoryPriv ETreeMemoryPriv;
 typedef struct ETreeMemoryClass ETreeMemoryClass;
 
-typedef int (*ETreeMemorySortCallback) (ETreeMemory *etmm, ETreePath path1, ETreePath path2, gpointer closure);
+typedef gint (*ETreeMemorySortCallback) (ETreeMemory *etmm, ETreePath path1, ETreePath path2, gpointer closure);
 
 struct ETreeMemory {
 	ETreeModel base;
@@ -63,13 +63,13 @@ ETreeMemory *e_tree_memory_new                    (void);
 /* node operations */
 ETreePath    e_tree_memory_node_insert            (ETreeMemory             *etree,
 						   ETreePath                parent,
-						   int                      position,
+						   gint                      position,
 						   gpointer                 node_data);
 ETreePath    e_tree_memory_node_insert_id         (ETreeMemory             *etree,
 						   ETreePath                parent,
-						   int                      position,
+						   gint                      position,
 						   gpointer                 node_data,
-						   char                    *id);
+						   gchar                    *id);
 ETreePath    e_tree_memory_node_insert_before     (ETreeMemory             *etree,
 						   ETreePath                parent,
 						   ETreePath                sibling,
