@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -179,7 +179,7 @@ etsm_node_data_changed (ETreeModel *etm, ETreePath node, ETreeSelectionModel *et
 }
 
 static void
-etsm_node_col_changed (ETreeModel *etm, ETreePath node, int col, ETreeSelectionModel *etsm)
+etsm_node_col_changed (ETreeModel *etm, ETreePath node, gint col, ETreeSelectionModel *etsm)
 {
 	free_id (etsm);
 }
@@ -191,7 +191,7 @@ etsm_node_inserted (ETreeModel *etm, ETreePath parent, ETreePath child, ETreeSel
 }
 
 static void
-etsm_node_removed (ETreeModel *etm, ETreePath parent, ETreePath child, int old_position, ETreeSelectionModel *etsm)
+etsm_node_removed (ETreeModel *etm, ETreePath parent, ETreePath child, gint old_position, ETreeSelectionModel *etsm)
 {
 	restore_cursor (etsm, etm);
 }
@@ -241,21 +241,21 @@ drop_model(ETreeSelectionModel *etsm)
 		return;
 
 	g_signal_handler_disconnect (G_OBJECT (priv->model),
-			             priv->tree_model_pre_change_id);
+				     priv->tree_model_pre_change_id);
 	g_signal_handler_disconnect (G_OBJECT (priv->model),
-			             priv->tree_model_no_change_id);
+				     priv->tree_model_no_change_id);
 	g_signal_handler_disconnect (G_OBJECT (priv->model),
-			             priv->tree_model_node_changed_id);
+				     priv->tree_model_node_changed_id);
 	g_signal_handler_disconnect (G_OBJECT (priv->model),
-			             priv->tree_model_node_data_changed_id);
+				     priv->tree_model_node_data_changed_id);
 	g_signal_handler_disconnect (G_OBJECT (priv->model),
-			             priv->tree_model_node_col_changed_id);
+				     priv->tree_model_node_col_changed_id);
 	g_signal_handler_disconnect (G_OBJECT (priv->model),
-			             priv->tree_model_node_inserted_id);
+				     priv->tree_model_node_inserted_id);
 	g_signal_handler_disconnect (G_OBJECT (priv->model),
-			             priv->tree_model_node_removed_id);
+				     priv->tree_model_node_removed_id);
 	g_signal_handler_disconnect (G_OBJECT (priv->model),
-			             priv->tree_model_node_deleted_id);
+				     priv->tree_model_node_deleted_id);
 
 	g_object_unref (priv->model);
 	priv->model = NULL;
@@ -392,7 +392,7 @@ etsm_row_foreach_cb (gpointer key, gpointer value, gpointer user_data)
 {
 	ETreePath path = key;
 	ModelAndCallback *mac = user_data;
-	int row = e_tree_table_adapter_row_of_node(mac->etsm->priv->etta, path);
+	gint row = e_tree_table_adapter_row_of_node(mac->etsm->priv->etta, path);
 	if (row >= 0)
 		mac->callback(row, mac->closure);
 }
@@ -455,7 +455,7 @@ etsm_selected_count (ESelectionModel *selection)
 	return g_hash_table_size (etsm->priv->paths);
 }
 
-static int
+static gint
 etsm_row_count (ESelectionModel *selection)
 {
 	ETreeSelectionModel *etsm = E_TREE_SELECTION_MODEL(selection);
@@ -521,7 +521,7 @@ etsm_invert_selection (ESelectionModel *selection)
 }
 
 static void
-etsm_change_one_row(ESelectionModel *selection, int row, gboolean grow)
+etsm_change_one_row(ESelectionModel *selection, gint row, gboolean grow)
 {
 	ETreeSelectionModel *etsm = E_TREE_SELECTION_MODEL(selection);
 	ETreePath path;
@@ -539,7 +539,7 @@ etsm_change_one_row(ESelectionModel *selection, int row, gboolean grow)
 }
 
 static void
-etsm_change_cursor (ESelectionModel *selection, int row, int col)
+etsm_change_cursor (ESelectionModel *selection, gint row, gint col)
 {
 	ETreeSelectionModel *etsm;
 
@@ -570,9 +570,9 @@ etsm_cursor_col (ESelectionModel *selection)
 }
 
 static void
-etsm_get_rows(int row, void *d)
+etsm_get_rows(gint row, gpointer d)
 {
-	int **rowp = d;
+	gint **rowp = d;
 
 	**rowp = row;
 	(*rowp)++;
@@ -583,7 +583,7 @@ etsm_select_single_row (ESelectionModel *selection, gint row)
 {
 	ETreeSelectionModel *etsm = E_TREE_SELECTION_MODEL(selection);
 	ETreePath path = e_tree_table_adapter_node_at_row (etsm->priv->etta, row);
-	int rows[5], *rowp = NULL, size;
+	gint rows[5], *rowp = NULL, size;
 
 	g_return_if_fail (path != NULL);
 
@@ -601,7 +601,7 @@ etsm_select_single_row (ESelectionModel *selection, gint row)
 		e_selection_model_selection_changed(E_SELECTION_MODEL(etsm));
 	} else {
 		if (rowp) {
-			int *p = rows;
+			gint *p = rows;
 
 			while (p<rowp)
 				e_selection_model_selection_row_changed((ESelectionModel *)etsm, *p++);
@@ -702,7 +702,7 @@ void
 e_tree_selection_model_select_paths (ETreeSelectionModel *etsm, GPtrArray *paths)
 {
 	ETreePath path;
-	int i;
+	gint i;
 
 	for (i=0;i<paths->len;i++) {
 		path = paths->pdata[i];
@@ -723,7 +723,7 @@ e_tree_selection_model_add_to_selection (ETreeSelectionModel *etsm, ETreePath pa
 void
 e_tree_selection_model_change_cursor (ETreeSelectionModel *etsm, ETreePath path)
 {
-	int row;
+	gint row;
 
 	etsm->priv->cursor_path = path;
 
@@ -783,23 +783,23 @@ e_tree_selection_model_class_init (ETreeSelectionModelClass *klass)
 	object_class->get_property = etsm_get_property;
 	object_class->set_property = etsm_set_property;
 
-	esm_class->is_row_selected    = etsm_is_row_selected    ;
-	esm_class->foreach            = etsm_foreach            ;
-	esm_class->clear              = etsm_clear              ;
-	esm_class->selected_count     = etsm_selected_count     ;
-	esm_class->select_all         = etsm_select_all         ;
-	esm_class->invert_selection   = etsm_invert_selection   ;
-	esm_class->row_count          = etsm_row_count          ;
+	esm_class->is_row_selected    = etsm_is_row_selected;
+	esm_class->foreach            = etsm_foreach;
+	esm_class->clear              = etsm_clear;
+	esm_class->selected_count     = etsm_selected_count;
+	esm_class->select_all         = etsm_select_all;
+	esm_class->invert_selection   = etsm_invert_selection;
+	esm_class->row_count          = etsm_row_count;
 
-	esm_class->change_one_row     = etsm_change_one_row     ;
-	esm_class->change_cursor      = etsm_change_cursor      ;
-	esm_class->cursor_row         = etsm_cursor_row         ;
-	esm_class->cursor_col         = etsm_cursor_col         ;
+	esm_class->change_one_row     = etsm_change_one_row;
+	esm_class->change_cursor      = etsm_change_cursor;
+	esm_class->cursor_row         = etsm_cursor_row;
+	esm_class->cursor_col         = etsm_cursor_col;
 
-	esm_class->select_single_row  = etsm_select_single_row  ;
-	esm_class->toggle_single_row  = etsm_toggle_single_row  ;
-	esm_class->move_selection_end = etsm_move_selection_end ;
-	esm_class->set_selection_end  = etsm_set_selection_end  ;
+	esm_class->select_single_row  = etsm_select_single_row;
+	esm_class->toggle_single_row  = etsm_toggle_single_row;
+	esm_class->move_selection_end = etsm_move_selection_end;
+	esm_class->set_selection_end  = etsm_set_selection_end;
 
 	g_object_class_install_property (object_class, PROP_CURSOR_ROW,
 					 g_param_spec_int ("cursor_row",
